html { background: #f1f1f1; }

body {
	background: #fff;
	color: #333;
	font-family: "Lucida Grande", "Lucida Sans Unicode", Tahoma, Verdana, sans-serif;
	margin: 2em auto 0 auto;
	width: 700px;
	padding: 1em 2em;
	-moz-border-radius: 12px;
	-khtml-border-radius: 12px;
	-webkit-border-radius: 12px;
	border-radius: 12px;
}

a { color: #2583ad; text-decoration: none; }

a:hover { color: #d54e21; }


h1 {
	font-size: 18px;
	margin-bottom: 0;
}

h2 { font-size: 16px; }

p, li {
	padding-bottom: 2px;
	font-size: 13px;
	line-height: 18px;
}

code {
	font-size: 13px;
}

ul, ol { padding: 5px 5px 5px 22px; }

#logo { margin: 6px 0 14px 0px; border-bottom: none;}

.step {
	margin: 20px 0 15px;
}

.step input {
	font-size: 18px;
}

a.button {
	font-size: 18px;
}

.step, th { text-align: left; padding: 0; }

.submit input, .button, .button-secondary {
	font-family: "Lucida Grande", "Lucida Sans Unicode", Tahoma, Verdana, sans-serif;
	padding: 5px 7px 7px;
	border: 1px solid #a3a3a3;
	margin-left: 0;
	-moz-border-radius: 3px;
	-khtml-border-radius: 3px;
	-webkit-border-radius: 3px;
	border-radius: 3px;
	color: #246;
	background: #e5e5e5;
}

.button-secondary {
	background: #cee1ef;
}

.submit input:hover, .button:hover, .button-secondary:hover {
	color: #d54e21;
	border-color: #535353;
}

.form-table {
	border-collapse: collapse;
	margin-top: 1em;
	width: 100%;
}

.form-table td {
	margin-bottom: 9px;
	padding: 10px;
	border-bottom: 8px solid #fff;
	font-size: 12px;
}

.form-table th {
	font-size: 13px;
	text-align: left;
	padding: 16px 10px 10px 10px;
	border-bottom: 8px solid #fff;
	width: 110px;
	vertical-align: top;
}

.form-table tr {
	background: #eaf3fa;
}

.form-table code {
	line-height: 18px;
	font-size: 18px;
}

.form-table p {
	margin: 4px 0 0 0;
	font-size: 11px;
}

.form-table input {
	line-height: 20px;
	font-size: 15px;
	padding: 2px;
}

h1 {
	border-bottom: 1px solid #dadada;
	clear: both;
	color: #666666;
	font: 24px Georgia, "Times New Roman", Times, serif;
	margin: 5px 0 0 -4px;
	padding: 0;
	padding-bottom: 7px;
}

#error-page {
	margin-top: 50px;
}

#error-page p {
	font-size: 14px;
	line-height: 16px;
	margin: 25px 0 20px;
}

#error-page code {
	font-size: 15px;
}