* { margin: 0; padding: 0; }

body {
	border-top-width: 30px;
	border-top-style: solid;
	font: 12px "Lucida Grande", "Lucida Sans Unicode", Tahoma, Verdana, sans-serif;
}

form {
	margin-left: 8px;
	padding: 16px 16px 40px 16px;
	font-weight: bold;
	-moz-border-radius: 5px;
	-khtml-border-radius: 5px;
	-webkit-border-radius: 5px;
	border-radius: 5px;
}

form .forgetmenot { font-weight: normal; float: left; margin-bottom: 0;}

#login form .submit input {
	font-family: "Lucida Grande", "Lucida Sans Unicode", Tahoma, Verdana, sans-serif;
	padding: 3px 5px;
	border: none;
	font-size: 13px;
	border-width: 1px;
	border-style: solid;
	-moz-border-radius: 3px;
	-khtml-border-radius: 3px;
	-webkit-border-radius: 3px;
	border-radius: 3px;
	cursor: default;
	text-decoration: none;	
	margin-top: -6px;
}

form .submit { float: right; }

form p { margin-bottom: 24px; }

h1 a {
	background: url(../images/logo-login.gif) no-repeat;
	width: 292px;
	height: 66px;
	text-indent: -9999px;
	overflow: hidden;
	padding-bottom: 15px;
	display: block;
}

#backtoblog a {
	position: absolute;
	top: 7px;
	left: 15px;
	text-decoration: none;
}

#login { width: 292px; margin: 7em auto; }

#login_error, .message {
	margin: 0 0 16px 8px;
	border-width: 1px;
	border-style: solid;
	padding: 12px;
}

#nav { margin: 0 0 0 8px; padding: 16px; }

#user_pass, #user_login, #user_email {
	font-size: 20px;
	width: 97%;
	padding: 3px;
	margin-right: 6px;
}