body {
	font-family: Tahoma;
}
.ui-tabs-nav {
	padding-left:0;
	padding-right:8px;
}
.ui-tabs-nav li {
	float: right;
}
.button {
	font-family: Tahoma;
	margin-left:0;
	margin-right: 5px;
}
#wphead #viewsite {
	margin-left:0;
	margin-right: 10px;
}
#viewsite {
	right:auto;
	left: 8px;
}
#wphead #viewsite a {
	font-family: Tahoma;
}
h1 {
	right:auto;
	left:0;
}
div#posting {
	padding-left:0;
	padding-right: 16px;
}
#photo_directions span {
	right:auto;
	left:3px;
}
#img_container a {
	float:right;
}
#img_container a, #img_container a:link, #img_container a:visited {
	margin:0 0 4px 4px;
}
div#categories {
	right:auto;
	left:16px;
}
div#categories h2 {
	margin: .5em 1em .5em 0;
}
#tagsdiv #newtag {
	margin-right:0;	
	margin-left: 5px;	
}
#jaxtag {
	padding-left:0;
	padding-right: 1em;
}
#tagchecklist {
	padding-left:0;
	padding-right: 1em;
}
#tagchecklist span {
	margin-right: 10px;
	margin-left: .5em;
	float: right;
}
#tagchecklist span a {
	margin: 6px -9px 0pt 0;
	float: right;
}
.submitbox {
	float: left;
}
.submitbox .submit input {
	text-align:right;
}
.video_split #extra_fields {
	float:right;
}
.video_split .editor_area {
	float: left;
}
.ac_results li {
	text-align:right;
}
#TB_ajaxContent #options {
	right:auto;
	left:25px;
}
#post_status {
	margin-left:0;
	margin-right: 10px;
}
#footer {
	padding: 10px 60px 0 0;
}
