body, td {
	font-family: Tahoma;
}
textarea, input, select {
	font-family: Tahoma;
}
h1, h2, h3 {
	font-family:arial;
}
.widefat td {
	padding: 7px 10px 9px 15px;
}
.widefat th {
	padding: 9px 10px 6px 15px;
	text-align: right;
}
.widefat th input {
	margin: 0 8px 0 0;
}
.widefat .check-column {
	text-align: left;
}
.wrap h2 {
	font-family:arial;
	margin: 5px -4px 0 0;
	padding-right:0;
	padding-left: 280px;
}
.wrap h2.long-header {
	padding-left: 0;
}
