/* Right Now */

#rightnow {
	border-width: 1px;
	border-style: solid;
	padding: 2px;
	margin-top: 10px;
	margin-right: 7px;
}

#rightnow .reallynow {
	padding: 6px;
	font-size: 15px;
	line-height: 2;
	margin: 0;
}

#rightnow .rbutton {
	font-weight: normal;
	padding: 6px;
	border-bottom: none;
	-moz-border-radius: 2px;
	-khtml-border-radius: 2px;
	-webkit-border-radius: 2px;
	border-radius: 2px;
	text-decoration: none;
}

#rightnow .reallynow span {
	display: block;
	text-align: left;
	float: left;
	padding: 0 6px;
}

#rightnow .reallynow a {
	display: block;
	text-align: right;
	float: right;
	padding: 0 6px;
	font-size: 14px;
	margin: 1px 6px 0 0;
}

#rightnow .youhave {
	font-size:  14px;
	padding: 10px;
}

#rightnow h3, #rightnow p {
	padding: 0 10px;
}

#rightnow a {
	font-weight: bold;
}

/* Widgets */

div#dashboard-widgets-wrap {
	margin-top: -20px;
	margin-right: -13px; /* 20 (div.dashboard-widget margin-right) - 7 (#rightnow margin-right) */
}

div#dashboard-widgets {
	width: 100%;
}

div.dashboard-widget-holder {	
	margin-top: 20px;
	width: 50%;
	float: left;
}

div.dashboard-widget-holder.third {
	width: 33.3%;
}

div.dashboard-widget-holder.fourth {
	width: 25%;
}

div.dashboard-widget-holder.full {
	width: 100%;
}

div.dashboard-widget-holder.double div.dashboard-widget {
	height: 54em;
	padding-bottom: 28px /* lame */
}

div.dashboard-widget {
	position: relative;
	margin-right: 20px;
	border-width: 1px;
	border-style: solid;
	padding: 2px;
	height: 27em;
	overflow: auto;
	font-size: 11px;
}

h3.dashboard-widget-title  {
	margin: 0;
	padding: 0 7px;
	font-size: 14px;
	line-height: 2;
}

h3.dashboard-widget-title span {
	display: block;
	text-align: left;
	float: left;
}

h3.dashboard-widget-title small {
	display: block;
	text-align: right;
	float: right;
	font-size: 75%;
	line-height: 2.67; /* math: it works, bitches */
}

h3.dashboard-widget-title img.rss-icon {
	vertical-align: middle;
	margin: .5em 0;
}

div.dashboard-widget-notice {
	padding: 0 14px;
	font-size: 1.2em;
	line-height: 2;
}

div.dashboard-widget-error {
	padding: 0 20px;
	font-size: 1.2em;
	line-height: 2;
}

div.dashboard-widget-content {
	padding: 10px 15px;
}

div.dashboard-widget-submit {
	border-top: 1px solid #ccc;
	padding: 1em 0 0 0;
	margin: 10px 0 0 0;
}
div.dashboard-widget-submit input {
	font-family: "Lucida Grande", "Lucida Sans Unicode", Tahoma, Verdana, sans-serif;
	padding: 4px 6px;
	border: none;
	font-size: 13px;
	-moz-border-radius: 3px;
	-khtml-border-radius: 3px;
	-webkit-border-radius: 3px;
	border-radius: 3px;
	cursor: pointer;
	text-decoration: none;	
}

div.dashboard-widget-content ul, div.dashboard-widget-content ol, div.dashboard-widget-content dl {
	margin: 0;
	text-indent: 0;
	padding-left: 15px;
}
div.dashboard-widget-content li {
	margin: .5em 0 1em;
}

div.dashboard-widget-content blockquote {
	margin: -1em 0;
}

div#dashboard_recent_comments p {
	font-size: 14px;
}

div.dashboard-widget-content p.comment-meta {
	font-size: 11px !important;
}

#dashboard_secondary div.dashboard-widget {
	height: auto;
}

#dashboard_secondary div.dashboard-widget-content ul {
	list-style: none;
	padding: 0;
}

#dashboard_secondary div.dashboard-widget-content ul li {
	display: block;
	width: 19.95%;
	padding-bottom: 10px;
	margin: 0;
	float: left;
	font-size: 95%;
}

#dashboard_secondary div.dashboard-widget-content {
	margin: 10px 5px;
	padding: 0;
}

#dashboard_secondary div.dashboard-widget-content ul li .post {
	display:block;
	font-family:Georgia,"Times New Roman",Times,serif;
	font-size:18px;
	line-height: 1.2em;
	height:90px;
	overflow:hidden;
}

#dashboard_secondary div.dashboard-widget-content ul li a {
	display: block;
	height:100%;
	overflow:hidden;
	margin: 5px 10px;
	text-decoration: none;
	padding: .5em;
	border-right: 1px solid #dadada;
	border-bottom: 1px solid #dadada;
}

#dashboard_secondary div.dashboard-widget-content ul li a cite {
	display: block;
	font-family: "Lucida Sans", "Lucida Grande", "Lucida Sans Unicode", Tahoma, Verdana, sans-serif;
}

#dashboard-widgets .widget_rss ul {
	list-style: none;
	padding: 0;
}

#dashboard-widgets .widget_rss ul li {
	clear: both;
}

#dashboard-widgets .widget_rss ul li span.rss-date {
	float: left;
	margin: 0;
}

#dashboard-widgets .widget_rss ul li a {
	float: left;
	margin: 0 .5em .2em 0;
	font-weight: bold;
}

#dashboard-widgets .widget_rss ul li div {
	clear: both;
	line-height: 1.5em;
}

#dashboard_primary a.rsswidget, #dashboard_plugins h5 {
	font-size: 14px;
}

#dashboard_primary span.rss-date {
	font-size: 14px;
}

#dashboard_plugins h4 {
	font-size: 1em;
	margin: 0 0 .1em;
}

#dashboard_plugins h5 {
	margin: 0;
	display: inline;
	line-height: 1.4em;
}

#dashboard_plugins p {
	margin: 0 0 1em;
	line-height: 1.5em;
}

.widget-loading {
}
