body {
	font-family: Tahoma;
}
/* Half the page disapears on IE6 */
* html body {
	width: 700px; 
	position: absolute; 
	left: 50%; 
	margin-right: 350px;
}
ul, ol {
	padding: 5px 22px 5px 5px;
}
.step, th {
	text-align:right;
}
.submit input, .button, .button-secondary  {
	font-family: Tahoma;
	margin-right:0;
}
.form-table th {
	text-align:right;
}
h1 {
	font-family:arial;
	margin: 5px -4px 0 0;
}
