-- MySQL dump 10.11
--
-- Host: localhost    Database: moztroni_wrdp2
-- ------------------------------------------------------
-- Server version	5.0.75-community-log

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Table structure for table `wp_comments`
--

DROP TABLE IF EXISTS `wp_comments`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `wp_comments` (
  `comment_ID` bigint(20) unsigned NOT NULL auto_increment,
  `comment_post_ID` int(11) NOT NULL default '0',
  `comment_author` tinytext NOT NULL,
  `comment_author_email` varchar(100) NOT NULL default '',
  `comment_author_url` varchar(200) NOT NULL default '',
  `comment_author_IP` varchar(100) NOT NULL default '',
  `comment_date` datetime NOT NULL default '0000-00-00 00:00:00',
  `comment_date_gmt` datetime NOT NULL default '0000-00-00 00:00:00',
  `comment_content` text NOT NULL,
  `comment_karma` int(11) NOT NULL default '0',
  `comment_approved` varchar(20) NOT NULL default '1',
  `comment_agent` varchar(255) NOT NULL default '',
  `comment_type` varchar(20) NOT NULL default '',
  `comment_parent` bigint(20) NOT NULL default '0',
  `user_id` bigint(20) NOT NULL default '0',
  PRIMARY KEY  (`comment_ID`),
  KEY `comment_approved` (`comment_approved`),
  KEY `comment_post_ID` (`comment_post_ID`),
  KEY `comment_approved_date_gmt` (`comment_approved`,`comment_date_gmt`),
  KEY `comment_date_gmt` (`comment_date_gmt`)
) ENGINE=MyISAM AUTO_INCREMENT=3 DEFAULT CHARSET=latin1;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `wp_comments`
--

LOCK TABLES `wp_comments` WRITE;
/*!40000 ALTER TABLE `wp_comments` DISABLE KEYS */;
INSERT INTO `wp_comments` VALUES (2,21,'What is Anti-Virus? | relationmortgage.com','','http://relationmortgage.com/what-is-anti-virus/','216.36.52.228','2009-01-13 15:41:23','2009-01-13 05:41:23','[...] What is Anti-Virus? [...]',0,'spam','Incutio XML-RPC -- WordPress/2.6.3','pingback',0,0);
/*!40000 ALTER TABLE `wp_comments` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `wp_links`
--

DROP TABLE IF EXISTS `wp_links`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `wp_links` (
  `link_id` bigint(20) NOT NULL auto_increment,
  `link_url` varchar(255) NOT NULL default '',
  `link_name` varchar(255) NOT NULL default '',
  `link_image` varchar(255) NOT NULL default '',
  `link_target` varchar(25) NOT NULL default '',
  `link_category` bigint(20) NOT NULL default '0',
  `link_description` varchar(255) NOT NULL default '',
  `link_visible` varchar(20) NOT NULL default 'Y',
  `link_owner` int(11) NOT NULL default '1',
  `link_rating` int(11) NOT NULL default '0',
  `link_updated` datetime NOT NULL default '0000-00-00 00:00:00',
  `link_rel` varchar(255) NOT NULL default '',
  `link_notes` mediumtext NOT NULL,
  `link_rss` varchar(255) NOT NULL default '',
  PRIMARY KEY  (`link_id`),
  KEY `link_category` (`link_category`),
  KEY `link_visible` (`link_visible`)
) ENGINE=MyISAM AUTO_INCREMENT=8 DEFAULT CHARSET=latin1;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `wp_links`
--

LOCK TABLES `wp_links` WRITE;
/*!40000 ALTER TABLE `wp_links` DISABLE KEYS */;
/*!40000 ALTER TABLE `wp_links` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `wp_options`
--

DROP TABLE IF EXISTS `wp_options`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `wp_options` (
  `option_id` bigint(20) NOT NULL auto_increment,
  `blog_id` int(11) NOT NULL default '0',
  `option_name` varchar(64) NOT NULL default '',
  `option_value` longtext NOT NULL,
  `autoload` varchar(20) NOT NULL default 'yes',
  PRIMARY KEY  (`option_id`,`blog_id`,`option_name`),
  KEY `option_name` (`option_name`)
) ENGINE=MyISAM AUTO_INCREMENT=349 DEFAULT CHARSET=latin1;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `wp_options`
--

LOCK TABLES `wp_options` WRITE;
/*!40000 ALTER TABLE `wp_options` DISABLE KEYS */;
INSERT INTO `wp_options` VALUES (1,0,'siteurl','http://moztronics.com.au','yes'),(2,0,'blogname','Moztronics','yes'),(3,0,'blogdescription','Engineering','yes'),(4,0,'users_can_register','','yes'),(5,0,'admin_email','moz@moztronics.com.au','yes'),(6,0,'start_of_week','1','yes'),(7,0,'use_balanceTags','0','yes'),(8,0,'use_smilies','1','yes'),(9,0,'require_name_email','1','yes'),(10,0,'comments_notify','1','yes'),(11,0,'posts_per_rss','10','yes'),(12,0,'rss_excerpt_length','50','yes'),(13,0,'rss_use_excerpt','0','yes'),(14,0,'mailserver_url','mail.example.com','yes'),(15,0,'mailserver_login','login@example.com','yes'),(16,0,'mailserver_pass','password','yes'),(17,0,'mailserver_port','110','yes'),(18,0,'default_category','1','yes'),(19,0,'default_comment_status','closed','yes'),(20,0,'default_ping_status','open','yes'),(21,0,'default_pingback_flag','1','yes'),(22,0,'default_post_edit_rows','10','yes'),(23,0,'posts_per_page','10','yes'),(24,0,'what_to_show','posts','yes'),(25,0,'date_format','j F, Y','yes'),(26,0,'time_format','g:i a','yes'),(27,0,'links_updated_date_format','F j, Y g:i a','yes'),(28,0,'links_recently_updated_prepend','<em>','yes'),(29,0,'links_recently_updated_append','</em>','yes'),(30,0,'links_recently_updated_time','120','yes'),(31,0,'comment_moderation','','yes'),(32,0,'moderation_notify','1','yes'),(33,0,'permalink_structure','/http:/moztronics.com.au/category/post-name/ ','yes'),(34,0,'gzipcompression','0','yes'),(35,0,'hack_file','0','yes'),(36,0,'blog_charset','UTF-8','yes'),(37,0,'moderation_keys','','no'),(38,0,'active_plugins','a:0:{}','yes'),(39,0,'home','http://moztronics.com.au','yes'),(40,0,'category_base','','yes'),(41,0,'ping_sites','http://rpc.pingomatic.com/','yes'),(42,0,'advanced_edit','0','yes'),(43,0,'comment_max_links','2','yes'),(44,0,'gmt_offset','10','yes'),(45,0,'default_email_category','1','yes'),(46,0,'recently_edited','a:5:{i:0;s:30:\"/themes/zinmagremedy/style.css\";i:1;s:29:\"/themes/zinmagremedy/page.php\";i:2;s:34:\"/themes/zinmagremedy/functions.php\";i:3;s:31:\"/themes/zinmagremedy/banner.css\";i:4;s:30:\"/themes/zinmagremedy/index.php\";}','no'),(47,0,'use_linksupdate','0','yes'),(48,0,'template','pixeled','yes'),(49,0,'stylesheet','pixeled','yes'),(50,0,'comment_whitelist','1','yes'),(51,0,'page_uris','','yes'),(52,0,'blacklist_keys','','no'),(53,0,'comment_registration','1','yes'),(54,0,'rss_language','en','yes'),(55,0,'html_type','text/html','yes'),(56,0,'use_trackback','0','yes'),(57,0,'default_role','administrator','yes'),(58,0,'db_version','8204','yes'),(59,0,'uploads_use_yearmonth_folders','1','yes'),(60,0,'upload_path','/home/moztroni/public_html/wp-content/uploads','yes'),(61,0,'random_seed','3b845be4222c1c3518d0e106793434a4','yes'),(62,0,'secret','((o0FRI5kC!9xMniEIrcAk@%wgBFIq{fq1QC#Q%ywXjaaLcpx9&2vsYjT7Nehlv1vxU#','yes'),(63,0,'blog_public','1','yes'),(64,0,'default_link_category','2','yes'),(65,0,'show_on_front','posts','yes'),(66,0,'tag_base','','yes'),(67,0,'show_avatars','1','yes'),(68,0,'avatar_rating','G','yes'),(69,0,'upload_url_path','','yes'),(70,0,'thumbnail_size_w','150','yes'),(71,0,'thumbnail_size_h','150','yes'),(72,0,'thumbnail_crop','1','yes'),(73,0,'medium_size_w','300','yes'),(74,0,'medium_size_h','300','yes'),(75,0,'avatar_default','mystery','yes'),(76,0,'enable_app','0','yes'),(77,0,'enable_xmlrpc','0','yes'),(78,0,'wp_user_roles','a:5:{s:13:\"administrator\";a:2:{s:4:\"name\";s:23:\"Administrator|User role\";s:12:\"capabilities\";a:53:{s:13:\"switch_themes\";b:1;s:11:\"edit_themes\";b:1;s:16:\"activate_plugins\";b:1;s:12:\"edit_plugins\";b:1;s:10:\"edit_users\";b:1;s:10:\"edit_files\";b:1;s:14:\"manage_options\";b:1;s:17:\"moderate_comments\";b:1;s:17:\"manage_categories\";b:1;s:12:\"manage_links\";b:1;s:12:\"upload_files\";b:1;s:6:\"import\";b:1;s:15:\"unfiltered_html\";b:1;s:10:\"edit_posts\";b:1;s:17:\"edit_others_posts\";b:1;s:20:\"edit_published_posts\";b:1;s:13:\"publish_posts\";b:1;s:10:\"edit_pages\";b:1;s:4:\"read\";b:1;s:8:\"level_10\";b:1;s:7:\"level_9\";b:1;s:7:\"level_8\";b:1;s:7:\"level_7\";b:1;s:7:\"level_6\";b:1;s:7:\"level_5\";b:1;s:7:\"level_4\";b:1;s:7:\"level_3\";b:1;s:7:\"level_2\";b:1;s:7:\"level_1\";b:1;s:7:\"level_0\";b:1;s:17:\"edit_others_pages\";b:1;s:20:\"edit_published_pages\";b:1;s:13:\"publish_pages\";b:1;s:12:\"delete_pages\";b:1;s:19:\"delete_others_pages\";b:1;s:22:\"delete_published_pages\";b:1;s:12:\"delete_posts\";b:1;s:19:\"delete_others_posts\";b:1;s:22:\"delete_published_posts\";b:1;s:20:\"delete_private_posts\";b:1;s:18:\"edit_private_posts\";b:1;s:18:\"read_private_posts\";b:1;s:20:\"delete_private_pages\";b:1;s:18:\"edit_private_pages\";b:1;s:18:\"read_private_pages\";b:1;s:12:\"delete_users\";b:1;s:12:\"create_users\";b:1;s:17:\"unfiltered_upload\";b:1;s:14:\"edit_dashboard\";b:1;s:14:\"update_plugins\";b:1;s:14:\"delete_plugins\";b:1;s:13:\"manage_cforms\";b:1;s:12:\"track_cforms\";b:1;}}s:6:\"editor\";a:2:{s:4:\"name\";s:16:\"Editor|User role\";s:12:\"capabilities\";a:34:{s:17:\"moderate_comments\";b:1;s:17:\"manage_categories\";b:1;s:12:\"manage_links\";b:1;s:12:\"upload_files\";b:1;s:15:\"unfiltered_html\";b:1;s:10:\"edit_posts\";b:1;s:17:\"edit_others_posts\";b:1;s:20:\"edit_published_posts\";b:1;s:13:\"publish_posts\";b:1;s:10:\"edit_pages\";b:1;s:4:\"read\";b:1;s:7:\"level_7\";b:1;s:7:\"level_6\";b:1;s:7:\"level_5\";b:1;s:7:\"level_4\";b:1;s:7:\"level_3\";b:1;s:7:\"level_2\";b:1;s:7:\"level_1\";b:1;s:7:\"level_0\";b:1;s:17:\"edit_others_pages\";b:1;s:20:\"edit_published_pages\";b:1;s:13:\"publish_pages\";b:1;s:12:\"delete_pages\";b:1;s:19:\"delete_others_pages\";b:1;s:22:\"delete_published_pages\";b:1;s:12:\"delete_posts\";b:1;s:19:\"delete_others_posts\";b:1;s:22:\"delete_published_posts\";b:1;s:20:\"delete_private_posts\";b:1;s:18:\"edit_private_posts\";b:1;s:18:\"read_private_posts\";b:1;s:20:\"delete_private_pages\";b:1;s:18:\"edit_private_pages\";b:1;s:18:\"read_private_pages\";b:1;}}s:6:\"author\";a:2:{s:4:\"name\";s:16:\"Author|User role\";s:12:\"capabilities\";a:10:{s:12:\"upload_files\";b:1;s:10:\"edit_posts\";b:1;s:20:\"edit_published_posts\";b:1;s:13:\"publish_posts\";b:1;s:4:\"read\";b:1;s:7:\"level_2\";b:1;s:7:\"level_1\";b:1;s:7:\"level_0\";b:1;s:12:\"delete_posts\";b:1;s:22:\"delete_published_posts\";b:1;}}s:11:\"contributor\";a:2:{s:4:\"name\";s:21:\"Contributor|User role\";s:12:\"capabilities\";a:5:{s:10:\"edit_posts\";b:1;s:4:\"read\";b:1;s:7:\"level_1\";b:1;s:7:\"level_0\";b:1;s:12:\"delete_posts\";b:1;}}s:10:\"subscriber\";a:2:{s:4:\"name\";s:20:\"Subscriber|User role\";s:12:\"capabilities\";a:2:{s:4:\"read\";b:1;s:7:\"level_0\";b:1;}}}','yes'),(80,0,'auth_salt','P*$yqR!Wbn&s','yes'),(83,0,'doing_cron','0','yes'),(85,0,'logged_in_salt','r2p%3yrilT*F','yes'),(346,0,'current_theme','Pixeled','yes'),(88,0,'sidebars_widgets','a:2:{s:9:\"sidebar-1\";a:7:{i:0;s:6:\"search\";i:1;s:20:\"categories-326691521\";i:2;s:5:\"pages\";i:3;s:10:\"wp-cumulus\";i:4;s:5:\"links\";i:5;s:8:\"cformsii\";i:6;s:4:\"meta\";}s:13:\"array_version\";i:3;}','yes'),(102,0,'cron','a:2:{i:1237546955;a:1:{s:17:\"wp_update_plugins\";a:1:{s:32:\"40cd750bba9870f18aada2478b24840a\";a:3:{s:8:\"schedule\";s:10:\"twicedaily\";s:4:\"args\";a:0:{}s:8:\"interval\";i:43200;}}}s:7:\"version\";i:2;}','yes'),(103,0,'update_core','O:8:\"stdClass\":5:{s:12:\"last_checked\";i:1237503339;s:15:\"version_checked\";s:5:\"2.6.5\";s:8:\"response\";s:7:\"upgrade\";s:3:\"url\";s:30:\"http://wordpress.org/download/\";s:7:\"current\";s:5:\"2.7.1\";}','yes'),(105,0,'dashboard_widget_options','a:3:{s:24:\"dashboard_incoming_links\";a:5:{s:4:\"home\";s:24:\"http://moztronics.com.au\";s:4:\"link\";s:106:\"http://blogsearch.google.com/blogsearch?hl=en&scoring=d&partner=wordpress&q=link:http://moztronics.com.au/\";s:3:\"url\";s:139:\"http://blogsearch.google.com/blogsearch_feeds?hl=en&scoring=d&ie=utf-8&num=10&output=rss&partner=wordpress&q=link:http://moztronics.com.au/\";s:5:\"items\";i:5;s:9:\"show_date\";i:0;}s:17:\"dashboard_primary\";a:7:{s:4:\"link\";s:33:\"http://wordpress.org/development/\";s:3:\"url\";s:38:\"http://wordpress.org/development/feed/\";s:5:\"title\";s:26:\"WordPress Development Blog\";s:5:\"items\";i:2;s:12:\"show_summary\";i:1;s:11:\"show_author\";i:0;s:9:\"show_date\";i:1;}s:19:\"dashboard_secondary\";a:4:{s:4:\"link\";s:28:\"http://planet.wordpress.org/\";s:3:\"url\";s:33:\"http://planet.wordpress.org/feed/\";s:5:\"title\";s:20:\"Other WordPress News\";s:5:\"items\";i:15;}}','yes'),(272,0,'stats_cache','a:3:{s:32:\"da2bb74c6fbc564d986789a266ef47ae\";a:1:{i:1237540698;a:2:{i:0;a:4:{s:7:\"post_id\";s:3:\"109\";s:10:\"post_title\";s:7:\"Contact\";s:14:\"post_permalink\";s:26:\"http://moztronics.com.au//\";s:5:\"views\";s:1:\"7\";}i:1;a:4:{s:7:\"post_id\";s:1:\"2\";s:10:\"post_title\";s:5:\"About\";s:14:\"post_permalink\";s:26:\"http://moztronics.com.au//\";s:5:\"views\";s:1:\"4\";}}}s:32:\"2af57f9d802d43e379262d79a5bbb2fc\";a:1:{i:1237540698;a:0:{}}s:32:\"3da88337e8483cbc205b9d55b969d037\";a:1:{i:1237540699;a:1:{i:0;a:2:{s:10:\"searchterm\";s:10:\"moztronics\";s:5:\"views\";s:1:\"4\";}}}}','yes'),(106,0,'rss_c53f804b4e3200060fda7cae530da1f0','O:9:\"MagpieRSS\":17:{s:6:\"parser\";i:0;s:12:\"current_item\";a:0:{}s:5:\"items\";a:0:{}s:7:\"channel\";a:5:{s:5:\"title\";s:51:\"link:http://moztronics.com.au/ - Google Blog Search\";s:4:\"link\";s:109:\"http://blogsearch.google.com/blogsearch?hl=en&scoring=d&ie=ISO-8859-1&num=10&q=link:http://moztronics.com.au/\";s:11:\"description\";s:85:\"Your search - <b>link:http://moztronics.com.au/</b> - did not match any documents.   \";s:10:\"opensearch\";a:3:{s:12:\"totalresults\";s:1:\"0\";s:10:\"startindex\";s:1:\"1\";s:12:\"itemsperpage\";s:2:\"10\";}s:7:\"tagline\";s:85:\"Your search - <b>link:http://moztronics.com.au/</b> - did not match any documents.   \";}s:9:\"textinput\";a:0:{}s:5:\"image\";a:0:{}s:9:\"feed_type\";s:3:\"RSS\";s:12:\"feed_version\";s:3:\"2.0\";s:5:\"stack\";a:0:{}s:9:\"inchannel\";b:0;s:6:\"initem\";b:0;s:9:\"incontent\";b:0;s:11:\"intextinput\";b:0;s:7:\"inimage\";b:0;s:13:\"current_field\";s:0:\"\";s:17:\"current_namespace\";b:0;s:19:\"_CONTENT_CONSTRUCTS\";a:6:{i:0;s:7:\"content\";i:1;s:7:\"summary\";i:2;s:4:\"info\";i:3;s:5:\"title\";i:4;s:7:\"tagline\";i:5;s:9:\"copyright\";}}','no'),(107,0,'rss_c53f804b4e3200060fda7cae530da1f0_ts','1237540698','no'),(108,0,'rss_a5420c83891a9c88ad2a4f04584a5efc','O:9:\"MagpieRSS\":19:{s:6:\"parser\";i:0;s:12:\"current_item\";a:0:{}s:5:\"items\";a:15:{i:0;a:7:{s:5:\"title\";s:33:\"uberdose on \"All in One SEO Pack\"\";s:4:\"link\";s:65:\"http://wordpress.org/extend/plugins/all-in-one-seo-pack/#post-753\";s:7:\"pubdate\";s:31:\"Fri, 30 Mar 2007 20:08:18 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:8:\"uberdose\";}s:4:\"guid\";s:40:\"753@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:92:\"Automatically optimizes your Wordpress blog for Search Engines (Search Engine Optimization).\";s:7:\"summary\";s:92:\"Automatically optimizes your Wordpress blog for Search Engines (Search Engine Optimization).\";}i:1;a:7:{s:5:\"title\";s:30:\"arnee on \"Google XML Sitemaps\"\";s:4:\"link\";s:70:\"http://wordpress.org/extend/plugins/google-sitemap-generator/#post-132\";s:7:\"pubdate\";s:31:\"Fri, 09 Mar 2007 22:31:32 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:5:\"arnee\";}s:4:\"guid\";s:40:\"132@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:87:\"This plugin will create a Google sitemaps compliant XML-Sitemap of your WordPress blog.\";s:7:\"summary\";s:87:\"This plugin will create a Google sitemaps compliant XML-Sitemap of your WordPress blog.\";}i:2;a:7:{s:5:\"title\";s:36:\"olivers on \"cformsII - contact form\"\";s:4:\"link\";s:52:\"http://wordpress.org/extend/plugins/cforms/#post-925\";s:7:\"pubdate\";s:31:\"Mon, 09 Apr 2007 22:12:26 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:7:\"olivers\";}s:4:\"guid\";s:40:\"925@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:119:\"cforms II is the most customizable, flexible &#038; powerful ajax supporting contact form plugin (&#038; comment form)!\";s:7:\"summary\";s:119:\"cforms II is the most customizable, flexible &#038; powerful ajax supporting contact form plugin (&#038; comment form)!\";}i:3;a:7:{s:5:\"title\";s:17:\"matt on \"Akismet\"\";s:4:\"link\";s:52:\"http://wordpress.org/extend/plugins/akismet/#post-15\";s:7:\"pubdate\";s:31:\"Fri, 09 Mar 2007 22:11:30 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"matt\";}s:4:\"guid\";s:39:\"15@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:98:\"Akismet checks your comments against the Akismet web service to see if they look like spam or not.\";s:7:\"summary\";s:98:\"Akismet checks your comments against the Akismet web service to see if they look like spam or not.\";}i:4;a:7:{s:5:\"title\";s:29:\"alexrabe on \"NextGEN Gallery\"\";s:4:\"link\";s:62:\"http://wordpress.org/extend/plugins/nextgen-gallery/#post-1169\";s:7:\"pubdate\";s:31:\"Mon, 23 Apr 2007 20:08:06 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:8:\"alexrabe\";}s:4:\"guid\";s:41:\"1169@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:102:\"NextGEN Gallery is a full integrated Image Gallery plugin for WordPress with a Flash slideshow option.\";s:7:\"summary\";s:102:\"NextGEN Gallery is a full integrated Image Gallery plugin for WordPress with a Flash slideshow option.\";}i:5;a:7:{s:5:\"title\";s:27:\"donncha on \"WP Super Cache\"\";s:4:\"link\";s:61:\"http://wordpress.org/extend/plugins/wp-super-cache/#post-2572\";s:7:\"pubdate\";s:31:\"Mon, 05 Nov 2007 11:40:04 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:7:\"donncha\";}s:4:\"guid\";s:41:\"2572@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:73:\"A very fast caching engine for WordPress that produces static html files.\";s:7:\"summary\";s:73:\"A very fast caching engine for WordPress that produces static html files.\";}i:6;a:7:{s:5:\"title\";s:32:\"takayukister on \"Contact Form 7\"\";s:4:\"link\";s:61:\"http://wordpress.org/extend/plugins/contact-form-7/#post-2141\";s:7:\"pubdate\";s:31:\"Thu, 02 Aug 2007 12:45:03 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:12:\"takayukister\";}s:4:\"guid\";s:41:\"2141@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:54:\"Just another contact form plugin. Simple but flexible.\";s:7:\"summary\";s:54:\"Just another contact form plugin. Simple but flexible.\";}i:7;a:7:{s:5:\"title\";s:29:\"andy on \"WordPress.com Stats\"\";s:4:\"link\";s:52:\"http://wordpress.org/extend/plugins/stats/#post-1355\";s:7:\"pubdate\";s:31:\"Sun, 06 May 2007 02:15:03 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"andy\";}s:4:\"guid\";s:41:\"1355@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:119:\"You can have simple, concise stats with no additional load on your server by plugging into WordPress.com\'s stat system.\";s:7:\"summary\";s:119:\"You can have simple, concise stats with no additional load on your server by plugging into WordPress.com\'s stat system.\";}i:8;a:7:{s:5:\"title\";s:28:\"ringmaster on \"WP-DB-Backup\"\";s:4:\"link\";s:58:\"http://wordpress.org/extend/plugins/wp-db-backup/#post-472\";s:7:\"pubdate\";s:31:\"Sat, 17 Mar 2007 04:41:26 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:10:\"ringmaster\";}s:4:\"guid\";s:40:\"472@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:44:\"On-demand backup of your WordPress database.\";s:7:\"summary\";s:44:\"On-demand backup of your WordPress database.\";}i:9;a:7:{s:5:\"title\";s:25:\"joostdevalk on \"Sociable\"\";s:4:\"link\";s:55:\"http://wordpress.org/extend/plugins/sociable/#post-2865\";s:7:\"pubdate\";s:31:\"Thu, 31 Jan 2008 11:36:17 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:11:\"joostdevalk\";}s:4:\"guid\";s:41:\"2865@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:100:\"Automatically add links on your posts, pages and RSS feed to your favorite social bookmarking sites.\";s:7:\"summary\";s:100:\"Automatically add links on your posts, pages and RSS feed to your favorite social bookmarking sites.\";}i:10;a:7:{s:5:\"title\";s:47:\"joostdevalk on \"Google Analytics for WordPress\"\";s:4:\"link\";s:77:\"http://wordpress.org/extend/plugins/google-analytics-for-wordpress/#post-2316\";s:7:\"pubdate\";s:31:\"Fri, 14 Sep 2007 12:15:27 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:11:\"joostdevalk\";}s:4:\"guid\";s:41:\"2316@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:150:\"The Google Analytics for WordPress plugin automatically tracks and segments all outbound links from within posts, comment author links, links within c\";s:7:\"summary\";s:150:\"The Google Analytics for WordPress plugin automatically tracks and segments all outbound links from within posts, comment author links, links within c\";}i:11;a:7:{s:5:\"title\";s:51:\"micropat on \"Add to Any Share/Save/Bookmark Button\"\";s:4:\"link\";s:56:\"http://wordpress.org/extend/plugins/add-to-any/#post-498\";s:7:\"pubdate\";s:31:\"Sat, 17 Mar 2007 23:08:16 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:8:\"micropat\";}s:4:\"guid\";s:40:\"498@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:149:\"Helps readers share, save, bookmark, and email your posts and pages using any service, such as Delicious, Digg, Facebook, Twitter, and over 100 more.\";s:7:\"summary\";s:149:\"Helps readers share, save, bookmark, and email your posts and pages using any service, such as Delicious, Digg, Facebook, Twitter, and over 100 more.\";}i:12;a:7:{s:5:\"title\";s:30:\"momo360modena on \"Simple Tags\"\";s:4:\"link\";s:58:\"http://wordpress.org/extend/plugins/simple-tags/#post-2463\";s:7:\"pubdate\";s:31:\"Wed, 10 Oct 2007 15:30:11 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:13:\"momo360modena\";}s:4:\"guid\";s:41:\"2463@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:150:\"Simple Tags is the successor of Simple Tagging Plugin and is THE perfect tool to manage perfectly your WP 2.3, 2.5, 2.6 and 2.7 tags (Related Posts, R\";s:7:\"summary\";s:150:\"Simple Tags is the successor of Simple Tagging Plugin and is THE perfect tool to manage perfectly your WP 2.3, 2.5, 2.6 and 2.7 tags (Related Posts, R\";}i:13;a:7:{s:5:\"title\";s:22:\"McShelby on \"Exec-PHP\"\";s:4:\"link\";s:55:\"http://wordpress.org/extend/plugins/exec-php/#post-2454\";s:7:\"pubdate\";s:31:\"Wed, 10 Oct 2007 05:30:05 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:8:\"McShelby\";}s:4:\"guid\";s:41:\"2454@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:71:\"The Exec-PHP plugin executes PHP code in posts, pages and text widgets.\";s:7:\"summary\";s:71:\"The Exec-PHP plugin executes PHP code in posts, pages and text widgets.\";}i:14;a:7:{s:5:\"title\";s:30:\"freediver on \"SEO Smart Links\"\";s:4:\"link\";s:66:\"http://wordpress.org/extend/plugins/seo-automatic-links/#post-5850\";s:7:\"pubdate\";s:31:\"Wed, 04 Jun 2008 20:32:49 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:9:\"freediver\";}s:4:\"guid\";s:41:\"5850@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:140:\"SEO Smart Links can automatically link keywords and phrases in your posts and comments with corresponding posts, pages, categories and tags.\";s:7:\"summary\";s:140:\"SEO Smart Links can automatically link keywords and phrases in your posts and comments with corresponding posts, pages, categories and tags.\";}}s:7:\"channel\";a:6:{s:5:\"title\";s:12:\"Most Popular\";s:4:\"link\";s:36:\"http://wordpress.org/extend/plugins/\";s:11:\"description\";s:12:\"Most Popular\";s:8:\"language\";s:2:\"en\";s:7:\"pubdate\";s:31:\"Sun, 11 Jan 2009 11:03:07 +0000\";s:7:\"tagline\";s:12:\"Most Popular\";}s:9:\"textinput\";a:0:{}s:5:\"image\";a:0:{}s:9:\"feed_type\";s:3:\"RSS\";s:12:\"feed_version\";s:3:\"2.0\";s:5:\"stack\";a:0:{}s:9:\"inchannel\";b:0;s:6:\"initem\";b:0;s:9:\"incontent\";b:0;s:11:\"intextinput\";b:0;s:7:\"inimage\";b:0;s:13:\"current_field\";s:0:\"\";s:17:\"current_namespace\";b:0;s:19:\"_CONTENT_CONSTRUCTS\";a:6:{i:0;s:7:\"content\";i:1;s:7:\"summary\";i:2;s:4:\"info\";i:3;s:5:\"title\";i:4;s:7:\"tagline\";i:5;s:9:\"copyright\";}s:13:\"last_modified\";s:21:\"2007-03-30 20:08:18\r\n\";s:4:\"etag\";s:36:\"\"a8894f3af502f182fd4e92b6405bade8\"\r\n\";}','no'),(109,0,'rss_a5420c83891a9c88ad2a4f04584a5efc_ts','1237540698','no'),(110,0,'rss_0ff4b43bd116a9d8720d689c80e7dfd4','O:9:\"MagpieRSS\":19:{s:6:\"parser\";i:0;s:12:\"current_item\";a:0:{}s:5:\"items\";a:10:{i:0;a:12:{s:5:\"title\";s:46:\"Contributing to WordPress, Part I: Development\";s:4:\"link\";s:86:\"http://wordpress.org/development/2009/03/contributing-to-wordpress-part-i-development/\";s:8:\"comments\";s:95:\"http://wordpress.org/development/2009/03/contributing-to-wordpress-part-i-development/#comments\";s:7:\"pubdate\";s:31:\"Thu, 12 Mar 2009 18:06:23 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:10:\"Jane Wells\";}s:8:\"category\";s:11:\"Development\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=567\";s:11:\"description\";s:317:\"A week or two ago at WordCamp Denver, I gave a presentation about some plans to create more opportunities for people to contribute to the WordPress open source project. The icon design contest was such a success that it seems clear we need to come up with ways for non-developers to contribute their talents and [...]\";s:7:\"content\";a:1:{s:7:\"encoded\";s:6523:\"<p>A week or two ago at <a href=\"http://denver.wordcamp.org/\">WordCamp Denver</a>, I gave a presentation about some plans to create more opportunities for people to contribute to the WordPress open source project. The icon design contest was such a success that it seems clear we need to come up with ways for non-developers to contribute their talents and skills to WordPress. Since the launch of 2.7, we&#8217;ve been working out what kinds of contribution opportunities would make sense, and we&#8217;ve come up with a handful. </p>\n<p>This (long) weekend, many WordPress users and developers (including half the core team) will be in Austin, TX for <a href=\"http://sxsw.com/interactive\">South by Southwest</a>. <a href=\"http://ma.tt/\">Matt Mullenweg</a>, <a href=\"http://boren.nu/\">Ryan Boren</a>, <a href=\"http://markjaquith.com/\">Mark Jaquith</a> and <a href=\"http://jane.wordpress.com\">I</a> will all be there, so say hello if you&#8217;re there, too. In the spirit of all this WordPress community connecting, I&#8217;ll be posting here every day during SxSW with information about the new contribution opportunities we&#8217;re creating. Each post will cover one or more of the following:</p>\n<ul>\n<li>Development (of course)</li>\n<li>QA</li>\n<li>Documentation</li>\n<li>Ideas and Opinions</li>\n<li>User Experience</li>\n<li>Graphic Design</li>\n<li>Accessibility</li>\n<li>Usability Testing</li>\n<li>WordPress.tv</li>\n<li>Community Organizing</li>\n</ul>\n<p>Since the first thing people think of when they think of contributing to WordPress is PHP development, we&#8217;ll start there. </p>\n<p>The code (<em>which is poetry</em>) is the meat of the application, so it makes sense that the most opportunities to contribute will continue to fall in this area. <a href=\"http://core.trac.wordpress.org/\">Trac</a> is always filled with tickets that need patches, patches that need testing, and issues that need some creative developer thinking/collaboration to find the right solution to a problem that has us going in circles. </p>\n<p>If you are proficient in PHP, consider looking through the tickets (especially the ones marked &#8220;bug,&#8221; since they should get higher priority) and writing a patch for one of them. If you&#8217;ve got more advanced skills, consider writing a patch for one of the more complex tickets, or offering corrections to a patch submitted by someone else (if needed). If you don&#8217;t trust your coding skills but know your way around the application files, look for tickets tagged has-patch and test the patches in as many browsers as you can, posting your results afterward in the ticket thread. </p>\n<p>If you find a bug in the course of your daily use of WordPress, report it. First, check Trac to see if the issue already has a ticket. You could also scan the archives of the <a href=\"http://lists.automattic.com/mailman/listinfo/wp-testers\">wp-testers list</a> to see if people have been talking about the bug, or email the list yourself to see if anyone has any information on the problem. If these actions don&#8217;t bear fruit, start a new ticket in Trac (you&#8217;ll need to create a login to do this). Be as detailed as you can about the issue, and don&#8217;t forget to make the proper selections from the metadata dropdown menus. Just in case anyone is unsure of how to make these selections&#8230;</p>\n<p>Use the severity  field with caution. Most bugs will be of normal severity. Marking a bug as high severity will not necessarily speed up development, and if it turns out that you&#8217;ve marked a bug&#8217;s severity incorrectly it may even slow down development. </p>\n<p>Priority will usually be normal. Leave it to the more senior developers to change the status to a higher priority, as they are familiar with all the tickets and Trac and will be better able to assess the priority in relation to other tickets. </p>\n<p>Ticket type. This is one of most misused fields, with many people marking tickets as defects that should not be. To address this, here&#8217;s a reminder of the ticket types and their intended uses. Your choices are: defect (bug), enhancement, feature request, and task (blessed). </p>\n<ul>\n<li>Defect (bug). Something is broken. You know how the feature is supposed to work (if you&#8217;re unsure, check the Codex or ask in the dev channel), but something has gone awry that needs to be fixed.</li>\n<li>Enhancement. Something is awkward or slow and could be designed or coded better without overhauling the function or screen design. Please don&#8217;t mark something as a defect (bug) if it is really an enhancement. </li>\n<li>Feature request. If there&#8217;s something that could be improved that would require significant restructuring of code or screen design, it should be marked as feature request rather than enhancement. Please note: this is not really the place to request features that are not currently in WordPress. Please continue to use the Ideas forum to suggest new features. The core developers will add new feature requests to Trac as they review the Ideas forum with each release cycle. </li>\n<li>Task (blessed). This type indicates approval from the core development team. Only core developers should use this selection. If you mark something as Task (blessed) yourself, you will have bad karma.</li>\n</ul>\n<p>Bug Hunts*! If you have checked the <a href=\"http://codex.wordpress.org/WordPress_Bug_Hunts\">Codex page for bug hunts</a> lately, you&#8217;ll notice it&#8217;s been awhile since there was one. No more! Official bug hunts, sprints for finding and fixing bugs, will be brought back on a regular basis. The first one will be announced soon, possibly next week, to try and tackle the bug tickets related to widgets. (No need to wait, though, there are <a href=\"http://core.trac.wordpress.org/query?status=assigned&#038;status=new&#038;status=reopened&#038;group=status&#038;milestone=2.8\">hundreds of open tickets in the 2.8 milestone</a> just waiting for a kind developer to pay them some attention.)</p>\n<p>As always, contributing developers can communicate with each other and with the core team in the #wordpress-dev IRC channel at irc.freenode.net, on the <a href=\"http://lists.automattic.com/mailman/listinfo/wp-hackers\">wp-hackers list</a>, and in the ticket threads on Trac. Regular developer chats in IRC will be returning to Wednesdays at noon (Pacific time) starting next week. </p>\n<p><em>[* - I used to love the bug hunt challenge in Space Cadet 3D Pinball back in the days of Windows 95]</em></p>\n\";}s:3:\"wfw\";a:1:{s:10:\"commentrss\";s:91:\"http://wordpress.org/development/2009/03/contributing-to-wordpress-part-i-development/feed/\";}s:7:\"summary\";s:317:\"A week or two ago at WordCamp Denver, I gave a presentation about some plans to create more opportunities for people to contribute to the WordPress open source project. The icon design contest was such a success that it seems clear we need to come up with ways for non-developers to contribute their talents and [...]\";s:12:\"atom_content\";s:6523:\"<p>A week or two ago at <a href=\"http://denver.wordcamp.org/\">WordCamp Denver</a>, I gave a presentation about some plans to create more opportunities for people to contribute to the WordPress open source project. The icon design contest was such a success that it seems clear we need to come up with ways for non-developers to contribute their talents and skills to WordPress. Since the launch of 2.7, we&#8217;ve been working out what kinds of contribution opportunities would make sense, and we&#8217;ve come up with a handful. </p>\n<p>This (long) weekend, many WordPress users and developers (including half the core team) will be in Austin, TX for <a href=\"http://sxsw.com/interactive\">South by Southwest</a>. <a href=\"http://ma.tt/\">Matt Mullenweg</a>, <a href=\"http://boren.nu/\">Ryan Boren</a>, <a href=\"http://markjaquith.com/\">Mark Jaquith</a> and <a href=\"http://jane.wordpress.com\">I</a> will all be there, so say hello if you&#8217;re there, too. In the spirit of all this WordPress community connecting, I&#8217;ll be posting here every day during SxSW with information about the new contribution opportunities we&#8217;re creating. Each post will cover one or more of the following:</p>\n<ul>\n<li>Development (of course)</li>\n<li>QA</li>\n<li>Documentation</li>\n<li>Ideas and Opinions</li>\n<li>User Experience</li>\n<li>Graphic Design</li>\n<li>Accessibility</li>\n<li>Usability Testing</li>\n<li>WordPress.tv</li>\n<li>Community Organizing</li>\n</ul>\n<p>Since the first thing people think of when they think of contributing to WordPress is PHP development, we&#8217;ll start there. </p>\n<p>The code (<em>which is poetry</em>) is the meat of the application, so it makes sense that the most opportunities to contribute will continue to fall in this area. <a href=\"http://core.trac.wordpress.org/\">Trac</a> is always filled with tickets that need patches, patches that need testing, and issues that need some creative developer thinking/collaboration to find the right solution to a problem that has us going in circles. </p>\n<p>If you are proficient in PHP, consider looking through the tickets (especially the ones marked &#8220;bug,&#8221; since they should get higher priority) and writing a patch for one of them. If you&#8217;ve got more advanced skills, consider writing a patch for one of the more complex tickets, or offering corrections to a patch submitted by someone else (if needed). If you don&#8217;t trust your coding skills but know your way around the application files, look for tickets tagged has-patch and test the patches in as many browsers as you can, posting your results afterward in the ticket thread. </p>\n<p>If you find a bug in the course of your daily use of WordPress, report it. First, check Trac to see if the issue already has a ticket. You could also scan the archives of the <a href=\"http://lists.automattic.com/mailman/listinfo/wp-testers\">wp-testers list</a> to see if people have been talking about the bug, or email the list yourself to see if anyone has any information on the problem. If these actions don&#8217;t bear fruit, start a new ticket in Trac (you&#8217;ll need to create a login to do this). Be as detailed as you can about the issue, and don&#8217;t forget to make the proper selections from the metadata dropdown menus. Just in case anyone is unsure of how to make these selections&#8230;</p>\n<p>Use the severity  field with caution. Most bugs will be of normal severity. Marking a bug as high severity will not necessarily speed up development, and if it turns out that you&#8217;ve marked a bug&#8217;s severity incorrectly it may even slow down development. </p>\n<p>Priority will usually be normal. Leave it to the more senior developers to change the status to a higher priority, as they are familiar with all the tickets and Trac and will be better able to assess the priority in relation to other tickets. </p>\n<p>Ticket type. This is one of most misused fields, with many people marking tickets as defects that should not be. To address this, here&#8217;s a reminder of the ticket types and their intended uses. Your choices are: defect (bug), enhancement, feature request, and task (blessed). </p>\n<ul>\n<li>Defect (bug). Something is broken. You know how the feature is supposed to work (if you&#8217;re unsure, check the Codex or ask in the dev channel), but something has gone awry that needs to be fixed.</li>\n<li>Enhancement. Something is awkward or slow and could be designed or coded better without overhauling the function or screen design. Please don&#8217;t mark something as a defect (bug) if it is really an enhancement. </li>\n<li>Feature request. If there&#8217;s something that could be improved that would require significant restructuring of code or screen design, it should be marked as feature request rather than enhancement. Please note: this is not really the place to request features that are not currently in WordPress. Please continue to use the Ideas forum to suggest new features. The core developers will add new feature requests to Trac as they review the Ideas forum with each release cycle. </li>\n<li>Task (blessed). This type indicates approval from the core development team. Only core developers should use this selection. If you mark something as Task (blessed) yourself, you will have bad karma.</li>\n</ul>\n<p>Bug Hunts*! If you have checked the <a href=\"http://codex.wordpress.org/WordPress_Bug_Hunts\">Codex page for bug hunts</a> lately, you&#8217;ll notice it&#8217;s been awhile since there was one. No more! Official bug hunts, sprints for finding and fixing bugs, will be brought back on a regular basis. The first one will be announced soon, possibly next week, to try and tackle the bug tickets related to widgets. (No need to wait, though, there are <a href=\"http://core.trac.wordpress.org/query?status=assigned&#038;status=new&#038;status=reopened&#038;group=status&#038;milestone=2.8\">hundreds of open tickets in the 2.8 milestone</a> just waiting for a kind developer to pay them some attention.)</p>\n<p>As always, contributing developers can communicate with each other and with the core team in the #wordpress-dev IRC channel at irc.freenode.net, on the <a href=\"http://lists.automattic.com/mailman/listinfo/wp-hackers\">wp-hackers list</a>, and in the ticket threads on Trac. Regular developer chats in IRC will be returning to Wednesdays at noon (Pacific time) starting next week. </p>\n<p><em>[* - I used to love the bug hunt challenge in Space Cadet 3D Pinball back in the days of Windows 95]</em></p>\n\";}i:1;a:12:{s:5:\"title\";s:24:\"Change the Web Challenge\";s:4:\"link\";s:66:\"http://wordpress.org/development/2009/02/change-the-web-challenge/\";s:8:\"comments\";s:75:\"http://wordpress.org/development/2009/02/change-the-web-challenge/#comments\";s:7:\"pubdate\";s:31:\"Thu, 26 Feb 2009 23:35:51 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:5:\"lloyd\";}s:8:\"category\";s:46:\"WidgetsChange the Web ChallengeContestsplugins\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=563\";s:11:\"description\";s:326:\"We&#8217;re excited to be part of the Change the Web Challenge.\nBasically, the contest is to create a plugin, widget, mash up, hack, or other variety of web application that helps people find and share opportunities to take action. The grand prize is 50 benjis, and the best WordPress plugin will also be featured in the [...]\";s:7:\"content\";a:1:{s:7:\"encoded\";s:1585:\"<p><a href=\"http://www.socialactions.com/changetheweb\"><img class=\"alignleft\" align=\"left\" title=\"Change the Web Challenge Logo\" src=\"http://wpdotorg.wordpress.com/files/2009/02/change-the-web-challenge-logo-sm.gif\" alt=\"\" width=\"174\" height=\"240\" /></a>We&#8217;re excited to be part of the <a href=\"http://www.socialactions.com/changetheweb\">Change the Web Challenge</a>.</p>\n<p>Basically, the contest is to create a plugin, widget, mash up, hack, or other variety of web application that helps people find and share opportunities to take action. The grand prize is 50 benjis, and the best WordPress plugin will also be featured in the <a href=\"http://wordpress.org/extend/plugins/\">Plugin Directory</a>. But the real prize is spreading a little more love in the world.</p>\n<p><a href=\"http://www.socialactions.com/changetheweb\">Click here</a> for all the details.</p>\n<p>&#8220;<a href=\"http://codex.wordpress.org/Writing_a_Plugin\">Writing a Plugin</a>&#8221; in the WordPress Codex is where I got started when I needed to get hooked in to WordPress. Others might like to grab one of the over 4,000 <a href=\"http://wordpress.org/extend/plugins/\">open source WordPress plugins</a> and tweak the source. If in need of a little help, the <a href=\"http://wordpress.org/support/forum/10\">Plugins and Hacks</a> forum is full of friends to assist you wrap your head around the code or debug a problem. Social Actions also has provided some <a href=\"http://www.socialactions.com/developers\">developer resources</a>.</p>\n<p>Let&#8217;s show them how we change the web the WordPress way!</p>\n\";}s:3:\"wfw\";a:1:{s:10:\"commentrss\";s:71:\"http://wordpress.org/development/2009/02/change-the-web-challenge/feed/\";}s:7:\"summary\";s:326:\"We&#8217;re excited to be part of the Change the Web Challenge.\nBasically, the contest is to create a plugin, widget, mash up, hack, or other variety of web application that helps people find and share opportunities to take action. The grand prize is 50 benjis, and the best WordPress plugin will also be featured in the [...]\";s:12:\"atom_content\";s:1585:\"<p><a href=\"http://www.socialactions.com/changetheweb\"><img class=\"alignleft\" align=\"left\" title=\"Change the Web Challenge Logo\" src=\"http://wpdotorg.wordpress.com/files/2009/02/change-the-web-challenge-logo-sm.gif\" alt=\"\" width=\"174\" height=\"240\" /></a>We&#8217;re excited to be part of the <a href=\"http://www.socialactions.com/changetheweb\">Change the Web Challenge</a>.</p>\n<p>Basically, the contest is to create a plugin, widget, mash up, hack, or other variety of web application that helps people find and share opportunities to take action. The grand prize is 50 benjis, and the best WordPress plugin will also be featured in the <a href=\"http://wordpress.org/extend/plugins/\">Plugin Directory</a>. But the real prize is spreading a little more love in the world.</p>\n<p><a href=\"http://www.socialactions.com/changetheweb\">Click here</a> for all the details.</p>\n<p>&#8220;<a href=\"http://codex.wordpress.org/Writing_a_Plugin\">Writing a Plugin</a>&#8221; in the WordPress Codex is where I got started when I needed to get hooked in to WordPress. Others might like to grab one of the over 4,000 <a href=\"http://wordpress.org/extend/plugins/\">open source WordPress plugins</a> and tweak the source. If in need of a little help, the <a href=\"http://wordpress.org/support/forum/10\">Plugins and Hacks</a> forum is full of friends to assist you wrap your head around the code or debug a problem. Social Actions also has provided some <a href=\"http://www.socialactions.com/developers\">developer resources</a>.</p>\n<p>Let&#8217;s show them how we change the web the WordPress way!</p>\n\";}i:2;a:12:{s:5:\"title\";s:41:\"New and Improved Plugins Directory Search\";s:4:\"link\";s:83:\"http://wordpress.org/development/2009/02/new-and-improved-plugins-directory-search/\";s:8:\"comments\";s:92:\"http://wordpress.org/development/2009/02/new-and-improved-plugins-directory-search/#comments\";s:7:\"pubdate\";s:31:\"Thu, 19 Feb 2009 01:29:24 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:8:\"mdawaffe\";}s:8:\"category\";s:20:\"Generalpluginssearch\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=544\";s:11:\"description\";s:399:\"One of the biggest problems and most frequent complaints we&#8217;ve had with the WordPress.org Plugins Directory is the horrible, horrible search results.\nNo longer.  We&#8217;re now using Sphinx (a &#8220;free open-source SQL full-text search engine&#8221;) to power search on the Plugins Directory both from the website and from within your blog&#8217;s admin (Plugins &#8594; Add New).\nIt [...]\";s:7:\"content\";a:1:{s:7:\"encoded\";s:1055:\"<p>One of the biggest problems and most frequent complaints we&#8217;ve had with the <a href=\"http://wordpress.org/extend/plugins/\">WordPress.org Plugins Directory</a> is the horrible, horrible search results.</p>\n<p>No longer.  We&#8217;re now using <a href=\"http://www.sphinxsearch.com/\">Sphinx</a> (a &#8220;free open-source SQL full-text search engine&#8221;) to power search on the Plugins Directory both from the website and from within your blog&#8217;s admin (Plugins &rarr; Add New).</p>\n<p>It works much better.  There are a few oddities floating around (our fault not sphinx&#8217;s) that we&#8217;ll be cleaning up shortly, but we&#8217;re happy enough with it on the whole to start letting everyone else use it <img src=\'http://wordpress.org/development/wp-includes/images/smilies/icon_smile.gif\' alt=\':)\' class=\'wp-smiley\' /> </p>\n<p>Currently, the search only indexes the plugin&#8217;s title and description/installation/FAQ/etc. (from the plugin&#8217;s readme.txt file), but we&#8217;ll be adding things like authors and tags soon.</p>\n\";}s:3:\"wfw\";a:1:{s:10:\"commentrss\";s:88:\"http://wordpress.org/development/2009/02/new-and-improved-plugins-directory-search/feed/\";}s:7:\"summary\";s:399:\"One of the biggest problems and most frequent complaints we&#8217;ve had with the WordPress.org Plugins Directory is the horrible, horrible search results.\nNo longer.  We&#8217;re now using Sphinx (a &#8220;free open-source SQL full-text search engine&#8221;) to power search on the Plugins Directory both from the website and from within your blog&#8217;s admin (Plugins &#8594; Add New).\nIt [...]\";s:12:\"atom_content\";s:1055:\"<p>One of the biggest problems and most frequent complaints we&#8217;ve had with the <a href=\"http://wordpress.org/extend/plugins/\">WordPress.org Plugins Directory</a> is the horrible, horrible search results.</p>\n<p>No longer.  We&#8217;re now using <a href=\"http://www.sphinxsearch.com/\">Sphinx</a> (a &#8220;free open-source SQL full-text search engine&#8221;) to power search on the Plugins Directory both from the website and from within your blog&#8217;s admin (Plugins &rarr; Add New).</p>\n<p>It works much better.  There are a few oddities floating around (our fault not sphinx&#8217;s) that we&#8217;ll be cleaning up shortly, but we&#8217;re happy enough with it on the whole to start letting everyone else use it <img src=\'http://wordpress.org/development/wp-includes/images/smilies/icon_smile.gif\' alt=\':)\' class=\'wp-smiley\' /> </p>\n<p>Currently, the search only indexes the plugin&#8217;s title and description/installation/FAQ/etc. (from the plugin&#8217;s readme.txt file), but we&#8217;ll be adding things like authors and tags soon.</p>\n\";}i:3;a:12:{s:5:\"title\";s:15:\"WordPress 2.7.1\";s:4:\"link\";s:55:\"http://wordpress.org/development/2009/02/wordpress-271/\";s:8:\"comments\";s:64:\"http://wordpress.org/development/2009/02/wordpress-271/#comments\";s:7:\"pubdate\";s:31:\"Tue, 10 Feb 2009 21:26:50 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:10:\"Ryan Boren\";}s:8:\"category\";s:8:\"Releases\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=536\";s:11:\"description\";s:341:\"2.7.1, the first 2.7 maintenance release, is now available.  2.7.1 fixes 68 tickets.  You can automatically upgrade from 2.7 to 2.7.1 via the Tools &#8594; Upgrade menu, or you can download the package and upgrade manually.\nYou may have noticed that we went much longer than usual to release this .1 update. We&#8217;re very proud of [...]\";s:7:\"content\";a:1:{s:7:\"encoded\";s:1319:\"<p>2.7.1, the first 2.7 maintenance release, is now available.  2.7.1 fixes <a href=\"http://trac.wordpress.org/query?status=closed&amp;milestone=2.7.1&amp;resolution=fixed&amp;order=priority\">68 tickets</a>.  You can automatically upgrade from 2.7 to 2.7.1 via the Tools &rarr; Upgrade menu, or you can <a href=\"http://wordpress.org/download/\">download the package</a> and upgrade manually.</p>\n<p>You may have noticed that we went much longer than usual to release this .1 update. We&#8217;re very proud of this fact because it&#8217;s a testament to the testing all of you contributed prior to the release of 2.7 which helped make it the most bug-free release we&#8217;ve had.</p>\n<p>Consult the <a href=\"http://trac.wordpress.org/query?status=closed&amp;milestone=2.7.1&amp;resolution=fixed&amp;order=priority\">list of fixed tickets</a> and the  <a href=\"http://core.trac.wordpress.org/changeset?old_path=tags/2.7&#038;old=10539&#038;new_path=tags/2.7.1&#038;new=10539\">full set of changes between 2.7 and 2.7.1</a> for details.</p>\n<p>Finally partly due to the stability of the 2.7 we&#8217;ve decided to push back 2.8 a few more weeks so we can bring in a few more speed optimizations, taxonomy enhancements, and new theme features. We also need to figure out which jazz musician to name the release after.</p>\n\";}s:3:\"wfw\";a:1:{s:10:\"commentrss\";s:60:\"http://wordpress.org/development/2009/02/wordpress-271/feed/\";}s:7:\"summary\";s:341:\"2.7.1, the first 2.7 maintenance release, is now available.  2.7.1 fixes 68 tickets.  You can automatically upgrade from 2.7 to 2.7.1 via the Tools &#8594; Upgrade menu, or you can download the package and upgrade manually.\nYou may have noticed that we went much longer than usual to release this .1 update. We&#8217;re very proud of [...]\";s:12:\"atom_content\";s:1319:\"<p>2.7.1, the first 2.7 maintenance release, is now available.  2.7.1 fixes <a href=\"http://trac.wordpress.org/query?status=closed&amp;milestone=2.7.1&amp;resolution=fixed&amp;order=priority\">68 tickets</a>.  You can automatically upgrade from 2.7 to 2.7.1 via the Tools &rarr; Upgrade menu, or you can <a href=\"http://wordpress.org/download/\">download the package</a> and upgrade manually.</p>\n<p>You may have noticed that we went much longer than usual to release this .1 update. We&#8217;re very proud of this fact because it&#8217;s a testament to the testing all of you contributed prior to the release of 2.7 which helped make it the most bug-free release we&#8217;ve had.</p>\n<p>Consult the <a href=\"http://trac.wordpress.org/query?status=closed&amp;milestone=2.7.1&amp;resolution=fixed&amp;order=priority\">list of fixed tickets</a> and the  <a href=\"http://core.trac.wordpress.org/changeset?old_path=tags/2.7&#038;old=10539&#038;new_path=tags/2.7.1&#038;new=10539\">full set of changes between 2.7 and 2.7.1</a> for details.</p>\n<p>Finally partly due to the stability of the 2.7 we&#8217;ve decided to push back 2.8 a few more weeks so we can bring in a few more speed optimizations, taxonomy enhancements, and new theme features. We also need to figure out which jazz musician to name the release after.</p>\n\";}i:4;a:12:{s:5:\"title\";s:28:\"Thank a Plugin Developer Day\";s:4:\"link\";s:70:\"http://wordpress.org/development/2009/01/thank-a-plugin-developer-day/\";s:8:\"comments\";s:79:\"http://wordpress.org/development/2009/01/thank-a-plugin-developer-day/#comments\";s:7:\"pubdate\";s:31:\"Wed, 28 Jan 2009 21:55:51 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:8:\"category\";s:27:\"Developmentmilestoneplugins\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=534\";s:11:\"description\";s:343:\"WordPress by itself is very simple &#8212; what makes it compelling for most of its users is the wide array of plugins (and themes) available for WP. The average WordPress blog has about 5 plugins installed! Today we just passed 4,000 plugins available in our plugin directory. (Which is also embedded into everyone&#8217;s WordPress 2.7 [...]\";s:7:\"content\";a:1:{s:7:\"encoded\";s:1037:\"<p>WordPress by itself is very simple &#8212; what makes it compelling for most of its users is the wide array of plugins (and themes) available for WP. The average WordPress blog has about 5 plugins installed! Today we just passed <a href=\"http://wordpress.org/extend/plugins/\">4,000 plugins available in our plugin directory</a>. (Which is also embedded into everyone&#8217;s WordPress 2.7 or above.)</p>\n<p>I declare January 28th our official &#8220;Thank a Plugin Developer&#8221; day. To celebrate take a look at the plugins you use and love, visit the author’s site, find their contact form, and drop them a note thanking them. (Or Paypal!) Look for the links in the plugin directory to &#8220;author homepage&#8221; and also to donate directly if they&#8217;ve specified a Paypal address.</p>\n<p>Thank you to everyone who has ever written a plugin for WordPress, and here&#8217;s to the next four thousand. <img src=\'http://wordpress.org/development/wp-includes/images/smilies/icon_smile.gif\' alt=\':)\' class=\'wp-smiley\' /> </p>\n\";}s:3:\"wfw\";a:1:{s:10:\"commentrss\";s:75:\"http://wordpress.org/development/2009/01/thank-a-plugin-developer-day/feed/\";}s:7:\"summary\";s:343:\"WordPress by itself is very simple &#8212; what makes it compelling for most of its users is the wide array of plugins (and themes) available for WP. The average WordPress blog has about 5 plugins installed! Today we just passed 4,000 plugins available in our plugin directory. (Which is also embedded into everyone&#8217;s WordPress 2.7 [...]\";s:12:\"atom_content\";s:1037:\"<p>WordPress by itself is very simple &#8212; what makes it compelling for most of its users is the wide array of plugins (and themes) available for WP. The average WordPress blog has about 5 plugins installed! Today we just passed <a href=\"http://wordpress.org/extend/plugins/\">4,000 plugins available in our plugin directory</a>. (Which is also embedded into everyone&#8217;s WordPress 2.7 or above.)</p>\n<p>I declare January 28th our official &#8220;Thank a Plugin Developer&#8221; day. To celebrate take a look at the plugins you use and love, visit the author’s site, find their contact form, and drop them a note thanking them. (Or Paypal!) Look for the links in the plugin directory to &#8220;author homepage&#8221; and also to donate directly if they&#8217;ve specified a Paypal address.</p>\n<p>Thank you to everyone who has ever written a plugin for WordPress, and here&#8217;s to the next four thousand. <img src=\'http://wordpress.org/development/wp-includes/images/smilies/icon_smile.gif\' alt=\':)\' class=\'wp-smiley\' /> </p>\n\";}i:5;a:12:{s:5:\"title\";s:12:\"WordPress.tv\";s:4:\"link\";s:53:\"http://wordpress.org/development/2009/01/wordpresstv/\";s:8:\"comments\";s:62:\"http://wordpress.org/development/2009/01/wordpresstv/#comments\";s:7:\"pubdate\";s:31:\"Sat, 17 Jan 2009 07:01:29 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:8:\"category\";s:23:\"WordCamptutorialsvideos\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=513\";s:11:\"description\";s:366:\"Today we&#8217;ve switched on WordPress.tv, your visual resource for all things WordPress. \n\nOn WordPress.tv, you&#8217;ll find tutorials for both WordPress self-installs and WordPress.com to help you get blogging fast and hassle-free. We&#8217;ve kicked things off with the basics &#8212; now you can shape what comes next. Just drop us a line and let us know [...]\";s:7:\"content\";a:1:{s:7:\"encoded\";s:1655:\"<p>Today we&#8217;ve switched on <a href=\"http://wordpress.tv\">WordPress.tv</a>, your visual resource for all things WordPress. </p>\n<p><embed src=\"http://v.wordpress.com/DEesBAlR\" type=\"application/x-shockwave-flash\" width=\"640\" height=\"360\" allowscriptaccess=\"always\" allowfullscreen=\"true\"></embed></p>\n<p>On WordPress.tv, you&#8217;ll find <a href=\"http://wordpress.tv/category/how-to/\">tutorials</a> for both <a href=\"http://www.wordpress.org\">WordPress</a> self-installs and <a href=\"http://www.wordpress.com\">WordPress.com</a> to help you get blogging fast and hassle-free. We&#8217;ve kicked things off with the basics &#8212; now you can shape what comes next. Just <a href=\"http://wordpress.tv/contact/\">drop us a line</a> and let us know what you&#8217;d like to see added. </p>\n<p>WordPress.tv is also now <em>the</em> place to find all that awesome  <a href=\"http://central.wordcamp.org/\">WordCamp</a> footage that was floating around the web without a home. See the presentations you missed and get a peek at behind-the-scenes action. We call it <a href=\"http://wordpress.tv/category/wordcamptv/\">WordCampTV</a>. </p>\n<p>You&#8217;ll also find slideshows of presentations made by WordPress gurus, plus interviews I&#8217;ve done with the media and fellow bloggers. </p>\n<p>I hope you&#8217;ll consider WordPress.tv not just a <a href=\"http://www.wordpress.org/support\">support</a> resource, but also a place to hang out and keep up with all the geeky goodness going on in the WordPress community. Tune in regularly for fresh content and updates to the <a href=\"http://blog.wordpress.tv/\">WordPress.tv blog</a>. Lots more is on the way. </p>\n\";}s:3:\"wfw\";a:1:{s:10:\"commentrss\";s:58:\"http://wordpress.org/development/2009/01/wordpresstv/feed/\";}s:7:\"summary\";s:366:\"Today we&#8217;ve switched on WordPress.tv, your visual resource for all things WordPress. \n\nOn WordPress.tv, you&#8217;ll find tutorials for both WordPress self-installs and WordPress.com to help you get blogging fast and hassle-free. We&#8217;ve kicked things off with the basics &#8212; now you can shape what comes next. Just drop us a line and let us know [...]\";s:12:\"atom_content\";s:1655:\"<p>Today we&#8217;ve switched on <a href=\"http://wordpress.tv\">WordPress.tv</a>, your visual resource for all things WordPress. </p>\n<p><embed src=\"http://v.wordpress.com/DEesBAlR\" type=\"application/x-shockwave-flash\" width=\"640\" height=\"360\" allowscriptaccess=\"always\" allowfullscreen=\"true\"></embed></p>\n<p>On WordPress.tv, you&#8217;ll find <a href=\"http://wordpress.tv/category/how-to/\">tutorials</a> for both <a href=\"http://www.wordpress.org\">WordPress</a> self-installs and <a href=\"http://www.wordpress.com\">WordPress.com</a> to help you get blogging fast and hassle-free. We&#8217;ve kicked things off with the basics &#8212; now you can shape what comes next. Just <a href=\"http://wordpress.tv/contact/\">drop us a line</a> and let us know what you&#8217;d like to see added. </p>\n<p>WordPress.tv is also now <em>the</em> place to find all that awesome  <a href=\"http://central.wordcamp.org/\">WordCamp</a> footage that was floating around the web without a home. See the presentations you missed and get a peek at behind-the-scenes action. We call it <a href=\"http://wordpress.tv/category/wordcamptv/\">WordCampTV</a>. </p>\n<p>You&#8217;ll also find slideshows of presentations made by WordPress gurus, plus interviews I&#8217;ve done with the media and fellow bloggers. </p>\n<p>I hope you&#8217;ll consider WordPress.tv not just a <a href=\"http://www.wordpress.org/support\">support</a> resource, but also a place to hang out and keep up with all the geeky goodness going on in the WordPress community. Tune in regularly for fresh content and updates to the <a href=\"http://blog.wordpress.tv/\">WordPress.tv blog</a>. Lots more is on the way. </p>\n\";}i:6;a:12:{s:5:\"title\";s:39:\"Prioritizing Features for WordPress 2.8\";s:4:\"link\";s:80:\"http://wordpress.org/development/2008/12/prioritizing-features-for-wordpress-28/\";s:8:\"comments\";s:89:\"http://wordpress.org/development/2008/12/prioritizing-features-for-wordpress-28/#comments\";s:7:\"pubdate\";s:31:\"Wed, 24 Dec 2008 00:17:58 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:10:\"Jane Wells\";}s:8:\"category\";s:32:\"DevelopmentFeatures2.8surveytrac\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=491\";s:11:\"description\";s:327:\"Everyone knows by now that WordPress 2.7 is packed with new features. Now that it&#8217;s available (almost 600,000 downloads as I write this!), it&#8217;s time to start working on 2.8. There were dozens of things that got tabled during 2.7 due to time constraints, and there are a lot of high-rated features in the Ideas [...]\";s:7:\"content\";a:1:{s:7:\"encoded\";s:2977:\"<p>Everyone knows by now that WordPress 2.7 is packed with new features. Now that it&#8217;s available (almost <a href=\"http://wordpress.org/download/counter/\">600,000 downloads</a> as I write this!), it&#8217;s time to start working on 2.8. There were dozens of things that got tabled during 2.7 due to time constraints, and there are a lot of high-rated features in the <a href=\"http://wordpress.org/extend/ideas\">Ideas forum</a>, so there are a lot of potential features under consideration.</p>\n<p>Right now, the lead developers are thinking the top priorities for 2.8 will be widget management, theme browser/installer and performance upgrades. The rest of the development time will be taken up with bug tickets and additional features/enhancements from a prioritized list. To that end, we&#8217;ve posted <a href=\"http://www.polldaddy.com/s/6FC3E15CDE20B5B5/\">a new survey</a> for you to help us prioritize features for 2.8. The list pulls from the developers&#8217; &#8220;2.7 leftovers&#8221; list as well as the most popular features from the Ideas forum. Just rank each feature and tell us your top pick (up to three). You also have the option of adding comments or additional suggestions, but this is not mandatory. For your response to count, you must rank all of the features in the list. The survey has only one page.  </p>\n<p>Note that media features are not included in this list as we will be posting a separate survey for media-specific features soon. </p>\n<p><a href=\"http://www.polldaddy.com/s/6FC3E15CDE20B5B5/\">Cast your votes</a> any time this week, but as always the sooner the better. This survey will close at noon on December 31, 2008 UTC.</p>\n<p>In the new year, we will be reviving scheduled IRC developer chats, where the lead developers will discuss the week&#8217;s progress on feature development, providing opportunities for people to ask questions or make suggestions. These will be held early in the day on Wednesdays (U.S. Wednesday), and the specific time will be posted here on the development blog once it&#8217;s been finalized. </p>\n<p>As a related aside, we spent a significant amount of time during 2.7 development sifting through Trac tickets that really shouldn&#8217;t have been there. Feature ideas and requests do not belong in Trac, they belong in the Ideas forum. Please reserve Trac for reporting bugs and things that need fixing (typos, code enhancements, etc.). If you are asking for a new UI, a new feature, or a new approach to coding something, that&#8217;s not an enhancement, it&#8217;s a new feature. New features will be entered into Trac by developers once it has been determined that the feature should be included in core. To help speed up development, moving forward we will close Trac tickets that are actually feature requests, with the comment that they should be posted in the Ideas forum instead. Please help the developers maximize their time by following this guideline. </p>\n<p>Thanks for your help!</p>\n\";}s:3:\"wfw\";a:1:{s:10:\"commentrss\";s:85:\"http://wordpress.org/development/2008/12/prioritizing-features-for-wordpress-28/feed/\";}s:7:\"summary\";s:327:\"Everyone knows by now that WordPress 2.7 is packed with new features. Now that it&#8217;s available (almost 600,000 downloads as I write this!), it&#8217;s time to start working on 2.8. There were dozens of things that got tabled during 2.7 due to time constraints, and there are a lot of high-rated features in the Ideas [...]\";s:12:\"atom_content\";s:2977:\"<p>Everyone knows by now that WordPress 2.7 is packed with new features. Now that it&#8217;s available (almost <a href=\"http://wordpress.org/download/counter/\">600,000 downloads</a> as I write this!), it&#8217;s time to start working on 2.8. There were dozens of things that got tabled during 2.7 due to time constraints, and there are a lot of high-rated features in the <a href=\"http://wordpress.org/extend/ideas\">Ideas forum</a>, so there are a lot of potential features under consideration.</p>\n<p>Right now, the lead developers are thinking the top priorities for 2.8 will be widget management, theme browser/installer and performance upgrades. The rest of the development time will be taken up with bug tickets and additional features/enhancements from a prioritized list. To that end, we&#8217;ve posted <a href=\"http://www.polldaddy.com/s/6FC3E15CDE20B5B5/\">a new survey</a> for you to help us prioritize features for 2.8. The list pulls from the developers&#8217; &#8220;2.7 leftovers&#8221; list as well as the most popular features from the Ideas forum. Just rank each feature and tell us your top pick (up to three). You also have the option of adding comments or additional suggestions, but this is not mandatory. For your response to count, you must rank all of the features in the list. The survey has only one page.  </p>\n<p>Note that media features are not included in this list as we will be posting a separate survey for media-specific features soon. </p>\n<p><a href=\"http://www.polldaddy.com/s/6FC3E15CDE20B5B5/\">Cast your votes</a> any time this week, but as always the sooner the better. This survey will close at noon on December 31, 2008 UTC.</p>\n<p>In the new year, we will be reviving scheduled IRC developer chats, where the lead developers will discuss the week&#8217;s progress on feature development, providing opportunities for people to ask questions or make suggestions. These will be held early in the day on Wednesdays (U.S. Wednesday), and the specific time will be posted here on the development blog once it&#8217;s been finalized. </p>\n<p>As a related aside, we spent a significant amount of time during 2.7 development sifting through Trac tickets that really shouldn&#8217;t have been there. Feature ideas and requests do not belong in Trac, they belong in the Ideas forum. Please reserve Trac for reporting bugs and things that need fixing (typos, code enhancements, etc.). If you are asking for a new UI, a new feature, or a new approach to coding something, that&#8217;s not an enhancement, it&#8217;s a new feature. New features will be entered into Trac by developers once it has been determined that the feature should be included in core. To help speed up development, moving forward we will close Trac tickets that are actually feature requests, with the comment that they should be posted in the Ideas forum instead. Please help the developers maximize their time by following this guideline. </p>\n<p>Thanks for your help!</p>\n\";}i:7;a:12:{s:5:\"title\";s:28:\"WordPress 2.7 “Coltrane”\";s:4:\"link\";s:50:\"http://wordpress.org/development/2008/12/coltrane/\";s:8:\"comments\";s:59:\"http://wordpress.org/development/2008/12/coltrane/#comments\";s:7:\"pubdate\";s:31:\"Thu, 11 Dec 2008 02:28:57 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:8:\"category\";s:19:\"DevelopmentReleases\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=477\";s:11:\"description\";s:318:\"The first thing you&#8217;ll notice about 2.7 is its new interface. From the top down, we&#8217;ve listened to your feedback and thought deeply about the design and the result is a WordPress that&#8217;s just plain faster. Nearly every task you do on your blog will take fewer clicks and be faster in 2.7 than it [...]\";s:7:\"content\";a:1:{s:7:\"encoded\";s:11933:\"<p>The first thing you&#8217;ll notice about 2.7 is its new interface. From the top down, we&#8217;ve listened to your feedback and thought deeply about the design and the result is a WordPress that&#8217;s just plain faster. Nearly every task you do on your blog will <strong>take fewer clicks and be faster</strong> in 2.7 than it did in a previous version. (<a href=\"http://wordpress.org/download/\">Download it now</a>, or read on for more.)</p>\n<p>Next you&#8217;ll begin to notice the new features subtly sprinkled through the new interface: the new dashboard that you can arrange with drag and drop to put the things most important to you on top, QuickPress, comment threading, paging, and the ability to reply to comments from your dashboard, the ability to install any plugin directly from WordPress.org with a single click, and sticky posts.</p>\n<p>Digging in further you might notice that every screen is customizable. Let&#8217;s say you never care about author on your post listings &#8212; just click &#8220;Screen Options&#8221; and uncheck it and it&#8217;s instantly gone from the page. The same for any module on the dashboard or write screen. If your screen is narrow and the menu is taking up too much horizontal room, click the arrow to minimize it to be icon-only, and then go to the write page and drag and drop everything from the right column into the main one, so your posting area is full-screen. (For example I like hiding everything except categories, tags, and publish. I put categories and tags on the right, and publish under the post box.)</p>\n<p>For a visual introduction to what 2.7 is, check out this video (available in HD, and full screen):</p>\n<p><object width=\"640\" height=\"360\" data=\"http://v.wordpress.com/hFr8Nyar\" type=\"application/x-shockwave-flash\"><param name=\"src\" value=\"http://v.wordpress.com/hFr8Nyar\" /><param name=\"allowfullscreen\" value=\"true\" /></object></p>\n<p>It&#8217;s all about you. It&#8217;s the next generation of WordPress, which is why we&#8217;ve bestowed it with the honor of being named for <a href=\"http://en.wikipedia.org/wiki/John_Coltrane\">John Coltrane</a>. <a href=\"http://wordpress.org/download/\">And you can download it today</a>.</p>\n<p>Last, but certainly not least, this may be the <strong>last time you ever have to manually upgrade WordPress again</strong>. We heard how tired you were of doing upgrades for yourself and your friends, so now WordPress includes a built-in upgrade that will automatically notify you of new releases, and when you&#8217;re ready it will download them, install them, and upgrade your blog with a single click.</p>\n<p>(As with any interface change it may take a little bit of time to acclimate yourself but soon you&#8217;ll find yourself whizzing through the screens. Even people who have hated it at first tell us after a few days they wonder how they got by before.)</p>\n<h3>The Story Behind 2.7</h3>\n<p>The real reason Coltrane is such a huge leap forward is because the community was so involved with every step of the process. <strong>Over 150 people contributed code directly to the release</strong>, our highest ever, with many tens of thousands more participating in the polls, surveys, tests, mailing lists, and other feedback mechanisms the WordPress dev team used in putting this release together.</p>\n<p>For some of the back story in the development of 2.7, check out these blog posts (thanks to <a href=\"http://weblogtoolscollection.com/\">WeblogToolsCollection</a> for the list):</p>\n<ul>\n<li><a href=\"http://wordpress.org/development/2008/10/usability-testing-report-25-and-crazyhorse/\">Usability Testing Report: 2.5 and CrazyHorse</a></li>\n<li><a href=\"http://wordpress.org/development/2008/10/the-new-27-dashboard/\">The New 2.7 Dashboard</a></li>\n<li><a href=\"http://wordpress.org/development/2008/10/the-visual-design-of-27/\">The Visual Design of 2.7</a></li>\n<li><a href=\"http://wordpress.org/development/2008/10/wordpress-27-wireframes/\">WordPress 2.7 wireframes</a></li>\n<li><a href=\"http://codex.wordpress.org/Version_2.7\">Comprehensive Codex Article on WordPress 2.7</a></li>\n<li><a href=\"http://wpdevel.wordpress.com/author/jane/\">WordPress Development Updates from Jane Wells</a></li>\n<li><a href=\"http://en.blog.wordpress.com/2008/05/20/new-york-usability-testing/\">WordPress Usability Testing in New York</a></li>\n<li><a href=\"http://boren.nu/archives/2008/10/31/wordpress-27-ui-configurability/\">WordPress 2.7 UI Configurability from Ryan Boren</a></li>\n<li><a href=\"http://markjaquith.wordpress.com/2008/11/06/wordpress-27-feature-preview-customizable-post-editing-screen/\">Customizable Post Editing Screen from Mark Jaquith</a></li>\n<li><a href=\"http://jane.wordpress.com/2008/09/15/wordpress-27-navigation-survey/\">WordPress 2.7 Navigation Survey from Jane Wells</a></li>\n<li><a href=\"http://jane.wordpress.com/2008/10/16/shortcutsfavorites-menu/\">Shortcuts/Favorites Menu from Jane Wells</a></li>\n<li><a href=\"http://www.slideshare.net/edanzico/riding-the-crazyhorse-future-generation-wordpress-presentation\">CrazyHorse Presentation at WordCamp SF</a></li>\n<li><a href=\"http://www.centernetworks.com/wordpress-27-demo\">WordPress 2.7 Walkthrough by Matt</a></li>\n<li><a href=\"http://www.idratherbewriting.com/2008/09/27/wordpress-27-and-beyond-%E2%80%93-keynote-by-matt-mullenweg-at-wordcamp-utah-2008/\">WordPress 2.7 and beyond from Matt at WordCamp Utah</a></li>\n</ul>\n<p>This was interesting to us, a blogging software release we actually blogged about, but the process was hugely informative. Prior to its release today Crazyhorse and 2.7 had been tested by tens of thousands of people on their blogs, hundreds of thousands of you count .com. The volume of feedback was so high that we decided to push back the release date a month to take time to incorporate it all and do more revisions based on what you guys said.</p>\n<p>For those of you wondering why we didn&#8217;t call this release 3.0, it&#8217;s because we abhor version number inflation. 3.0 will just be the next release after 2.9. The major features in new point releases approach also works well for products like OS X, with huge changes between a 10.3 and 10.4.</p>\n<h3>The Future</h3>\n<p>Those of you following along at home might have noticed this was our second major redesign of WordPress this year. Whoa nelly! While that wasn&#8217;t ideal, and I especially sympathize with those of you creating books or tutorials around WordPress, there&#8217;s good news. The changes to WordPress in 2.5 and 2.7 were necessary for us to break free of much of the legacy cruft and interface bloat that had built up over the years (gradually) and more importantly provide us with a UI framework and interface language we can use at the foundation to build tomorrow&#8217;s WordPress on, to express ideas we haven&#8217;t been able to before. So at the end of 2009 I expect, interface-wise, WordPress to look largely the same as it does now.</p>\n<p>That said, we couldn&#8217;t be more excited about the future with regards to features. Now that we&#8217;ve cleared out more basic things, we are looking forward in the coming year to really tackling media handling including audio and video, better tools for plugin and theme developers, widgets, theme updates, more integrated and contextual help, and easier integration with projects like <a href=\"http://buddypress.org/\">BuddyPress</a> and <a href=\"http://bbpress.org/\">bbPress</a>.</p>\n<h3>Thank Yous</h3>\n<p>We would like to take a moment to thank the following WordPress.org users for being a part of 2.7: <a href=\"http://segert.net/\">Verena Segert</a>, <a href=\"http://www.fieldii.com/\">Ben Dunkle</a>, 082net, <a href=\"http://ckon.wordpress.com/\">_ck_</a>, <a href=\"http://technosailor.com/\">Aaron Brazell</a>, Aaron Campbell, Aaron Harp, aaron_guitar, abackstrom, <a href=\"http://alexrabe.boelinger.com/\">Alex Rabe</a>, <a href=\"http://flightpathblog.com/\">Alex Shiels</a>, anderswc, andr, <a href=\"http://azaozz.wordpress.com/\">Andrew Ozz</a>, andy, <a href=\"http://apeatling.wordpress.com/\">Andy Peatling</a>, <a href=\"http://ilfilosofo.com/\">Austin Matzko</a>, axelseaa, bendalton, <a href=\"http://extralogical.net/\">Benedict Eastaugh</a>, <a href=\"http://www.umaitech.com/\">Betsy Kimak</a>, <a href=\"http://www.burobjorn.nl/\">Björn Wijers</a>, <a href=\"http://bobrik.name/\">bobrik</a>, brianwhite, bubel, <a href=\"http://www.majordojo.com/\">Byrne Reese</a>, caesarsgrunt, capripot, <a href=\"http://maisonbisson.com/blog/\">Casey Bisson</a>, <a href=\"http://www.cefm.ca/\">Charles E. Frees-Melvin</a>, <a href=\"http://chrisjohnston.org\">Chris Johnston</a>, codestyling, corischlegel, count_0, <a href=\"http://www.red-sweater.com/blog/\">Daniel Jalkut</a>, Daniel Torreblanca, <a href=\"http://www.misthaven.org.uk/blog/\">David McFarlane</a>, dbuser123, <a href=\"http://op111.net/\">Demetris Kikizas</a>, <a href=\"http://dd32.id.au/\">Dion Hulse</a>, docwhat, <a href=\"http://ocaoimh.ie\">Donncha O Caoimh</a>, <a href=\"http://literalbarrage.org/blog/\">Doug Stewart</a>, <a href=\"http://dougal.gunters.org\">Dougal Campbell</a>, dsader, dtsn, dwc, g30rg3x, guillep2k, <a href=\"http://hailin.wordpress.com/\">Hailin Wu</a>, <a href=\"http://engel.uk.to/\">Hans Engel</a>, <a href=\"http://santosj.name/\">Jacob Santos</a>, <a href=\"http://jamierumbelow.net/\">Jamie Rumbelow</a>, <a href=\"http://www.janbrasna.com/\">Jan Brasna</a>, <a href=\"http://jane.wordpress.com/\">Jane Wells</a>, Jean-LucfromBrussels, <a href=\"http://poplarware.com/HodgBlog/\">Jennifer Hodgdon</a>, <a href=\"http://simianuprising.com/\">Jeremy Clarke</a>, <a href=\"http://jmini.fr/\">Jérémie Bresson</a>, jick, <a href=\"http://www.joetek.ca/\">Joe Taiabjee</a>, <a href=\"http://johnblackbourn.com/\">John Blackbourn</a>, John Conners, John Lamansky, johnhennmacc, <a href=\"http://yoast.com/\">Joost de Valk</a>, <a href=\"http://josephscott.org/\">Joseph Scott</a>, kashani, <a href=\"http://www.kpdesign.net/\">Kim Parsell</a>, <a href=\"http://foolswisdom.com/\">Lloyd Budd</a>, <a href=\"http://elektroelch.de/blog\">Lutz Schröer</a>, <a href=\"http://www.malaiac.net\">Malaiac</a>, <a href=\"http://markjaquith.com/\">Mark Jaquith</a>, <a href=\"http://www.blogitude.com/\">Mark Steel</a>, <a href=\"http://mattsblog.ca/\">Matt Freedman</a>, <a href=\"http://ma.tt/\">Matt Mullenweg</a>, <a href=\"htttp://iammattthomas.com/\">Matt Thomas</a>, matthewh84, mattyrob, mcs_trekkie, <a href=\"http://blogwaffe.com/\">Michael Adams</a>, <a href=\"http://www.ioerror.us/\">Michael Hampton</a>, <a href=\"http://codex.wordpress.org/User:MichaelH\">MichaelH</a>, mictasm, <a href=\"http://mikeschinkel.com/\">Mike Schinkel</a>, msi08, msw0418, mtekk, <a href=\"http://mtdewvirus.com/\">Nick Momrik</a>, <a href=\"http://nikolay.bg/\">Nikolay Bachiyski</a>, <a href=\"http://jcksn.com/\">Noel Jackson</a>, <a href=\"http://ottodestruct.com/\">Otto</a>, <a href=\"http://planetozh.com/\">Ozh</a>, paddya, paul, pedrop, pishmishy, Po0ky, RanYanivHartstein, raychampagne, rdworth, reinkim, rickoman, rm53, rnt, <a href=\"http://robert.accettura.com/\">Robert Accettura</a>, roganty, <a href=\"http://boren.nu/\">Ryan Boren</a>, <a href=\"http://cubegames.net/\">Ryan McCue</a>, <a href=\"http://unlettered.com/\">Sam Bauers</a>, Sam_a, schiller, <a href=\"http://www.scott-h.com/\">Scott Houst</a>, sekundek, <a href=\"http://bugssite.org/\">Shane</a>, Simek, <a href=\"http://www.simonwheatley.co.uk/\">Simon Wheatley</a>, <a href=\"http://sivel.net/\">sivel</a>, st_falcon, stefano, strider72, tai, takayukister, techcookies, Terragg, thinlight, tott, <a href=\"http://www.trevorfitzgerald.com/\">Trevor Fitzgerald</a>, tschai, Txanny, <a href=\"http://www.manionline.org/\">Valiallah (Mani) Monajjemi</a>, <a href=\"http://viper007bond.com/\">Viper007Bond</a>, <a href=\"http://wordpress.org/support/profile/1064655\">Vladimir Kolesnikov</a>, wasp, wet, wfrantz, x11tech, xknown, xorax, <a href=\"http://ydekproductions.com/\">ydekproductions</a>, yoavf, yonosoytu, yoshi, zedlander</p>\n\";}s:3:\"wfw\";a:1:{s:10:\"commentrss\";s:55:\"http://wordpress.org/development/2008/12/coltrane/feed/\";}s:7:\"summary\";s:318:\"The first thing you&#8217;ll notice about 2.7 is its new interface. From the top down, we&#8217;ve listened to your feedback and thought deeply about the design and the result is a WordPress that&#8217;s just plain faster. Nearly every task you do on your blog will take fewer clicks and be faster in 2.7 than it [...]\";s:12:\"atom_content\";s:11933:\"<p>The first thing you&#8217;ll notice about 2.7 is its new interface. From the top down, we&#8217;ve listened to your feedback and thought deeply about the design and the result is a WordPress that&#8217;s just plain faster. Nearly every task you do on your blog will <strong>take fewer clicks and be faster</strong> in 2.7 than it did in a previous version. (<a href=\"http://wordpress.org/download/\">Download it now</a>, or read on for more.)</p>\n<p>Next you&#8217;ll begin to notice the new features subtly sprinkled through the new interface: the new dashboard that you can arrange with drag and drop to put the things most important to you on top, QuickPress, comment threading, paging, and the ability to reply to comments from your dashboard, the ability to install any plugin directly from WordPress.org with a single click, and sticky posts.</p>\n<p>Digging in further you might notice that every screen is customizable. Let&#8217;s say you never care about author on your post listings &#8212; just click &#8220;Screen Options&#8221; and uncheck it and it&#8217;s instantly gone from the page. The same for any module on the dashboard or write screen. If your screen is narrow and the menu is taking up too much horizontal room, click the arrow to minimize it to be icon-only, and then go to the write page and drag and drop everything from the right column into the main one, so your posting area is full-screen. (For example I like hiding everything except categories, tags, and publish. I put categories and tags on the right, and publish under the post box.)</p>\n<p>For a visual introduction to what 2.7 is, check out this video (available in HD, and full screen):</p>\n<p><object width=\"640\" height=\"360\" data=\"http://v.wordpress.com/hFr8Nyar\" type=\"application/x-shockwave-flash\"><param name=\"src\" value=\"http://v.wordpress.com/hFr8Nyar\" /><param name=\"allowfullscreen\" value=\"true\" /></object></p>\n<p>It&#8217;s all about you. It&#8217;s the next generation of WordPress, which is why we&#8217;ve bestowed it with the honor of being named for <a href=\"http://en.wikipedia.org/wiki/John_Coltrane\">John Coltrane</a>. <a href=\"http://wordpress.org/download/\">And you can download it today</a>.</p>\n<p>Last, but certainly not least, this may be the <strong>last time you ever have to manually upgrade WordPress again</strong>. We heard how tired you were of doing upgrades for yourself and your friends, so now WordPress includes a built-in upgrade that will automatically notify you of new releases, and when you&#8217;re ready it will download them, install them, and upgrade your blog with a single click.</p>\n<p>(As with any interface change it may take a little bit of time to acclimate yourself but soon you&#8217;ll find yourself whizzing through the screens. Even people who have hated it at first tell us after a few days they wonder how they got by before.)</p>\n<h3>The Story Behind 2.7</h3>\n<p>The real reason Coltrane is such a huge leap forward is because the community was so involved with every step of the process. <strong>Over 150 people contributed code directly to the release</strong>, our highest ever, with many tens of thousands more participating in the polls, surveys, tests, mailing lists, and other feedback mechanisms the WordPress dev team used in putting this release together.</p>\n<p>For some of the back story in the development of 2.7, check out these blog posts (thanks to <a href=\"http://weblogtoolscollection.com/\">WeblogToolsCollection</a> for the list):</p>\n<ul>\n<li><a href=\"http://wordpress.org/development/2008/10/usability-testing-report-25-and-crazyhorse/\">Usability Testing Report: 2.5 and CrazyHorse</a></li>\n<li><a href=\"http://wordpress.org/development/2008/10/the-new-27-dashboard/\">The New 2.7 Dashboard</a></li>\n<li><a href=\"http://wordpress.org/development/2008/10/the-visual-design-of-27/\">The Visual Design of 2.7</a></li>\n<li><a href=\"http://wordpress.org/development/2008/10/wordpress-27-wireframes/\">WordPress 2.7 wireframes</a></li>\n<li><a href=\"http://codex.wordpress.org/Version_2.7\">Comprehensive Codex Article on WordPress 2.7</a></li>\n<li><a href=\"http://wpdevel.wordpress.com/author/jane/\">WordPress Development Updates from Jane Wells</a></li>\n<li><a href=\"http://en.blog.wordpress.com/2008/05/20/new-york-usability-testing/\">WordPress Usability Testing in New York</a></li>\n<li><a href=\"http://boren.nu/archives/2008/10/31/wordpress-27-ui-configurability/\">WordPress 2.7 UI Configurability from Ryan Boren</a></li>\n<li><a href=\"http://markjaquith.wordpress.com/2008/11/06/wordpress-27-feature-preview-customizable-post-editing-screen/\">Customizable Post Editing Screen from Mark Jaquith</a></li>\n<li><a href=\"http://jane.wordpress.com/2008/09/15/wordpress-27-navigation-survey/\">WordPress 2.7 Navigation Survey from Jane Wells</a></li>\n<li><a href=\"http://jane.wordpress.com/2008/10/16/shortcutsfavorites-menu/\">Shortcuts/Favorites Menu from Jane Wells</a></li>\n<li><a href=\"http://www.slideshare.net/edanzico/riding-the-crazyhorse-future-generation-wordpress-presentation\">CrazyHorse Presentation at WordCamp SF</a></li>\n<li><a href=\"http://www.centernetworks.com/wordpress-27-demo\">WordPress 2.7 Walkthrough by Matt</a></li>\n<li><a href=\"http://www.idratherbewriting.com/2008/09/27/wordpress-27-and-beyond-%E2%80%93-keynote-by-matt-mullenweg-at-wordcamp-utah-2008/\">WordPress 2.7 and beyond from Matt at WordCamp Utah</a></li>\n</ul>\n<p>This was interesting to us, a blogging software release we actually blogged about, but the process was hugely informative. Prior to its release today Crazyhorse and 2.7 had been tested by tens of thousands of people on their blogs, hundreds of thousands of you count .com. The volume of feedback was so high that we decided to push back the release date a month to take time to incorporate it all and do more revisions based on what you guys said.</p>\n<p>For those of you wondering why we didn&#8217;t call this release 3.0, it&#8217;s because we abhor version number inflation. 3.0 will just be the next release after 2.9. The major features in new point releases approach also works well for products like OS X, with huge changes between a 10.3 and 10.4.</p>\n<h3>The Future</h3>\n<p>Those of you following along at home might have noticed this was our second major redesign of WordPress this year. Whoa nelly! While that wasn&#8217;t ideal, and I especially sympathize with those of you creating books or tutorials around WordPress, there&#8217;s good news. The changes to WordPress in 2.5 and 2.7 were necessary for us to break free of much of the legacy cruft and interface bloat that had built up over the years (gradually) and more importantly provide us with a UI framework and interface language we can use at the foundation to build tomorrow&#8217;s WordPress on, to express ideas we haven&#8217;t been able to before. So at the end of 2009 I expect, interface-wise, WordPress to look largely the same as it does now.</p>\n<p>That said, we couldn&#8217;t be more excited about the future with regards to features. Now that we&#8217;ve cleared out more basic things, we are looking forward in the coming year to really tackling media handling including audio and video, better tools for plugin and theme developers, widgets, theme updates, more integrated and contextual help, and easier integration with projects like <a href=\"http://buddypress.org/\">BuddyPress</a> and <a href=\"http://bbpress.org/\">bbPress</a>.</p>\n<h3>Thank Yous</h3>\n<p>We would like to take a moment to thank the following WordPress.org users for being a part of 2.7: <a href=\"http://segert.net/\">Verena Segert</a>, <a href=\"http://www.fieldii.com/\">Ben Dunkle</a>, 082net, <a href=\"http://ckon.wordpress.com/\">_ck_</a>, <a href=\"http://technosailor.com/\">Aaron Brazell</a>, Aaron Campbell, Aaron Harp, aaron_guitar, abackstrom, <a href=\"http://alexrabe.boelinger.com/\">Alex Rabe</a>, <a href=\"http://flightpathblog.com/\">Alex Shiels</a>, anderswc, andr, <a href=\"http://azaozz.wordpress.com/\">Andrew Ozz</a>, andy, <a href=\"http://apeatling.wordpress.com/\">Andy Peatling</a>, <a href=\"http://ilfilosofo.com/\">Austin Matzko</a>, axelseaa, bendalton, <a href=\"http://extralogical.net/\">Benedict Eastaugh</a>, <a href=\"http://www.umaitech.com/\">Betsy Kimak</a>, <a href=\"http://www.burobjorn.nl/\">Björn Wijers</a>, <a href=\"http://bobrik.name/\">bobrik</a>, brianwhite, bubel, <a href=\"http://www.majordojo.com/\">Byrne Reese</a>, caesarsgrunt, capripot, <a href=\"http://maisonbisson.com/blog/\">Casey Bisson</a>, <a href=\"http://www.cefm.ca/\">Charles E. Frees-Melvin</a>, <a href=\"http://chrisjohnston.org\">Chris Johnston</a>, codestyling, corischlegel, count_0, <a href=\"http://www.red-sweater.com/blog/\">Daniel Jalkut</a>, Daniel Torreblanca, <a href=\"http://www.misthaven.org.uk/blog/\">David McFarlane</a>, dbuser123, <a href=\"http://op111.net/\">Demetris Kikizas</a>, <a href=\"http://dd32.id.au/\">Dion Hulse</a>, docwhat, <a href=\"http://ocaoimh.ie\">Donncha O Caoimh</a>, <a href=\"http://literalbarrage.org/blog/\">Doug Stewart</a>, <a href=\"http://dougal.gunters.org\">Dougal Campbell</a>, dsader, dtsn, dwc, g30rg3x, guillep2k, <a href=\"http://hailin.wordpress.com/\">Hailin Wu</a>, <a href=\"http://engel.uk.to/\">Hans Engel</a>, <a href=\"http://santosj.name/\">Jacob Santos</a>, <a href=\"http://jamierumbelow.net/\">Jamie Rumbelow</a>, <a href=\"http://www.janbrasna.com/\">Jan Brasna</a>, <a href=\"http://jane.wordpress.com/\">Jane Wells</a>, Jean-LucfromBrussels, <a href=\"http://poplarware.com/HodgBlog/\">Jennifer Hodgdon</a>, <a href=\"http://simianuprising.com/\">Jeremy Clarke</a>, <a href=\"http://jmini.fr/\">Jérémie Bresson</a>, jick, <a href=\"http://www.joetek.ca/\">Joe Taiabjee</a>, <a href=\"http://johnblackbourn.com/\">John Blackbourn</a>, John Conners, John Lamansky, johnhennmacc, <a href=\"http://yoast.com/\">Joost de Valk</a>, <a href=\"http://josephscott.org/\">Joseph Scott</a>, kashani, <a href=\"http://www.kpdesign.net/\">Kim Parsell</a>, <a href=\"http://foolswisdom.com/\">Lloyd Budd</a>, <a href=\"http://elektroelch.de/blog\">Lutz Schröer</a>, <a href=\"http://www.malaiac.net\">Malaiac</a>, <a href=\"http://markjaquith.com/\">Mark Jaquith</a>, <a href=\"http://www.blogitude.com/\">Mark Steel</a>, <a href=\"http://mattsblog.ca/\">Matt Freedman</a>, <a href=\"http://ma.tt/\">Matt Mullenweg</a>, <a href=\"htttp://iammattthomas.com/\">Matt Thomas</a>, matthewh84, mattyrob, mcs_trekkie, <a href=\"http://blogwaffe.com/\">Michael Adams</a>, <a href=\"http://www.ioerror.us/\">Michael Hampton</a>, <a href=\"http://codex.wordpress.org/User:MichaelH\">MichaelH</a>, mictasm, <a href=\"http://mikeschinkel.com/\">Mike Schinkel</a>, msi08, msw0418, mtekk, <a href=\"http://mtdewvirus.com/\">Nick Momrik</a>, <a href=\"http://nikolay.bg/\">Nikolay Bachiyski</a>, <a href=\"http://jcksn.com/\">Noel Jackson</a>, <a href=\"http://ottodestruct.com/\">Otto</a>, <a href=\"http://planetozh.com/\">Ozh</a>, paddya, paul, pedrop, pishmishy, Po0ky, RanYanivHartstein, raychampagne, rdworth, reinkim, rickoman, rm53, rnt, <a href=\"http://robert.accettura.com/\">Robert Accettura</a>, roganty, <a href=\"http://boren.nu/\">Ryan Boren</a>, <a href=\"http://cubegames.net/\">Ryan McCue</a>, <a href=\"http://unlettered.com/\">Sam Bauers</a>, Sam_a, schiller, <a href=\"http://www.scott-h.com/\">Scott Houst</a>, sekundek, <a href=\"http://bugssite.org/\">Shane</a>, Simek, <a href=\"http://www.simonwheatley.co.uk/\">Simon Wheatley</a>, <a href=\"http://sivel.net/\">sivel</a>, st_falcon, stefano, strider72, tai, takayukister, techcookies, Terragg, thinlight, tott, <a href=\"http://www.trevorfitzgerald.com/\">Trevor Fitzgerald</a>, tschai, Txanny, <a href=\"http://www.manionline.org/\">Valiallah (Mani) Monajjemi</a>, <a href=\"http://viper007bond.com/\">Viper007Bond</a>, <a href=\"http://wordpress.org/support/profile/1064655\">Vladimir Kolesnikov</a>, wasp, wet, wfrantz, x11tech, xknown, xorax, <a href=\"http://ydekproductions.com/\">ydekproductions</a>, yoavf, yonosoytu, yoshi, zedlander</p>\n\";}i:8;a:12:{s:5:\"title\";s:25:\"2.7 Release Candidate Two\";s:4:\"link\";s:66:\"http://wordpress.org/development/2008/12/27-release-candidate-two/\";s:8:\"comments\";s:75:\"http://wordpress.org/development/2008/12/27-release-candidate-two/#comments\";s:7:\"pubdate\";s:31:\"Wed, 10 Dec 2008 00:55:33 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:8:\"category\";s:11:\"Development\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=474\";s:11:\"description\";s:315:\"There comes a time in every WordPress release when it&#8217;s ready for the world , to come out of its cocoon and feel the light of the world on its wings for the first time.\nIt&#8217;s not quite that time yet, but we&#8217;re as close as we&#8217;ve ever been, hence the immediate availability of 2.7 Release [...]\";s:7:\"content\";a:1:{s:7:\"encoded\";s:836:\"<p>There comes a time in every WordPress release when it&#8217;s ready for the world , to come out of its cocoon and feel the light of the world on its wings for the first time.</p>\n<p>It&#8217;s not quite that time yet, but we&#8217;re as close as we&#8217;ve ever been, hence the <a href=\"http://wordpress.org/wordpress-2.7-RC2.zip\">immediate availability of 2.7 Release Candidate 2, or RC2 for short</a>.</p>\n<p>Of course if you were already testing 2.7, you can just use the built-in core updater (Tools > Upgrade) to download and install RC2 for you (and later upgrade you to the final release when it&#8217;s available) but if not you can use the download link above.</p>\n<p>We feel this release is pretty much exactly what we&#8217;re going to ship as 2.7, barring any final bugs or polish tweaks that you report or we find.</p>\n\";}s:3:\"wfw\";a:1:{s:10:\"commentrss\";s:71:\"http://wordpress.org/development/2008/12/27-release-candidate-two/feed/\";}s:7:\"summary\";s:315:\"There comes a time in every WordPress release when it&#8217;s ready for the world , to come out of its cocoon and feel the light of the world on its wings for the first time.\nIt&#8217;s not quite that time yet, but we&#8217;re as close as we&#8217;ve ever been, hence the immediate availability of 2.7 Release [...]\";s:12:\"atom_content\";s:836:\"<p>There comes a time in every WordPress release when it&#8217;s ready for the world , to come out of its cocoon and feel the light of the world on its wings for the first time.</p>\n<p>It&#8217;s not quite that time yet, but we&#8217;re as close as we&#8217;ve ever been, hence the <a href=\"http://wordpress.org/wordpress-2.7-RC2.zip\">immediate availability of 2.7 Release Candidate 2, or RC2 for short</a>.</p>\n<p>Of course if you were already testing 2.7, you can just use the built-in core updater (Tools > Upgrade) to download and install RC2 for you (and later upgrade you to the final release when it&#8217;s available) but if not you can use the download link above.</p>\n<p>We feel this release is pretty much exactly what we&#8217;re going to ship as 2.7, barring any final bugs or polish tweaks that you report or we find.</p>\n\";}i:9;a:12:{s:5:\"title\";s:33:\"WordPress 2.7 Release Candidate 1\";s:4:\"link\";s:74:\"http://wordpress.org/development/2008/12/wordpress-27-release-candidate-1/\";s:8:\"comments\";s:83:\"http://wordpress.org/development/2008/12/wordpress-27-release-candidate-1/#comments\";s:7:\"pubdate\";s:31:\"Mon, 01 Dec 2008 22:26:14 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:10:\"Ryan Boren\";}s:8:\"category\";s:8:\"Releases\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=467\";s:11:\"description\";s:312:\"With the release of RC1, we&#8217;re in the final leg of development before the release of 2.7.  280 commits since beta 3 have polished the new admin UI (including new menu icons created by the winners of our icon design contest) and fixed all known blocker bugs.\nWe think RC1 is ready for everyone to try [...]\";s:7:\"content\";a:1:{s:7:\"encoded\";s:843:\"<p>With the release of RC1, we&#8217;re in the final leg of development before the release of 2.7.  <a href=\"http://trac.wordpress.org/timeline?from=12%2F01%2F08&amp;daysback=16&amp;changeset=on&amp;update=Update\">280 commits</a> since beta 3 have polished the new admin UI (including new menu icons created by the <a href=\"http://wordpress.org/development/2008/11/the-results-of-project-icon/\">winners of our icon design contest</a>) and fixed all known blocker bugs.</p>\n<p>We think RC1 is ready for everyone to try out.  Please <a href=\"http://wordpress.org/wordpress-2.7-RC1.zip\">download RC1</a> and help us make the final release the best it can be.  As always, <a href=\"http://codex.wordpress.org/WordPress_Backups\">back up your blog</a> before upgrading.</p>\n<p><a href=\"http://wordpress.org/wordpress-2.7-RC1.zip\">Get RC1</a>.</p>\n\";}s:3:\"wfw\";a:1:{s:10:\"commentrss\";s:79:\"http://wordpress.org/development/2008/12/wordpress-27-release-candidate-1/feed/\";}s:7:\"summary\";s:312:\"With the release of RC1, we&#8217;re in the final leg of development before the release of 2.7.  280 commits since beta 3 have polished the new admin UI (including new menu icons created by the winners of our icon design contest) and fixed all known blocker bugs.\nWe think RC1 is ready for everyone to try [...]\";s:12:\"atom_content\";s:843:\"<p>With the release of RC1, we&#8217;re in the final leg of development before the release of 2.7.  <a href=\"http://trac.wordpress.org/timeline?from=12%2F01%2F08&amp;daysback=16&amp;changeset=on&amp;update=Update\">280 commits</a> since beta 3 have polished the new admin UI (including new menu icons created by the <a href=\"http://wordpress.org/development/2008/11/the-results-of-project-icon/\">winners of our icon design contest</a>) and fixed all known blocker bugs.</p>\n<p>We think RC1 is ready for everyone to try out.  Please <a href=\"http://wordpress.org/wordpress-2.7-RC1.zip\">download RC1</a> and help us make the final release the best it can be.  As always, <a href=\"http://codex.wordpress.org/WordPress_Backups\">back up your blog</a> before upgrading.</p>\n<p><a href=\"http://wordpress.org/wordpress-2.7-RC1.zip\">Get RC1</a>.</p>\n\";}}s:7:\"channel\";a:8:{s:5:\"title\";s:26:\"WordPress Development Blog\";s:4:\"link\";s:32:\"http://wordpress.org/development\";s:11:\"description\";s:33:\"WordPress development and updates\";s:7:\"pubdate\";s:31:\"Thu, 12 Mar 2009 18:06:23 +0000\";s:9:\"generator\";s:41:\"http://wordpress.org/?v=2.8-bleeding-edge\";s:8:\"language\";s:2:\"en\";s:2:\"sy\";a:2:{s:12:\"updateperiod\";s:6:\"hourly\";s:15:\"updatefrequency\";s:1:\"1\";}s:7:\"tagline\";s:33:\"WordPress development and updates\";}s:9:\"textinput\";a:0:{}s:5:\"image\";a:0:{}s:9:\"feed_type\";s:3:\"RSS\";s:12:\"feed_version\";s:3:\"2.0\";s:5:\"stack\";a:0:{}s:9:\"inchannel\";b:0;s:6:\"initem\";b:0;s:9:\"incontent\";b:0;s:11:\"intextinput\";b:0;s:7:\"inimage\";b:0;s:13:\"current_field\";s:0:\"\";s:17:\"current_namespace\";b:0;s:19:\"_CONTENT_CONSTRUCTS\";a:6:{i:0;s:7:\"content\";i:1;s:7:\"summary\";i:2;s:4:\"info\";i:3;s:5:\"title\";i:4;s:7:\"tagline\";i:5;s:9:\"copyright\";}s:13:\"last_modified\";s:31:\"Thu, 12 Mar 2009 18:06:23 GMT\r\n\";s:4:\"etag\";s:36:\"\"91c656ac477271f4918187532321c7b5\"\r\n\";}','no'),(111,0,'rss_0ff4b43bd116a9d8720d689c80e7dfd4_ts','1237540698','no'),(112,0,'rss_57bc725ad6568758915363af670fd8bc','O:9:\"MagpieRSS\":19:{s:6:\"parser\";i:0;s:12:\"current_item\";a:0:{}s:5:\"items\";a:15:{i:0;a:7:{s:5:\"title\";s:28:\"miknight on \"Unit Converter\"\";s:4:\"link\";s:61:\"http://wordpress.org/extend/plugins/unit-converter/#post-9732\";s:7:\"pubdate\";s:31:\"Thu, 19 Mar 2009 09:49:39 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:8:\"miknight\";}s:4:\"guid\";s:41:\"9732@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:140:\"Detects units of measurement in your blog text and automatically displays the metric or imperial equivalent in one of several possible ways.\";s:7:\"summary\";s:140:\"Detects units of measurement in your blog text and automatically displays the metric or imperial equivalent in one of several possible ways.\";}i:1;a:7:{s:5:\"title\";s:29:\"nicmyers on \"Where I\'ve Been\"\";s:4:\"link\";s:61:\"http://wordpress.org/extend/plugins/where-ive-been/#post-9723\";s:7:\"pubdate\";s:31:\"Wed, 18 Mar 2009 22:36:59 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:8:\"nicmyers\";}s:4:\"guid\";s:41:\"9723@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:73:\"Where I\'ve Been embeds your whereivebeen.com maps on your Wordpress blog.\";s:7:\"summary\";s:73:\"Where I\'ve Been embeds your whereivebeen.com maps on your Wordpress blog.\";}i:2;a:7:{s:5:\"title\";s:41:\"anantgarg on \"Third Party Accounts Login\"\";s:4:\"link\";s:73:\"http://wordpress.org/extend/plugins/third-party-accounts-login/#post-9722\";s:7:\"pubdate\";s:31:\"Wed, 18 Mar 2009 20:49:23 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:9:\"anantgarg\";}s:4:\"guid\";s:41:\"9722@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:145:\"Enable your users to comment by entering their name/email/website details via well known OpenID service providers like Google, Yahoo, Flickr etc.\";s:7:\"summary\";s:145:\"Enable your users to comment by entering their name/email/website details via well known OpenID service providers like Google, Yahoo, Flickr etc.\";}i:3;a:7:{s:5:\"title\";s:32:\"ppalli on \"Add LightBox & Title\"\";s:4:\"link\";s:65:\"http://wordpress.org/extend/plugins/add-lightbox-title/#post-9721\";s:7:\"pubdate\";s:31:\"Wed, 18 Mar 2009 17:21:10 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:6:\"ppalli\";}s:4:\"guid\";s:41:\"9721@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:118:\"This plugin for WordPress automatically add the rel=&quot;lightbox[ID-OF-THE-POST]&quot; and recovers the image title.\";s:7:\"summary\";s:118:\"This plugin for WordPress automatically add the rel=&quot;lightbox[ID-OF-THE-POST]&quot; and recovers the image title.\";}i:4;a:7:{s:5:\"title\";s:26:\"webkoof on \"Indic Comment\"\";s:4:\"link\";s:58:\"http://wordpress.org/extend/plugins/indicomment/#post-9720\";s:7:\"pubdate\";s:31:\"Wed, 18 Mar 2009 16:59:22 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:7:\"webkoof\";}s:4:\"guid\";s:41:\"9720@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:150:\"Visitors  can write their comment in Indian languages. Vistor\'s write in Roman script and the plugin automatically converts it in corresponding Indian\";s:7:\"summary\";s:150:\"Visitors  can write their comment in Indian languages. Vistor\'s write in Roman script and the plugin automatically converts it in corresponding Indian\";}i:5;a:7:{s:5:\"title\";s:21:\"gwycon on \"Admin Log\"\";s:4:\"link\";s:56:\"http://wordpress.org/extend/plugins/admin-log/#post-9718\";s:7:\"pubdate\";s:31:\"Wed, 18 Mar 2009 11:56:42 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:6:\"gwycon\";}s:4:\"guid\";s:41:\"9718@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:147:\"Need to see who is accessing what in your admin section? This Plugin logs admin activity, and shows the page, user information, and time of access.\";s:7:\"summary\";s:147:\"Need to see who is accessing what in your admin section? This Plugin logs admin activity, and shows the page, user information, and time of access.\";}i:6;a:7:{s:5:\"title\";s:29:\"checkfront on \"Clean-Contact\"\";s:4:\"link\";s:60:\"http://wordpress.org/extend/plugins/clean-contact/#post-9715\";s:7:\"pubdate\";s:31:\"Wed, 18 Mar 2009 08:11:21 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:10:\"checkfront\";}s:4:\"guid\";s:41:\"9715@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:113:\"A Clean, no hassle contact form plugin for Wordpress, with advanced Spam protection that doesn\'t require Captcha.\";s:7:\"summary\";s:113:\"A Clean, no hassle contact form plugin for Wordpress, with advanced Spam protection that doesn\'t require Captcha.\";}i:7;a:7:{s:5:\"title\";s:41:\"brandondove on \"Geocache Stat Bar Widget\"\";s:4:\"link\";s:71:\"http://wordpress.org/extend/plugins/geocache-stat-bar-widget/#post-9714\";s:7:\"pubdate\";s:31:\"Wed, 18 Mar 2009 04:20:05 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:11:\"brandondove\";}s:4:\"guid\";s:41:\"9714@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:33:\"Official Geocache stat bar widget\";s:7:\"summary\";s:33:\"Official Geocache stat bar widget\";}i:8;a:7:{s:5:\"title\";s:51:\"petervanderdoes on \"AVH First Defense Against Spam\"\";s:4:\"link\";s:77:\"http://wordpress.org/extend/plugins/avh-first-defense-against-spam/#post-9713\";s:7:\"pubdate\";s:31:\"Wed, 18 Mar 2009 00:16:52 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:15:\"petervanderdoes\";}s:4:\"guid\";s:41:\"9713@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:111:\"The AVH First Defense Against Spam plugin gives you the ability to block spammers before any content is served.\";s:7:\"summary\";s:111:\"The AVH First Defense Against Spam plugin gives you the ability to block spammers before any content is served.\";}i:9;a:7:{s:5:\"title\";s:49:\"wilfahrt on \"JSXGraph - Graphics with JavaScript\"\";s:4:\"link\";s:55:\"http://wordpress.org/extend/plugins/jsxgraph/#post-9712\";s:7:\"pubdate\";s:31:\"Tue, 17 Mar 2009 20:16:33 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:8:\"wilfahrt\";}s:4:\"guid\";s:41:\"9712@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:107:\"Using the JSXGraph filter makes it a lot easier to embed JSXGraph constructions into wordpress pages/posts.\";s:7:\"summary\";s:107:\"Using the JSXGraph filter makes it a lot easier to embed JSXGraph constructions into wordpress pages/posts.\";}i:10;a:7:{s:5:\"title\";s:28:\"bravenewcode on \"Earth Hour\"\";s:4:\"link\";s:57:\"http://wordpress.org/extend/plugins/earth-hour/#post-9711\";s:7:\"pubdate\";s:31:\"Tue, 17 Mar 2009 19:35:58 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:12:\"bravenewcode\";}s:4:\"guid\";s:41:\"9711@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:143:\"Earth Hour is a WordPress plugin that will temporarily disable a blog during Earth Hour to show support for the initiative and the environment.\";s:7:\"summary\";s:143:\"Earth Hour is a WordPress plugin that will temporarily disable a blog during Earth Hour to show support for the initiative and the environment.\";}i:11;a:7:{s:5:\"title\";s:31:\"aviflombaum on \"Designer Pages\"\";s:4:\"link\";s:79:\"http://wordpress.org/extend/plugins/designer-pages-collection-widget/#post-9709\";s:7:\"pubdate\";s:31:\"Tue, 17 Mar 2009 19:03:53 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:11:\"aviflombaum\";}s:4:\"guid\";s:41:\"9709@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:124:\"Allows you to easily add a widget from a Designer Pages (http://www.designerpages.com) collection to your WordPress website.\";s:7:\"summary\";s:124:\"Allows you to easily add a widget from a Designer Pages (http://www.designerpages.com) collection to your WordPress website.\";}i:12;a:7:{s:5:\"title\";s:20:\"n0mad on \"WordCount\"\";s:4:\"link\";s:56:\"http://wordpress.org/extend/plugins/wordcount/#post-9707\";s:7:\"pubdate\";s:31:\"Tue, 17 Mar 2009 16:28:45 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:5:\"n0mad\";}s:4:\"guid\";s:41:\"9707@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:26:\"measure your reading speed\";s:7:\"summary\";s:26:\"measure your reading speed\";}i:13;a:7:{s:5:\"title\";s:32:\"maxpagels on \"Most Popular Tags\"\";s:4:\"link\";s:64:\"http://wordpress.org/extend/plugins/most-popular-tags/#post-9706\";s:7:\"pubdate\";s:31:\"Tue, 17 Mar 2009 15:43:29 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:9:\"maxpagels\";}s:4:\"guid\";s:41:\"9706@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:68:\"Most Popular Tags provides a widget for displaying popular post tags\";s:7:\"summary\";s:68:\"Most Popular Tags provides a widget for displaying popular post tags\";}i:14;a:7:{s:5:\"title\";s:47:\"dumbfounder on \"Searchles Related Posts Widget\"\";s:4:\"link\";s:70:\"http://wordpress.org/extend/plugins/searchles-related-posts/#post-9705\";s:7:\"pubdate\";s:31:\"Tue, 17 Mar 2009 15:40:53 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:11:\"dumbfounder\";}s:4:\"guid\";s:41:\"9705@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:89:\"Display contextually related posts from your blog using the Searchles Discovery Platform.\";s:7:\"summary\";s:89:\"Display contextually related posts from your blog using the Searchles Discovery Platform.\";}}s:7:\"channel\";a:6:{s:5:\"title\";s:6:\"Newest\";s:4:\"link\";s:36:\"http://wordpress.org/extend/plugins/\";s:11:\"description\";s:6:\"Newest\";s:8:\"language\";s:2:\"en\";s:7:\"pubdate\";s:31:\"Fri, 20 Mar 2009 09:18:18 +0000\";s:7:\"tagline\";s:6:\"Newest\";}s:9:\"textinput\";a:0:{}s:5:\"image\";a:0:{}s:9:\"feed_type\";s:3:\"RSS\";s:12:\"feed_version\";s:3:\"2.0\";s:5:\"stack\";a:0:{}s:9:\"inchannel\";b:0;s:6:\"initem\";b:0;s:9:\"incontent\";b:0;s:11:\"intextinput\";b:0;s:7:\"inimage\";b:0;s:13:\"current_field\";s:0:\"\";s:17:\"current_namespace\";b:0;s:19:\"_CONTENT_CONSTRUCTS\";a:6:{i:0;s:7:\"content\";i:1;s:7:\"summary\";i:2;s:4:\"info\";i:3;s:5:\"title\";i:4;s:7:\"tagline\";i:5;s:9:\"copyright\";}s:13:\"last_modified\";s:21:\"2009-03-19 09:49:39\r\n\";s:4:\"etag\";s:36:\"\"d664c80cc3c1b607d723b357f23f1950\"\r\n\";}','no'),(113,0,'rss_57bc725ad6568758915363af670fd8bc_ts','1237540698','no'),(114,0,'rss_1a5f760f2e2b48827d4974a60857e7c2','O:9:\"MagpieRSS\":19:{s:6:\"parser\";i:0;s:12:\"current_item\";a:0:{}s:5:\"items\";a:15:{i:0;a:7:{s:5:\"title\";s:49:\"wilfahrt on \"JSXGraph - Graphics with JavaScript\"\";s:4:\"link\";s:55:\"http://wordpress.org/extend/plugins/jsxgraph/#post-9712\";s:7:\"pubdate\";s:31:\"Tue, 17 Mar 2009 20:16:33 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:8:\"wilfahrt\";}s:4:\"guid\";s:41:\"9712@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:107:\"Using the JSXGraph filter makes it a lot easier to embed JSXGraph constructions into wordpress pages/posts.\";s:7:\"summary\";s:107:\"Using the JSXGraph filter makes it a lot easier to embed JSXGraph constructions into wordpress pages/posts.\";}i:1;a:7:{s:5:\"title\";s:20:\"bingu on \"replyMail\"\";s:4:\"link\";s:56:\"http://wordpress.org/extend/plugins/replymail/#post-8371\";s:7:\"pubdate\";s:31:\"Sun, 04 Jan 2009 17:45:18 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:5:\"bingu\";}s:4:\"guid\";s:41:\"8371@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:111:\"Enhance the threaded comments system of WordPress 2.7.\nWhen someone reply to your comment, send a email to you.\";s:7:\"summary\";s:111:\"Enhance the threaded comments system of WordPress 2.7.\nWhen someone reply to your comment, send a email to you.\";}i:2;a:7:{s:5:\"title\";s:31:\"jfarthing84 on \"Theme My Login\"\";s:4:\"link\";s:61:\"http://wordpress.org/extend/plugins/theme-my-login/#post-9627\";s:7:\"pubdate\";s:31:\"Fri, 13 Mar 2009 02:30:52 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:11:\"jfarthing84\";}s:4:\"guid\";s:41:\"9627@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:122:\"This plugin themes the WordPress login, register, forgot password and profile pages to look like the rest of your website.\";s:7:\"summary\";s:122:\"This plugin themes the WordPress login, register, forgot password and profile pages to look like the rest of your website.\";}i:3;a:7:{s:5:\"title\";s:74:\"amummey on \"cSprites - Speed Up Page Load Time with Dynamic Image Sprites\"\";s:4:\"link\";s:69:\"http://wordpress.org/extend/plugins/csprites-for-wordpress/#post-9388\";s:7:\"pubdate\";s:31:\"Sun, 01 Mar 2009 09:48:40 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:7:\"amummey\";}s:4:\"guid\";s:41:\"9388@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:145:\"Automatically compress your images into a big sprite, decreasing web page load time. SEO features automatically generate rich ALT and TITLE tags.\";s:7:\"summary\";s:145:\"Automatically compress your images into a big sprite, decreasing web page load time. SEO features automatically generate rich ALT and TITLE tags.\";}i:4;a:7:{s:5:\"title\";s:39:\"tadhg on \"Related Posts by Tags Widget\"\";s:4:\"link\";s:68:\"http://wordpress.org/extend/plugins/related-posts-by-tags/#post-9181\";s:7:\"pubdate\";s:31:\"Wed, 18 Feb 2009 01:55:32 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:5:\"tadhg\";}s:4:\"guid\";s:41:\"9181@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:99:\"Provides a sidebar widget containing links to posts with a similar set of tags to the current post.\";s:7:\"summary\";s:99:\"Provides a sidebar widget containing links to posts with a similar set of tags to the current post.\";}i:5;a:7:{s:5:\"title\";s:33:\"misiek303 on \"Misiek Photo Album\"\";s:4:\"link\";s:65:\"http://wordpress.org/extend/plugins/misiek-photo-album/#post-9615\";s:7:\"pubdate\";s:31:\"Thu, 12 Mar 2009 01:19:04 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:9:\"misiek303\";}s:4:\"guid\";s:41:\"9615@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:91:\"Plugin allows you to add photo albums to your site using media library from your wordpress.\";s:7:\"summary\";s:91:\"Plugin allows you to add photo albums to your site using media library from your wordpress.\";}i:6;a:7:{s:5:\"title\";s:27:\"ilovecolors on \"ILC FLVBox\"\";s:4:\"link\";s:57:\"http://wordpress.org/extend/plugins/ilc-flvbox/#post-8692\";s:7:\"pubdate\";s:31:\"Wed, 21 Jan 2009 05:32:29 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:11:\"ilovecolors\";}s:4:\"guid\";s:41:\"8692@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:55:\"Plays FLV video inline in content or in a modal dialog.\";s:7:\"summary\";s:55:\"Plays FLV video inline in content or in a modal dialog.\";}i:7;a:7:{s:5:\"title\";s:30:\"rhalpha on \"infolinks Ad Wrap\"\";s:4:\"link\";s:64:\"http://wordpress.org/extend/plugins/infolinks-ad-wrap/#post-9648\";s:7:\"pubdate\";s:31:\"Fri, 13 Mar 2009 20:50:20 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:7:\"rhalpha\";}s:4:\"guid\";s:41:\"9648@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:72:\"Simple plugin to wrap infolinks zone tags around content and/or comments\";s:7:\"summary\";s:72:\"Simple plugin to wrap infolinks zone tags around content and/or comments\";}i:8;a:7:{s:5:\"title\";s:28:\"bravenewcode on \"Earth Hour\"\";s:4:\"link\";s:57:\"http://wordpress.org/extend/plugins/earth-hour/#post-9711\";s:7:\"pubdate\";s:31:\"Tue, 17 Mar 2009 19:35:58 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:12:\"bravenewcode\";}s:4:\"guid\";s:41:\"9711@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:143:\"Earth Hour is a WordPress plugin that will temporarily disable a blog during Earth Hour to show support for the initiative and the environment.\";s:7:\"summary\";s:143:\"Earth Hour is a WordPress plugin that will temporarily disable a blog during Earth Hour to show support for the initiative and the environment.\";}i:9;a:7:{s:5:\"title\";s:24:\"benmillett on \"VimeoRSS\"\";s:4:\"link\";s:55:\"http://wordpress.org/extend/plugins/vimeorss/#post-4833\";s:7:\"pubdate\";s:31:\"Thu, 13 Mar 2008 18:07:42 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:10:\"benmillett\";}s:4:\"guid\";s:41:\"4833@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:116:\"A non-JavaScript badge generator for videos in one\'s vimeo account.  This behaves similarly to the flickrrss plugin.\";s:7:\"summary\";s:116:\"A non-JavaScript badge generator for videos in one\'s vimeo account.  This behaves similarly to the flickrrss plugin.\";}i:10;a:7:{s:5:\"title\";s:21:\"Caspie on \"Fast Tube\"\";s:4:\"link\";s:56:\"http://wordpress.org/extend/plugins/fast-tube/#post-9203\";s:7:\"pubdate\";s:31:\"Thu, 19 Feb 2009 11:26:16 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:6:\"Caspie\";}s:4:\"guid\";s:41:\"9203@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:94:\"Fast and easy way to insert videos from YouTube right into your WordPress blog posts or pages.\";s:7:\"summary\";s:94:\"Fast and easy way to insert videos from YouTube right into your WordPress blog posts or pages.\";}i:11;a:7:{s:5:\"title\";s:20:\"mjgiarlo on \"OpenID\"\";s:4:\"link\";s:52:\"http://wordpress.org/extend/plugins/openid/#post-210\";s:7:\"pubdate\";s:31:\"Fri, 09 Mar 2007 22:53:08 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:8:\"mjgiarlo\";}s:4:\"guid\";s:40:\"210@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:90:\"Allows WordPress to provide and consumer OpenIDs for authentication of users and comments.\";s:7:\"summary\";s:90:\"Allows WordPress to provide and consumer OpenIDs for authentication of users and comments.\";}i:12;a:7:{s:5:\"title\";s:35:\"jczorkmid on \"Use Google Libraries\"\";s:4:\"link\";s:67:\"http://wordpress.org/extend/plugins/use-google-libraries/#post-7817\";s:7:\"pubdate\";s:31:\"Mon, 24 Nov 2008 13:13:13 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:9:\"jczorkmid\";}s:4:\"guid\";s:41:\"7817@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:127:\"Allows your site to use common javascript libraries from Google\'s AJAX \nLibraries CDN, rather than from Wordpress\'s own copies.\";s:7:\"summary\";s:127:\"Allows your site to use common javascript libraries from Google\'s AJAX \nLibraries CDN, rather than from Wordpress\'s own copies.\";}i:13;a:7:{s:5:\"title\";s:35:\"ydubois on \"YD Recent Posts Widget\"\";s:4:\"link\";s:69:\"http://wordpress.org/extend/plugins/yd-recent-posts-widget/#post-9534\";s:7:\"pubdate\";s:31:\"Sun, 08 Mar 2009 17:46:46 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:7:\"ydubois\";}s:4:\"guid\";s:41:\"9534@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:118:\"This Wordpress plugin installs a new sidebar widget that can display the recent posts with automatic thumbnail images.\";s:7:\"summary\";s:118:\"This Wordpress plugin installs a new sidebar widget that can display the recent posts with automatic thumbnail images.\";}i:14;a:7:{s:5:\"title\";s:25:\"mcosx on \"One Word A Day\"\";s:4:\"link\";s:61:\"http://wordpress.org/extend/plugins/one-word-a-day/#post-9684\";s:7:\"pubdate\";s:31:\"Mon, 16 Mar 2009 10:16:11 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:5:\"mcosx\";}s:4:\"guid\";s:41:\"9684@http://wordpress.org/extend/plugins/\";s:11:\"description\";s:66:\"Displays a new English word every day with a multiple choice quiz.\";s:7:\"summary\";s:66:\"Displays a new English word every day with a multiple choice quiz.\";}}s:7:\"channel\";a:6:{s:5:\"title\";s:16:\"Recently Updated\";s:4:\"link\";s:36:\"http://wordpress.org/extend/plugins/\";s:11:\"description\";s:16:\"Recently Updated\";s:8:\"language\";s:2:\"en\";s:7:\"pubdate\";s:31:\"Fri, 20 Mar 2009 09:18:18 +0000\";s:7:\"tagline\";s:16:\"Recently Updated\";}s:9:\"textinput\";a:0:{}s:5:\"image\";a:0:{}s:9:\"feed_type\";s:3:\"RSS\";s:12:\"feed_version\";s:3:\"2.0\";s:5:\"stack\";a:0:{}s:9:\"inchannel\";b:0;s:6:\"initem\";b:0;s:9:\"incontent\";b:0;s:11:\"intextinput\";b:0;s:7:\"inimage\";b:0;s:13:\"current_field\";s:0:\"\";s:17:\"current_namespace\";b:0;s:19:\"_CONTENT_CONSTRUCTS\";a:6:{i:0;s:7:\"content\";i:1;s:7:\"summary\";i:2;s:4:\"info\";i:3;s:5:\"title\";i:4;s:7:\"tagline\";i:5;s:9:\"copyright\";}s:13:\"last_modified\";s:21:\"2009-03-17 20:16:33\r\n\";s:4:\"etag\";s:36:\"\"029d7cd65464e923a9f2c293a301e9e7\"\r\n\";}','no'),(115,0,'rss_1a5f760f2e2b48827d4974a60857e7c2_ts','1237540698','no'),(345,0,'category_children','a:5:{i:4;a:4:{i:0;s:2:\"26\";i:1;s:2:\"25\";i:2;s:2:\"22\";i:3;s:2:\"24\";}i:14;a:7:{i:0;s:2:\"19\";i:1;s:1:\"5\";i:2;s:2:\"17\";i:3;s:2:\"18\";i:4;s:2:\"28\";i:5;s:2:\"23\";i:6;s:2:\"27\";}i:12;a:7:{i:0;s:2:\"10\";i:1;s:1:\"8\";i:2;s:1:\"3\";i:3;s:2:\"11\";i:4;s:1:\"6\";i:5;s:1:\"9\";i:6;s:1:\"7\";}i:29;a:1:{i:0;s:2:\"30\";}i:13;a:3:{i:0;s:2:\"20\";i:1;s:2:\"21\";i:2;s:2:\"15\";}}','yes'),(120,0,'remedy_slide_category','Featured','yes'),(121,0,'remedy_slide_count','12','yes'),(122,0,'remedy_feat_category','Featured','yes'),(116,0,'rss_867bd5c64f85878d03a060509cd2f92c','O:9:\"MagpieRSS\":19:{s:6:\"parser\";i:0;s:12:\"current_item\";a:0:{}s:5:\"items\";a:50:{i:0;a:7:{s:5:\"title\";s:43:\"Weblog Tools Collection: IE 8 and WordPress\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5389\";s:4:\"link\";s:72:\"http://weblogtoolscollection.com/archives/2009/03/19/ie-8-and-wordpress/\";s:11:\"description\";s:880:\"<p>So on the day of the <a href=\"http://www.microsoft.com/presspass/press/2009/mar09/03-18IE8AvailablePR.mspx\">release of the much [add verb of choice here] Internet Explorer 8</a>, we would like to know what happens to your WordPress blog in IE 8.</p>\n<p>Does anything look different? Does anything work? How about the Dashboard or the <a href=\"http://cmscritic.com/wordpress-users-may-want-to-avoid-microsofts-new-internet-explorer-8\">admin interface</a>? Did you find any problems? Are you tearing your hair out or are you grinning from ear to ear? Would you suggest that everyone upgrade or would you suggest that we stay away?</p>\n<p>This is one of those times that I wish we allowed the posting of screenshots along with the comments on this blog but links to screenshots would be much appreciated. Anyone know of a plugin that allows posting of screenshots in comments?</p>\";s:7:\"pubdate\";s:31:\"Thu, 19 Mar 2009 19:53:05 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:10:\"Mark Ghosh\";}s:7:\"summary\";s:880:\"<p>So on the day of the <a href=\"http://www.microsoft.com/presspass/press/2009/mar09/03-18IE8AvailablePR.mspx\">release of the much [add verb of choice here] Internet Explorer 8</a>, we would like to know what happens to your WordPress blog in IE 8.</p>\n<p>Does anything look different? Does anything work? How about the Dashboard or the <a href=\"http://cmscritic.com/wordpress-users-may-want-to-avoid-microsofts-new-internet-explorer-8\">admin interface</a>? Did you find any problems? Are you tearing your hair out or are you grinning from ear to ear? Would you suggest that everyone upgrade or would you suggest that we stay away?</p>\n<p>This is one of those times that I wish we allowed the posting of screenshots along with the comments on this blog but links to screenshots would be much appreciated. Anyone know of a plugin that allows posting of screenshots in comments?</p>\";}i:1;a:7:{s:5:\"title\";s:67:\"Weblog Tools Collection: WordPress for iPhone Version 1.2 Available\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5358\";s:4:\"link\";s:95:\"http://weblogtoolscollection.com/archives/2009/03/19/wordpress-for-iphone-version-12-available/\";s:11:\"description\";s:4811:\"<p>The new version of WordPress for iPhone (and iPod touch) app is now live and available for download in the iTunes App store.  This version has a lot of fixes/enhancements that many people (including me) have been waiting for.  I&#8217;ve been playing around with version 1.2 for a little bit and here are some of my first impressions.</p>\n<h3>New Features (and Some Comments)</h3>\n<ul>\n<li><strong>Landscape mode with extra wide keyboard</strong><br />\n<img class=\"alignnone size-full wp-image-5370\" title=\"WordPress for iPhone Landscape Keyboard\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/wp_iphone_landscape_keyboard.jpg\" alt=\"WordPress for iPhone Landscape Keyboard\" width=\"320\" height=\"213\" /><br />\nThis is probably the most desired feature for this application simply because it is physically painful to type a full length blog post in the iPhone portrait keyboard.  I am glad that the portrait keyboard restriction is now a thing of the past!</li>\n<li><strong>Link creation help</strong><br />\n<img class=\"alignnone size-full wp-image-5371\" title=\"WordPress for iPhone Link Create 1st Dialog\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/wp_iphone_link_create_1.jpg\" alt=\"wp_iphone_link_create_1\" width=\"320\" height=\"213\" /><br />\n<img class=\"alignnone size-full wp-image-5372\" title=\"WordPress for iPhone Link Create 2nd Dialog\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/wp_iphone_link_create_2.jpg\" alt=\"WordPress for iPhone Link Create 2nd Dialog\" width=\"320\" height=\"213\" /><br />\nI wasn&#8217;t sure where this feature was hiding at first, but I soon found the trick to invoking this feature.  Basically anytime you are writing, you can type something that resembles a link (for example &#8220;www.&#8221; or &#8220;http&#8221;) to invoke a little prompt that asks you if you want to create a link.  Answering yes will bring up another prompt asking you to fill in the URL.  I think this is slick interface although some people might find it a bit annoying.  It would be nice to merge these two dialogs into one dialog and also have the option to turn this feature off.</li>\n<li><strong>Support for editing and creating pages</strong><br />\n<img class=\"alignnone size-full wp-image-5373\" title=\"WordPress for iPhone Pages Support\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/wp_iphone_pages.jpg\" alt=\"WordPress for iPhone Pages Support\" width=\"320\" height=\"213\" /><br />\nThere&#8217;s not much to say here.  Previously you weren&#8217;t able to create/edit pages.  Now you can.  Note that this feature is only available for WordPress.org 2.7+ or WordPress.com blogs.</li>\n<li><strong>Comment moderation</strong><br />\n<img src=\"http://weblogtoolscollection.com/b2-img/2009/03/wp_iphone_comments1.jpg\" alt=\"WordPress for iPhone Comments Moderation\" title=\"WordPress for iPhone Comments Moderation\" width=\"320\" height=\"213\" class=\"alignnone size-full wp-image-5387\" /><br />\nThis is one of my other favorite enhancements because I usually spend more time moderating comments than writing blog posts.  To be able to do this on-the-go without having to continually login and deal with browser cookies is quite convenient.  Note that this feature is only available for WordPress.org 2.7+ or WordPress.com blogs.</li>\n<li><strong>Asynchronous publishing</strong><br />\nThere weren&#8217;t any visible changes for this feature, but I assume asynchronous is better than what was in the earlier version.</li>\n<li><strong>Photo resizing options</strong><br />\n<img class=\"alignnone size-full wp-image-5375\" title=\"WordPress for iPhone Photo Resize\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/wp_iphone_photo_resize.jpg\" alt=\"WordPress for iPhone Photo Resize\" width=\"320\" height=\"213\" /><br />\nWhen this feature is enabled, all photos attached to the post will be resized to be no larger than 640&#215;480 to save space and publishing time.  It&#8217;s a nice feature to have, but I don&#8217;t think I will be using it personally.</li>\n</ul>\n<h3>Bug in Version 1.2</h3>\n<p>I know that you are thinking, &#8220;already?&#8221; right?  Indeed, the WordPress for iPhone App team has confirmed the <a href=\"http://iphone.wordpress.org/2009/03/19/heads-up-photo-bug-in-version-12/\">existence of a photo bug in this version</a>.  They are assuring us that the fix will be pushed out as soon as possible.  It&#8217;s best for you to wait on the upgrade if you post photos with the WordPress for iPhone application.  If not, then you should definitely upgrade and enjoy these great new features!</p>\n<h3>Go grab it!</h3>\n<p>You can get the WordPress for iPhone (and iPod touch) app for free at the <a title=\"WordPress for iPhone iTunes App Store\" href=\"http://itunes.apple.com/WebObjects/MZStore.woa/wa/viewSoftware?id=285073074&amp;mt=8\">iTunes App store</a>.</p>\";s:7:\"pubdate\";s:31:\"Thu, 19 Mar 2009 11:33:32 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:14:\"Thaya Kareeson\";}s:7:\"summary\";s:4811:\"<p>The new version of WordPress for iPhone (and iPod touch) app is now live and available for download in the iTunes App store.  This version has a lot of fixes/enhancements that many people (including me) have been waiting for.  I&#8217;ve been playing around with version 1.2 for a little bit and here are some of my first impressions.</p>\n<h3>New Features (and Some Comments)</h3>\n<ul>\n<li><strong>Landscape mode with extra wide keyboard</strong><br />\n<img class=\"alignnone size-full wp-image-5370\" title=\"WordPress for iPhone Landscape Keyboard\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/wp_iphone_landscape_keyboard.jpg\" alt=\"WordPress for iPhone Landscape Keyboard\" width=\"320\" height=\"213\" /><br />\nThis is probably the most desired feature for this application simply because it is physically painful to type a full length blog post in the iPhone portrait keyboard.  I am glad that the portrait keyboard restriction is now a thing of the past!</li>\n<li><strong>Link creation help</strong><br />\n<img class=\"alignnone size-full wp-image-5371\" title=\"WordPress for iPhone Link Create 1st Dialog\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/wp_iphone_link_create_1.jpg\" alt=\"wp_iphone_link_create_1\" width=\"320\" height=\"213\" /><br />\n<img class=\"alignnone size-full wp-image-5372\" title=\"WordPress for iPhone Link Create 2nd Dialog\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/wp_iphone_link_create_2.jpg\" alt=\"WordPress for iPhone Link Create 2nd Dialog\" width=\"320\" height=\"213\" /><br />\nI wasn&#8217;t sure where this feature was hiding at first, but I soon found the trick to invoking this feature.  Basically anytime you are writing, you can type something that resembles a link (for example &#8220;www.&#8221; or &#8220;http&#8221;) to invoke a little prompt that asks you if you want to create a link.  Answering yes will bring up another prompt asking you to fill in the URL.  I think this is slick interface although some people might find it a bit annoying.  It would be nice to merge these two dialogs into one dialog and also have the option to turn this feature off.</li>\n<li><strong>Support for editing and creating pages</strong><br />\n<img class=\"alignnone size-full wp-image-5373\" title=\"WordPress for iPhone Pages Support\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/wp_iphone_pages.jpg\" alt=\"WordPress for iPhone Pages Support\" width=\"320\" height=\"213\" /><br />\nThere&#8217;s not much to say here.  Previously you weren&#8217;t able to create/edit pages.  Now you can.  Note that this feature is only available for WordPress.org 2.7+ or WordPress.com blogs.</li>\n<li><strong>Comment moderation</strong><br />\n<img src=\"http://weblogtoolscollection.com/b2-img/2009/03/wp_iphone_comments1.jpg\" alt=\"WordPress for iPhone Comments Moderation\" title=\"WordPress for iPhone Comments Moderation\" width=\"320\" height=\"213\" class=\"alignnone size-full wp-image-5387\" /><br />\nThis is one of my other favorite enhancements because I usually spend more time moderating comments than writing blog posts.  To be able to do this on-the-go without having to continually login and deal with browser cookies is quite convenient.  Note that this feature is only available for WordPress.org 2.7+ or WordPress.com blogs.</li>\n<li><strong>Asynchronous publishing</strong><br />\nThere weren&#8217;t any visible changes for this feature, but I assume asynchronous is better than what was in the earlier version.</li>\n<li><strong>Photo resizing options</strong><br />\n<img class=\"alignnone size-full wp-image-5375\" title=\"WordPress for iPhone Photo Resize\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/wp_iphone_photo_resize.jpg\" alt=\"WordPress for iPhone Photo Resize\" width=\"320\" height=\"213\" /><br />\nWhen this feature is enabled, all photos attached to the post will be resized to be no larger than 640&#215;480 to save space and publishing time.  It&#8217;s a nice feature to have, but I don&#8217;t think I will be using it personally.</li>\n</ul>\n<h3>Bug in Version 1.2</h3>\n<p>I know that you are thinking, &#8220;already?&#8221; right?  Indeed, the WordPress for iPhone App team has confirmed the <a href=\"http://iphone.wordpress.org/2009/03/19/heads-up-photo-bug-in-version-12/\">existence of a photo bug in this version</a>.  They are assuring us that the fix will be pushed out as soon as possible.  It&#8217;s best for you to wait on the upgrade if you post photos with the WordPress for iPhone application.  If not, then you should definitely upgrade and enjoy these great new features!</p>\n<h3>Go grab it!</h3>\n<p>You can get the WordPress for iPhone (and iPod touch) app for free at the <a title=\"WordPress for iPhone iTunes App Store\" href=\"http://itunes.apple.com/WebObjects/MZStore.woa/wa/viewSoftware?id=285073074&amp;mt=8\">iTunes App store</a>.</p>\";}i:2;a:7:{s:5:\"title\";s:119:\"Lorelle on WP: WordPress News Report: iPhone, Widgets API, WordCamps in Hong Kong and China, International WordPress.tv\";s:4:\"guid\";s:36:\"http://lorelle.wordpress.com/?p=3987\";s:4:\"link\";s:140:\"http://lorelle.wordpress.com/2009/03/19/wordpress-news-report-iphone-widgets-api-wordcamps-in-hong-kong-and-china-international-wordpresstv/\";s:11:\"description\";s:21301:\"<div class=\"snap_preview\"><br /><p><a href=\"http://lorelle.wordpress.com/tag/wordpress-news/\" title=\"WordPress News\"><img src=\"http://lorelle.files.wordpress.com/2007/01/wpnews1.png\" alt=\"WordPress News\" align=\"right\" /></a>This week&#8217;s <a href=\"http://www.blogherald.com/tag/wordpress-news/\" title=\"Articles on WordPress News on the Blog Herald\" rel=\"tag\">Blog Herald WordPress News</a> is <a href=\"http://www.blogherald.com/2009/03/19/wordpress-news-iphones-up-wordpress-widgets-api-28-delayed-international-wordpresstv-and-more/\" title=\"WordPress News: iPhones Up, WordPress Widgets API, 2.8 Delayed, International WordPress.tv, and More\">WordPress News: iPhones Up, WordPress Widgets API, 2.8 Delayed, International WordPress.tv, and More</a>, and I&#8217;ve covered a lot of WordPress news you can use:</p>\n<blockquote><p>iPhone for WordPress is in the iTunes store. WordPress Widgets will use new Widgets API as of WordPress 2.8. Security authentication will improve with OAuth in future versions. WordPress 2.8 delayed. WordCamps in Hong Kong and China coming up. International languages embraced on WordPress.tv. And more WordPress news, tips, resources, and help.</p></blockquote>\n<p>If you missed last week&#8217;s edition on the Blog Herald, it was <a href=\"http://www.blogherald.com/2009/03/12/wordpress-news-plugins-reach-milestone-new-wordpress-community-project-help-to-search-for-wordpress-help/\" title=\"WordPress News: Plugins Reach Milestone, New WordPress Community Project, Help to Search for WordPress Help\">WordPress News: Plugins Reach Milestone, New WordPress Community Project, Help to Search for WordPress Help</a>. </p>\n<p>I am working with the editor of the <a href=\"http://www.blogherald.com/\" title=\"Blog Herald\" rel=\"tag\">Blog Herald</a> to change the look and style of the <a href=\"http://www.blogherald.com/tag/wordpress-news/\" title=\"Articles on WordPress News on the Blog Herald\" rel=\"tag\">Blog Herald WordPress News</a>. I&#8217;d love your input here or on the <a href=\"http://www.blogherald.com/2009/03/10/changing-the-blog-herald-wordpress-news-your-help-needed/\" title=\"Changing the Blog Herald WordPress News: Your Help Needed\">announcement regarding potential changes and input</a>. The Blog Herald WordPress News is designed to meet the needs of the WordPress Community, so help us help you blog better with WordPress. </p>\n<p>Here are some highlights for this week you do not want to miss, followed by <a href=\"http://lorelle.wordpress.com/tag/wordpress-news/feed/#wpevents\" title=\"WordPress Events\">WordPress Events, WordCamps, and Meetups</a> coming soon.<span id=\"more-3987\"></span></p>\n<h4>iPhone for WordPress</h4>\n<p>The <a href=\"http://iphone.wordpress.org/2009/03/18/version-12-live-in-itunes-app-store/\" title=\"Version 1.2 Live in iTunes App Store\">iPhone for WordPress Version 1.2</a> is now in the iTunes App Store, ready for you to <a href=\"http://itunes.apple.com/WebObjects/MZStore.woa/wa/viewSoftware?id=285073074&amp;mt=8\" title=\"download iPhone for WordPress\">blog and track comments on your iPhone</a>.</p>\n<h4>WordPress 2.8 News</h4>\n<p>The <a href=\"http://wpdevel.wordpress.com/2009/03/13/28-will-land-some-time-in-april-peopl/\" title=\"2.8 will land some time in April. Peopl …\">WordPress Development team has confirmed</a> that WordPress 2.8 will be released in April, pushing back the release date a few weeks in order to take a little more time with improving the underlying code, incorporating the new Widgets API, and improvements for managing JavaScripts, Plugins, AJAX, and more. </p>\n<p>There is a list of <a href=\"http://codex.wordpress.org/Version_2.8\" title=\"WordPress 2.8 in the Codex\">features, changes, and improvements in the WordPress Codex</a>.</p>\n<p>A new <a href=\"http://core.trac.wordpress.org/ticket/8441\" title=\"new widgets API\">WordPress Widgets API</a> in in development for WordPress 2.8. Based upon MultiWidget Class, it will handle all the multi-widget functions and hooks to implement a multi-widget Plugin, giving developers an easier process to extend their WordPress Plugins with Widget functionality. </p>\n<p><a href=\"http://wpdevel.wordpress.com/2009/03/18/converting-default-widgets-to-the-new-wi/\" title=\"Converting default widgets to the new widgets api\">The WordPress Development team has announced</a> that they are converting all default WordPress Widgets to work with the new Widgets API. If you are a WordPress Plugin author with a Widget-enabled Plugin, or you want to expand the flexibility of your Plugin for WordPress 2.8, check this out. </p>\n<p><a href=\"http://lesterchan.net/wordpress/2009/03/17/new-wp_widget-class-in-wordpress-28/\" title=\"New WP_Widget Class In WordPress 2.8\">Lester Chan covers the new WP_Widget Class</a> in WordPress 2.8 in greater detail to help Plugin authors understand how it works and how it can help them.</p>\n<p>There will be a lot of changes under the hood, but not so much on the surface in WordPress 2.8. If you are working with WordPress Themes, Plugins, or development, articles on WordPress 2.8 news you should be aware of include: </p>\n<ul>\n<li><a href=\"http://wpdevel.wordpress.com/2008/12/27/optimizing-script-loading/\" title=\"Optimizing script loading\">Optimizing Script Loading</a></li>\n<li><a href=\"http://wpdevel.wordpress.com/2009/01/07/optimizing-script-loading-part-2/\" title=\"Optimizing script loading part 2\">Optimizing script loading part 2</a></li>\n<li><a href=\"http://wpdevel.wordpress.com/2009/01/15/optimizing-script-loading-implementation/\" title=\"Optimizing script loading, implementation\">Optimizing script loading, implementation</a></li>\n<li><a href=\"http://lesterchan.net/wordpress/2009/01/15/javascript-in-my-plugins/\" title=\"JavaScript In My Plugins\">Preparing for WordPress 2.8: Using JavaScript in WordPress Plugins</a></li>\n<li><a href=\"http://wpengineer.com/change-your-wordpress-theme-on/\" title=\"Change your WordPress Theme on …\">Change your WordPress Theme on …</a></li>\n<li><a href=\"http://wpengineer.com/wordpress-28-body_class-automatic_feed_links/\" title=\"WordPress 2.8 body_class, automatic_feed_links\">WordPress 2.8 body_class, automatic_feed_links</a></li>\n<li><a href=\"http://www.wp-fun.co.uk/2009/02/09/what-a-body/\" title=\"What a body!\">What a body!</a></li>\n</ul>\n<p><a href=\"http://willnorris.com/2009/03/authentication-in-wordpress-28\" title=\"Will Norris: Authentication in WordPress 2.8\">Will Norris wrote about &#8220;Authentication in WordPress 2.8</a>&#8221; as part of his ongoing project for the <a href=\"http://wordpress.org/extend/plugins/openid/\" title=\"OpenID plugin\">OpenID WordPress Plugin</a>. Working with <a href=\"http://peter.westwood.name/\" title=\"Peter Westwood\">Peter Westwood</a>, WordPress 2.8 now includes a new filter for authentication that passes through three paramters, along with the username and password. According to <a href=\"http://ma.tt/\" title=\"Matt Mullenweg\" rel=\"tag\">Matt Mullenweg</a>, right now, the OAuth for WordPress will be a WordPress Plugin, with hopes of integrating it into the core in the future. </p>\n<h4>WordPress.tv Goes International and Offers Insider News</h4>\n<p><a href=\"http://wordpress.tv/\" title=\"WordPress.tv\" rel=\"tag\">WordPress.tv</a> has now <a href=\"http://blog.wordpress.tv/2009/03/18/wordpresstv-the-shape-of-things-to-come-blow-by-blow/\" title=\"WordPress.tv: the shape of things to come, blow-by-blow\">launched</a> the <a href=\"http://dev.wordpress.tv/\" title=\"Making WordPress.tv\">Making WordPress.tv</a> development blog run on the new <a href=\"http://en.blog.wordpress.com/2009/03/11/p2-the-new-prologue/\" title=\"freshly launched P2 theme,\">P2 WordPress Theme</a> for those who want to keep up with what is going on with the new video service for the WordPress Community. </p>\n<p>The first goal for improving the new WordPress.tv is to improve the localization, the ability to understand the videos in your language. Michael Pick is working on <a href=\"http://blog.wordpress.tv/2009/03/17/wordpresstv-in-your-language/\" title=\"WordPress.tv - in your language\">adding language filtering</a> to help with the translation of videos into other languages. You can now filter the videos by language preference, too. </p>\n<p>If you would like to help, let them know. </p>\n<h4>WordPress Tips and Plugins on Twitter</h4>\n<p>I&#8217;ve started sharing WordPress Tips and Plugin suggestions I&#8217;ve collected over the past couple years on Twitter at <a href=\"http://twitter.com/lorelleonwp/\" title=\"Lorelle on WordPress Twitter\">@lorelleonwp</a>. </p>\n<p>I post one WordPress tip and one WordPress Plugin link every morning (PST) covering recent versions of WordPress and WordPress usages and features. </p>\n<p>Thanks and credit for making this happen goes to <a href=\"http://www.tweetlater.com/\" title=\"TweetLater\">TweetLater</a>, a future Twitter posting and management system I <a href=\"http://www.blogherald.com/2009/03/03/exploring-social-media-future-tweets-with-tweetlater/\" title=\"Exploring Social Media: Future Tweets with TweetLater\">reviewed recently</a>.</p>\n<p><a name=\"wpevents\">&nbsp;</a></p>\n<h3>WordPress Events and WordCamps</h3>\n<p>Upcoming WordCamps and WordPress events include:</p>\n<p><strong>March 2009</strong></p>\n<ul>\n<li><a href=\"http://upcoming.yahoo.com/event/2126113/\" title=\"Mar 18, 2009: Utah WordPress Meetup at Spurlock House\">Utah WordPress Meetup - March 18, 2009</a></li>\n<li><a href=\"http://www.meetup.com/LasVegasWordPress/calendar/9781074/\" title=\"Las Vegas WordPress Meetup\">Las Vegas WordPress Meetup - March 19, 2009</a></li>\n<li><a href=\"http://www.meetup.com/The-Ferndale-WordPress-Meetup-Group/calendar/9915631/\" title=\"March WordPress Meetup\">Ferndale, Michigan - March WordPress Meetup - March 23, 2009</a></li>\n<li><a title=\"Atlanta WordPress Users Group\" href=\"http://wordpress.meetup.com/184/calendar/9720888/\">Atlanta, Georgia - Atlanta WordPress Users Group - March 24, 2009</a></li>\n<li><a href=\"http://www.meetup.com/wordpressnyc/calendar/9804958/\" title=\"The Wonderful World of Widgets\">New York City WordPress Meetup - The Wonderful World of Widgets - March 24, 2009</a></li>\n<li><a href=\"http://www.meetup.com/Seattle-WordPress-2-0/calendar/9811427/\" title=\"Seattle WordPress 2.0 March Meetup\">Seattle WordPress Meetup - March 24, 2009</a></li>\n<li><a href=\"http://www.meetup.com/LasVegasWordPress/calendar/9781075/\" title=\"Las Vegas WordPress Meetup\">Las Vegas WordPress Meetup - Thursday, March 26, 2009</a></li>\n<li><a href=\"http://www.meetup.com/dfwwordpress/calendar/9847328/\" title=\"The Dallas/Ft. Worth Area WordPress March Meetup\">The Dallas/Ft. Worth Area WordPress March Meetup - March 28, 2009</a></li>\n<li><a href=\"http://www.meetup.com/mywplife/calendar/9847344/\" title=\"The Chicago WordPress March Meetup: Plugins\">The Chicago WordPress March Meetup - WordPress Plugins - March 28, 2009</a></li>\n<li><a href=\"http://wordpress.meetup.com/184/calendar/9807239/\" title=\"Atlanta WordPress Users Group March Meetup\">Atlanta, Georgia - Atlanta WordPress Users Group Meetup - March 28, 2009</a></li>\n<li><a href=\"http://www.meetup.com/Greater-Charlotte-Area-WordPress-Group/calendar/9796418/\" title=\"Greater Charlotte Area WordPress Group March Meetup\">North Carolina - Greater Charlotte Area WordPress Group March Meetup - March 28, 2009</a></li>\n<li><a href=\"http://www.meetup.com/Eastbay-WordPress-Meetup/calendar/9761302/\" title=\"The East Bay WordPress March Mash-up\">Alameda, California - The East Bay WordPress March Mash-up - March 29, 2009</a></li>\n</ul>\n<p><strong>April 2009</strong></p>\n<ul>\n<li><a href=\"http://www.meetup.com/The-New-Jersey-WordPress-Meetup-Group/calendar/9886762/\" title=\"The New Jersey WordPress April Meetup\">The New Jersey WordPress April Meetup - April 1, 2009</a></li>\n<li><a href=\"http://www.meetup.com/LasVegasWordPress/calendar/9834941/\" title=\"Las Vegas WordPress Meetup\">Las Vegas WordPress Meetup - April 1, 2009</a></li>\n<li><a href=\"http://www.meetup.com/The-New-Jersey-WordPress-Meetup-Group/calendar/9809084/\" title=\"April NJ WordPress Meetup\">New Jersey WordPress Meetup - April 1, 2009</a></li>\n<li><a href=\"http://www.meetup.com/gulf-coast-wordpress/calendar/9893149/\" title=\"Gulf Coast WordPress/Blogger April Meetup\">Gulf Coast WordPress/Blogger April Meetup - April 2, 2009</a></li>\n<li><a title=\"WordCamp China\" href=\"http://wordcampchina.org/\">WordCamp China - April 4, 2009</a></li>\n<li><a href=\"http://hk.wordcamp.org/\" title=\"WordCamp Hong Kong\">WordCamp Hong Kong - April 5, 2009</a></li>\n<li><a href=\"http://www.meetup.com/SF-WordPress-Users/calendar/9935018/\" title=\"South Florida WordPress April Meetup\">Ft. Lauderdale, Florida - South Florida WordPress April Meetup - April 8, 2009</a></li>\n<li><a href=\"http://wordcampnola.com/\" title=\"WordCamp New Orleans NOLA\">New Orleans, Louisiana - WordCamp NOLA - April 10-11, 2008</a> (<a href=\"http://www.twitter.com/WordCampNOLA\" title=\"WordCamp New Orleans NOLA\">Twitter</a>)</li>\n<li><a href=\"http://www.meetup.com/The-Southern-California-WordPress-Meetup-Group/calendar/9961829/\" title=\"April Meetup - Southern California WordPress Group\">Long Beach, California - Southern California WordPress Group - April 18, 2009</a></li>\n</ul>\n<p><strong>May 2009</strong></p>\n<ul>\n<li><a href=\"http://www.sobevent.com/\" title=\"SOBCon\">Chicago - Successful and Outstanding Bloggers Conference (SOBCon) - May 1-5, 2009</a></li>\n<li><a href=\"http://phug.ca/wordcamptoronto\" title=\"WordCamp Toronto\">WordCamp Toronto - May 8-10, 2009</a></li>\n<li><a href=\"http://wordcamprva.org/\" title=\"May 9, 2009: WordCamp RVA at Hirschler Fleischer\">Richmond, Virginia - WordCamp RVA - May 9, 2009</a></li>\n<li><a href=\"http://www.wordcampcolumbus.com/\" title=\"WordCamp Columbus\">Ohio - WordCamp Columbus - May 16, 2009</a></li>\n<li><a href=\"http://wordcampmidatlantic.com/\" title=\"WordCamp Mid-Atlantic\">Washington, D.C., Baltimore and Philadelphia - WordCamp Mid-Atlantic - May 16, 2009</a></li>\n<li><a href=\"http://www.wordcamp.it/\" title=\"WordCamp Milan 2009\">Milan, Italy - WordCamp Milan 2009 - May 22-23, 2009</a></li>\n<li><a href=\"http://2009.sf.wordcamp.org/\" title=\"WordCamp San Francisco 2009\">WordCamp San Francisco 2009 - May 30, 2009</a></li>\n</ul>\n<h4>Past WordPress News Reports</h4>\n<ul>\n<li><a href=\"http://www.blogherald.com/2009/03/12/wordpress-news-plugins-reach-milestone-new-wordpress-community-project-help-to-search-for-wordpress-help/\" title=\"WordPress News: Plugins Reach Milestone, New WordPress Community Project, Help to Search for WordPress Help\">WordPress News: Plugins Reach Milestone, New WordPress Community Project, Help to Search for WordPress Help</a></li>\n<li><a href=\"http://www.blogherald.com/2009/02/26/wordpress-news-wordpress-wins-at-irish-blogger-awards-wordpress-events-everywhere-wordpress-for-powerpoint-flash-security-issue-feedburner-deadline/\" title=\"WordPress News: WordPress Wins at Irish Blogger Awards, WordPress Events Everywhere, WordPress for PowerPoint, Flash Security Issue, Feedburner Deadline\">WordPress News: WordPress Wins at Irish Blogger Awards, WordPress Events Everywhere, WordPress for PowerPoint, Flash Security Issue, Feedburner Deadline</a></li>\n<li><a href=\"http://www.blogherald.com/2009/02/20/wordpress-news-can-you-spot-a-wordpress-blog-wordpress-28-news-plugin-directory-searcable-iphone-app-tested-and-more/\" title=\"WordPress News: Can You Spot a WordPress Blog? WordPress 2.8 News, Plugin Directory Searcable, iPhone App Tested, and More\">WordPress News: Can You Spot a WordPress Blog? WordPress 2.8 News, Plugin Directory Searcable, iPhone App Tested, and More</a></li>\n<li><a href=\"http://www.blogherald.com/2009/02/05/wordpress-news-release-week-news-wordpress-271-buddypress-wordpress-mu-and-more-releases/\" title=\"WordPress News: Release Week News, WordPress 2.7.1, BuddyPress, WordPress MU, and More Releases\">WordPress News: Release Week News, WordPress 2.7.1, BuddyPress, WordPress MU, and More Releases</a></li>\n<li><a href=\"http://www.blogherald.com/2009/01/29/wordpress-news-logogate-wordcamps-everywhere-wordpresstv-buddypress-wordpressmu-wordpress-plugin-podcast-and-more/\" title=\"WordPress News: Logogate, WordCamps Everywhere, WordPress.tv, BuddyPress, WordPressMU, WordPress Plugin Podcast, and More\">WordPress News: Logogate, WordCamps Everywhere, WordPress.tv, BuddyPress, WordPressMU, WordPress Plugin Podcast, and More</a></li>\n<li><a href=\"http://www.blogherald.com/2009/01/23/wordpress-news-wordpresstv-wordcamp-whistler-wordpress-logo-city-saves-money-and-more/\" title=\"WordPress News: WordPress.tv, WordCamp Whistler, WordPress Logo, City Saves Money, and More\">WordPress News: WordPress.tv, WordCamp Whistler, WordPress Logo, City Saves Money, and More</a></li>\n</ul>\n<p><em>Each week, the <a title=\"Blog Herald\" rel=\"tag\" href=\"http://www.blogherald.com/\">Blog Herald</a> features <strong>WordPress News</strong>, a weekly column by <a href=\"http://lorelle.wordpress.com/\" title=\"Lorelle on WordPress\" rel=\"tag\">Lorelle VanFossen of Lorelle on WordPress</a> featuring the news around the WordPress Community. If you have a WordPress news item or tip to suggest, please contact her at this special email address: <a href=\"mailto:&#x6c;&#111;&#114;&#x65;&#x6c;&#108;&#101;&#x6f;&#x6e;&#119;&#111;&#114;&#100;&#112;&#x72;&#101;&#x73;&#x73;&#64;&#103;&#109;&#x61;&#x69;&#x6c;&#46;&#x63;&#111;&#x6d;\">&#x6c;&#x6f;&#114;&#x65;&#x6c;&#x6c;&#x65;&#x6f;&#110;&#x77;&#x6f;&#114;&#100;&#x70;&#x72;&#101;&#x73;&#115;&#x40;&#103;&#109;&#x61;&#105;&#x6c;&#x2e;&#x63;&#x6f;&#109;</a></em></p>\n<p><img src=\"http://lorelle.files.wordpress.com/2006/08/sig.gif\" alt=\"\" /><br />\n<hr />\n<p><font size=\"-1\"><b>Site Search Tags:</b> <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+news\" rel=\"tag\">wordpress news</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=blog+herald\" rel=\"tag\">blog herald</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=blog+herald+wordpress+news\" rel=\"tag\">blog herald wordpress news</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=weekly+wordpress+news\" rel=\"tag\">weekly wordpress news</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+themes\" rel=\"tag\">wordpress themes</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+plugins\" rel=\"tag\">wordpress plugins</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+tips\" rel=\"tag\">wordpress tips</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+help\" rel=\"tag\">wordpress help</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+advice\" rel=\"tag\">wordpress advice</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+techniques\" rel=\"tag\">wordpress techniques</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+tips\" rel=\"tag\">wordpress tips</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+development\" rel=\"tag\">wordpress development</a> </p>\n<p><a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/02/rss.png\" alt=\"Feed on Lorelle on WordPress\" /></a> <a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\">Subscribe</a>  <a href=\"http://feeds.feedburner.com/LorelleOnWordPress\" title=\"Feedburner Lorelle on WordPress Feed\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/04/feedburnericon.gif\" alt=\"Feedburner icon\" />Via Feedburner</a>  <a href=\"http://www.feedblitz.com/f/?Sub=182399\" title=\"Lorelle on WordPress - full site feed email subscription\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/03/email.gif\" alt=\"\" />Subscribe by Email</a> <a href=\"http://lorelle.wordpress.com/\" title=\"Visit Lorelle on WordPress\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2008/03/pointer.gif\" alt=\"\" />Visit</a><br /><a href=\"http://lorelle.wordpress.com/about/\" title=\"Copyright Protected by Brent and Lorelle VanFossen\">Copyright Lorelle VanFossen</a>, the author of <a href=\"http://lorelle.wordpress.com/books/blogging-tips/\" title=\"Blogging Tips Book By Lorelle VanFossen\"><em>Blogging Tips, What Bloggers Won\'t Tell You About Blogging</em></a>.</font></p>\nPosted in WordPress News  <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/lorelle.wordpress.com/3987/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/lorelle.wordpress.com/3987/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/lorelle.wordpress.com/3987/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/lorelle.wordpress.com/3987/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/lorelle.wordpress.com/3987/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/lorelle.wordpress.com/3987/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/lorelle.wordpress.com/3987/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/lorelle.wordpress.com/3987/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/lorelle.wordpress.com/3987/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/lorelle.wordpress.com/3987/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=lorelle.wordpress.com&blog=72&post=3987&subd=lorelle&ref=&feed=1\" /></div>\";s:7:\"pubdate\";s:31:\"Thu, 19 Mar 2009 07:07:38 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:17:\"Lorelle VanFossen\";}s:7:\"summary\";s:21301:\"<div class=\"snap_preview\"><br /><p><a href=\"http://lorelle.wordpress.com/tag/wordpress-news/\" title=\"WordPress News\"><img src=\"http://lorelle.files.wordpress.com/2007/01/wpnews1.png\" alt=\"WordPress News\" align=\"right\" /></a>This week&#8217;s <a href=\"http://www.blogherald.com/tag/wordpress-news/\" title=\"Articles on WordPress News on the Blog Herald\" rel=\"tag\">Blog Herald WordPress News</a> is <a href=\"http://www.blogherald.com/2009/03/19/wordpress-news-iphones-up-wordpress-widgets-api-28-delayed-international-wordpresstv-and-more/\" title=\"WordPress News: iPhones Up, WordPress Widgets API, 2.8 Delayed, International WordPress.tv, and More\">WordPress News: iPhones Up, WordPress Widgets API, 2.8 Delayed, International WordPress.tv, and More</a>, and I&#8217;ve covered a lot of WordPress news you can use:</p>\n<blockquote><p>iPhone for WordPress is in the iTunes store. WordPress Widgets will use new Widgets API as of WordPress 2.8. Security authentication will improve with OAuth in future versions. WordPress 2.8 delayed. WordCamps in Hong Kong and China coming up. International languages embraced on WordPress.tv. And more WordPress news, tips, resources, and help.</p></blockquote>\n<p>If you missed last week&#8217;s edition on the Blog Herald, it was <a href=\"http://www.blogherald.com/2009/03/12/wordpress-news-plugins-reach-milestone-new-wordpress-community-project-help-to-search-for-wordpress-help/\" title=\"WordPress News: Plugins Reach Milestone, New WordPress Community Project, Help to Search for WordPress Help\">WordPress News: Plugins Reach Milestone, New WordPress Community Project, Help to Search for WordPress Help</a>. </p>\n<p>I am working with the editor of the <a href=\"http://www.blogherald.com/\" title=\"Blog Herald\" rel=\"tag\">Blog Herald</a> to change the look and style of the <a href=\"http://www.blogherald.com/tag/wordpress-news/\" title=\"Articles on WordPress News on the Blog Herald\" rel=\"tag\">Blog Herald WordPress News</a>. I&#8217;d love your input here or on the <a href=\"http://www.blogherald.com/2009/03/10/changing-the-blog-herald-wordpress-news-your-help-needed/\" title=\"Changing the Blog Herald WordPress News: Your Help Needed\">announcement regarding potential changes and input</a>. The Blog Herald WordPress News is designed to meet the needs of the WordPress Community, so help us help you blog better with WordPress. </p>\n<p>Here are some highlights for this week you do not want to miss, followed by <a href=\"http://lorelle.wordpress.com/tag/wordpress-news/feed/#wpevents\" title=\"WordPress Events\">WordPress Events, WordCamps, and Meetups</a> coming soon.<span id=\"more-3987\"></span></p>\n<h4>iPhone for WordPress</h4>\n<p>The <a href=\"http://iphone.wordpress.org/2009/03/18/version-12-live-in-itunes-app-store/\" title=\"Version 1.2 Live in iTunes App Store\">iPhone for WordPress Version 1.2</a> is now in the iTunes App Store, ready for you to <a href=\"http://itunes.apple.com/WebObjects/MZStore.woa/wa/viewSoftware?id=285073074&amp;mt=8\" title=\"download iPhone for WordPress\">blog and track comments on your iPhone</a>.</p>\n<h4>WordPress 2.8 News</h4>\n<p>The <a href=\"http://wpdevel.wordpress.com/2009/03/13/28-will-land-some-time-in-april-peopl/\" title=\"2.8 will land some time in April. Peopl …\">WordPress Development team has confirmed</a> that WordPress 2.8 will be released in April, pushing back the release date a few weeks in order to take a little more time with improving the underlying code, incorporating the new Widgets API, and improvements for managing JavaScripts, Plugins, AJAX, and more. </p>\n<p>There is a list of <a href=\"http://codex.wordpress.org/Version_2.8\" title=\"WordPress 2.8 in the Codex\">features, changes, and improvements in the WordPress Codex</a>.</p>\n<p>A new <a href=\"http://core.trac.wordpress.org/ticket/8441\" title=\"new widgets API\">WordPress Widgets API</a> in in development for WordPress 2.8. Based upon MultiWidget Class, it will handle all the multi-widget functions and hooks to implement a multi-widget Plugin, giving developers an easier process to extend their WordPress Plugins with Widget functionality. </p>\n<p><a href=\"http://wpdevel.wordpress.com/2009/03/18/converting-default-widgets-to-the-new-wi/\" title=\"Converting default widgets to the new widgets api\">The WordPress Development team has announced</a> that they are converting all default WordPress Widgets to work with the new Widgets API. If you are a WordPress Plugin author with a Widget-enabled Plugin, or you want to expand the flexibility of your Plugin for WordPress 2.8, check this out. </p>\n<p><a href=\"http://lesterchan.net/wordpress/2009/03/17/new-wp_widget-class-in-wordpress-28/\" title=\"New WP_Widget Class In WordPress 2.8\">Lester Chan covers the new WP_Widget Class</a> in WordPress 2.8 in greater detail to help Plugin authors understand how it works and how it can help them.</p>\n<p>There will be a lot of changes under the hood, but not so much on the surface in WordPress 2.8. If you are working with WordPress Themes, Plugins, or development, articles on WordPress 2.8 news you should be aware of include: </p>\n<ul>\n<li><a href=\"http://wpdevel.wordpress.com/2008/12/27/optimizing-script-loading/\" title=\"Optimizing script loading\">Optimizing Script Loading</a></li>\n<li><a href=\"http://wpdevel.wordpress.com/2009/01/07/optimizing-script-loading-part-2/\" title=\"Optimizing script loading part 2\">Optimizing script loading part 2</a></li>\n<li><a href=\"http://wpdevel.wordpress.com/2009/01/15/optimizing-script-loading-implementation/\" title=\"Optimizing script loading, implementation\">Optimizing script loading, implementation</a></li>\n<li><a href=\"http://lesterchan.net/wordpress/2009/01/15/javascript-in-my-plugins/\" title=\"JavaScript In My Plugins\">Preparing for WordPress 2.8: Using JavaScript in WordPress Plugins</a></li>\n<li><a href=\"http://wpengineer.com/change-your-wordpress-theme-on/\" title=\"Change your WordPress Theme on …\">Change your WordPress Theme on …</a></li>\n<li><a href=\"http://wpengineer.com/wordpress-28-body_class-automatic_feed_links/\" title=\"WordPress 2.8 body_class, automatic_feed_links\">WordPress 2.8 body_class, automatic_feed_links</a></li>\n<li><a href=\"http://www.wp-fun.co.uk/2009/02/09/what-a-body/\" title=\"What a body!\">What a body!</a></li>\n</ul>\n<p><a href=\"http://willnorris.com/2009/03/authentication-in-wordpress-28\" title=\"Will Norris: Authentication in WordPress 2.8\">Will Norris wrote about &#8220;Authentication in WordPress 2.8</a>&#8221; as part of his ongoing project for the <a href=\"http://wordpress.org/extend/plugins/openid/\" title=\"OpenID plugin\">OpenID WordPress Plugin</a>. Working with <a href=\"http://peter.westwood.name/\" title=\"Peter Westwood\">Peter Westwood</a>, WordPress 2.8 now includes a new filter for authentication that passes through three paramters, along with the username and password. According to <a href=\"http://ma.tt/\" title=\"Matt Mullenweg\" rel=\"tag\">Matt Mullenweg</a>, right now, the OAuth for WordPress will be a WordPress Plugin, with hopes of integrating it into the core in the future. </p>\n<h4>WordPress.tv Goes International and Offers Insider News</h4>\n<p><a href=\"http://wordpress.tv/\" title=\"WordPress.tv\" rel=\"tag\">WordPress.tv</a> has now <a href=\"http://blog.wordpress.tv/2009/03/18/wordpresstv-the-shape-of-things-to-come-blow-by-blow/\" title=\"WordPress.tv: the shape of things to come, blow-by-blow\">launched</a> the <a href=\"http://dev.wordpress.tv/\" title=\"Making WordPress.tv\">Making WordPress.tv</a> development blog run on the new <a href=\"http://en.blog.wordpress.com/2009/03/11/p2-the-new-prologue/\" title=\"freshly launched P2 theme,\">P2 WordPress Theme</a> for those who want to keep up with what is going on with the new video service for the WordPress Community. </p>\n<p>The first goal for improving the new WordPress.tv is to improve the localization, the ability to understand the videos in your language. Michael Pick is working on <a href=\"http://blog.wordpress.tv/2009/03/17/wordpresstv-in-your-language/\" title=\"WordPress.tv - in your language\">adding language filtering</a> to help with the translation of videos into other languages. You can now filter the videos by language preference, too. </p>\n<p>If you would like to help, let them know. </p>\n<h4>WordPress Tips and Plugins on Twitter</h4>\n<p>I&#8217;ve started sharing WordPress Tips and Plugin suggestions I&#8217;ve collected over the past couple years on Twitter at <a href=\"http://twitter.com/lorelleonwp/\" title=\"Lorelle on WordPress Twitter\">@lorelleonwp</a>. </p>\n<p>I post one WordPress tip and one WordPress Plugin link every morning (PST) covering recent versions of WordPress and WordPress usages and features. </p>\n<p>Thanks and credit for making this happen goes to <a href=\"http://www.tweetlater.com/\" title=\"TweetLater\">TweetLater</a>, a future Twitter posting and management system I <a href=\"http://www.blogherald.com/2009/03/03/exploring-social-media-future-tweets-with-tweetlater/\" title=\"Exploring Social Media: Future Tweets with TweetLater\">reviewed recently</a>.</p>\n<p><a name=\"wpevents\">&nbsp;</a></p>\n<h3>WordPress Events and WordCamps</h3>\n<p>Upcoming WordCamps and WordPress events include:</p>\n<p><strong>March 2009</strong></p>\n<ul>\n<li><a href=\"http://upcoming.yahoo.com/event/2126113/\" title=\"Mar 18, 2009: Utah WordPress Meetup at Spurlock House\">Utah WordPress Meetup - March 18, 2009</a></li>\n<li><a href=\"http://www.meetup.com/LasVegasWordPress/calendar/9781074/\" title=\"Las Vegas WordPress Meetup\">Las Vegas WordPress Meetup - March 19, 2009</a></li>\n<li><a href=\"http://www.meetup.com/The-Ferndale-WordPress-Meetup-Group/calendar/9915631/\" title=\"March WordPress Meetup\">Ferndale, Michigan - March WordPress Meetup - March 23, 2009</a></li>\n<li><a title=\"Atlanta WordPress Users Group\" href=\"http://wordpress.meetup.com/184/calendar/9720888/\">Atlanta, Georgia - Atlanta WordPress Users Group - March 24, 2009</a></li>\n<li><a href=\"http://www.meetup.com/wordpressnyc/calendar/9804958/\" title=\"The Wonderful World of Widgets\">New York City WordPress Meetup - The Wonderful World of Widgets - March 24, 2009</a></li>\n<li><a href=\"http://www.meetup.com/Seattle-WordPress-2-0/calendar/9811427/\" title=\"Seattle WordPress 2.0 March Meetup\">Seattle WordPress Meetup - March 24, 2009</a></li>\n<li><a href=\"http://www.meetup.com/LasVegasWordPress/calendar/9781075/\" title=\"Las Vegas WordPress Meetup\">Las Vegas WordPress Meetup - Thursday, March 26, 2009</a></li>\n<li><a href=\"http://www.meetup.com/dfwwordpress/calendar/9847328/\" title=\"The Dallas/Ft. Worth Area WordPress March Meetup\">The Dallas/Ft. Worth Area WordPress March Meetup - March 28, 2009</a></li>\n<li><a href=\"http://www.meetup.com/mywplife/calendar/9847344/\" title=\"The Chicago WordPress March Meetup: Plugins\">The Chicago WordPress March Meetup - WordPress Plugins - March 28, 2009</a></li>\n<li><a href=\"http://wordpress.meetup.com/184/calendar/9807239/\" title=\"Atlanta WordPress Users Group March Meetup\">Atlanta, Georgia - Atlanta WordPress Users Group Meetup - March 28, 2009</a></li>\n<li><a href=\"http://www.meetup.com/Greater-Charlotte-Area-WordPress-Group/calendar/9796418/\" title=\"Greater Charlotte Area WordPress Group March Meetup\">North Carolina - Greater Charlotte Area WordPress Group March Meetup - March 28, 2009</a></li>\n<li><a href=\"http://www.meetup.com/Eastbay-WordPress-Meetup/calendar/9761302/\" title=\"The East Bay WordPress March Mash-up\">Alameda, California - The East Bay WordPress March Mash-up - March 29, 2009</a></li>\n</ul>\n<p><strong>April 2009</strong></p>\n<ul>\n<li><a href=\"http://www.meetup.com/The-New-Jersey-WordPress-Meetup-Group/calendar/9886762/\" title=\"The New Jersey WordPress April Meetup\">The New Jersey WordPress April Meetup - April 1, 2009</a></li>\n<li><a href=\"http://www.meetup.com/LasVegasWordPress/calendar/9834941/\" title=\"Las Vegas WordPress Meetup\">Las Vegas WordPress Meetup - April 1, 2009</a></li>\n<li><a href=\"http://www.meetup.com/The-New-Jersey-WordPress-Meetup-Group/calendar/9809084/\" title=\"April NJ WordPress Meetup\">New Jersey WordPress Meetup - April 1, 2009</a></li>\n<li><a href=\"http://www.meetup.com/gulf-coast-wordpress/calendar/9893149/\" title=\"Gulf Coast WordPress/Blogger April Meetup\">Gulf Coast WordPress/Blogger April Meetup - April 2, 2009</a></li>\n<li><a title=\"WordCamp China\" href=\"http://wordcampchina.org/\">WordCamp China - April 4, 2009</a></li>\n<li><a href=\"http://hk.wordcamp.org/\" title=\"WordCamp Hong Kong\">WordCamp Hong Kong - April 5, 2009</a></li>\n<li><a href=\"http://www.meetup.com/SF-WordPress-Users/calendar/9935018/\" title=\"South Florida WordPress April Meetup\">Ft. Lauderdale, Florida - South Florida WordPress April Meetup - April 8, 2009</a></li>\n<li><a href=\"http://wordcampnola.com/\" title=\"WordCamp New Orleans NOLA\">New Orleans, Louisiana - WordCamp NOLA - April 10-11, 2008</a> (<a href=\"http://www.twitter.com/WordCampNOLA\" title=\"WordCamp New Orleans NOLA\">Twitter</a>)</li>\n<li><a href=\"http://www.meetup.com/The-Southern-California-WordPress-Meetup-Group/calendar/9961829/\" title=\"April Meetup - Southern California WordPress Group\">Long Beach, California - Southern California WordPress Group - April 18, 2009</a></li>\n</ul>\n<p><strong>May 2009</strong></p>\n<ul>\n<li><a href=\"http://www.sobevent.com/\" title=\"SOBCon\">Chicago - Successful and Outstanding Bloggers Conference (SOBCon) - May 1-5, 2009</a></li>\n<li><a href=\"http://phug.ca/wordcamptoronto\" title=\"WordCamp Toronto\">WordCamp Toronto - May 8-10, 2009</a></li>\n<li><a href=\"http://wordcamprva.org/\" title=\"May 9, 2009: WordCamp RVA at Hirschler Fleischer\">Richmond, Virginia - WordCamp RVA - May 9, 2009</a></li>\n<li><a href=\"http://www.wordcampcolumbus.com/\" title=\"WordCamp Columbus\">Ohio - WordCamp Columbus - May 16, 2009</a></li>\n<li><a href=\"http://wordcampmidatlantic.com/\" title=\"WordCamp Mid-Atlantic\">Washington, D.C., Baltimore and Philadelphia - WordCamp Mid-Atlantic - May 16, 2009</a></li>\n<li><a href=\"http://www.wordcamp.it/\" title=\"WordCamp Milan 2009\">Milan, Italy - WordCamp Milan 2009 - May 22-23, 2009</a></li>\n<li><a href=\"http://2009.sf.wordcamp.org/\" title=\"WordCamp San Francisco 2009\">WordCamp San Francisco 2009 - May 30, 2009</a></li>\n</ul>\n<h4>Past WordPress News Reports</h4>\n<ul>\n<li><a href=\"http://www.blogherald.com/2009/03/12/wordpress-news-plugins-reach-milestone-new-wordpress-community-project-help-to-search-for-wordpress-help/\" title=\"WordPress News: Plugins Reach Milestone, New WordPress Community Project, Help to Search for WordPress Help\">WordPress News: Plugins Reach Milestone, New WordPress Community Project, Help to Search for WordPress Help</a></li>\n<li><a href=\"http://www.blogherald.com/2009/02/26/wordpress-news-wordpress-wins-at-irish-blogger-awards-wordpress-events-everywhere-wordpress-for-powerpoint-flash-security-issue-feedburner-deadline/\" title=\"WordPress News: WordPress Wins at Irish Blogger Awards, WordPress Events Everywhere, WordPress for PowerPoint, Flash Security Issue, Feedburner Deadline\">WordPress News: WordPress Wins at Irish Blogger Awards, WordPress Events Everywhere, WordPress for PowerPoint, Flash Security Issue, Feedburner Deadline</a></li>\n<li><a href=\"http://www.blogherald.com/2009/02/20/wordpress-news-can-you-spot-a-wordpress-blog-wordpress-28-news-plugin-directory-searcable-iphone-app-tested-and-more/\" title=\"WordPress News: Can You Spot a WordPress Blog? WordPress 2.8 News, Plugin Directory Searcable, iPhone App Tested, and More\">WordPress News: Can You Spot a WordPress Blog? WordPress 2.8 News, Plugin Directory Searcable, iPhone App Tested, and More</a></li>\n<li><a href=\"http://www.blogherald.com/2009/02/05/wordpress-news-release-week-news-wordpress-271-buddypress-wordpress-mu-and-more-releases/\" title=\"WordPress News: Release Week News, WordPress 2.7.1, BuddyPress, WordPress MU, and More Releases\">WordPress News: Release Week News, WordPress 2.7.1, BuddyPress, WordPress MU, and More Releases</a></li>\n<li><a href=\"http://www.blogherald.com/2009/01/29/wordpress-news-logogate-wordcamps-everywhere-wordpresstv-buddypress-wordpressmu-wordpress-plugin-podcast-and-more/\" title=\"WordPress News: Logogate, WordCamps Everywhere, WordPress.tv, BuddyPress, WordPressMU, WordPress Plugin Podcast, and More\">WordPress News: Logogate, WordCamps Everywhere, WordPress.tv, BuddyPress, WordPressMU, WordPress Plugin Podcast, and More</a></li>\n<li><a href=\"http://www.blogherald.com/2009/01/23/wordpress-news-wordpresstv-wordcamp-whistler-wordpress-logo-city-saves-money-and-more/\" title=\"WordPress News: WordPress.tv, WordCamp Whistler, WordPress Logo, City Saves Money, and More\">WordPress News: WordPress.tv, WordCamp Whistler, WordPress Logo, City Saves Money, and More</a></li>\n</ul>\n<p><em>Each week, the <a title=\"Blog Herald\" rel=\"tag\" href=\"http://www.blogherald.com/\">Blog Herald</a> features <strong>WordPress News</strong>, a weekly column by <a href=\"http://lorelle.wordpress.com/\" title=\"Lorelle on WordPress\" rel=\"tag\">Lorelle VanFossen of Lorelle on WordPress</a> featuring the news around the WordPress Community. If you have a WordPress news item or tip to suggest, please contact her at this special email address: <a href=\"mailto:&#x6c;&#111;&#114;&#x65;&#x6c;&#108;&#101;&#x6f;&#x6e;&#119;&#111;&#114;&#100;&#112;&#x72;&#101;&#x73;&#x73;&#64;&#103;&#109;&#x61;&#x69;&#x6c;&#46;&#x63;&#111;&#x6d;\">&#x6c;&#x6f;&#114;&#x65;&#x6c;&#x6c;&#x65;&#x6f;&#110;&#x77;&#x6f;&#114;&#100;&#x70;&#x72;&#101;&#x73;&#115;&#x40;&#103;&#109;&#x61;&#105;&#x6c;&#x2e;&#x63;&#x6f;&#109;</a></em></p>\n<p><img src=\"http://lorelle.files.wordpress.com/2006/08/sig.gif\" alt=\"\" /><br />\n<hr />\n<p><font size=\"-1\"><b>Site Search Tags:</b> <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+news\" rel=\"tag\">wordpress news</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=blog+herald\" rel=\"tag\">blog herald</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=blog+herald+wordpress+news\" rel=\"tag\">blog herald wordpress news</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=weekly+wordpress+news\" rel=\"tag\">weekly wordpress news</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+themes\" rel=\"tag\">wordpress themes</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+plugins\" rel=\"tag\">wordpress plugins</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+tips\" rel=\"tag\">wordpress tips</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+help\" rel=\"tag\">wordpress help</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+advice\" rel=\"tag\">wordpress advice</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+techniques\" rel=\"tag\">wordpress techniques</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+tips\" rel=\"tag\">wordpress tips</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+development\" rel=\"tag\">wordpress development</a> </p>\n<p><a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/02/rss.png\" alt=\"Feed on Lorelle on WordPress\" /></a> <a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\">Subscribe</a>  <a href=\"http://feeds.feedburner.com/LorelleOnWordPress\" title=\"Feedburner Lorelle on WordPress Feed\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/04/feedburnericon.gif\" alt=\"Feedburner icon\" />Via Feedburner</a>  <a href=\"http://www.feedblitz.com/f/?Sub=182399\" title=\"Lorelle on WordPress - full site feed email subscription\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/03/email.gif\" alt=\"\" />Subscribe by Email</a> <a href=\"http://lorelle.wordpress.com/\" title=\"Visit Lorelle on WordPress\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2008/03/pointer.gif\" alt=\"\" />Visit</a><br /><a href=\"http://lorelle.wordpress.com/about/\" title=\"Copyright Protected by Brent and Lorelle VanFossen\">Copyright Lorelle VanFossen</a>, the author of <a href=\"http://lorelle.wordpress.com/books/blogging-tips/\" title=\"Blogging Tips Book By Lorelle VanFossen\"><em>Blogging Tips, What Bloggers Won\'t Tell You About Blogging</em></a>.</font></p>\nPosted in WordPress News  <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/lorelle.wordpress.com/3987/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/lorelle.wordpress.com/3987/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/lorelle.wordpress.com/3987/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/lorelle.wordpress.com/3987/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/lorelle.wordpress.com/3987/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/lorelle.wordpress.com/3987/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/lorelle.wordpress.com/3987/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/lorelle.wordpress.com/3987/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/lorelle.wordpress.com/3987/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/lorelle.wordpress.com/3987/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=lorelle.wordpress.com&blog=72&post=3987&subd=lorelle&ref=&feed=1\" /></div>\";}i:3;a:7:{s:5:\"title\";s:19:\"Matt: Berkun on 2.7\";s:4:\"guid\";s:21:\"http://ma.tt/?p=12693\";s:4:\"link\";s:34:\"http://ma.tt/2009/03/berkun-on-27/\";s:11:\"description\";s:114:\"<p><a href=\"http://www.scottberkun.com/blog/2009/review-wordpress-27/\">Scott Berkun reviews Wordpress 2.7</a>.</p>\";s:7:\"pubdate\";s:31:\"Wed, 18 Mar 2009 20:50:27 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:114:\"<p><a href=\"http://www.scottberkun.com/blog/2009/review-wordpress-27/\">Scott Berkun reviews Wordpress 2.7</a>.</p>\";}i:4;a:7:{s:5:\"title\";s:60:\"Weblog Tools Collection: WordPress Plugin Releases for 03/18\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5356\";s:4:\"link\";s:88:\"http://weblogtoolscollection.com/archives/2009/03/18/wordpress-plugin-releases-for-0318/\";s:11:\"description\";s:3841:\"<h3>New Plugins</h3>\n<p><a href=\"http://justintadlock.com/archives/2009/03/15/query-posts-widget-wordpress-plugin\">Query Posts</a></p>\n<p>Description:<br />\nThis widget gives average users the ability to show off their posts in any way they&#8217;d like. Nearly 40 options are available to show posts from the widget controls. The widget can also be used an unlimited number of times.</p>\n<p><a href=\"http://www.blogtrafficexchange.com/related-websites/\">Related Websites</a></p>\n<p>The Related Websites plugin is the Blog Traffic Exchange. By a blogger for bloggers. No advertising on member blogs. Just a pure, highly relevant blog traffic exchange. Think of it as a related posts for the blogosphere.</p>\n<p><a href=\"http://gwycon.com/products/wordpress-plugins/to-do-list/\">To Do List</a></p>\n<p>Maintains a to do list in the admin area. This can be viewed in the admin area, and edited/saved etc. It is saved as a text file in the Plugin folder. Blog owners can keep track of tasks and activities, and any other information necessary.</p>\n<p><a href=\"http://blog.avirtualhome.com/wordpress-plugins/avh-first-defense-against-spam/\">AVH First Defense Against Spam</a></p>\n<p>The AVH First Defense Against Spam WordPress plugin gives you the ability to block spammers before any content is served. Spammers are identified by checking if the visitors IP exists in a database served by <a href=\"http://stopforumspam.com\">stopforumspam.com</a> or by a local blacklist.</p>\n<p><a href=\"http://sivel.net/2009/03/wordpress-reset/\">WordPress Reset</a></p>\n<p>Resets the WordPress database back to it&#8217;s defaults. Deletes all customizations and content. Does not modify files only resets the database.</p>\n<p><a href=\"http://www.krues8dr.com/wordpress-unstyle-comment-replies-plugin/\">Unstyle Comment Replies</a></p>\n<p>This plugin will remove comment reply classes and create custom classes for parents with zebra striping.</p>\n<p><a href=\"http://josephscott.org/code/wordpress/plugin-libxml2-fix/\">LibXML2 Fix</a></p>\n<p>Work around for some versions of libxml2 2.7.x that strip out brackets when parsing XML.</p>\n<h3>Updated Plugins</h3>\n<p><a href=\"http://kune.fr/blog/wordpress/index-tag-page-v11/\">Index Tag Page</a></p>\n<p>With this plugin, you will be able to display an index with all your tags, sort alphabetically. The shortcode is <code>[indextag nb=XX ul=YY li=ZZ letter=LL menu=1/0]</code>. <em>Page in French</em></p>\n<p><a href=\"http://www.webmaster-source.com/gocodes-redirection-plugin-wordpress/\">GoCodes</a></p>\n<p>GoCodes let&#8217;s you create shortcut URLs to anywhere on the internet, right from your Wordpress Admin. The plugin is also useful for masking affiliate program URLs.</p>\n<p><a href=\"http://wp.gdragon.info/category/plugins/gd-press-tools/\">GD Press Tools</a></p>\n<p>GD Press Tools is a collection of various additional administration tools. This tools can be integrated into the various WordPress admin panels, can perform maintenance operations, chanage some aspects of WordPress.</p>\n<p><a href=\"http://sivel.net/2008/02/shadowbox-js/\">Shadowbox JS</a></p>\n<p>A javascript media viewer similar to Lightbox and Thickbox only better. Supports all types of media, not just images. This plugin uses Shadowbox.js written my Michael J. I. Jackson.</p>\n<p><a href=\"http://mohanjith.com/wordpress/web-invoice.html\">Web Invoice - Invoicing and billing for WordPress</a></p>\n<p>Web-Invoice lets you create and send web invoices and setup recurring billing for your clients.</p>\n<p><a href=\"http://mohanjith.com/wordpress/syntaxhighlighter2.html\">SyntaxHighlighter2</a></p>\n<p>Easily post source code such as PHP or HTML and display it in a styled box.</p>\n<p><a href=\"http://www.mittineague.com/dev/co.php\">Clean Options</a></p>\n<p>Finds orphaned options and allows for their removal from the wp_options table</p>\";s:7:\"pubdate\";s:31:\"Wed, 18 Mar 2009 19:53:36 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:3841:\"<h3>New Plugins</h3>\n<p><a href=\"http://justintadlock.com/archives/2009/03/15/query-posts-widget-wordpress-plugin\">Query Posts</a></p>\n<p>Description:<br />\nThis widget gives average users the ability to show off their posts in any way they&#8217;d like. Nearly 40 options are available to show posts from the widget controls. The widget can also be used an unlimited number of times.</p>\n<p><a href=\"http://www.blogtrafficexchange.com/related-websites/\">Related Websites</a></p>\n<p>The Related Websites plugin is the Blog Traffic Exchange. By a blogger for bloggers. No advertising on member blogs. Just a pure, highly relevant blog traffic exchange. Think of it as a related posts for the blogosphere.</p>\n<p><a href=\"http://gwycon.com/products/wordpress-plugins/to-do-list/\">To Do List</a></p>\n<p>Maintains a to do list in the admin area. This can be viewed in the admin area, and edited/saved etc. It is saved as a text file in the Plugin folder. Blog owners can keep track of tasks and activities, and any other information necessary.</p>\n<p><a href=\"http://blog.avirtualhome.com/wordpress-plugins/avh-first-defense-against-spam/\">AVH First Defense Against Spam</a></p>\n<p>The AVH First Defense Against Spam WordPress plugin gives you the ability to block spammers before any content is served. Spammers are identified by checking if the visitors IP exists in a database served by <a href=\"http://stopforumspam.com\">stopforumspam.com</a> or by a local blacklist.</p>\n<p><a href=\"http://sivel.net/2009/03/wordpress-reset/\">WordPress Reset</a></p>\n<p>Resets the WordPress database back to it&#8217;s defaults. Deletes all customizations and content. Does not modify files only resets the database.</p>\n<p><a href=\"http://www.krues8dr.com/wordpress-unstyle-comment-replies-plugin/\">Unstyle Comment Replies</a></p>\n<p>This plugin will remove comment reply classes and create custom classes for parents with zebra striping.</p>\n<p><a href=\"http://josephscott.org/code/wordpress/plugin-libxml2-fix/\">LibXML2 Fix</a></p>\n<p>Work around for some versions of libxml2 2.7.x that strip out brackets when parsing XML.</p>\n<h3>Updated Plugins</h3>\n<p><a href=\"http://kune.fr/blog/wordpress/index-tag-page-v11/\">Index Tag Page</a></p>\n<p>With this plugin, you will be able to display an index with all your tags, sort alphabetically. The shortcode is <code>[indextag nb=XX ul=YY li=ZZ letter=LL menu=1/0]</code>. <em>Page in French</em></p>\n<p><a href=\"http://www.webmaster-source.com/gocodes-redirection-plugin-wordpress/\">GoCodes</a></p>\n<p>GoCodes let&#8217;s you create shortcut URLs to anywhere on the internet, right from your Wordpress Admin. The plugin is also useful for masking affiliate program URLs.</p>\n<p><a href=\"http://wp.gdragon.info/category/plugins/gd-press-tools/\">GD Press Tools</a></p>\n<p>GD Press Tools is a collection of various additional administration tools. This tools can be integrated into the various WordPress admin panels, can perform maintenance operations, chanage some aspects of WordPress.</p>\n<p><a href=\"http://sivel.net/2008/02/shadowbox-js/\">Shadowbox JS</a></p>\n<p>A javascript media viewer similar to Lightbox and Thickbox only better. Supports all types of media, not just images. This plugin uses Shadowbox.js written my Michael J. I. Jackson.</p>\n<p><a href=\"http://mohanjith.com/wordpress/web-invoice.html\">Web Invoice - Invoicing and billing for WordPress</a></p>\n<p>Web-Invoice lets you create and send web invoices and setup recurring billing for your clients.</p>\n<p><a href=\"http://mohanjith.com/wordpress/syntaxhighlighter2.html\">SyntaxHighlighter2</a></p>\n<p>Easily post source code such as PHP or HTML and display it in a styled box.</p>\n<p><a href=\"http://www.mittineague.com/dev/co.php\">Clean Options</a></p>\n<p>Finds orphaned options and allows for their removal from the wp_options table</p>\";}i:5;a:7:{s:5:\"title\";s:59:\"Weblog Tools Collection: WordPress Theme Releases for 03/17\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5350\";s:4:\"link\";s:87:\"http://weblogtoolscollection.com/archives/2009/03/17/wordpress-theme-releases-for-0317/\";s:11:\"description\";s:2856:\"<p><a href=\"http://themes.jestro.com/titan/\">Titan</a></p>\n<p><img title=\"Titan\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/titan.gif\" alt=\"Titan\" width=\"150\" height=\"87\" /></p>\n<p>Titan is a clean brown and white, two column theme.</p>\n<p><a href=\"http://human3rror.com/2009/03/13/crushpress-wordpress-theme-released/\">CrushPress</a></p>\n<p><img title=\"CrushPress\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/crushpress.jpg\" alt=\"CrushPress\" width=\"150\" height=\"125\" /></p>\n<p>Three column, fixed width, with a image rotator with a large content area for big photos or videos.</p>\n<p><a href=\"http://www.themestube.com/concrete-free-wordpress-theme/\">Concrete</a></p>\n<p><a href=\"http://demo.themestube.com/?wptheme=concrete\"><img title=\"Concrete\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/concrete.gif\" alt=\"Concrete\" width=\"150\" height=\"123\" /></a></p>\n<p>Concrete is a 2 Column stylish wordpress theme with some transparency effect and a grungy stone like background for that i named it “Concrete“. It’s a simple yet appealing theme giving your blog impressive look by beautifully used icons, content and twitter widget integration which automatically picks 3 last tweets from your twitter account and displays it with animated effect achieved using jQuery. It is fully Wordpress 2.7 ready and well designed by every aspect such as search form buttons, comment area and quote style.</p>\n<p><a href=\"http://www.acosmin.com/typographywp-free-wordpress-theme/\">Typography WP</a></p>\n<p><a href=\"http://typographywp.acosmin.com/\"><img title=\"Typography WP\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/typographywp.gif\" alt=\"Typography WP\" width=\"150\" height=\"85\" /></a></p>\n<p>A WordPress theme, using simple lines and nice typography. Some of the futures: drop down menu, threaded comments, control panel, different color scheme, different backgrounds and much more.</p>\n<p><a href=\"http://www.blogohblog.com/wordpress-theme-simple-paper/\">Simple Paper</a></p>\n<p><a href=\"http://wpthemes.blogohblog.net/index.php?wptheme=Simple+Paper\"><img title=\"Simple Paper\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/simplepaper.jpg\" alt=\"Simple Paper\" width=\"150\" height=\"87\" /></a></p>\n<p>Simple Paper comes with a unique design (left-aligned), fixed menu, stylized comments, paginated posts and easily editable CSS.</p>\n<p><a href=\"http://ableparris.com/2009/03/15/sugar-cane-a-sweet-wordpress-child-theme/\">Sugar Cane</a></p>\n<p><img title=\"Sugar Cane\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/sugarcane.jpg\" alt=\"Sugar Cane\" width=\"150\" height=\"131\" /></p>\n<p>Two column Wordpress child theme for the <a href=\"http://themeshaper.com/thematic-for-wordpress/\">Thematic framework</a> by Ian Stewart. Sugar Cane’s strength is that it makes both long and short posts look great and easy to read</p>\";s:7:\"pubdate\";s:31:\"Tue, 17 Mar 2009 14:31:32 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:2856:\"<p><a href=\"http://themes.jestro.com/titan/\">Titan</a></p>\n<p><img title=\"Titan\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/titan.gif\" alt=\"Titan\" width=\"150\" height=\"87\" /></p>\n<p>Titan is a clean brown and white, two column theme.</p>\n<p><a href=\"http://human3rror.com/2009/03/13/crushpress-wordpress-theme-released/\">CrushPress</a></p>\n<p><img title=\"CrushPress\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/crushpress.jpg\" alt=\"CrushPress\" width=\"150\" height=\"125\" /></p>\n<p>Three column, fixed width, with a image rotator with a large content area for big photos or videos.</p>\n<p><a href=\"http://www.themestube.com/concrete-free-wordpress-theme/\">Concrete</a></p>\n<p><a href=\"http://demo.themestube.com/?wptheme=concrete\"><img title=\"Concrete\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/concrete.gif\" alt=\"Concrete\" width=\"150\" height=\"123\" /></a></p>\n<p>Concrete is a 2 Column stylish wordpress theme with some transparency effect and a grungy stone like background for that i named it “Concrete“. It’s a simple yet appealing theme giving your blog impressive look by beautifully used icons, content and twitter widget integration which automatically picks 3 last tweets from your twitter account and displays it with animated effect achieved using jQuery. It is fully Wordpress 2.7 ready and well designed by every aspect such as search form buttons, comment area and quote style.</p>\n<p><a href=\"http://www.acosmin.com/typographywp-free-wordpress-theme/\">Typography WP</a></p>\n<p><a href=\"http://typographywp.acosmin.com/\"><img title=\"Typography WP\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/typographywp.gif\" alt=\"Typography WP\" width=\"150\" height=\"85\" /></a></p>\n<p>A WordPress theme, using simple lines and nice typography. Some of the futures: drop down menu, threaded comments, control panel, different color scheme, different backgrounds and much more.</p>\n<p><a href=\"http://www.blogohblog.com/wordpress-theme-simple-paper/\">Simple Paper</a></p>\n<p><a href=\"http://wpthemes.blogohblog.net/index.php?wptheme=Simple+Paper\"><img title=\"Simple Paper\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/simplepaper.jpg\" alt=\"Simple Paper\" width=\"150\" height=\"87\" /></a></p>\n<p>Simple Paper comes with a unique design (left-aligned), fixed menu, stylized comments, paginated posts and easily editable CSS.</p>\n<p><a href=\"http://ableparris.com/2009/03/15/sugar-cane-a-sweet-wordpress-child-theme/\">Sugar Cane</a></p>\n<p><img title=\"Sugar Cane\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/sugarcane.jpg\" alt=\"Sugar Cane\" width=\"150\" height=\"131\" /></p>\n<p>Two column Wordpress child theme for the <a href=\"http://themeshaper.com/thematic-for-wordpress/\">Thematic framework</a> by Ian Stewart. Sugar Cane’s strength is that it makes both long and short posts look great and easy to read</p>\";}i:6;a:7:{s:5:\"title\";s:44:\"Weblog Tools Collection: Postie Has New Life\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5336\";s:4:\"link\";s:73:\"http://weblogtoolscollection.com/archives/2009/03/16/postie-has-new-life/\";s:11:\"description\";s:1604:\"<p>Some of you may remember that back on January 15th, I asked <a href=\"http://weblogtoolscollection.com/archives/2009/01/15/do-you-post-by-email/\">if you had ever published a blog post via email</a>. Many of you in the comments let me know that you enjoyed using Postie but wished it contained some of the same features that are found with the <a href=\"http://posterous.com/\">Posterous</a> service. </p>\n<p>According to <a href=\"http://blog.robfelty.com/plugins/postie/\">Robert Felty</a> who has taken over development of the plugin, the new version of Postie enables the following:</p>\n<blockquote><p>Postie offers many advanced features for posting to your blog via e-mail, including the ability to assign categories by name, included pictures and videos, and automatically strip off signatures. It also has support for both imap and pop3, with the option for ssl with both.</p></blockquote>\n<p>The latest version which is 1.1.5 contains the following feature set:</p>\n<ul>\n<li> Added option to have postie posts be pending review, published, or draft</li>\n<li> Settings panel only shows up for administrators</li>\n<li> Need not be user &#8220;admin&#8221; to modify settings or to post from non-registered users</li>\n<li> Can now set administrator name. Authorized e-mail addresses which don&#8217;t have a user get posted under this name</li>\n<li> Will use IPTC captions if available</li>\n<li> Added option to replace newline characters with</li>\n</ul>\n<p>If you&#8217;re grateful for Robert stepping up and taking over development, think about donating some cash to him or at least, say thanks.</p>\";s:7:\"pubdate\";s:31:\"Mon, 16 Mar 2009 10:54:06 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:13:\"Jeff Chandler\";}s:7:\"summary\";s:1604:\"<p>Some of you may remember that back on January 15th, I asked <a href=\"http://weblogtoolscollection.com/archives/2009/01/15/do-you-post-by-email/\">if you had ever published a blog post via email</a>. Many of you in the comments let me know that you enjoyed using Postie but wished it contained some of the same features that are found with the <a href=\"http://posterous.com/\">Posterous</a> service. </p>\n<p>According to <a href=\"http://blog.robfelty.com/plugins/postie/\">Robert Felty</a> who has taken over development of the plugin, the new version of Postie enables the following:</p>\n<blockquote><p>Postie offers many advanced features for posting to your blog via e-mail, including the ability to assign categories by name, included pictures and videos, and automatically strip off signatures. It also has support for both imap and pop3, with the option for ssl with both.</p></blockquote>\n<p>The latest version which is 1.1.5 contains the following feature set:</p>\n<ul>\n<li> Added option to have postie posts be pending review, published, or draft</li>\n<li> Settings panel only shows up for administrators</li>\n<li> Need not be user &#8220;admin&#8221; to modify settings or to post from non-registered users</li>\n<li> Can now set administrator name. Authorized e-mail addresses which don&#8217;t have a user get posted under this name</li>\n<li> Will use IPTC captions if available</li>\n<li> Added option to replace newline characters with</li>\n</ul>\n<p>If you&#8217;re grateful for Robert stepping up and taking over development, think about donating some cash to him or at least, say thanks.</p>\";}i:7;a:7:{s:5:\"title\";s:49:\"Weblog Tools Collection: Plugin Review: WP Mollom\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5333\";s:4:\"link\";s:77:\"http://weblogtoolscollection.com/archives/2009/03/15/plugin-review-wp-mollom/\";s:11:\"description\";s:6077:\"<p>We hate spam. We hate it so much that we always find solutions to spam. So, this week we continue our <a href=\"http://weblogtoolscollection.com/archives/category/apad/\">Weekly Plugin Review</a> series with a review of an Akismet alternative called <a href=\"http://wordpress.org/extend/plugins/wp-mollom\">Mollom</a>.</p>\n<h3>Description:</h3>\n<p>This plugin makes it possible to use the anti-spam services provided by Mollom on your own Wordpress blog. What is Mollom? It&#8217;s a free anti-spam service that was founded by Dries Buytaert (Drupal) and Benjamin Schrauwen. The plugin can be used as a substitute for Akismet, Defensio, Spam Karma and others.</p>\n<h3>What does it do?</h3>\n<p><a href=\"http://mollom.com/\">Mollom</a> works much like Akismet: comments are sent to a central server which uses intelligent, self-learning algorithms to determine wether or not a comment is spam or not. Spam-classification isn&#8217;t a binary process and as a result, common anti-spam services perform bad when handling false positives. Mollom takes care of this. If it can&#8217;t clearly classify a comment, it will present the commenter with a secure CAPTCHA test instead of dumping the comment on an ever-increasing moderation queue that needs frequent attention. Mollom is a centralized service which can identify spammers across the network of websites who use Mollom. When a single spam-source is identified on one or more sites, the whole network will be protected against spam from that source.</p>\n<p>The main target is to make it as less time/effort consuming to fight spam so that weblog administrators can focus on what really matters: blogging and having fun!</p>\n<h3>Features:</h3>\n<ul>\n<li><strong>Easy install:</strong> Install the plugin through WP Extend or through the zip file. Register your site with Mollom to get a set of keys and configure the plugin.</li>\n<li><strong>Spam blocking:</strong> The plugin blocks spam before it&#8217;s even saved to the database. Only ham and comments for which a CAPTCHA has been successfully solved, will be saved.</li>\n<li><strong>Send feedback to Mollom:</strong> The plugin provides an alternate moderation module in the admin interface which allows you to send feedback to Mollom if, in your view, a comment is a false positive nonetheless. Mollom learns from this feedback!</li>\n<li><strong>CAPTCHA:</strong> You can see in the moderation queue which comments are &#8216;unapproved&#8217; or got a CAPTCHA. This should make it easy to spot potential false positives.</li>\n<li><strong>Statistics:</strong> Detailed statistics which show how Mollom is performing on your blog.</li>\n</ul>\n<h3>Review:</h3>\n<p>Honestly, there is not much I can talk about the effectiveness of the plugin, because testing this requires a few weeks / months before its true results can be seen. However, I am pretty pleased that there is yet another secondary service to Akismet and this one offers a few extra features.</p>\n<p>The fallback to the CAPTCHA option is a really good alternative to just blocking the user or the comment landing in the moderation queue and you requiring to manually approve comments.</p>\n<p>Mollom is available completely for free with upto 100 successful captcha and 100 legitimate posts, i.e. comments, posts, forum topics etc. per day. If you&#8217;re site is any heavier than this, then you&#8217;ll need to upgrade to the paid option of Mollum with is 30EUR monthly.</p>\n<p>If you&#8217;re getting started on the plugin you can refer to <a href=\"http://mollom.com/tutorials/wordpress\">the manual</a> for help.</p>\n<h3>Now, it&#8217;s your turn to Review:</h3>\n<p>We published a <a href=\"http://weblogtoolscollection.com/archives/2009/03/15/plugin-reviews-from-our-readers/\">list of reviews from our readers</a> today. I&#8217;m pleased to have received eight entries in less than four days. This week you have a choice of six plugins to choose from:</p>\n<ul>\n<li><a href=\"http://www.phoenixheart.net/2008/11/referrer-detector/\">Referrer Detector</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/01/11/plugin-review-referrer-detector/\">Our Review</a>)</li>\n<li><a href=\"http://www.mailpress.org/\">MailPress</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/02/08/plugin-review-mailpress/\">Our Review</a>)</li>\n<li><a href=\"http://garinungkadol.com/downloads/post-avatar/\">Post Avatar</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/02/22/plugin-review-post-avatar/\">Our Review</a>)</li>\n<li><a href=\"http://www.svenkubiak.de/yawasp-en/\">Yawasp (Yet Another WordPress Anti-Spam Plugin)</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/02/15/plugin-review-yawasp/\">Our Review</a>)</li>\n<li><a href=\"http://ajaydsouza.com/wordpress/plugins/autoclose/\">Autoclose</a> (<a href=\"http://weblogtoolscollection.com/archives/2009/02/01/plugin-review-autoclose/\">Our Review</a>)</li>\n<li><a href=\"http://wordpress.org/extend/plugins/wp-mollom\">WP Mollom</a></li>\n</ul>\n<p>You have until <strong>Saturday, March 21 - 11.59pm </strong><a href=\"http://wwp.greenwichmeantime.com/time-zone/usa/eastern-time/\"><strong>EST</strong></a> to send in your review to <strong>submissions AT wltc DOT net</strong> with the following information:</p>\n<p><strong>Subject line of the email:</strong> [APAD Plugin Review]: <em>plugin name</em>. Replace <em>plugin name</em> with the name of the plugin you reviewed.</p>\n<p><strong>Content of the Email:</strong></p>\n<ol>\n<li>URL of the review on your blog. Make sure this is a direct link to the post</li>\n<li>An excerpt of your post. Maximum 50 words. This will be used by us.</li>\n</ol>\n<p>Remember you&#8217;ll need to link to the corresponding review on our blog when you&#8217;re reviewing a plugin. You do not need to review a single plugin. If you so choose, you can review all the six plugins above in individual posts and send us separate emails for each of them! Refer to the <a href=\"http://weblogtoolscollection.com/archives/2009/03/11/would-you-like-to-review-plugins-on-wltc/\">original post for more details</a>.</p>\";s:7:\"pubdate\";s:31:\"Sun, 15 Mar 2009 19:00:55 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:6077:\"<p>We hate spam. We hate it so much that we always find solutions to spam. So, this week we continue our <a href=\"http://weblogtoolscollection.com/archives/category/apad/\">Weekly Plugin Review</a> series with a review of an Akismet alternative called <a href=\"http://wordpress.org/extend/plugins/wp-mollom\">Mollom</a>.</p>\n<h3>Description:</h3>\n<p>This plugin makes it possible to use the anti-spam services provided by Mollom on your own Wordpress blog. What is Mollom? It&#8217;s a free anti-spam service that was founded by Dries Buytaert (Drupal) and Benjamin Schrauwen. The plugin can be used as a substitute for Akismet, Defensio, Spam Karma and others.</p>\n<h3>What does it do?</h3>\n<p><a href=\"http://mollom.com/\">Mollom</a> works much like Akismet: comments are sent to a central server which uses intelligent, self-learning algorithms to determine wether or not a comment is spam or not. Spam-classification isn&#8217;t a binary process and as a result, common anti-spam services perform bad when handling false positives. Mollom takes care of this. If it can&#8217;t clearly classify a comment, it will present the commenter with a secure CAPTCHA test instead of dumping the comment on an ever-increasing moderation queue that needs frequent attention. Mollom is a centralized service which can identify spammers across the network of websites who use Mollom. When a single spam-source is identified on one or more sites, the whole network will be protected against spam from that source.</p>\n<p>The main target is to make it as less time/effort consuming to fight spam so that weblog administrators can focus on what really matters: blogging and having fun!</p>\n<h3>Features:</h3>\n<ul>\n<li><strong>Easy install:</strong> Install the plugin through WP Extend or through the zip file. Register your site with Mollom to get a set of keys and configure the plugin.</li>\n<li><strong>Spam blocking:</strong> The plugin blocks spam before it&#8217;s even saved to the database. Only ham and comments for which a CAPTCHA has been successfully solved, will be saved.</li>\n<li><strong>Send feedback to Mollom:</strong> The plugin provides an alternate moderation module in the admin interface which allows you to send feedback to Mollom if, in your view, a comment is a false positive nonetheless. Mollom learns from this feedback!</li>\n<li><strong>CAPTCHA:</strong> You can see in the moderation queue which comments are &#8216;unapproved&#8217; or got a CAPTCHA. This should make it easy to spot potential false positives.</li>\n<li><strong>Statistics:</strong> Detailed statistics which show how Mollom is performing on your blog.</li>\n</ul>\n<h3>Review:</h3>\n<p>Honestly, there is not much I can talk about the effectiveness of the plugin, because testing this requires a few weeks / months before its true results can be seen. However, I am pretty pleased that there is yet another secondary service to Akismet and this one offers a few extra features.</p>\n<p>The fallback to the CAPTCHA option is a really good alternative to just blocking the user or the comment landing in the moderation queue and you requiring to manually approve comments.</p>\n<p>Mollom is available completely for free with upto 100 successful captcha and 100 legitimate posts, i.e. comments, posts, forum topics etc. per day. If you&#8217;re site is any heavier than this, then you&#8217;ll need to upgrade to the paid option of Mollum with is 30EUR monthly.</p>\n<p>If you&#8217;re getting started on the plugin you can refer to <a href=\"http://mollom.com/tutorials/wordpress\">the manual</a> for help.</p>\n<h3>Now, it&#8217;s your turn to Review:</h3>\n<p>We published a <a href=\"http://weblogtoolscollection.com/archives/2009/03/15/plugin-reviews-from-our-readers/\">list of reviews from our readers</a> today. I&#8217;m pleased to have received eight entries in less than four days. This week you have a choice of six plugins to choose from:</p>\n<ul>\n<li><a href=\"http://www.phoenixheart.net/2008/11/referrer-detector/\">Referrer Detector</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/01/11/plugin-review-referrer-detector/\">Our Review</a>)</li>\n<li><a href=\"http://www.mailpress.org/\">MailPress</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/02/08/plugin-review-mailpress/\">Our Review</a>)</li>\n<li><a href=\"http://garinungkadol.com/downloads/post-avatar/\">Post Avatar</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/02/22/plugin-review-post-avatar/\">Our Review</a>)</li>\n<li><a href=\"http://www.svenkubiak.de/yawasp-en/\">Yawasp (Yet Another WordPress Anti-Spam Plugin)</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/02/15/plugin-review-yawasp/\">Our Review</a>)</li>\n<li><a href=\"http://ajaydsouza.com/wordpress/plugins/autoclose/\">Autoclose</a> (<a href=\"http://weblogtoolscollection.com/archives/2009/02/01/plugin-review-autoclose/\">Our Review</a>)</li>\n<li><a href=\"http://wordpress.org/extend/plugins/wp-mollom\">WP Mollom</a></li>\n</ul>\n<p>You have until <strong>Saturday, March 21 - 11.59pm </strong><a href=\"http://wwp.greenwichmeantime.com/time-zone/usa/eastern-time/\"><strong>EST</strong></a> to send in your review to <strong>submissions AT wltc DOT net</strong> with the following information:</p>\n<p><strong>Subject line of the email:</strong> [APAD Plugin Review]: <em>plugin name</em>. Replace <em>plugin name</em> with the name of the plugin you reviewed.</p>\n<p><strong>Content of the Email:</strong></p>\n<ol>\n<li>URL of the review on your blog. Make sure this is a direct link to the post</li>\n<li>An excerpt of your post. Maximum 50 words. This will be used by us.</li>\n</ol>\n<p>Remember you&#8217;ll need to link to the corresponding review on our blog when you&#8217;re reviewing a plugin. You do not need to review a single plugin. If you so choose, you can review all the six plugins above in individual posts and send us separate emails for each of them! Refer to the <a href=\"http://weblogtoolscollection.com/archives/2009/03/11/would-you-like-to-review-plugins-on-wltc/\">original post for more details</a>.</p>\";}i:8;a:7:{s:5:\"title\";s:71:\"Weblog Tools Collection: How to Track RSS Subscribers in a Blog Contest\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5276\";s:4:\"link\";s:100:\"http://weblogtoolscollection.com/archives/2009/03/15/how-to-track-rss-subscribers-in-a-blog-contest/\";s:11:\"description\";s:2852:\"<p>Let me start off by saying that this post will <strong>not</strong> talk about how to get sponsors, how to determine prizes, or how to determine rules for a blog contest.  This post will talk about how to tweak your WordPress blog to solve the biggest problem in running a blog contest to gain RSS subscribers.</p>\n<h3>Problem</h3>\n<p>The issue here is that there is no easy way to track if each contestant has actually subscribed to your RSS feed.  Without the ability to confirm RSS subscription, anybody can just claim that they have subscribed to your feed and get a free entry into the contest.</p>\n<h3>Solution</h3>\n<p>A known solution to this problem is to include a special contest code into your RSS feed and not have this code visible on your website.  That way each contestant will be forced to grab the code from your feed and submit the code via comments to verify that they have subscribed to the RSS feed.  To implement this solution with the minimum amount of effort you will need to do the following two things:</p>\n<h4>1. Include the special contest code into your RSS feed</h4>\n<p>You can automatically do this by adding the following code snippet to your theme&#8217;s functions.php.  The following code will make the text &#8220;Special Contest Code: yourcodehere&#8221; show up at the end of each post in the RSS feed, but not show up on your website.</p>\n<blockquote>\n<pre>function contest_post_filter($content) {\n  if ( is_feed() )\n    return $content.\'Special Contest Code: yourcodehere\';\n  else\n    return $content;\n}\nadd_filter(\'the_content\',\'contest_post_filter\');</pre>\n</blockquote>\n<p>Make sure you change &#8220;yourcodehere&#8221; to your own special contest code.</p>\n<h4>2. Automatically censor all comments with the code in it</h4>\n<p>You can automatically hide all RSS confirmation code in your comments by including the following code snippet into your functions.php:</p>\n<blockquote>\n<pre>function contest_comment_filter($comment_text) {\n  return str_replace(\'yourcodehere\', \'[code hidden]\', $comment_text);\n}\nadd_filter(\'get_comment_text\',\'contest_comment_filter\');</pre>\n</blockquote>\n<p>Once the contest is over, you can lock the comments on that post and remove the following line to have all confirmation codes reappear for validation:</p>\n<blockquote>\n<pre>add_filter(\'get_comment_text\',\'contest_comment_filter\');</pre>\n</blockquote>\n<h3>Why is Does This Work?</h3>\n<p>Simply because you do not have to deal with the contest again until your contest is over.  Your special contest code is hidden from view, so there is no way of cheating.  Once your contest is over, you can just un-hide the contest codes, tally up the participants, and [randomly] pick your winners.</p>\n<p>Do you think you have a better method of tracking RSS subscribers in a contest?  If so, please share in the comments section.</p>\";s:7:\"pubdate\";s:31:\"Sun, 15 Mar 2009 11:52:50 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:14:\"Thaya Kareeson\";}s:7:\"summary\";s:2852:\"<p>Let me start off by saying that this post will <strong>not</strong> talk about how to get sponsors, how to determine prizes, or how to determine rules for a blog contest.  This post will talk about how to tweak your WordPress blog to solve the biggest problem in running a blog contest to gain RSS subscribers.</p>\n<h3>Problem</h3>\n<p>The issue here is that there is no easy way to track if each contestant has actually subscribed to your RSS feed.  Without the ability to confirm RSS subscription, anybody can just claim that they have subscribed to your feed and get a free entry into the contest.</p>\n<h3>Solution</h3>\n<p>A known solution to this problem is to include a special contest code into your RSS feed and not have this code visible on your website.  That way each contestant will be forced to grab the code from your feed and submit the code via comments to verify that they have subscribed to the RSS feed.  To implement this solution with the minimum amount of effort you will need to do the following two things:</p>\n<h4>1. Include the special contest code into your RSS feed</h4>\n<p>You can automatically do this by adding the following code snippet to your theme&#8217;s functions.php.  The following code will make the text &#8220;Special Contest Code: yourcodehere&#8221; show up at the end of each post in the RSS feed, but not show up on your website.</p>\n<blockquote>\n<pre>function contest_post_filter($content) {\n  if ( is_feed() )\n    return $content.\'Special Contest Code: yourcodehere\';\n  else\n    return $content;\n}\nadd_filter(\'the_content\',\'contest_post_filter\');</pre>\n</blockquote>\n<p>Make sure you change &#8220;yourcodehere&#8221; to your own special contest code.</p>\n<h4>2. Automatically censor all comments with the code in it</h4>\n<p>You can automatically hide all RSS confirmation code in your comments by including the following code snippet into your functions.php:</p>\n<blockquote>\n<pre>function contest_comment_filter($comment_text) {\n  return str_replace(\'yourcodehere\', \'[code hidden]\', $comment_text);\n}\nadd_filter(\'get_comment_text\',\'contest_comment_filter\');</pre>\n</blockquote>\n<p>Once the contest is over, you can lock the comments on that post and remove the following line to have all confirmation codes reappear for validation:</p>\n<blockquote>\n<pre>add_filter(\'get_comment_text\',\'contest_comment_filter\');</pre>\n</blockquote>\n<h3>Why is Does This Work?</h3>\n<p>Simply because you do not have to deal with the contest again until your contest is over.  Your special contest code is hidden from view, so there is no way of cheating.  Once your contest is over, you can just un-hide the contest codes, tally up the participants, and [randomly] pick your winners.</p>\n<p>Do you think you have a better method of tracking RSS subscribers in a contest?  If so, please share in the comments section.</p>\";}i:9;a:7:{s:5:\"title\";s:23:\"Matt: Arriving in Hanoi\";s:4:\"guid\";s:21:\"http://ma.tt/?p=12274\";s:4:\"link\";s:39:\"http://ma.tt/2009/03/arriving-in-hanoi/\";s:11:\"description\";s:14672:\"<p>Arriving in Hanoi, Vietnam and some brief sojourns around the city.</p>\n<p><span id=\"more-12274\"></span></p>\n\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0364-2/\" title=\"mcm_0364\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0364-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0364\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0365-2/\" title=\"mcm_0365\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0365-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"rice field in suburb of hanoi\" title=\"mcm_0365\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0366-2/\" title=\"mcm_0366\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0366-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0366\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0367-2/\" title=\"mcm_0367\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0367-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0367\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0368/\" title=\"mcm_0368\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0368-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0368\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0369/\" title=\"mcm_0369\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0369-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0369\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0370/\" title=\"mcm_0370\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0370-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0370\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0371/\" title=\"mcm_0371\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0371-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0371\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0372/\" title=\"mcm_0372\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0372-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0372\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0373/\" title=\"mcm_0373\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0373-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0373\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0374-2/\" title=\"mcm_0374\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0374-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0374\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0375/\" title=\"mcm_0375\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0375-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0375\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0376/\" title=\"mcm_0376\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_0376-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0376\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0377/\" title=\"mcm_0377\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0377-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0377\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0378/\" title=\"mcm_0378\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0378-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0378\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0379-2/\" title=\"mcm_0379\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0379-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0379\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0381/\" title=\"mcm_0381\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0381-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0381\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0382-2/\" title=\"mcm_0382\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0382-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0382\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0384/\" title=\"mcm_0384\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0384-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0384\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0386-2/\" title=\"mcm_0386\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0386-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0386\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0387-2/\" title=\"mcm_0387\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0387-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0387\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0388/\" title=\"mcm_0388\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0388-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0388\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0390/\" title=\"mcm_0390\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0390-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0390\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0391-2/\" title=\"mcm_0391\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0391-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0391\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0392/\" title=\"mcm_0392\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0392-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0392\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0393/\" title=\"mcm_0393\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0393-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0393\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0394-2/\" title=\"mcm_0394\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0394-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0394\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0395/\" title=\"mcm_0395\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0395-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0395\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0396-2/\" title=\"mcm_0396\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0396-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0396\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0397/\" title=\"mcm_0397\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0397-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0397\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0398/\" title=\"mcm_0398\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0398-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0398\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0399-2/\" title=\"mcm_0399\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0399-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0399\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0400/\" title=\"mcm_0400\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0400-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0400\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0401-2/\" title=\"mcm_0401\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0401-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"She really loves that chicken\" title=\"mcm_0401\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0403-2/\" title=\"mcm_0403\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0403-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0403\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0405/\" title=\"mcm_0405\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0405-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0405\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0406-2/\" title=\"mcm_0406\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0406-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0406\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0409/\" title=\"mcm_0409\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0409-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0409\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0410-2/\" title=\"mcm_0410\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0410-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0410\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0412/\" title=\"mcm_0412\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0412-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0412\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0413/\" title=\"mcm_0413\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0413-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0413\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0416/\" title=\"mcm_0416\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_0416-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0416\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0417/\" title=\"mcm_0417\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0417-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0417\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0418/\" title=\"mcm_0418\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0418-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0418\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0419-2/\" title=\"mcm_0419\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0419-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0419\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0422-2/\" title=\"mcm_0422\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0422-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0422\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0423-2/\" title=\"mcm_0423\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0423-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0423\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0425/\" title=\"mcm_0425\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0425-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0425\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0426/\" title=\"mcm_0426\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0426-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0426\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0427-2/\" title=\"mcm_0427\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0427-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0427\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0428-2/\" title=\"mcm_0428\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0428-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0428\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0429-2/\" title=\"mcm_0429\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_0429-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0429\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0430-2/\" title=\"mcm_0430\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0430-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0430\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0431-3/\" title=\"mcm_0431\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0431-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0431\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0432-3/\" title=\"mcm_0432\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0432-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0432\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0433-3/\" title=\"mcm_0433\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0433-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0433\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0434-2/\" title=\"mcm_0434\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0434-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0434\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0435-3/\" title=\"mcm_0435\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0435-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0435\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0437-2/\" title=\"mcm_0437\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0437-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0437\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0438-2/\" title=\"mcm_0438\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0438-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0438\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0439-2/\" title=\"mcm_0439\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0439-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0439\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0440-2/\" title=\"mcm_0440\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0440-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0440\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0441-3/\" title=\"mcm_0441\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0441-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0441\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0442-3/\" title=\"mcm_0442\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0442-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0442\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0443-2/\" title=\"mcm_0443\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0443-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0443\" /></a>\";s:7:\"pubdate\";s:31:\"Sun, 15 Mar 2009 09:32:06 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:14672:\"<p>Arriving in Hanoi, Vietnam and some brief sojourns around the city.</p>\n<p><span id=\"more-12274\"></span></p>\n\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0364-2/\" title=\"mcm_0364\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0364-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0364\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0365-2/\" title=\"mcm_0365\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0365-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"rice field in suburb of hanoi\" title=\"mcm_0365\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0366-2/\" title=\"mcm_0366\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0366-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0366\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0367-2/\" title=\"mcm_0367\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0367-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0367\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0368/\" title=\"mcm_0368\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0368-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0368\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0369/\" title=\"mcm_0369\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0369-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0369\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0370/\" title=\"mcm_0370\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0370-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0370\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0371/\" title=\"mcm_0371\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0371-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0371\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0372/\" title=\"mcm_0372\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0372-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0372\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0373/\" title=\"mcm_0373\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0373-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0373\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0374-2/\" title=\"mcm_0374\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0374-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0374\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0375/\" title=\"mcm_0375\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0375-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0375\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0376/\" title=\"mcm_0376\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_0376-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0376\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0377/\" title=\"mcm_0377\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0377-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0377\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0378/\" title=\"mcm_0378\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0378-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0378\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0379-2/\" title=\"mcm_0379\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0379-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0379\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0381/\" title=\"mcm_0381\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0381-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0381\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0382-2/\" title=\"mcm_0382\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0382-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0382\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0384/\" title=\"mcm_0384\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0384-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0384\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0386-2/\" title=\"mcm_0386\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0386-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0386\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0387-2/\" title=\"mcm_0387\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0387-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0387\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0388/\" title=\"mcm_0388\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0388-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0388\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0390/\" title=\"mcm_0390\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0390-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0390\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0391-2/\" title=\"mcm_0391\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0391-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0391\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0392/\" title=\"mcm_0392\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0392-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0392\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0393/\" title=\"mcm_0393\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0393-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0393\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0394-2/\" title=\"mcm_0394\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0394-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0394\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0395/\" title=\"mcm_0395\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0395-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0395\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0396-2/\" title=\"mcm_0396\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0396-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0396\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0397/\" title=\"mcm_0397\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0397-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0397\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0398/\" title=\"mcm_0398\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0398-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0398\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0399-2/\" title=\"mcm_0399\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0399-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0399\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0400/\" title=\"mcm_0400\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0400-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0400\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0401-2/\" title=\"mcm_0401\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0401-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"She really loves that chicken\" title=\"mcm_0401\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0403-2/\" title=\"mcm_0403\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0403-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0403\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0405/\" title=\"mcm_0405\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0405-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0405\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0406-2/\" title=\"mcm_0406\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0406-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0406\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0409/\" title=\"mcm_0409\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0409-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0409\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0410-2/\" title=\"mcm_0410\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0410-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0410\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0412/\" title=\"mcm_0412\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0412-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0412\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0413/\" title=\"mcm_0413\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0413-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0413\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0416/\" title=\"mcm_0416\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_0416-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0416\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0417/\" title=\"mcm_0417\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0417-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0417\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0418/\" title=\"mcm_0418\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0418-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0418\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0419-2/\" title=\"mcm_0419\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0419-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0419\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0422-2/\" title=\"mcm_0422\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0422-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0422\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0423-2/\" title=\"mcm_0423\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0423-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0423\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0425/\" title=\"mcm_0425\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0425-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0425\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0426/\" title=\"mcm_0426\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0426-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0426\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0427-2/\" title=\"mcm_0427\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0427-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0427\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0428-2/\" title=\"mcm_0428\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0428-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0428\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0429-2/\" title=\"mcm_0429\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_0429-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0429\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0430-2/\" title=\"mcm_0430\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0430-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0430\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0431-3/\" title=\"mcm_0431\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0431-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0431\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0432-3/\" title=\"mcm_0432\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0432-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0432\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0433-3/\" title=\"mcm_0433\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0433-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0433\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0434-2/\" title=\"mcm_0434\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0434-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0434\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0435-3/\" title=\"mcm_0435\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0435-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0435\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0437-2/\" title=\"mcm_0437\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0437-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0437\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0438-2/\" title=\"mcm_0438\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0438-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0438\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0439-2/\" title=\"mcm_0439\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0439-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0439\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0440-2/\" title=\"mcm_0440\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0440-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0440\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0441-3/\" title=\"mcm_0441\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0441-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0441\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0442-3/\" title=\"mcm_0442\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0442-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0442\" /></a>\n<a href=\"http://ma.tt/2009/03/arriving-in-hanoi/mcm_0443-2/\" title=\"mcm_0443\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_0443-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0443\" /></a>\";}i:10;a:7:{s:5:\"title\";s:23:\"Matt: Gravatar in Gmail\";s:4:\"guid\";s:21:\"http://ma.tt/?p=12652\";s:4:\"link\";s:39:\"http://ma.tt/2009/03/gravatar-in-gmail/\";s:11:\"description\";s:277:\"<p><a href=\"http://jonefox.com/blog/2009/03/14/gravatar-in-gmail/\">Jon experiments with Gravatar in Gmail</a>. I would love to see more of this. We also need a better way to get Gravatars into your Apple address book / iPhone for people that don&#8217;t have a set picture.</p>\";s:7:\"pubdate\";s:31:\"Sun, 15 Mar 2009 09:29:46 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:277:\"<p><a href=\"http://jonefox.com/blog/2009/03/14/gravatar-in-gmail/\">Jon experiments with Gravatar in Gmail</a>. I would love to see more of this. We also need a better way to get Gravatars into your Apple address book / iPhone for people that don&#8217;t have a set picture.</p>\";}i:11;a:7:{s:5:\"title\";s:56:\"Weblog Tools Collection: Plugin Reviews from our Readers\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5327\";s:4:\"link\";s:85:\"http://weblogtoolscollection.com/archives/2009/03/15/plugin-reviews-from-our-readers/\";s:11:\"description\";s:8837:\"<p>Having launched our new <a title=\"View posts from User Reviews Category\" href=\"http://weblogtoolscollection.com/archives/category/user-reviews/\">User Reviews</a> process for plugins, I didn&#8217;t give most our readers any time to get their plugin reviews across to me. In spite of this, we received a total eight plugin reviews for five different plugins.</p>\n<p>Here&#8217;s the list. Do check out the links and read what the reviewer has to say. Did you like their review? Comment and tell them. Share your experiences of the plugins with them.</p>\n<h3>WP Greet Box</h3>\n<p>We <a href=\"http://weblogtoolscollection.com/archives/2009/01/18/plugin-review-wp-greet-box/\">reviewed WP Greet Box</a> on January 18. WP Greet Box is a simple plugin lets you show a different greeting message to your new visitors depending on their referrer URL.</p>\n<p>WP Greet Box topped our list with three reviews of the eight reviews we received.</p>\n<p><strong>JayPee</strong> had this to say:</p>\n<blockquote><p>WP Greet Box not only helps you promote your RSS feed and increase your RSS feed readers but having these targeted suggestions on your blog increases your blog exposure and loyal readership. Aside from promoting your RSS feed, encouraging social network bookmarking and article submission, WP Greet Box also displays related posts to the current post which leads to more pageviews and helps reduce bounce rate.</p></blockquote>\n<p><a href=\"http://jaypeeonline.net/wordpress-plugins/wp-plugin-review-wp-greet-box/\">Read the complete review from JayPee Online &gt;</a></p>\n<p><strong>David Porter</strong>, the WordPress Master talks about WP Greet Box:</p>\n<blockquote><p>As a blog publisher, one of the things I’m (and just about every blogger) always looking for is a new way to add more RSS feed subscribers and to get my blog to start out a bit from others.</p>\n<p>There are a lot plugins to help with this out there, but not all plugins are created equal, if ya know what I mean.</p>\n<p>Today, I want to show a plugin that I’ve fallen in love with, and that helps with getting those RSS readers and with making you stick out a bit in a over populated blogger’s world.</p>\n<p>The plugin is called: WP Greet Box</p></blockquote>\n<p><a href=\"http://www.wordpress-master.com/plugin-review-wp-greet-box.html\">Read the complete review from WordPress Master</a></p>\n<p>Keenan Payne <strong>Pro Blog Tutorials</strong> reviewed WP Greet Box, pretty much following the pattern we have out here on WLTC.</p>\n<blockquote><p>Once you install and activate the plugin, it’s all self-explanatory from there. One thing you will more than likely do when you first install the plugin is activate various greeting messages. The default messages that come with the plugin are the ones like Digg, MySpace, FaceBook, and many, many more.</p></blockquote>\n<p><a href=\"http://problogtuts.com/plugins/wp-plugin-review-wp-greet-box/\">Read the complete review from Pro Blog Tutorials &gt;</a></p>\n<h3>Improved Plugin Installation</h3>\n<p>We <a href=\"http://weblogtoolscollection.com/archives/2009/03/01/plugin-review-improved-plugin-installation/\">reviewed Improved Plugin Installation</a> on March 1. This plugin is an improvement to the current WP 2.7 plugin installation methods. It allows you to install one or more plugins simply by typing the names of the plugins or the download URLs in a textarea. This means you can install all your favorite wordpress plugins in one go!</p>\n<p>IPI came in as second with two plugin reviews of the eight.</p>\n<p>The first was by <strong>Fyre Vortex</strong>:</p>\n<blockquote><p>Gone are the times that you have to scour to the ends of the Internet to find the plugin for Wordpress that you wanted. But you couldn&#8217;t remember the name of the plugin/author of it.</p>\n<p>Or that you just wanted to go to the plugin site, click a bookmarklet (You know, like the Is.Gd and Tr.Im bookarmklets that you drag up to your menu bar and click for something to happen?) and have it installed automatically?</p>\n<p>Well, luckily for you, all of the features that I mentioned are all in this one plugin: Improved Plugin Installation!</p></blockquote>\n<p><a href=\"http://fyrevortex.com/2009/03/12/improved-plugin-installation/\">Read the complete review from Fyre Vortex &gt;</a></p>\n<p>The second was by Lynette of <strong>Tech Based Marketing</strong>:</p>\n<blockquote><p>When WordPress released version 2.7 with better plugin discovery, and installation features, I literally did a happy dance - now let’s hope for something similar for themes but that’s another post for another day. So when I saw the Improved Plugin Installation Plugin mentioned over at Weblog Tools Collection&#8230;</p></blockquote>\n<p><a href=\"http://techbasedmarketing.com/blog/business-blogging/wordpress-plugin-installation-gets-even-easier/1030/\">Read the complete review from Tech Based Marketing &gt;</a></p>\n<h3>WP125</h3>\n<p>We <a href=\"http://weblogtoolscollection.com/archives/2009/01/25/plugin-review-wp125/\">reviewed WP125</a> on January 25th. The <a href=\"http://www.webmaster-source.com/wp125-ad-plugin-wordpress/\">WP125</a> plugin is designed to make it easy to manage 125×125 banner ads on your blog.</p>\n<p>WP125 received one review from Izzat Aziz:</p>\n<blockquote><p>WP125 is Wordpress Plugin that handled my 125 x 125 ads at the sidebar. It make advertiser job easier and faster. Even so there is some bug and need improvement.</p></blockquote>\n<p><a href=\"http://izzataziz.com/2009/03/12/wp125-wordpress-plugin-review/\">Read the complete review from Izzat &gt;</a></p>\n<h3>Feed Reading Blogroll</h3>\n<p>We <a href=\"http://weblogtoolscollection.com/archives/2009/03/08/plugin-review-feed-reading-blogroll/\">reviewed Feed Reading Blog Roll</a> last week. This plugin provides a sidebar-widget and a template-tag that add an enhanced blogroll to your sidebar. It checks on all your linked sites, when the most recent update has occurred.</p>\n<p>FRB received one review from <strong>Aggelos</strong>:</p>\n<blockquote><p>If you got bored of these flat blogrolls, or if you want to offer something more to your visitors, then the Feed Reading Blogroll is what you are looking for. We are already planing to implement this plugin on our new Thessaloniki section. So, what is this plugin about? How it works? How or why are we going to use it on our new section? Just read the rest of the story.</p></blockquote>\n<p><a href=\"http://www.newsfilter.gr/2009/03/14/feed-reading-blogroll-wordpress-plugin-review/\">Read the complete review from News Filter &gt;</a></p>\n<h3>Simple:Press</h3>\n<p>This was <a href=\"http://weblogtoolscollection.com/archives/2009/01/04/plugin-review-simplepress-forum/\">the first plugin we reviewed</a> on January 4. Simple:Press is a feature rich forum plugin for WordPress. It fully integrates into your WP based site utilizing the same user records and database and displaying on a single WP page.</p>\n<p>Simple:Press also received one review from <strong>Sebastian</strong>:</p>\n<blockquote><p>After a  bbPress rant in my last post about forum plugins, I reviewed Simple:Press now. I take you from installation over managing option, setting up forums and customizing the look straight to the posting action. Come with me.</p></blockquote>\n<p><a href=\"http://we-hate-you.com/2009/webdesign-css-wordpress/simplepress-plugin-review\">Read the complete review from We Hate You &gt;</a></p>\n<h3>The Others</h3>\n<p>Four plugins remained without a review this week.</p>\n<ul>\n<li><a href=\"http://www.phoenixheart.net/2008/11/referrer-detector/\">Referrer Detector</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/01/11/plugin-review-referrer-detector/\">Our Review</a>)</li>\n<li><a href=\"http://www.mailpress.org/\">MailPress</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/02/08/plugin-review-mailpress/\">Our Review</a>)</li>\n<li><a href=\"http://garinungkadol.com/downloads/post-avatar/\">Post Avatar</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/02/22/plugin-review-post-avatar/\">Our Review</a>)</li>\n<li><a href=\"http://www.svenkubiak.de/yawasp-en/\">Yawasp (Yet Another WordPress Anti-Spam Plugin)</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/02/15/plugin-review-yawasp/\">Our Review</a>)</li>\n</ul>\n<p>Yet another <a href=\"http://weblogtoolscollection.com/archives/2009/02/01/plugin-review-autoclose/\">plugin that we reviewed</a> and I missed to mention in my earlier blog post was <a href=\"http://ajaydsouza.com/wordpress/plugins/autoclose/\">AutoClose</a>.</p>\n<p>If you haven&#8217;t reviewed any plugin this week, don&#8217;t worry. For next week, you have the five plugins above which did not receive a review, in addition to the one I&#8217;ll be reviewing later today. I&#8217;ll give you further details about the same in that post.</p>\";s:7:\"pubdate\";s:31:\"Sun, 15 Mar 2009 08:19:29 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:8837:\"<p>Having launched our new <a title=\"View posts from User Reviews Category\" href=\"http://weblogtoolscollection.com/archives/category/user-reviews/\">User Reviews</a> process for plugins, I didn&#8217;t give most our readers any time to get their plugin reviews across to me. In spite of this, we received a total eight plugin reviews for five different plugins.</p>\n<p>Here&#8217;s the list. Do check out the links and read what the reviewer has to say. Did you like their review? Comment and tell them. Share your experiences of the plugins with them.</p>\n<h3>WP Greet Box</h3>\n<p>We <a href=\"http://weblogtoolscollection.com/archives/2009/01/18/plugin-review-wp-greet-box/\">reviewed WP Greet Box</a> on January 18. WP Greet Box is a simple plugin lets you show a different greeting message to your new visitors depending on their referrer URL.</p>\n<p>WP Greet Box topped our list with three reviews of the eight reviews we received.</p>\n<p><strong>JayPee</strong> had this to say:</p>\n<blockquote><p>WP Greet Box not only helps you promote your RSS feed and increase your RSS feed readers but having these targeted suggestions on your blog increases your blog exposure and loyal readership. Aside from promoting your RSS feed, encouraging social network bookmarking and article submission, WP Greet Box also displays related posts to the current post which leads to more pageviews and helps reduce bounce rate.</p></blockquote>\n<p><a href=\"http://jaypeeonline.net/wordpress-plugins/wp-plugin-review-wp-greet-box/\">Read the complete review from JayPee Online &gt;</a></p>\n<p><strong>David Porter</strong>, the WordPress Master talks about WP Greet Box:</p>\n<blockquote><p>As a blog publisher, one of the things I’m (and just about every blogger) always looking for is a new way to add more RSS feed subscribers and to get my blog to start out a bit from others.</p>\n<p>There are a lot plugins to help with this out there, but not all plugins are created equal, if ya know what I mean.</p>\n<p>Today, I want to show a plugin that I’ve fallen in love with, and that helps with getting those RSS readers and with making you stick out a bit in a over populated blogger’s world.</p>\n<p>The plugin is called: WP Greet Box</p></blockquote>\n<p><a href=\"http://www.wordpress-master.com/plugin-review-wp-greet-box.html\">Read the complete review from WordPress Master</a></p>\n<p>Keenan Payne <strong>Pro Blog Tutorials</strong> reviewed WP Greet Box, pretty much following the pattern we have out here on WLTC.</p>\n<blockquote><p>Once you install and activate the plugin, it’s all self-explanatory from there. One thing you will more than likely do when you first install the plugin is activate various greeting messages. The default messages that come with the plugin are the ones like Digg, MySpace, FaceBook, and many, many more.</p></blockquote>\n<p><a href=\"http://problogtuts.com/plugins/wp-plugin-review-wp-greet-box/\">Read the complete review from Pro Blog Tutorials &gt;</a></p>\n<h3>Improved Plugin Installation</h3>\n<p>We <a href=\"http://weblogtoolscollection.com/archives/2009/03/01/plugin-review-improved-plugin-installation/\">reviewed Improved Plugin Installation</a> on March 1. This plugin is an improvement to the current WP 2.7 plugin installation methods. It allows you to install one or more plugins simply by typing the names of the plugins or the download URLs in a textarea. This means you can install all your favorite wordpress plugins in one go!</p>\n<p>IPI came in as second with two plugin reviews of the eight.</p>\n<p>The first was by <strong>Fyre Vortex</strong>:</p>\n<blockquote><p>Gone are the times that you have to scour to the ends of the Internet to find the plugin for Wordpress that you wanted. But you couldn&#8217;t remember the name of the plugin/author of it.</p>\n<p>Or that you just wanted to go to the plugin site, click a bookmarklet (You know, like the Is.Gd and Tr.Im bookarmklets that you drag up to your menu bar and click for something to happen?) and have it installed automatically?</p>\n<p>Well, luckily for you, all of the features that I mentioned are all in this one plugin: Improved Plugin Installation!</p></blockquote>\n<p><a href=\"http://fyrevortex.com/2009/03/12/improved-plugin-installation/\">Read the complete review from Fyre Vortex &gt;</a></p>\n<p>The second was by Lynette of <strong>Tech Based Marketing</strong>:</p>\n<blockquote><p>When WordPress released version 2.7 with better plugin discovery, and installation features, I literally did a happy dance - now let’s hope for something similar for themes but that’s another post for another day. So when I saw the Improved Plugin Installation Plugin mentioned over at Weblog Tools Collection&#8230;</p></blockquote>\n<p><a href=\"http://techbasedmarketing.com/blog/business-blogging/wordpress-plugin-installation-gets-even-easier/1030/\">Read the complete review from Tech Based Marketing &gt;</a></p>\n<h3>WP125</h3>\n<p>We <a href=\"http://weblogtoolscollection.com/archives/2009/01/25/plugin-review-wp125/\">reviewed WP125</a> on January 25th. The <a href=\"http://www.webmaster-source.com/wp125-ad-plugin-wordpress/\">WP125</a> plugin is designed to make it easy to manage 125×125 banner ads on your blog.</p>\n<p>WP125 received one review from Izzat Aziz:</p>\n<blockquote><p>WP125 is Wordpress Plugin that handled my 125 x 125 ads at the sidebar. It make advertiser job easier and faster. Even so there is some bug and need improvement.</p></blockquote>\n<p><a href=\"http://izzataziz.com/2009/03/12/wp125-wordpress-plugin-review/\">Read the complete review from Izzat &gt;</a></p>\n<h3>Feed Reading Blogroll</h3>\n<p>We <a href=\"http://weblogtoolscollection.com/archives/2009/03/08/plugin-review-feed-reading-blogroll/\">reviewed Feed Reading Blog Roll</a> last week. This plugin provides a sidebar-widget and a template-tag that add an enhanced blogroll to your sidebar. It checks on all your linked sites, when the most recent update has occurred.</p>\n<p>FRB received one review from <strong>Aggelos</strong>:</p>\n<blockquote><p>If you got bored of these flat blogrolls, or if you want to offer something more to your visitors, then the Feed Reading Blogroll is what you are looking for. We are already planing to implement this plugin on our new Thessaloniki section. So, what is this plugin about? How it works? How or why are we going to use it on our new section? Just read the rest of the story.</p></blockquote>\n<p><a href=\"http://www.newsfilter.gr/2009/03/14/feed-reading-blogroll-wordpress-plugin-review/\">Read the complete review from News Filter &gt;</a></p>\n<h3>Simple:Press</h3>\n<p>This was <a href=\"http://weblogtoolscollection.com/archives/2009/01/04/plugin-review-simplepress-forum/\">the first plugin we reviewed</a> on January 4. Simple:Press is a feature rich forum plugin for WordPress. It fully integrates into your WP based site utilizing the same user records and database and displaying on a single WP page.</p>\n<p>Simple:Press also received one review from <strong>Sebastian</strong>:</p>\n<blockquote><p>After a  bbPress rant in my last post about forum plugins, I reviewed Simple:Press now. I take you from installation over managing option, setting up forums and customizing the look straight to the posting action. Come with me.</p></blockquote>\n<p><a href=\"http://we-hate-you.com/2009/webdesign-css-wordpress/simplepress-plugin-review\">Read the complete review from We Hate You &gt;</a></p>\n<h3>The Others</h3>\n<p>Four plugins remained without a review this week.</p>\n<ul>\n<li><a href=\"http://www.phoenixheart.net/2008/11/referrer-detector/\">Referrer Detector</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/01/11/plugin-review-referrer-detector/\">Our Review</a>)</li>\n<li><a href=\"http://www.mailpress.org/\">MailPress</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/02/08/plugin-review-mailpress/\">Our Review</a>)</li>\n<li><a href=\"http://garinungkadol.com/downloads/post-avatar/\">Post Avatar</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/02/22/plugin-review-post-avatar/\">Our Review</a>)</li>\n<li><a href=\"http://www.svenkubiak.de/yawasp-en/\">Yawasp (Yet Another WordPress Anti-Spam Plugin)</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/02/15/plugin-review-yawasp/\">Our Review</a>)</li>\n</ul>\n<p>Yet another <a href=\"http://weblogtoolscollection.com/archives/2009/02/01/plugin-review-autoclose/\">plugin that we reviewed</a> and I missed to mention in my earlier blog post was <a href=\"http://ajaydsouza.com/wordpress/plugins/autoclose/\">AutoClose</a>.</p>\n<p>If you haven&#8217;t reviewed any plugin this week, don&#8217;t worry. For next week, you have the five plugins above which did not receive a review, in addition to the one I&#8217;ll be reviewing later today. I&#8217;ll give you further details about the same in that post.</p>\";}i:12;a:7:{s:5:\"title\";s:60:\"Weblog Tools Collection: WordPress Plugin Releases for 03/14\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5321\";s:4:\"link\";s:88:\"http://weblogtoolscollection.com/archives/2009/03/14/wordpress-plugin-releases-for-0314/\";s:11:\"description\";s:4250:\"<h3>New Releases</h3>\n<p><a href=\"http://wp.gdragon.info/2009/03/09/gd-press-tools-020/\">GD Press Tools</a></p>\n<p>GD Press Tools is a collection of various additional administration tools. Plugin is still under heavy development and over time number of tools will grow.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/julia-beta/\">JuLiA</a></p>\n<p>JuLiA (Just a Linguistic Algorithm) is an automated comment moderation plugin for Wordpress that uses machine learning and natural language processing techniques to recognize abusiveness in comment content.</p>\n<p><a href=\"http://www.goosegrade.com/wordpress\">gooseGrade Plugin</a></p>\n<p>Allow your readers to become citizen editors. gooseGrade is a free service that allows your readers to post spelling, grammar, factual, and other errors straight to you. After you or any other WordPress admin approves the edit, the gooseGrade plugin will automatically fix the error. It&#8217;s like magic.</p>\n<p><a href=\"http://bavotasan.com/wordpress/free-wordpress-plugins/simple-image-grabber-wordpress-plugin/\">Simple Image Grabber</a></p>\n<p>Retrieve and display images from a WordPress post.</p>\n<p><a href=\"http://www.ilovecolors.com.ar/folding-menu-plugin-wordpress/\">Folding Menu Plugin</a></p>\n<p>Create a folding menu for WordPress built in Pages widget using jQuery.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/peoplepond/\">PeoplePond</a></p>\n<p><a href=\"http://peoplepond.com/\">PeoplePond</a> provides the tools needed to take ownership of your online identity and reputation management.</p>\n<p><a href=\"http://www.paulmc.org/whatithink/wordpress/plugins/twitter-friends-widget/\">Twitter Friends Widget</a></p>\n<p>Twitter Friends is a WordPress plugin that displays your Twitter friends in your sidebar in the same way that they appear on your Twitter homepage.</p>\n<h3>Updated Releases</h3>\n<p><a href=\"http://ajaydsouza.com/wordpress/plugins/top-10/\">Top 10</a></p>\n<p>WordPress doesn’t count page views by default. Top 10 will count the number of page views on your single posts on a daily as well as overall basis. You can then display the page view count on individual posts and pages as well as display a list of most popular posts based on page views.</p>\n<p>The latest version includes the ability to choose &#8220;daily popular&#8221; should be of how many days. List is also compatible with caching plugins. Also added a new page in WP-Admin to view the popular posts. <em>Deactivate old version before upgrading</em>.</p>\n<p><a href=\"http://sivel.net/2009/02/public-post-preview/\">Public Post Preview</a></p>\n<p>Enables you to give a link to anonymous users for public preview of a post before it is published.</p>\n<p>New to this update is not limiting public previews to posts in draft or pending status. The plugin now allows public previews of any post that is not in ‘publish’ status.</p>\n<p><a href=\"http://sivel.net/2008/08/page-restrict/\">Page Restrict</a></p>\n<p>This plugin will allow you to restrict all, none, or certain pages to logged in users only.</p>\n<p>New to this update is a meta box for easy restriction on the write/edit page pages, restrict viewing comments on restricted pages and restrict page content in search results.</p>\n<p><a href=\"http://chitika.com/blog/wordpress/\">Chitika Premium plugin</a></p>\n<p>Automate and simplify using Chitika | Premium in your WordPress blog. This plugin will automate adding Chitika|Premium to your blog posts.</p>\n<p>The latest version makes it easy to customize more about the placement appearance of your ads.</p>\n<p><a href=\"http://www.artiss.co.uk/simple-adsense-insert\">Simple Adsense Insert</a></p>\n<p>Simple AdSense Insert is a WordPress plugin that provides a basic ability to display AdSense adverts on your blog.</p>\n<p><a href=\"http://omninoggin.com/wordpress-plugins/wp-greet-box-wordpress-plugin/\">WP Greet Box</a></p>\n<p>This plugin lets you show a different greeting message to your new visitors depending on their referrer url.</p>\n<p>New version adds support for friendfeed.com, linkedin.com, and plurk.com along with corresponding icons.</p>\n<p>Are you a plugin author? <a href=\"http://weblogtoolscollection.com/submit-news\">Submit your plugin</a> to get featured in our daily releases.</p>\";s:7:\"pubdate\";s:31:\"Sat, 14 Mar 2009 16:24:07 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:4250:\"<h3>New Releases</h3>\n<p><a href=\"http://wp.gdragon.info/2009/03/09/gd-press-tools-020/\">GD Press Tools</a></p>\n<p>GD Press Tools is a collection of various additional administration tools. Plugin is still under heavy development and over time number of tools will grow.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/julia-beta/\">JuLiA</a></p>\n<p>JuLiA (Just a Linguistic Algorithm) is an automated comment moderation plugin for Wordpress that uses machine learning and natural language processing techniques to recognize abusiveness in comment content.</p>\n<p><a href=\"http://www.goosegrade.com/wordpress\">gooseGrade Plugin</a></p>\n<p>Allow your readers to become citizen editors. gooseGrade is a free service that allows your readers to post spelling, grammar, factual, and other errors straight to you. After you or any other WordPress admin approves the edit, the gooseGrade plugin will automatically fix the error. It&#8217;s like magic.</p>\n<p><a href=\"http://bavotasan.com/wordpress/free-wordpress-plugins/simple-image-grabber-wordpress-plugin/\">Simple Image Grabber</a></p>\n<p>Retrieve and display images from a WordPress post.</p>\n<p><a href=\"http://www.ilovecolors.com.ar/folding-menu-plugin-wordpress/\">Folding Menu Plugin</a></p>\n<p>Create a folding menu for WordPress built in Pages widget using jQuery.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/peoplepond/\">PeoplePond</a></p>\n<p><a href=\"http://peoplepond.com/\">PeoplePond</a> provides the tools needed to take ownership of your online identity and reputation management.</p>\n<p><a href=\"http://www.paulmc.org/whatithink/wordpress/plugins/twitter-friends-widget/\">Twitter Friends Widget</a></p>\n<p>Twitter Friends is a WordPress plugin that displays your Twitter friends in your sidebar in the same way that they appear on your Twitter homepage.</p>\n<h3>Updated Releases</h3>\n<p><a href=\"http://ajaydsouza.com/wordpress/plugins/top-10/\">Top 10</a></p>\n<p>WordPress doesn’t count page views by default. Top 10 will count the number of page views on your single posts on a daily as well as overall basis. You can then display the page view count on individual posts and pages as well as display a list of most popular posts based on page views.</p>\n<p>The latest version includes the ability to choose &#8220;daily popular&#8221; should be of how many days. List is also compatible with caching plugins. Also added a new page in WP-Admin to view the popular posts. <em>Deactivate old version before upgrading</em>.</p>\n<p><a href=\"http://sivel.net/2009/02/public-post-preview/\">Public Post Preview</a></p>\n<p>Enables you to give a link to anonymous users for public preview of a post before it is published.</p>\n<p>New to this update is not limiting public previews to posts in draft or pending status. The plugin now allows public previews of any post that is not in ‘publish’ status.</p>\n<p><a href=\"http://sivel.net/2008/08/page-restrict/\">Page Restrict</a></p>\n<p>This plugin will allow you to restrict all, none, or certain pages to logged in users only.</p>\n<p>New to this update is a meta box for easy restriction on the write/edit page pages, restrict viewing comments on restricted pages and restrict page content in search results.</p>\n<p><a href=\"http://chitika.com/blog/wordpress/\">Chitika Premium plugin</a></p>\n<p>Automate and simplify using Chitika | Premium in your WordPress blog. This plugin will automate adding Chitika|Premium to your blog posts.</p>\n<p>The latest version makes it easy to customize more about the placement appearance of your ads.</p>\n<p><a href=\"http://www.artiss.co.uk/simple-adsense-insert\">Simple Adsense Insert</a></p>\n<p>Simple AdSense Insert is a WordPress plugin that provides a basic ability to display AdSense adverts on your blog.</p>\n<p><a href=\"http://omninoggin.com/wordpress-plugins/wp-greet-box-wordpress-plugin/\">WP Greet Box</a></p>\n<p>This plugin lets you show a different greeting message to your new visitors depending on their referrer url.</p>\n<p>New version adds support for friendfeed.com, linkedin.com, and plurk.com along with corresponding icons.</p>\n<p>Are you a plugin author? <a href=\"http://weblogtoolscollection.com/submit-news\">Submit your plugin</a> to get featured in our daily releases.</p>\";}i:13;a:7:{s:5:\"title\";s:61:\"Weblog Tools Collection: 24 Hours left to submit your Reviews\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5324\";s:4:\"link\";s:90:\"http://weblogtoolscollection.com/archives/2009/03/14/24-hours-left-to-submit-your-reviews/\";s:11:\"description\";s:2693:\"<p>You must be aware that we&#8217;ve launched a new series where every reader of Weblog Tools Collection can contribute and get featured in return.</p>\n<p>We&#8217;ve asked you to pick a plugin from our <a href=\"http://weblogtoolscollection.com/archives/category/apad/\">Weekly Plugin Review</a> posts and review the same and then email us the link. Since, the launch, we&#8217;ve already received a few entries.</p>\n<p>The plugins you can choose from:</p>\n<ul>\n<li><a href=\"http://simplepressforum.com/\">Simple:Press Forum</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/01/04/plugin-review-simplepress-forum/\">Our Review</a>)</li>\n<li><a href=\"http://www.phoenixheart.net/2008/11/referrer-detector/\">Referrer Detector</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/01/11/plugin-review-referrer-detector/\">Our Review</a>)</li>\n<li><a href=\"http://omninoggin.com/projects/wordpress-plugins/wp-greet-box-wordpress-plugin/\">WP Greet Box</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/01/18/plugin-review-wp-greet-box/\">Our Review</a>)</li>\n<li><a href=\"http://www.webmaster-source.com/wp125-ad-plugin-wordpress/\">WP125</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/01/25/plugin-review-wp125/\">Our Review</a>)</li>\n<li><a href=\"http://www.mailpress.org/\">MailPress</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/02/08/plugin-review-mailpress/\">Our Review</a>)</li>\n<li><a href=\"http://www.svenkubiak.de/yawasp-en/\">Yawasp (Yet Another WordPress Anti-Spam Plugin)</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/02/15/plugin-review-yawasp/\">Our Review</a>)</li>\n<li><a href=\"http://garinungkadol.com/downloads/post-avatar/\">Post Avatar</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/02/22/plugin-review-post-avatar/\">Our Review</a>)</li>\n<li><a href=\"http://www.improvingtheweb.com/wordpress-plugins/improved-plugin-installation/\">Improved Plugin Installation</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/03/01/plugin-review-improved-plugin-installation/\">Our Review</a>)</li>\n<li><a href=\"http://www.weinschenker.name/plugin-feed-reading-blogroll/\">Feed Reading Blogroll</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/03/08/plugin-review-feed-reading-blogroll/\">Our Review</a>)</li>\n</ul>\n<p><a href=\"http://weblogtoolscollection.com/archives/2009/03/11/would-you-like-to-review-plugins-on-wltc/\">View complete details of the how to submit your reviews »</a></p>\n<p>Remember your entries must reach us by <strong>Saturday, March 14 - 11.59pm </strong><a href=\"http://wwp.greenwichmeantime.com/time-zone/usa/eastern-time/\"><strong>EST</strong></a></p>\";s:7:\"pubdate\";s:31:\"Sat, 14 Mar 2009 04:01:00 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:2693:\"<p>You must be aware that we&#8217;ve launched a new series where every reader of Weblog Tools Collection can contribute and get featured in return.</p>\n<p>We&#8217;ve asked you to pick a plugin from our <a href=\"http://weblogtoolscollection.com/archives/category/apad/\">Weekly Plugin Review</a> posts and review the same and then email us the link. Since, the launch, we&#8217;ve already received a few entries.</p>\n<p>The plugins you can choose from:</p>\n<ul>\n<li><a href=\"http://simplepressforum.com/\">Simple:Press Forum</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/01/04/plugin-review-simplepress-forum/\">Our Review</a>)</li>\n<li><a href=\"http://www.phoenixheart.net/2008/11/referrer-detector/\">Referrer Detector</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/01/11/plugin-review-referrer-detector/\">Our Review</a>)</li>\n<li><a href=\"http://omninoggin.com/projects/wordpress-plugins/wp-greet-box-wordpress-plugin/\">WP Greet Box</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/01/18/plugin-review-wp-greet-box/\">Our Review</a>)</li>\n<li><a href=\"http://www.webmaster-source.com/wp125-ad-plugin-wordpress/\">WP125</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/01/25/plugin-review-wp125/\">Our Review</a>)</li>\n<li><a href=\"http://www.mailpress.org/\">MailPress</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/02/08/plugin-review-mailpress/\">Our Review</a>)</li>\n<li><a href=\"http://www.svenkubiak.de/yawasp-en/\">Yawasp (Yet Another WordPress Anti-Spam Plugin)</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/02/15/plugin-review-yawasp/\">Our Review</a>)</li>\n<li><a href=\"http://garinungkadol.com/downloads/post-avatar/\">Post Avatar</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/02/22/plugin-review-post-avatar/\">Our Review</a>)</li>\n<li><a href=\"http://www.improvingtheweb.com/wordpress-plugins/improved-plugin-installation/\">Improved Plugin Installation</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/03/01/plugin-review-improved-plugin-installation/\">Our Review</a>)</li>\n<li><a href=\"http://www.weinschenker.name/plugin-feed-reading-blogroll/\">Feed Reading Blogroll</a> - (<a href=\"http://weblogtoolscollection.com/archives/2009/03/08/plugin-review-feed-reading-blogroll/\">Our Review</a>)</li>\n</ul>\n<p><a href=\"http://weblogtoolscollection.com/archives/2009/03/11/would-you-like-to-review-plugins-on-wltc/\">View complete details of the how to submit your reviews »</a></p>\n<p>Remember your entries must reach us by <strong>Saturday, March 14 - 11.59pm </strong><a href=\"http://wwp.greenwichmeantime.com/time-zone/usa/eastern-time/\"><strong>EST</strong></a></p>\";}i:14;a:7:{s:5:\"title\";s:20:\"Matt: Vietnam School\";s:4:\"guid\";s:21:\"http://ma.tt/?p=12357\";s:4:\"link\";s:36:\"http://ma.tt/2009/03/vietnam-school/\";s:11:\"description\";s:39987:\"<p>Visiting <a href=\"http://www.roomtoread.org/\">Room to Read</a> school with <a href=\"http://www.fourhourworkweek.com/blog/\">Tim Ferriss</a> and two other donors about 3 hours outside of Saigon / Ho Chi Min City. <a href=\"http://www.fourhourworkweek.com/blog/2008/04/23/4hww-readers-school-in-vietnam-opens-its-doors-time-for-a-trip/\">More about the school here</a>. They teach ages 2-5. Also: birthday dinner for John.</p>\n<p><span id=\"more-12357\"></span></p>\n\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3578-2/\" title=\"mcm_3578\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3578-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3578\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3579-3/\" title=\"mcm_3579\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3579-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3579\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3580-2/\" title=\"mcm_3580\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3580-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3580\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3581-2/\" title=\"mcm_3581\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3581-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3581\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3583-2/\" title=\"mcm_3583\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3583-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3583\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3586/\" title=\"mcm_3586\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3586-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"Yes, that&#039;s soup on the back of a motorbike\" title=\"mcm_3586\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3588-2/\" title=\"mcm_3588\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3588-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3588\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3591/\" title=\"mcm_3591\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3591-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3591\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3593/\" title=\"mcm_3593\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3593-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3593\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3594/\" title=\"mcm_3594\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3594-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3594\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3595/\" title=\"mcm_3595\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3595-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"The ferry that took us across the river\" title=\"mcm_3595\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3597/\" title=\"mcm_3597\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3597-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3597\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3598/\" title=\"mcm_3598\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3598-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3598\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3599/\" title=\"mcm_3599\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3599-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3599\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3600/\" title=\"mcm_3600\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3600-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3600\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3601/\" title=\"mcm_3601\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3601-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3601\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3603-2/\" title=\"mcm_3603\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3603-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3603\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3604/\" title=\"mcm_3604\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3604-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"Arriving at the school, all the kids came out\" title=\"mcm_3604\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3606/\" title=\"mcm_3606\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3606-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3606\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3611-2/\" title=\"mcm_3611\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3611-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3611\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3614/\" title=\"mcm_3614\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3614-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3614\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3617/\" title=\"mcm_3617\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3617-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3617\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3618/\" title=\"mcm_3618\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3618-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3618\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3619/\" title=\"mcm_3619\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3619-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3619\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3620-2/\" title=\"mcm_3620\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3620-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3620\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3621/\" title=\"mcm_3621\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3621-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3621\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3624/\" title=\"mcm_3624\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3624-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3624\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3625/\" title=\"mcm_3625\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3625-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3625\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3626-2/\" title=\"mcm_3626\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3626-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3626\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3627/\" title=\"mcm_3627\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3627-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3627\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3628/\" title=\"mcm_3628\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3628-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3628\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3629-2/\" title=\"mcm_3629\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3629-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3629\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3633/\" title=\"mcm_3633\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3633-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3633\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3634/\" title=\"mcm_3634\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3634-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3634\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3635/\" title=\"mcm_3635\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3635-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3635\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3636/\" title=\"mcm_3636\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3636-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3636\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3637/\" title=\"mcm_3637\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3637-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3637\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3638-2/\" title=\"mcm_3638\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3638-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3638\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3639/\" title=\"mcm_3639\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3639-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3639\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3641-2/\" title=\"mcm_3641\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3641-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3641\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3642/\" title=\"mcm_3642\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3642-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3642\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3643-2/\" title=\"mcm_3643\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3643-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3643\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3647-2/\" title=\"mcm_3647\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3647-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"This girl was fascinated by my camera, has the exact same expression in a few other pics\" title=\"mcm_3647\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3648-2/\" title=\"mcm_3648\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3648-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3648\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3652-3/\" title=\"mcm_3652\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3652-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"The school starts classes at 2 years old\" title=\"mcm_3652\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3653-2/\" title=\"mcm_3653\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3653-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3653\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3654-3/\" title=\"mcm_3654\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3654-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3654\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3656-2/\" title=\"mcm_3656\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3656-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3656\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3659/\" title=\"mcm_3659\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3659-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3659\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3660-2/\" title=\"mcm_3660\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3660-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3660\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3661-2/\" title=\"mcm_3661\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3661-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3661\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3664/\" title=\"mcm_3664\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3664-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3664\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3666-2/\" title=\"mcm_3666\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3666-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3666\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3667-2/\" title=\"mcm_3667\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3667-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3667\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3669-2/\" title=\"mcm_3669\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3669-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3669\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3671-2/\" title=\"mcm_3671\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3671-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3671\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3674/\" title=\"mcm_3674\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3674-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3674\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3677/\" title=\"mcm_3677\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3677-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3677\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3678/\" title=\"mcm_3678\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3678-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3678\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3679-2/\" title=\"mcm_3679\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3679-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3679\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3680-2/\" title=\"mcm_3680\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3680-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3680\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3686/\" title=\"mcm_3686\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3686-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3686\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3687-2/\" title=\"mcm_3687\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3687-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3687\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3692-2/\" title=\"mcm_3692\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3692-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3692\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3695/\" title=\"mcm_3695\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3695-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3695\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3698-3/\" title=\"mcm_3698\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3698-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3698\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3699-3/\" title=\"mcm_3699\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3699-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3699\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3700-2/\" title=\"mcm_3700\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3700-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3700\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3704/\" title=\"mcm_3704\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3704-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3704\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3707-3/\" title=\"mcm_3707\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3707-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3707\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3712-2/\" title=\"mcm_3712\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3712-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3712\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3714-2/\" title=\"mcm_3714\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3714-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3714\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3716-3/\" title=\"mcm_3716\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3716-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3716\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3717-2/\" title=\"mcm_3717\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3717-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3717\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3719/\" title=\"mcm_3719\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3719-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3719\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3720/\" title=\"mcm_3720\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3720-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3720\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3722/\" title=\"mcm_3722\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3722-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3722\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3724/\" title=\"mcm_3724\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3724-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"Tim does a convincing monkey impression\" title=\"mcm_3724\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3732-3/\" title=\"mcm_3732\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3732-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3732\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3733/\" title=\"mcm_3733\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3733-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3733\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3734/\" title=\"mcm_3734\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3734-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3734\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3735/\" title=\"mcm_3735\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3735-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3735\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3738-3/\" title=\"mcm_3738\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3738-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3738\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3739-2/\" title=\"mcm_3739\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3739-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3739\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3742/\" title=\"mcm_3742\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3742-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3742\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3749-2/\" title=\"mcm_3749\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3749-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3749\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3754/\" title=\"mcm_3754\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3754-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3754\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3760/\" title=\"mcm_3760\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3760-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3760\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3763/\" title=\"mcm_3763\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3763-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3763\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3767-3/\" title=\"mcm_3767\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3767-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3767\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3772/\" title=\"mcm_3772\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3772-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3772\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3773/\" title=\"mcm_3773\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3773-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3773\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3774-2/\" title=\"mcm_3774\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3774-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3774\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3778-3/\" title=\"mcm_3778\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3778-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3778\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3780-2/\" title=\"mcm_3780\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3780-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3780\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3781-2/\" title=\"mcm_3781\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3781-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3781\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3782/\" title=\"mcm_3782\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3782-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3782\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3786/\" title=\"mcm_3786\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3786-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"Breakfast of champions\" title=\"mcm_3786\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3787-2/\" title=\"mcm_3787\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3787-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3787\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3792-2/\" title=\"mcm_3792\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3792-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3792\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3796-2/\" title=\"mcm_3796\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3796-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3796\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3798/\" title=\"mcm_3798\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3798-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3798\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3800/\" title=\"mcm_3800\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3800-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3800\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3801/\" title=\"mcm_3801\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3801-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3801\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3803/\" title=\"mcm_3803\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3803-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3803\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3808-2/\" title=\"mcm_3808\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3808-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3808\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3813/\" title=\"mcm_3813\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3813-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3813\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3816-2/\" title=\"mcm_3816\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3816-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3816\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3820/\" title=\"mcm_3820\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3820-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3820\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3822-2/\" title=\"mcm_3822\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3822-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3822\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3824/\" title=\"mcm_3824\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3824-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3824\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3825-2/\" title=\"mcm_3825\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3825-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3825\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3826-3/\" title=\"mcm_3826\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3826-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"There were hammocks everywhere, I love it\" title=\"mcm_3826\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3827-3/\" title=\"mcm_3827\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3827-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3827\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3829/\" title=\"mcm_3829\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3829-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3829\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3831-2/\" title=\"mcm_3831\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3831-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3831\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3832/\" title=\"mcm_3832\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3832-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3832\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3833-2/\" title=\"mcm_3833\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3833-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3833\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3834-3/\" title=\"mcm_3834\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3834-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3834\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3838-2/\" title=\"mcm_3838\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3838-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3838\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3839/\" title=\"mcm_3839\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3839-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"Snails!\" title=\"mcm_3839\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3840/\" title=\"mcm_3840\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3840-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3840\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3841-2/\" title=\"mcm_3841\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3841-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3841\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3842/\" title=\"mcm_3842\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3842-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3842\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3845/\" title=\"mcm_3845\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3845-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3845\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3846-2/\" title=\"mcm_3846\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3846-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3846\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3848-2/\" title=\"mcm_3848\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3848-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3848\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3849-2/\" title=\"mcm_3849\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3849-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3849\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3851-3/\" title=\"mcm_3851\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3851-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3851\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3853/\" title=\"mcm_3853\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3853-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3853\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3856-2/\" title=\"mcm_3856\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3856-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3856\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3857-3/\" title=\"mcm_3857\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3857-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3857\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3859/\" title=\"mcm_3859\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3859-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3859\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3861-2/\" title=\"mcm_3861\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3861-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3861\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3862-2/\" title=\"mcm_3862\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3862-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3862\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3864-2/\" title=\"mcm_3864\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3864-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3864\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3866/\" title=\"mcm_3866\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3866-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3866\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3867-2/\" title=\"mcm_3867\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3867-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3867\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3868/\" title=\"mcm_3868\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3868-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3868\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3869/\" title=\"mcm_3869\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3869-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3869\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3870-2/\" title=\"mcm_3870\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3870-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3870\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3872/\" title=\"mcm_3872\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3872-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3872\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3875-2/\" title=\"mcm_3875\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3875-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3875\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3881/\" title=\"mcm_3881\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3881-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3881\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3884-2/\" title=\"mcm_3884\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3884-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3884\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3887-2/\" title=\"mcm_3887\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3887-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3887\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3890/\" title=\"mcm_3890\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3890-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3890\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3894/\" title=\"mcm_3894\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3894-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3894\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3902/\" title=\"mcm_3902\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3902-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3902\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3903-2/\" title=\"mcm_3903\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3903-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3903\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3904/\" title=\"mcm_3904\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3904-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3904\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3905-2/\" title=\"mcm_3905\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3905-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3905\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3906/\" title=\"mcm_3906\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3906-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3906\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3908-2/\" title=\"mcm_3908\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3908-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3908\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3911-3/\" title=\"mcm_3911\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3911-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3911\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3912/\" title=\"mcm_3912\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3912-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3912\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3914/\" title=\"mcm_3914\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3914-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3914\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3916/\" title=\"mcm_3916\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3916-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3916\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3917/\" title=\"mcm_3917\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3917-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3917\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3919/\" title=\"mcm_3919\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3919-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3919\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3920-2/\" title=\"mcm_3920\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3920-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3920\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3929/\" title=\"mcm_3929\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3929-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3929\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3930-2/\" title=\"mcm_3930\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3930-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3930\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3935/\" title=\"mcm_3935\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3935-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3935\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3936-2/\" title=\"mcm_3936\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3936-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3936\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3942-2/\" title=\"mcm_3942\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3942-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3942\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3945/\" title=\"mcm_3945\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3945-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3945\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3946/\" title=\"mcm_3946\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3946-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3946\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3948/\" title=\"mcm_3948\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3948-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3948\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3953/\" title=\"mcm_3953\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3953-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3953\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3954/\" title=\"mcm_3954\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3954-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3954\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3955-2/\" title=\"mcm_3955\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3955-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3955\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3958/\" title=\"mcm_3958\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3958-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3958\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3962-2/\" title=\"mcm_3962\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3962-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3962\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3964/\" title=\"mcm_3964\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3964-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3964\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3965/\" title=\"mcm_3965\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3965-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3965\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3968-2/\" title=\"mcm_3968\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3968-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3968\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3970-2/\" title=\"mcm_3970\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3970-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3970\" /></a>\";s:7:\"pubdate\";s:31:\"Sat, 14 Mar 2009 01:30:51 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:39987:\"<p>Visiting <a href=\"http://www.roomtoread.org/\">Room to Read</a> school with <a href=\"http://www.fourhourworkweek.com/blog/\">Tim Ferriss</a> and two other donors about 3 hours outside of Saigon / Ho Chi Min City. <a href=\"http://www.fourhourworkweek.com/blog/2008/04/23/4hww-readers-school-in-vietnam-opens-its-doors-time-for-a-trip/\">More about the school here</a>. They teach ages 2-5. Also: birthday dinner for John.</p>\n<p><span id=\"more-12357\"></span></p>\n\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3578-2/\" title=\"mcm_3578\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3578-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3578\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3579-3/\" title=\"mcm_3579\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3579-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3579\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3580-2/\" title=\"mcm_3580\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3580-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3580\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3581-2/\" title=\"mcm_3581\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3581-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3581\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3583-2/\" title=\"mcm_3583\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3583-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3583\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3586/\" title=\"mcm_3586\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3586-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"Yes, that&#039;s soup on the back of a motorbike\" title=\"mcm_3586\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3588-2/\" title=\"mcm_3588\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3588-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3588\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3591/\" title=\"mcm_3591\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3591-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3591\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3593/\" title=\"mcm_3593\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3593-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3593\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3594/\" title=\"mcm_3594\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3594-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3594\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3595/\" title=\"mcm_3595\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3595-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"The ferry that took us across the river\" title=\"mcm_3595\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3597/\" title=\"mcm_3597\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3597-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3597\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3598/\" title=\"mcm_3598\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3598-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3598\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3599/\" title=\"mcm_3599\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3599-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3599\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3600/\" title=\"mcm_3600\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3600-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3600\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3601/\" title=\"mcm_3601\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3601-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3601\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3603-2/\" title=\"mcm_3603\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3603-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3603\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3604/\" title=\"mcm_3604\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3604-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"Arriving at the school, all the kids came out\" title=\"mcm_3604\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3606/\" title=\"mcm_3606\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3606-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3606\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3611-2/\" title=\"mcm_3611\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3611-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3611\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3614/\" title=\"mcm_3614\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3614-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3614\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3617/\" title=\"mcm_3617\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3617-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3617\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3618/\" title=\"mcm_3618\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3618-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3618\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3619/\" title=\"mcm_3619\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3619-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3619\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3620-2/\" title=\"mcm_3620\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3620-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3620\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3621/\" title=\"mcm_3621\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3621-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3621\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3624/\" title=\"mcm_3624\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3624-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3624\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3625/\" title=\"mcm_3625\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3625-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3625\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3626-2/\" title=\"mcm_3626\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3626-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3626\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3627/\" title=\"mcm_3627\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3627-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3627\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3628/\" title=\"mcm_3628\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3628-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3628\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3629-2/\" title=\"mcm_3629\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3629-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3629\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3633/\" title=\"mcm_3633\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3633-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3633\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3634/\" title=\"mcm_3634\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3634-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3634\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3635/\" title=\"mcm_3635\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3635-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3635\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3636/\" title=\"mcm_3636\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3636-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3636\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3637/\" title=\"mcm_3637\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3637-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3637\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3638-2/\" title=\"mcm_3638\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3638-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3638\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3639/\" title=\"mcm_3639\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3639-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3639\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3641-2/\" title=\"mcm_3641\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3641-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3641\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3642/\" title=\"mcm_3642\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3642-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3642\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3643-2/\" title=\"mcm_3643\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3643-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3643\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3647-2/\" title=\"mcm_3647\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3647-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"This girl was fascinated by my camera, has the exact same expression in a few other pics\" title=\"mcm_3647\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3648-2/\" title=\"mcm_3648\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3648-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3648\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3652-3/\" title=\"mcm_3652\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3652-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"The school starts classes at 2 years old\" title=\"mcm_3652\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3653-2/\" title=\"mcm_3653\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3653-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3653\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3654-3/\" title=\"mcm_3654\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3654-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3654\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3656-2/\" title=\"mcm_3656\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3656-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3656\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3659/\" title=\"mcm_3659\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3659-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3659\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3660-2/\" title=\"mcm_3660\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3660-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3660\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3661-2/\" title=\"mcm_3661\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3661-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3661\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3664/\" title=\"mcm_3664\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3664-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3664\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3666-2/\" title=\"mcm_3666\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3666-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3666\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3667-2/\" title=\"mcm_3667\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3667-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3667\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3669-2/\" title=\"mcm_3669\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3669-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3669\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3671-2/\" title=\"mcm_3671\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3671-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3671\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3674/\" title=\"mcm_3674\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3674-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3674\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3677/\" title=\"mcm_3677\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3677-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3677\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3678/\" title=\"mcm_3678\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3678-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3678\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3679-2/\" title=\"mcm_3679\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3679-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3679\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3680-2/\" title=\"mcm_3680\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3680-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3680\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3686/\" title=\"mcm_3686\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3686-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3686\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3687-2/\" title=\"mcm_3687\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3687-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3687\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3692-2/\" title=\"mcm_3692\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3692-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3692\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3695/\" title=\"mcm_3695\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3695-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3695\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3698-3/\" title=\"mcm_3698\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3698-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3698\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3699-3/\" title=\"mcm_3699\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3699-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3699\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3700-2/\" title=\"mcm_3700\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3700-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3700\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3704/\" title=\"mcm_3704\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3704-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3704\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3707-3/\" title=\"mcm_3707\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3707-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3707\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3712-2/\" title=\"mcm_3712\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3712-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3712\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3714-2/\" title=\"mcm_3714\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3714-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3714\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3716-3/\" title=\"mcm_3716\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3716-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3716\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3717-2/\" title=\"mcm_3717\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3717-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3717\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3719/\" title=\"mcm_3719\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3719-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3719\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3720/\" title=\"mcm_3720\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3720-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3720\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3722/\" title=\"mcm_3722\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3722-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3722\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3724/\" title=\"mcm_3724\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3724-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"Tim does a convincing monkey impression\" title=\"mcm_3724\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3732-3/\" title=\"mcm_3732\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3732-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3732\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3733/\" title=\"mcm_3733\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3733-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3733\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3734/\" title=\"mcm_3734\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3734-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3734\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3735/\" title=\"mcm_3735\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3735-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3735\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3738-3/\" title=\"mcm_3738\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3738-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3738\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3739-2/\" title=\"mcm_3739\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3739-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3739\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3742/\" title=\"mcm_3742\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3742-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3742\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3749-2/\" title=\"mcm_3749\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3749-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3749\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3754/\" title=\"mcm_3754\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3754-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3754\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3760/\" title=\"mcm_3760\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3760-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3760\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3763/\" title=\"mcm_3763\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3763-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3763\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3767-3/\" title=\"mcm_3767\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3767-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3767\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3772/\" title=\"mcm_3772\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3772-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3772\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3773/\" title=\"mcm_3773\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3773-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3773\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3774-2/\" title=\"mcm_3774\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3774-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3774\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3778-3/\" title=\"mcm_3778\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3778-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3778\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3780-2/\" title=\"mcm_3780\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3780-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3780\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3781-2/\" title=\"mcm_3781\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3781-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3781\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3782/\" title=\"mcm_3782\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3782-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3782\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3786/\" title=\"mcm_3786\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3786-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"Breakfast of champions\" title=\"mcm_3786\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3787-2/\" title=\"mcm_3787\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3787-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3787\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3792-2/\" title=\"mcm_3792\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3792-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3792\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3796-2/\" title=\"mcm_3796\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3796-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3796\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3798/\" title=\"mcm_3798\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3798-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3798\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3800/\" title=\"mcm_3800\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3800-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3800\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3801/\" title=\"mcm_3801\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3801-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3801\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3803/\" title=\"mcm_3803\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3803-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3803\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3808-2/\" title=\"mcm_3808\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3808-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3808\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3813/\" title=\"mcm_3813\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3813-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3813\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3816-2/\" title=\"mcm_3816\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3816-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3816\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3820/\" title=\"mcm_3820\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3820-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3820\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3822-2/\" title=\"mcm_3822\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3822-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3822\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3824/\" title=\"mcm_3824\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3824-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3824\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3825-2/\" title=\"mcm_3825\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3825-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3825\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3826-3/\" title=\"mcm_3826\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3826-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"There were hammocks everywhere, I love it\" title=\"mcm_3826\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3827-3/\" title=\"mcm_3827\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3827-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3827\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3829/\" title=\"mcm_3829\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3829-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3829\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3831-2/\" title=\"mcm_3831\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3831-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3831\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3832/\" title=\"mcm_3832\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3832-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3832\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3833-2/\" title=\"mcm_3833\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3833-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3833\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3834-3/\" title=\"mcm_3834\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3834-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3834\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3838-2/\" title=\"mcm_3838\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3838-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3838\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3839/\" title=\"mcm_3839\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3839-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"Snails!\" title=\"mcm_3839\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3840/\" title=\"mcm_3840\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3840-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3840\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3841-2/\" title=\"mcm_3841\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3841-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3841\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3842/\" title=\"mcm_3842\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3842-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3842\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3845/\" title=\"mcm_3845\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3845-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3845\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3846-2/\" title=\"mcm_3846\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3846-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3846\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3848-2/\" title=\"mcm_3848\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3848-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3848\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3849-2/\" title=\"mcm_3849\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3849-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3849\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3851-3/\" title=\"mcm_3851\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3851-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3851\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3853/\" title=\"mcm_3853\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3853-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3853\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3856-2/\" title=\"mcm_3856\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3856-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3856\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3857-3/\" title=\"mcm_3857\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3857-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3857\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3859/\" title=\"mcm_3859\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3859-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3859\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3861-2/\" title=\"mcm_3861\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3861-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3861\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3862-2/\" title=\"mcm_3862\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3862-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3862\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3864-2/\" title=\"mcm_3864\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3864-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3864\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3866/\" title=\"mcm_3866\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3866-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3866\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3867-2/\" title=\"mcm_3867\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3867-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3867\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3868/\" title=\"mcm_3868\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3868-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3868\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3869/\" title=\"mcm_3869\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3869-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3869\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3870-2/\" title=\"mcm_3870\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3870-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3870\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3872/\" title=\"mcm_3872\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3872-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3872\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3875-2/\" title=\"mcm_3875\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3875-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3875\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3881/\" title=\"mcm_3881\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3881-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3881\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3884-2/\" title=\"mcm_3884\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3884-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3884\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3887-2/\" title=\"mcm_3887\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3887-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3887\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3890/\" title=\"mcm_3890\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3890-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3890\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3894/\" title=\"mcm_3894\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3894-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3894\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3902/\" title=\"mcm_3902\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3902-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3902\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3903-2/\" title=\"mcm_3903\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3903-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3903\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3904/\" title=\"mcm_3904\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3904-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3904\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3905-2/\" title=\"mcm_3905\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3905-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3905\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3906/\" title=\"mcm_3906\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3906-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3906\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3908-2/\" title=\"mcm_3908\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3908-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3908\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3911-3/\" title=\"mcm_3911\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3911-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3911\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3912/\" title=\"mcm_3912\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3912-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3912\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3914/\" title=\"mcm_3914\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3914-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3914\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3916/\" title=\"mcm_3916\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3916-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3916\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3917/\" title=\"mcm_3917\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3917-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3917\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3919/\" title=\"mcm_3919\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3919-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3919\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3920-2/\" title=\"mcm_3920\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3920-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3920\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3929/\" title=\"mcm_3929\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3929-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3929\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3930-2/\" title=\"mcm_3930\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3930-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3930\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3935/\" title=\"mcm_3935\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3935-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3935\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3936-2/\" title=\"mcm_3936\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3936-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3936\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3942-2/\" title=\"mcm_3942\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3942-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3942\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3945/\" title=\"mcm_3945\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3945-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3945\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3946/\" title=\"mcm_3946\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3946-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3946\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3948/\" title=\"mcm_3948\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3948-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3948\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3953/\" title=\"mcm_3953\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3953-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3953\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3954/\" title=\"mcm_3954\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3954-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3954\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3955-2/\" title=\"mcm_3955\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3955-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3955\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3958/\" title=\"mcm_3958\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3958-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3958\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3962-2/\" title=\"mcm_3962\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3962-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3962\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3964/\" title=\"mcm_3964\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3964-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3964\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3965/\" title=\"mcm_3965\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3965-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3965\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3968-2/\" title=\"mcm_3968\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3968-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3968\" /></a>\n<a href=\"http://ma.tt/2009/03/vietnam-school/mcm_3970-2/\" title=\"mcm_3970\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3970-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3970\" /></a>\";}i:15;a:7:{s:5:\"title\";s:12:\"Matt: Saigon\";s:4:\"guid\";s:21:\"http://ma.tt/?p=12426\";s:4:\"link\";s:28:\"http://ma.tt/2009/03/saigon/\";s:11:\"description\";s:7745:\"<p>Traveling to Saigon, small night market, and BBQ dinner.</p>\n<p><span id=\"more-12426\"></span></p>\n\n<a href=\"http://ma.tt/2009/03/saigon/mcm_2498-2/\" title=\"mcm_2498\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_2498-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_2498\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_2502-2/\" title=\"mcm_2502\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_2502-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_2502\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_2504-2/\" title=\"mcm_2504\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_2504-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_2504\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_2506/\" title=\"mcm_2506\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_2506-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_2506\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_2507-2/\" title=\"mcm_2507\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_2507-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_2507\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_2508-2/\" title=\"mcm_2508\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_2508-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_2508\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_2510-2/\" title=\"mcm_2510\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_2510-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_2510\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_2512/\" title=\"mcm_2512\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_2512-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_2512\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_2514/\" title=\"mcm_2514\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_2514-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_2514\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_2515/\" title=\"mcm_2515\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_2515-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_2515\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_2516-2/\" title=\"mcm_2516\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_2516-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_2516\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_2517-2/\" title=\"mcm_2517\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_2517-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_2517\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_2520/\" title=\"mcm_2520\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_2520-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_2520\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_2530/\" title=\"mcm_2530\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_2530-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_2530\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3527/\" title=\"mcm_3527\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3527-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3527\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3528/\" title=\"mcm_3528\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3528-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3528\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3533/\" title=\"mcm_3533\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3533-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3533\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3534/\" title=\"mcm_3534\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3534-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3534\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3535-2/\" title=\"mcm_3535\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3535-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3535\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3538/\" title=\"mcm_3538\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3538-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3538\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3540/\" title=\"mcm_3540\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3540-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3540\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3541-2/\" title=\"mcm_3541\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3541-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3541\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3543/\" title=\"mcm_3543\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3543-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3543\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3544/\" title=\"mcm_3544\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3544-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3544\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3548-2/\" title=\"mcm_3548\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3548-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3548\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3552/\" title=\"mcm_3552\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3552-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3552\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3554/\" title=\"mcm_3554\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3554-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3554\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3555/\" title=\"mcm_3555\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3555-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3555\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3558/\" title=\"mcm_3558\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3558-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3558\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3559-2/\" title=\"mcm_3559\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3559-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3559\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3562-2/\" title=\"mcm_3562\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3562-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3562\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3563/\" title=\"mcm_3563\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3563-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3563\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3564/\" title=\"mcm_3564\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3564-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3564\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3568-3/\" title=\"mcm_3568\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3568-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3568\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3571/\" title=\"mcm_3571\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3571-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3571\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3574-2/\" title=\"mcm_3574\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3574-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"Saigon Opera House\" title=\"mcm_3574\" /></a>\";s:7:\"pubdate\";s:31:\"Sat, 14 Mar 2009 00:45:54 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:7745:\"<p>Traveling to Saigon, small night market, and BBQ dinner.</p>\n<p><span id=\"more-12426\"></span></p>\n\n<a href=\"http://ma.tt/2009/03/saigon/mcm_2498-2/\" title=\"mcm_2498\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_2498-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_2498\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_2502-2/\" title=\"mcm_2502\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_2502-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_2502\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_2504-2/\" title=\"mcm_2504\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_2504-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_2504\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_2506/\" title=\"mcm_2506\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_2506-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_2506\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_2507-2/\" title=\"mcm_2507\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_2507-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_2507\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_2508-2/\" title=\"mcm_2508\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_2508-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_2508\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_2510-2/\" title=\"mcm_2510\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_2510-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_2510\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_2512/\" title=\"mcm_2512\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_2512-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_2512\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_2514/\" title=\"mcm_2514\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_2514-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_2514\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_2515/\" title=\"mcm_2515\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_2515-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_2515\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_2516-2/\" title=\"mcm_2516\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_2516-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_2516\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_2517-2/\" title=\"mcm_2517\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_2517-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_2517\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_2520/\" title=\"mcm_2520\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_2520-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_2520\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_2530/\" title=\"mcm_2530\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_2530-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_2530\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3527/\" title=\"mcm_3527\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3527-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3527\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3528/\" title=\"mcm_3528\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3528-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3528\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3533/\" title=\"mcm_3533\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3533-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3533\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3534/\" title=\"mcm_3534\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3534-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3534\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3535-2/\" title=\"mcm_3535\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3535-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3535\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3538/\" title=\"mcm_3538\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3538-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3538\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3540/\" title=\"mcm_3540\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3540-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3540\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3541-2/\" title=\"mcm_3541\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3541-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3541\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3543/\" title=\"mcm_3543\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3543-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3543\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3544/\" title=\"mcm_3544\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3544-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3544\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3548-2/\" title=\"mcm_3548\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3548-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3548\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3552/\" title=\"mcm_3552\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3552-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3552\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3554/\" title=\"mcm_3554\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3554-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3554\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3555/\" title=\"mcm_3555\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3555-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3555\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3558/\" title=\"mcm_3558\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_3558-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3558\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3559-2/\" title=\"mcm_3559\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3559-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3559\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3562-2/\" title=\"mcm_3562\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3562-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3562\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3563/\" title=\"mcm_3563\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3563-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3563\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3564/\" title=\"mcm_3564\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3564-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3564\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3568-3/\" title=\"mcm_3568\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3568-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3568\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3571/\" title=\"mcm_3571\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3571-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_3571\" /></a>\n<a href=\"http://ma.tt/2009/03/saigon/mcm_3574-2/\" title=\"mcm_3574\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_3574-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"Saigon Opera House\" title=\"mcm_3574\" /></a>\";}i:16;a:7:{s:5:\"title\";s:59:\"Weblog Tools Collection: WordPress Theme Releases for 03/13\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5320\";s:4:\"link\";s:87:\"http://weblogtoolscollection.com/archives/2009/03/13/wordpress-theme-releases-for-0313/\";s:11:\"description\";s:2803:\"<p><a href=\"http://bloggingfornoobs.com/freethemes/spring-time-free-wordpress-theme/\">Spring Time</a></p>\n<p><img title=\"Spring Time\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/springtime.png\" alt=\"Spring Time\" width=\"150\" height=\"104\" /></p>\n<p>Ad Ready, Precoded for several plugins (including tweetbacks, pagenavi, where did they go, wp-related posts, odiogo, yoast breadcrumbs), Featured Video Ready, and Feedburner ready. Precoded for limit post, canonical urls, keyword insertion.</p>\n<p><a href=\"http://cordobo.com/free-wordpress-templates/green-park-2/\">Green Park 2</a></p>\n<p><img title=\"Green Park 2\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/greenpark2.png\" alt=\"Green Park 2\" width=\"150\" height=\"112\" /></p>\n<p>It&#8217;s a simple &amp; elegant light-weight theme for WordPress, with the support for WordPress widgets and CSS sprites.</p>\n<p><a href=\"http://kune.fr/blog/wordpress/wp-jobboard-transform-wordpress-into-a-jobboard/\">WP-Jobboard</a></p>\n<p><a href=\"http://wp-jobboard.kune.fr/\"><img title=\"WP-JobBoard\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/wpjobboard.png\" alt=\"WP-JobBoard\" width=\"150\" height=\"67\" /></a></p>\n<p>Turn your WordPress install in a simple job board. Three column, widget ready.</p>\n<p><a href=\"http://3oneseven.com/15/spyker/\">Spyker wpMU</a></p>\n<p><a href=\"http://wp2.3oneseven.com/index.php?wptheme=Spyker\"><img title=\"Spyker wpMU\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/spykerwpmu.png\" alt=\"Spyker wpMU\" width=\"150\" height=\"106\" /></a></p>\n<p>The Spyker WP theme, one of of a kind WordPress theme. The theme is drenched in gray with light wooden effects.</p>\n<p><a href=\"http://www.csstemplatesfree.org/business-design.html\">Business Design</a></p>\n<p><a href=\"http://www.csstemplatesfree.org/templates/Business-Design/\"><img title=\"Business Design\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/businessdesign.jpg\" alt=\"Business Design\" width=\"150\" height=\"90\" /></a></p>\n<p>Business Design is a plain, two column with right sidebar, widget ready Wordpress Business Theme.</p>\n<p><a href=\"http://www.bluepandadesign.com/crimson/\">Crimson</a></p>\n<p><img title=\"Crimson\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/crimson.png\" alt=\"Crimson\" width=\"150\" height=\"150\" /></p>\n<p>Three column, fixed width, widget and gravatar ready theme</p>\n<p><a href=\"http://human3rror.com/2009/03/11/lunchbag-wordpress-theme-is-here/\">LunchBag</a></p>\n<p><img title=\"LunchBag\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/lunchbag.png\" alt=\"LunchBag\" width=\"150\" height=\"114\" /></p>\n<p>Three column, widget ready theme with two static fixed sidebars</p>\n<p>Are you a theme author? <a href=\"http://weblogtoolscollection.com/submit-news\">Submit your theme</a> to get featured in our release posts!</p>\";s:7:\"pubdate\";s:31:\"Fri, 13 Mar 2009 19:17:32 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:2803:\"<p><a href=\"http://bloggingfornoobs.com/freethemes/spring-time-free-wordpress-theme/\">Spring Time</a></p>\n<p><img title=\"Spring Time\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/springtime.png\" alt=\"Spring Time\" width=\"150\" height=\"104\" /></p>\n<p>Ad Ready, Precoded for several plugins (including tweetbacks, pagenavi, where did they go, wp-related posts, odiogo, yoast breadcrumbs), Featured Video Ready, and Feedburner ready. Precoded for limit post, canonical urls, keyword insertion.</p>\n<p><a href=\"http://cordobo.com/free-wordpress-templates/green-park-2/\">Green Park 2</a></p>\n<p><img title=\"Green Park 2\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/greenpark2.png\" alt=\"Green Park 2\" width=\"150\" height=\"112\" /></p>\n<p>It&#8217;s a simple &amp; elegant light-weight theme for WordPress, with the support for WordPress widgets and CSS sprites.</p>\n<p><a href=\"http://kune.fr/blog/wordpress/wp-jobboard-transform-wordpress-into-a-jobboard/\">WP-Jobboard</a></p>\n<p><a href=\"http://wp-jobboard.kune.fr/\"><img title=\"WP-JobBoard\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/wpjobboard.png\" alt=\"WP-JobBoard\" width=\"150\" height=\"67\" /></a></p>\n<p>Turn your WordPress install in a simple job board. Three column, widget ready.</p>\n<p><a href=\"http://3oneseven.com/15/spyker/\">Spyker wpMU</a></p>\n<p><a href=\"http://wp2.3oneseven.com/index.php?wptheme=Spyker\"><img title=\"Spyker wpMU\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/spykerwpmu.png\" alt=\"Spyker wpMU\" width=\"150\" height=\"106\" /></a></p>\n<p>The Spyker WP theme, one of of a kind WordPress theme. The theme is drenched in gray with light wooden effects.</p>\n<p><a href=\"http://www.csstemplatesfree.org/business-design.html\">Business Design</a></p>\n<p><a href=\"http://www.csstemplatesfree.org/templates/Business-Design/\"><img title=\"Business Design\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/businessdesign.jpg\" alt=\"Business Design\" width=\"150\" height=\"90\" /></a></p>\n<p>Business Design is a plain, two column with right sidebar, widget ready Wordpress Business Theme.</p>\n<p><a href=\"http://www.bluepandadesign.com/crimson/\">Crimson</a></p>\n<p><img title=\"Crimson\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/crimson.png\" alt=\"Crimson\" width=\"150\" height=\"150\" /></p>\n<p>Three column, fixed width, widget and gravatar ready theme</p>\n<p><a href=\"http://human3rror.com/2009/03/11/lunchbag-wordpress-theme-is-here/\">LunchBag</a></p>\n<p><img title=\"LunchBag\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/lunchbag.png\" alt=\"LunchBag\" width=\"150\" height=\"114\" /></p>\n<p>Three column, widget ready theme with two static fixed sidebars</p>\n<p>Are you a theme author? <a href=\"http://weblogtoolscollection.com/submit-news\">Submit your theme</a> to get featured in our release posts!</p>\";}i:17;a:7:{s:5:\"title\";s:53:\"Lorelle on WP: New P2 Prologue Theme on WordPress.com\";s:4:\"guid\";s:36:\"http://lorelle.wordpress.com/?p=3981\";s:4:\"link\";s:78:\"http://lorelle.wordpress.com/2009/03/12/new-p2-prologue-theme-on-wordpresscom/\";s:11:\"description\";s:5102:\"<div class=\"snap_preview\"><br /><p><a href=\"http://lorelle.wordpress.com/tag/wordpressdotcom/\" title=\"WordPressdotcom news and tips\"><img src=\"http://lorelle.files.wordpress.com/2007/04/wordpressdotcomnews.gif\" alt=\"WordPress.com News\" align=\"right\" /></a><a title=\"P2: The New Prologue\" href=\"http://en.blog.wordpress.com/2009/03/11/p2-the-new-prologue/\">P2: The New Prologue</a> is out for <a href=\"http://www.wordpress.com/\" title=\"WordPress.com free blogs\" rel=\"tag\">WordPress.com</a> bloggers to play with. Based upon the <a href=\"http://en.blog.wordpress.com/2008/01/28/introducing-prologue/\" title=\"Prologue\">Prologue WordPress Theme</a> that has been called Twitter-Meets-Blog, this is a form of social networking microblogging WordPress Theme. </p>\n<p>The announcement offers more information and a video, but this is not a WordPress Theme for everyone. It is designed for multiple contributor blogs or groups, allowing people to communicate Twitter-style with each other. The <a href=\"http://wpdevel.wordpress.com/\" title=\"WordPress Development Updates\">WordPress Development Updates</a> blog uses Prologue. WordPress developers tweet their patches, collaborate, share what they are working on, and boost each other through the process, though recently it has also been used as a general blog, breaking the one-line-per-post rule, which shows the flexibility of the Theme.</p>\n<p>The features include:</p>\n<ul>\n<li>Live notifications.</li>\n<li>Easy participation by multiple contributors.</li>\n<li>Posting from the front page of the blog - without using the WordPress Administration Panels.</li>\n<li>Comments on the front page of the site with in-line editing (no page refresh) with AJAX.</li>\n<li>Threaded comment display on the front page, as well as on single post pageviews.</li>\n<li>Live tag suggestion.</li>\n<li>Show/hide feature for threaded comments.</li>\n<li>Keyboard shortcuts for faster posting and navigation.</li>\n<li>Feeds for the blog, comments, authors, tags, searches, and more.</li>\n</ul>\n<p>Some may want to activate the P2 WordPress Theme on their current blog, which is a fairly dramatic change. It&#8217;s currently a plain white page with the focus on the content. User&#8217;s comments are highlighted in the sidebar with their Gravatars next to their name and the post title they commented on. </p>\n<p>This is a great Theme to use in addition to your main blog, especially if you are working with a group of people and you want to set up a group only discussion and collaboration system. </p>\n<p>Or if you are into microblogging, this could be your new WordPress Theme.</p>\n<p><img src=\"http://lorelle.files.wordpress.com/2006/08/sig.gif\" alt=\"\" /></p>\n<hr />\n<p><font size=\"-1\"><a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/02/rss.png\" alt=\"Feed on Lorelle on WordPress\" /></a> <a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\">Subscribe</a>  <a href=\"http://feeds.feedburner.com/LorelleOnWordPress\" title=\"Feedburner Lorelle on WordPress Feed\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/04/feedburnericon.gif\" alt=\"Feedburner icon\" />Via Feedburner</a>  <a href=\"http://www.feedblitz.com/f/?Sub=182399\" title=\"Lorelle on WordPress - full site feed email subscription\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/03/email.gif\" alt=\"\" />Subscribe by Email</a></p>\n<p><a href=\"http://lorelle.wordpress.com/about/\" title=\"Copyright Protected by Brent and Lorelle VanFossen\">Copyright Lorelle VanFossen</a>, member of the <a href=\"http://9rules.com/\" title=\"Member of 9Rules Blogging Network\">9Rules Network</a>, and author of <a href=\"http://lorelle.wordpress.com/books/blogging-tips/\" title=\"Blogging Tips Book By Lorelle VanFossen\"><em>Blogging Tips, What Bloggers Won\'t Tell You About Blogging</em></a>.</font></p>\nPosted in WordPress News, Wordpressdotcom  <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/lorelle.wordpress.com/3981/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/lorelle.wordpress.com/3981/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/lorelle.wordpress.com/3981/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/lorelle.wordpress.com/3981/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/lorelle.wordpress.com/3981/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/lorelle.wordpress.com/3981/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/lorelle.wordpress.com/3981/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/lorelle.wordpress.com/3981/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/lorelle.wordpress.com/3981/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/lorelle.wordpress.com/3981/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=lorelle.wordpress.com&blog=72&post=3981&subd=lorelle&ref=&feed=1\" /></div>\";s:7:\"pubdate\";s:31:\"Fri, 13 Mar 2009 01:29:40 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:17:\"Lorelle VanFossen\";}s:7:\"summary\";s:5102:\"<div class=\"snap_preview\"><br /><p><a href=\"http://lorelle.wordpress.com/tag/wordpressdotcom/\" title=\"WordPressdotcom news and tips\"><img src=\"http://lorelle.files.wordpress.com/2007/04/wordpressdotcomnews.gif\" alt=\"WordPress.com News\" align=\"right\" /></a><a title=\"P2: The New Prologue\" href=\"http://en.blog.wordpress.com/2009/03/11/p2-the-new-prologue/\">P2: The New Prologue</a> is out for <a href=\"http://www.wordpress.com/\" title=\"WordPress.com free blogs\" rel=\"tag\">WordPress.com</a> bloggers to play with. Based upon the <a href=\"http://en.blog.wordpress.com/2008/01/28/introducing-prologue/\" title=\"Prologue\">Prologue WordPress Theme</a> that has been called Twitter-Meets-Blog, this is a form of social networking microblogging WordPress Theme. </p>\n<p>The announcement offers more information and a video, but this is not a WordPress Theme for everyone. It is designed for multiple contributor blogs or groups, allowing people to communicate Twitter-style with each other. The <a href=\"http://wpdevel.wordpress.com/\" title=\"WordPress Development Updates\">WordPress Development Updates</a> blog uses Prologue. WordPress developers tweet their patches, collaborate, share what they are working on, and boost each other through the process, though recently it has also been used as a general blog, breaking the one-line-per-post rule, which shows the flexibility of the Theme.</p>\n<p>The features include:</p>\n<ul>\n<li>Live notifications.</li>\n<li>Easy participation by multiple contributors.</li>\n<li>Posting from the front page of the blog - without using the WordPress Administration Panels.</li>\n<li>Comments on the front page of the site with in-line editing (no page refresh) with AJAX.</li>\n<li>Threaded comment display on the front page, as well as on single post pageviews.</li>\n<li>Live tag suggestion.</li>\n<li>Show/hide feature for threaded comments.</li>\n<li>Keyboard shortcuts for faster posting and navigation.</li>\n<li>Feeds for the blog, comments, authors, tags, searches, and more.</li>\n</ul>\n<p>Some may want to activate the P2 WordPress Theme on their current blog, which is a fairly dramatic change. It&#8217;s currently a plain white page with the focus on the content. User&#8217;s comments are highlighted in the sidebar with their Gravatars next to their name and the post title they commented on. </p>\n<p>This is a great Theme to use in addition to your main blog, especially if you are working with a group of people and you want to set up a group only discussion and collaboration system. </p>\n<p>Or if you are into microblogging, this could be your new WordPress Theme.</p>\n<p><img src=\"http://lorelle.files.wordpress.com/2006/08/sig.gif\" alt=\"\" /></p>\n<hr />\n<p><font size=\"-1\"><a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/02/rss.png\" alt=\"Feed on Lorelle on WordPress\" /></a> <a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\">Subscribe</a>  <a href=\"http://feeds.feedburner.com/LorelleOnWordPress\" title=\"Feedburner Lorelle on WordPress Feed\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/04/feedburnericon.gif\" alt=\"Feedburner icon\" />Via Feedburner</a>  <a href=\"http://www.feedblitz.com/f/?Sub=182399\" title=\"Lorelle on WordPress - full site feed email subscription\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/03/email.gif\" alt=\"\" />Subscribe by Email</a></p>\n<p><a href=\"http://lorelle.wordpress.com/about/\" title=\"Copyright Protected by Brent and Lorelle VanFossen\">Copyright Lorelle VanFossen</a>, member of the <a href=\"http://9rules.com/\" title=\"Member of 9Rules Blogging Network\">9Rules Network</a>, and author of <a href=\"http://lorelle.wordpress.com/books/blogging-tips/\" title=\"Blogging Tips Book By Lorelle VanFossen\"><em>Blogging Tips, What Bloggers Won\'t Tell You About Blogging</em></a>.</font></p>\nPosted in WordPress News, Wordpressdotcom  <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/lorelle.wordpress.com/3981/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/lorelle.wordpress.com/3981/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/lorelle.wordpress.com/3981/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/lorelle.wordpress.com/3981/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/lorelle.wordpress.com/3981/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/lorelle.wordpress.com/3981/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/lorelle.wordpress.com/3981/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/lorelle.wordpress.com/3981/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/lorelle.wordpress.com/3981/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/lorelle.wordpress.com/3981/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=lorelle.wordpress.com&blog=72&post=3981&subd=lorelle&ref=&feed=1\" /></div>\";}i:18;a:7:{s:5:\"title\";s:43:\"Alex King: Crowd Favorite is Hiring (again)\";s:4:\"guid\";s:66:\"http://alexking.org/blog/2009/03/12/crowd-favorite-is-hiring-again\";s:4:\"link\";s:66:\"http://alexking.org/blog/2009/03/12/crowd-favorite-is-hiring-again\";s:11:\"description\";s:809:\"<p>Looks like it&#8217;s time to grow the team at <a href=\"http://crowdfavorite.com\">Crowd Favorite</a> again. We&#8217;re looking to add a good, experienced developer to the team. The highlights:</p>\n<ul>\n<li>Wants to work on cool projects, including many that involve WordPress.</li>\n<li>Experience building web applications.</li>\n<li>Experience with Open Source.</li>\n<li>Enjoys developing in PHP.</li>\n</ul>\n<p>Full job posting <a href=\"http://crowdfavorite.com/jobs/\">here</a>.</p>\n<p>If the above sounds like you, I hope to hear from you soon.</p>\n<p><a href=\"http://sharethis.com/item?&wp=2.2.3&amp;publisher=a1583af8-28eb-4210-97bd-2bb5c02bc265&amp;title=Crowd+Favorite+is+Hiring+%28again%29&amp;url=http%3A%2F%2Falexking.org%2Fblog%2F2009%2F03%2F12%2Fcrowd-favorite-is-hiring-again\">ShareThis</a></p>\";s:7:\"pubdate\";s:31:\"Thu, 12 Mar 2009 21:15:39 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Alex\";}s:7:\"summary\";s:809:\"<p>Looks like it&#8217;s time to grow the team at <a href=\"http://crowdfavorite.com\">Crowd Favorite</a> again. We&#8217;re looking to add a good, experienced developer to the team. The highlights:</p>\n<ul>\n<li>Wants to work on cool projects, including many that involve WordPress.</li>\n<li>Experience building web applications.</li>\n<li>Experience with Open Source.</li>\n<li>Enjoys developing in PHP.</li>\n</ul>\n<p>Full job posting <a href=\"http://crowdfavorite.com/jobs/\">here</a>.</p>\n<p>If the above sounds like you, I hope to hear from you soon.</p>\n<p><a href=\"http://sharethis.com/item?&wp=2.2.3&amp;publisher=a1583af8-28eb-4210-97bd-2bb5c02bc265&amp;title=Crowd+Favorite+is+Hiring+%28again%29&amp;url=http%3A%2F%2Falexking.org%2Fblog%2F2009%2F03%2F12%2Fcrowd-favorite-is-hiring-again\">ShareThis</a></p>\";}i:19;a:7:{s:5:\"title\";s:75:\"Mark Jaquith: Heading to SXSW, WordPress consulting availability in mid-May\";s:4:\"guid\";s:39:\"http://markjaquith.wordpress.com/?p=257\";s:4:\"link\";s:105:\"http://markjaquith.wordpress.com/2009/03/12/heading-to-sxsw-wordpress-consulting-availability-in-mid-may/\";s:11:\"description\";s:2292:\"<div class=\"snap_preview\"><br /><p>Tomorrow I&#8217;m heading off to Austin, TX for the <a href=\"http://sxsw.com/interactive\">South by Southwest Interactive Festival</a>. If you&#8217;re going to be there, and you&#8217;re a WordPress fan, make sure you say hi and let me know what cool uses you&#8217;ve found for WordPress! The best way to find out where I am or to get in contact with me is to <a href=\"http://twitter.com/markjaquith\">follow me on Twitter</a>. Ping me in an @message if you&#8217;d like to chat.</p>\n<p>Also, if you have need of a <a href=\"http://coveredwebservices.com/\">WordPress guru</a>, I&#8217;m back on the market! My contract with <a href=\"http://b5media.com/\">b5media</a> has moved to a part-time arrangement, so if you&#8217;re looking for someone to figure out how WordPress and your company or product fit together, <a href=\"http://coveredwebservices.com/contact/\">drop me a note</a> or track me down while I&#8217;m in Austin. I have a really exciting secret project occupying my time until mid-May, but if you can wait a few months to start your project, we can start that conversation now.</p>\n  <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/markjaquith.wordpress.com/257/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/markjaquith.wordpress.com/257/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/markjaquith.wordpress.com/257/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/markjaquith.wordpress.com/257/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/markjaquith.wordpress.com/257/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/markjaquith.wordpress.com/257/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/markjaquith.wordpress.com/257/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/markjaquith.wordpress.com/257/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/markjaquith.wordpress.com/257/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/markjaquith.wordpress.com/257/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=markjaquith.wordpress.com&blog=316&post=257&subd=markjaquith&ref=&feed=1\" /></div>\";s:7:\"pubdate\";s:31:\"Thu, 12 Mar 2009 20:27:37 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:12:\"Mark Jaquith\";}s:7:\"summary\";s:2292:\"<div class=\"snap_preview\"><br /><p>Tomorrow I&#8217;m heading off to Austin, TX for the <a href=\"http://sxsw.com/interactive\">South by Southwest Interactive Festival</a>. If you&#8217;re going to be there, and you&#8217;re a WordPress fan, make sure you say hi and let me know what cool uses you&#8217;ve found for WordPress! The best way to find out where I am or to get in contact with me is to <a href=\"http://twitter.com/markjaquith\">follow me on Twitter</a>. Ping me in an @message if you&#8217;d like to chat.</p>\n<p>Also, if you have need of a <a href=\"http://coveredwebservices.com/\">WordPress guru</a>, I&#8217;m back on the market! My contract with <a href=\"http://b5media.com/\">b5media</a> has moved to a part-time arrangement, so if you&#8217;re looking for someone to figure out how WordPress and your company or product fit together, <a href=\"http://coveredwebservices.com/contact/\">drop me a note</a> or track me down while I&#8217;m in Austin. I have a really exciting secret project occupying my time until mid-May, but if you can wait a few months to start your project, we can start that conversation now.</p>\n  <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/markjaquith.wordpress.com/257/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/markjaquith.wordpress.com/257/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/markjaquith.wordpress.com/257/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/markjaquith.wordpress.com/257/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/markjaquith.wordpress.com/257/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/markjaquith.wordpress.com/257/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/markjaquith.wordpress.com/257/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/markjaquith.wordpress.com/257/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/markjaquith.wordpress.com/257/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/markjaquith.wordpress.com/257/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=markjaquith.wordpress.com&blog=316&post=257&subd=markjaquith&ref=&feed=1\" /></div>\";}i:20;a:7:{s:5:\"title\";s:56:\"Dev Blog: Contributing to WordPress, Part I: Development\";s:4:\"guid\";s:39:\"http://wordpress.org/development/?p=567\";s:4:\"link\";s:86:\"http://wordpress.org/development/2009/03/contributing-to-wordpress-part-i-development/\";s:11:\"description\";s:6522:\"<p>A week or two ago at <a href=\"http://denver.wordcamp.org/\">WordCamp Denver</a>, I gave a presentation about some plans to create more opportunities for people to contribute to the WordPress open source project. The icon design contest was such a success that it seems clear we need to come up with ways for non-developers to contribute their talents and skills to WordPress. Since the launch of 2.7, we&#8217;ve been working out what kinds of contribution opportunities would make sense, and we&#8217;ve come up with a handful. </p>\n<p>This (long) weekend, many WordPress users and developers (including half the core team) will be in Austin, TX for <a href=\"http://sxsw.com/interactive\">South by Southwest</a>. <a href=\"http://ma.tt/\">Matt Mullenweg</a>, <a href=\"http://boren.nu/\">Ryan Boren</a>, <a href=\"http://markjaquith.com/\">Mark Jaquith</a> and <a href=\"http://jane.wordpress.com\">I</a> will all be there, so say hello if you&#8217;re there, too. In the spirit of all this WordPress community connecting, I&#8217;ll be posting here every day during SxSW with information about the new contribution opportunities we&#8217;re creating. Each post will cover one or more of the following:</p>\n<ul>\n<li>Development (of course)</li>\n<li>QA</li>\n<li>Documentation</li>\n<li>Ideas and Opinions</li>\n<li>User Experience</li>\n<li>Graphic Design</li>\n<li>Accessibility</li>\n<li>Usability Testing</li>\n<li>WordPress.tv</li>\n<li>Community Organizing</li>\n</ul>\n<p>Since the first thing people think of when they think of contributing to WordPress is PHP development, we&#8217;ll start there. </p>\n<p>The code (<em>which is poetry</em>) is the meat of the application, so it makes sense that the most opportunities to contribute will continue to fall in this area. <a href=\"http://core.trac.wordpress.org/\">Trac</a> is always filled with tickets that need patches, patches that need testing, and issues that need some creative developer thinking/collaboration to find the right solution to a problem that has us going in circles. </p>\n<p>If you are proficient in PHP, consider looking through the tickets (especially the ones marked &#8220;bug,&#8221; since they should get higher priority) and writing a patch for one of them. If you&#8217;ve got more advanced skills, consider writing a patch for one of the more complex tickets, or offering corrections to a patch submitted by someone else (if needed). If you don&#8217;t trust your coding skills but know your way around the application files, look for tickets tagged has-patch and test the patches in as many browsers as you can, posting your results afterward in the ticket thread. </p>\n<p>If you find a bug in the course of your daily use of WordPress, report it. First, check Trac to see if the issue already has a ticket. You could also scan the archives of the <a href=\"http://lists.automattic.com/mailman/listinfo/wp-testers\">wp-testers list</a> to see if people have been talking about the bug, or email the list yourself to see if anyone has any information on the problem. If these actions don&#8217;t bear fruit, start a new ticket in Trac (you&#8217;ll need to create a login to do this). Be as detailed as you can about the issue, and don&#8217;t forget to make the proper selections from the metadata dropdown menus. Just in case anyone is unsure of how to make these selections&#8230;</p>\n<p>Use the severity  field with caution. Most bugs will be of normal severity. Marking a bug as high severity will not necessarily speed up development, and if it turns out that you&#8217;ve marked a bug&#8217;s severity incorrectly it may even slow down development. </p>\n<p>Priority will usually be normal. Leave it to the more senior developers to change the status to a higher priority, as they are familiar with all the tickets and Trac and will be better able to assess the priority in relation to other tickets. </p>\n<p>Ticket type. This is one of most misused fields, with many people marking tickets as defects that should not be. To address this, here&#8217;s a reminder of the ticket types and their intended uses. Your choices are: defect (bug), enhancement, feature request, and task (blessed). </p>\n<ul>\n<li>Defect (bug). Something is broken. You know how the feature is supposed to work (if you&#8217;re unsure, check the Codex or ask in the dev channel), but something has gone awry that needs to be fixed.</li>\n<li>Enhancement. Something is awkward or slow and could be designed or coded better without overhauling the function or screen design. Please don&#8217;t mark something as a defect (bug) if it is really an enhancement. </li>\n<li>Feature request. If there&#8217;s something that could be improved that would require significant restructuring of code or screen design, it should be marked as feature request rather than enhancement. Please note: this is not really the place to request features that are not currently in WordPress. Please continue to use the Ideas forum to suggest new features. The core developers will add new feature requests to Trac as they review the Ideas forum with each release cycle. </li>\n<li>Task (blessed). This type indicates approval from the core development team. Only core developers should use this selection. If you mark something as Task (blessed) yourself, you will have bad karma.</li>\n</ul>\n<p>Bug Hunts*! If you have checked the <a href=\"http://codex.wordpress.org/WordPress_Bug_Hunts\">Codex page for bug hunts</a> lately, you&#8217;ll notice it&#8217;s been awhile since there was one. No more! Official bug hunts, sprints for finding and fixing bugs, will be brought back on a regular basis. The first one will be announced soon, possibly next week, to try and tackle the bug tickets related to widgets. (No need to wait, though, there are <a href=\"http://core.trac.wordpress.org/query?status=assigned&#038;status=new&#038;status=reopened&#038;group=status&#038;milestone=2.8\">hundreds of open tickets in the 2.8 milestone</a> just waiting for a kind developer to pay them some attention.)</p>\n<p>As always, contributing developers can communicate with each other and with the core team in the #wordpress-dev IRC channel at irc.freenode.net, on the <a href=\"http://lists.automattic.com/mailman/listinfo/wp-hackers\">wp-hackers list</a>, and in the ticket threads on Trac. Regular developer chats in IRC will be returning to Wednesdays at noon (Pacific time) starting next week. </p>\n<p><em>[* - I used to love the bug hunt challenge in Space Cadet 3D Pinball back in the days of Windows 95]</em></p>\";s:7:\"pubdate\";s:31:\"Thu, 12 Mar 2009 18:06:23 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:10:\"Jane Wells\";}s:7:\"summary\";s:6522:\"<p>A week or two ago at <a href=\"http://denver.wordcamp.org/\">WordCamp Denver</a>, I gave a presentation about some plans to create more opportunities for people to contribute to the WordPress open source project. The icon design contest was such a success that it seems clear we need to come up with ways for non-developers to contribute their talents and skills to WordPress. Since the launch of 2.7, we&#8217;ve been working out what kinds of contribution opportunities would make sense, and we&#8217;ve come up with a handful. </p>\n<p>This (long) weekend, many WordPress users and developers (including half the core team) will be in Austin, TX for <a href=\"http://sxsw.com/interactive\">South by Southwest</a>. <a href=\"http://ma.tt/\">Matt Mullenweg</a>, <a href=\"http://boren.nu/\">Ryan Boren</a>, <a href=\"http://markjaquith.com/\">Mark Jaquith</a> and <a href=\"http://jane.wordpress.com\">I</a> will all be there, so say hello if you&#8217;re there, too. In the spirit of all this WordPress community connecting, I&#8217;ll be posting here every day during SxSW with information about the new contribution opportunities we&#8217;re creating. Each post will cover one or more of the following:</p>\n<ul>\n<li>Development (of course)</li>\n<li>QA</li>\n<li>Documentation</li>\n<li>Ideas and Opinions</li>\n<li>User Experience</li>\n<li>Graphic Design</li>\n<li>Accessibility</li>\n<li>Usability Testing</li>\n<li>WordPress.tv</li>\n<li>Community Organizing</li>\n</ul>\n<p>Since the first thing people think of when they think of contributing to WordPress is PHP development, we&#8217;ll start there. </p>\n<p>The code (<em>which is poetry</em>) is the meat of the application, so it makes sense that the most opportunities to contribute will continue to fall in this area. <a href=\"http://core.trac.wordpress.org/\">Trac</a> is always filled with tickets that need patches, patches that need testing, and issues that need some creative developer thinking/collaboration to find the right solution to a problem that has us going in circles. </p>\n<p>If you are proficient in PHP, consider looking through the tickets (especially the ones marked &#8220;bug,&#8221; since they should get higher priority) and writing a patch for one of them. If you&#8217;ve got more advanced skills, consider writing a patch for one of the more complex tickets, or offering corrections to a patch submitted by someone else (if needed). If you don&#8217;t trust your coding skills but know your way around the application files, look for tickets tagged has-patch and test the patches in as many browsers as you can, posting your results afterward in the ticket thread. </p>\n<p>If you find a bug in the course of your daily use of WordPress, report it. First, check Trac to see if the issue already has a ticket. You could also scan the archives of the <a href=\"http://lists.automattic.com/mailman/listinfo/wp-testers\">wp-testers list</a> to see if people have been talking about the bug, or email the list yourself to see if anyone has any information on the problem. If these actions don&#8217;t bear fruit, start a new ticket in Trac (you&#8217;ll need to create a login to do this). Be as detailed as you can about the issue, and don&#8217;t forget to make the proper selections from the metadata dropdown menus. Just in case anyone is unsure of how to make these selections&#8230;</p>\n<p>Use the severity  field with caution. Most bugs will be of normal severity. Marking a bug as high severity will not necessarily speed up development, and if it turns out that you&#8217;ve marked a bug&#8217;s severity incorrectly it may even slow down development. </p>\n<p>Priority will usually be normal. Leave it to the more senior developers to change the status to a higher priority, as they are familiar with all the tickets and Trac and will be better able to assess the priority in relation to other tickets. </p>\n<p>Ticket type. This is one of most misused fields, with many people marking tickets as defects that should not be. To address this, here&#8217;s a reminder of the ticket types and their intended uses. Your choices are: defect (bug), enhancement, feature request, and task (blessed). </p>\n<ul>\n<li>Defect (bug). Something is broken. You know how the feature is supposed to work (if you&#8217;re unsure, check the Codex or ask in the dev channel), but something has gone awry that needs to be fixed.</li>\n<li>Enhancement. Something is awkward or slow and could be designed or coded better without overhauling the function or screen design. Please don&#8217;t mark something as a defect (bug) if it is really an enhancement. </li>\n<li>Feature request. If there&#8217;s something that could be improved that would require significant restructuring of code or screen design, it should be marked as feature request rather than enhancement. Please note: this is not really the place to request features that are not currently in WordPress. Please continue to use the Ideas forum to suggest new features. The core developers will add new feature requests to Trac as they review the Ideas forum with each release cycle. </li>\n<li>Task (blessed). This type indicates approval from the core development team. Only core developers should use this selection. If you mark something as Task (blessed) yourself, you will have bad karma.</li>\n</ul>\n<p>Bug Hunts*! If you have checked the <a href=\"http://codex.wordpress.org/WordPress_Bug_Hunts\">Codex page for bug hunts</a> lately, you&#8217;ll notice it&#8217;s been awhile since there was one. No more! Official bug hunts, sprints for finding and fixing bugs, will be brought back on a regular basis. The first one will be announced soon, possibly next week, to try and tackle the bug tickets related to widgets. (No need to wait, though, there are <a href=\"http://core.trac.wordpress.org/query?status=assigned&#038;status=new&#038;status=reopened&#038;group=status&#038;milestone=2.8\">hundreds of open tickets in the 2.8 milestone</a> just waiting for a kind developer to pay them some attention.)</p>\n<p>As always, contributing developers can communicate with each other and with the core team in the #wordpress-dev IRC channel at irc.freenode.net, on the <a href=\"http://lists.automattic.com/mailman/listinfo/wp-hackers\">wp-hackers list</a>, and in the ticket threads on Trac. Regular developer chats in IRC will be returning to Wednesdays at noon (Pacific time) starting next week. </p>\n<p><em>[* - I used to love the bug hunt challenge in Space Cadet 3D Pinball back in the days of Windows 95]</em></p>\";}i:21;a:7:{s:5:\"title\";s:75:\"Lorelle on WP: ScotBlog - WordPressMU and BuddyPress Social Networking Site\";s:4:\"guid\";s:36:\"http://lorelle.wordpress.com/?p=3976\";s:4:\"link\";s:99:\"http://lorelle.wordpress.com/2009/03/12/scotblog-wordpressmu-and-buddypress-social-networking-site/\";s:11:\"description\";s:7377:\"<div class=\"snap_preview\"><br /><p><a href=\"http://lorelle.wordpress.com/tag/wordpress-news/\" title=\"WordPress News\"><img src=\"http://lorelle.files.wordpress.com/2007/01/wpnews1.png\" alt=\"WordPress News\" align=\"right\" /></a>According to a news story in <a href=\"http://netnewsdaily.com/\" title=\"Net News Daily\">Net News Daily</a>, <a title=\"Teens Create Social Networking Site\" href=\"http://netnewsdaily.com/?p=849\">two teenagers from Scotland have created a social blogging</a> platform on <a href=\"http://mu.wordpress.org/\" title=\"WordPressMU\" rel=\"tag\">WordPressMU</a> and <a href=\"http://buddypress.org/\" title=\"BuddyPress\" rel=\"tag\">BuddyPress</a> called <a href=\"http://www.scotblog.net\" title=\"Scotblog\">Scotblog</a>. </p>\n<blockquote><p>Scott Campbell and Nathan Adam, both 13, decided to launch the site after they spotted a gap in the market.</p>\n<p>“The internet needed a cool new social blogging site,” said Campbell, who lives in the North East of Scotland, “We provide a user friendly, fun, safe interface, which is easy for anyone to use.”</p></blockquote>\n<p>Scotblog.net is free and not restricted to those living in Scotland, though it&#8217;s welcome states &#8220;celebrate your heritage by connecting with family and friends across the globe&#8230;The ScotBlog way.&#8221;</p>\n<p><a href=\"http://www.scotblog.net\" title=\"Scotblog\"><img src=\"http://lorelle.files.wordpress.com/2009/03/scotblog.gif\" alt=\"scotblog\" title=\"scotblog\" width=\"229\" height=\"73\" class=\"alignleft size-full wp-image-3977\" /></a>They also call ScotBlog the first Social Blogging site. Although that definition is unclear, it is a well-developed online community site that uses the social functionality of BuddyPress with the power of multiple blogs and emphasis on social media tools and networking.</p>\n<p>The front page greets you in the fashion of a blog, with &#8220;most recent published posts&#8221; in chronological order from among all the bloggers, and showcases the groups the members &#8220;belong&#8221; to including <a href=\"http://scotblog.net/groups/bebo-1409600174\" title=\"Bebo\">Bebo</a>, <a href=\"http://scotblog.net/groups/twitter\" title=\"Twitter\">Twitter</a>, <a href=\"http://scotblog.net/groups/young-entrepreneurs\" title=\"Young Entrepreneurs\">Young Entrepreneurs</a>, <a href=\"http://scotblog.net/groups/photographers\" title=\"Photographers\">Photographers</a>, and <a href=\"http://scotblog.net/groups/scottish-history-1048200280\" title=\"Scottish History\">Scottish History</a>, the types of community groups long anticipated on <a href=\"http://www.wordpress.com/\" title=\"WordPress.com free blogs\" rel=\"tag\">WordPress.com</a>. The group pages showcase the group members and their most recent &#8220;group wire&#8221; comments.</p>\n<p>When you click on a member&#8217;s link, like the example page of the administrator, <a href=\"http://scotblog.net/members/admin/\" title=\"ScotBlog.net\">ScotBlog Page</a>, their page showcases the avatar/gravatar, blogs, the latest activity, groups, friends, and wire comments, similar to a Facebook wall. This is the equivalent of a Facebook page that links to their blogs and social networks.</p>\n<p>Like WordPress.com and other WordPressMU, blogs are set up by domain names. <a href=\"http://scottcampbell.scotblog.net/\" title=\"The Blog of Scott Campbell\">Scott Campbell&#8217;s blog</a> is set up as a test site but does feature advertising, which other blogs do not. There currently isn&#8217;t a Terms of Service form or page in the sign up so it&#8217;s unclear if they will allow advertising on a per blog basis or what restrictions there are to commercial blogging or spam blogs, the bane of such free hosted blog services. </p>\n<p>Currently, the blogs are styled with interesting WordPress Themes but the member page is still fairly bland and not reflective of their blogs. Hopefully in time, there will be a branding connection between the two, bluring the edges between blog and social media networking tools.</p>\n<p><a href=\"http://www.scotblog.net\" title=\"Scotblog\">Scotblog</a> is off to a good start and a fascinating example of the integration of BuddyPress and WordPressMU to build a community network of blogs and social groups. </p>\n<p><img src=\"http://lorelle.files.wordpress.com/2006/08/sig.gif\" alt=\"\" /><img src=\"http://lorelle.files.wordpress.com/2006/08/9rules.gif\" alt=\"Member of the 9Rules Blogging Network\" /><br />\n<hr />\n<p><font size=\"-1\"><b>Site Search Tags:</b> <a href=\"http://lorelle.wordpress.com/index.php?s=blogging+tips\" rel=\"tag\">blogging tips</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=blog+writing\" rel=\"tag\">blog writing</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=social+media\" rel=\"tag\">social media</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=networks\" rel=\"tag\">networks</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=blog+networks\" rel=\"tag\">blog networks</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=social+networks\" rel=\"tag\">social networks</a> <br /><a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/02/rss.png\" alt=\"Feed on Lorelle on WordPress\" /></a> <a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\">Subscribe</a>  <a href=\"http://feeds.feedburner.com/LorelleOnWordPress\" title=\"Feedburner Lorelle on WordPress Feed\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/04/feedburnericon.gif\" alt=\"Feedburner icon\" />Via Feedburner</a>  <a href=\"http://www.feedblitz.com/f/?Sub=182399\" title=\"Lorelle on WordPress - full site feed email subscription\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/03/email.gif\" alt=\"\" />Subscribe by Email</a></p>\n<p><a href=\"http://lorelle.wordpress.com/about/\" title=\"Copyright Protected by Brent and Lorelle VanFossen\">Copyright Lorelle VanFossen</a>, member of the <a href=\"http://9rules.com/\" title=\"Member of 9Rules Blogging Network\">9Rules Network</a>, and author of <a href=\"http://lorelle.wordpress.com/books/blogging-tips/\" title=\"Blogging Tips Book By Lorelle VanFossen\"><em>Blogging Tips, What Bloggers Won\'t Tell You About Blogging</em></a>.</font></p>\nPosted in WordPress News  <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/lorelle.wordpress.com/3976/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/lorelle.wordpress.com/3976/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/lorelle.wordpress.com/3976/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/lorelle.wordpress.com/3976/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/lorelle.wordpress.com/3976/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/lorelle.wordpress.com/3976/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/lorelle.wordpress.com/3976/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/lorelle.wordpress.com/3976/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/lorelle.wordpress.com/3976/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/lorelle.wordpress.com/3976/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=lorelle.wordpress.com&blog=72&post=3976&subd=lorelle&ref=&feed=1\" /></div>\";s:7:\"pubdate\";s:31:\"Thu, 12 Mar 2009 17:51:23 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:17:\"Lorelle VanFossen\";}s:7:\"summary\";s:7377:\"<div class=\"snap_preview\"><br /><p><a href=\"http://lorelle.wordpress.com/tag/wordpress-news/\" title=\"WordPress News\"><img src=\"http://lorelle.files.wordpress.com/2007/01/wpnews1.png\" alt=\"WordPress News\" align=\"right\" /></a>According to a news story in <a href=\"http://netnewsdaily.com/\" title=\"Net News Daily\">Net News Daily</a>, <a title=\"Teens Create Social Networking Site\" href=\"http://netnewsdaily.com/?p=849\">two teenagers from Scotland have created a social blogging</a> platform on <a href=\"http://mu.wordpress.org/\" title=\"WordPressMU\" rel=\"tag\">WordPressMU</a> and <a href=\"http://buddypress.org/\" title=\"BuddyPress\" rel=\"tag\">BuddyPress</a> called <a href=\"http://www.scotblog.net\" title=\"Scotblog\">Scotblog</a>. </p>\n<blockquote><p>Scott Campbell and Nathan Adam, both 13, decided to launch the site after they spotted a gap in the market.</p>\n<p>“The internet needed a cool new social blogging site,” said Campbell, who lives in the North East of Scotland, “We provide a user friendly, fun, safe interface, which is easy for anyone to use.”</p></blockquote>\n<p>Scotblog.net is free and not restricted to those living in Scotland, though it&#8217;s welcome states &#8220;celebrate your heritage by connecting with family and friends across the globe&#8230;The ScotBlog way.&#8221;</p>\n<p><a href=\"http://www.scotblog.net\" title=\"Scotblog\"><img src=\"http://lorelle.files.wordpress.com/2009/03/scotblog.gif\" alt=\"scotblog\" title=\"scotblog\" width=\"229\" height=\"73\" class=\"alignleft size-full wp-image-3977\" /></a>They also call ScotBlog the first Social Blogging site. Although that definition is unclear, it is a well-developed online community site that uses the social functionality of BuddyPress with the power of multiple blogs and emphasis on social media tools and networking.</p>\n<p>The front page greets you in the fashion of a blog, with &#8220;most recent published posts&#8221; in chronological order from among all the bloggers, and showcases the groups the members &#8220;belong&#8221; to including <a href=\"http://scotblog.net/groups/bebo-1409600174\" title=\"Bebo\">Bebo</a>, <a href=\"http://scotblog.net/groups/twitter\" title=\"Twitter\">Twitter</a>, <a href=\"http://scotblog.net/groups/young-entrepreneurs\" title=\"Young Entrepreneurs\">Young Entrepreneurs</a>, <a href=\"http://scotblog.net/groups/photographers\" title=\"Photographers\">Photographers</a>, and <a href=\"http://scotblog.net/groups/scottish-history-1048200280\" title=\"Scottish History\">Scottish History</a>, the types of community groups long anticipated on <a href=\"http://www.wordpress.com/\" title=\"WordPress.com free blogs\" rel=\"tag\">WordPress.com</a>. The group pages showcase the group members and their most recent &#8220;group wire&#8221; comments.</p>\n<p>When you click on a member&#8217;s link, like the example page of the administrator, <a href=\"http://scotblog.net/members/admin/\" title=\"ScotBlog.net\">ScotBlog Page</a>, their page showcases the avatar/gravatar, blogs, the latest activity, groups, friends, and wire comments, similar to a Facebook wall. This is the equivalent of a Facebook page that links to their blogs and social networks.</p>\n<p>Like WordPress.com and other WordPressMU, blogs are set up by domain names. <a href=\"http://scottcampbell.scotblog.net/\" title=\"The Blog of Scott Campbell\">Scott Campbell&#8217;s blog</a> is set up as a test site but does feature advertising, which other blogs do not. There currently isn&#8217;t a Terms of Service form or page in the sign up so it&#8217;s unclear if they will allow advertising on a per blog basis or what restrictions there are to commercial blogging or spam blogs, the bane of such free hosted blog services. </p>\n<p>Currently, the blogs are styled with interesting WordPress Themes but the member page is still fairly bland and not reflective of their blogs. Hopefully in time, there will be a branding connection between the two, bluring the edges between blog and social media networking tools.</p>\n<p><a href=\"http://www.scotblog.net\" title=\"Scotblog\">Scotblog</a> is off to a good start and a fascinating example of the integration of BuddyPress and WordPressMU to build a community network of blogs and social groups. </p>\n<p><img src=\"http://lorelle.files.wordpress.com/2006/08/sig.gif\" alt=\"\" /><img src=\"http://lorelle.files.wordpress.com/2006/08/9rules.gif\" alt=\"Member of the 9Rules Blogging Network\" /><br />\n<hr />\n<p><font size=\"-1\"><b>Site Search Tags:</b> <a href=\"http://lorelle.wordpress.com/index.php?s=blogging+tips\" rel=\"tag\">blogging tips</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=blog+writing\" rel=\"tag\">blog writing</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=social+media\" rel=\"tag\">social media</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=networks\" rel=\"tag\">networks</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=blog+networks\" rel=\"tag\">blog networks</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=social+networks\" rel=\"tag\">social networks</a> <br /><a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/02/rss.png\" alt=\"Feed on Lorelle on WordPress\" /></a> <a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\">Subscribe</a>  <a href=\"http://feeds.feedburner.com/LorelleOnWordPress\" title=\"Feedburner Lorelle on WordPress Feed\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/04/feedburnericon.gif\" alt=\"Feedburner icon\" />Via Feedburner</a>  <a href=\"http://www.feedblitz.com/f/?Sub=182399\" title=\"Lorelle on WordPress - full site feed email subscription\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/03/email.gif\" alt=\"\" />Subscribe by Email</a></p>\n<p><a href=\"http://lorelle.wordpress.com/about/\" title=\"Copyright Protected by Brent and Lorelle VanFossen\">Copyright Lorelle VanFossen</a>, member of the <a href=\"http://9rules.com/\" title=\"Member of 9Rules Blogging Network\">9Rules Network</a>, and author of <a href=\"http://lorelle.wordpress.com/books/blogging-tips/\" title=\"Blogging Tips Book By Lorelle VanFossen\"><em>Blogging Tips, What Bloggers Won\'t Tell You About Blogging</em></a>.</font></p>\nPosted in WordPress News  <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/lorelle.wordpress.com/3976/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/lorelle.wordpress.com/3976/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/lorelle.wordpress.com/3976/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/lorelle.wordpress.com/3976/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/lorelle.wordpress.com/3976/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/lorelle.wordpress.com/3976/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/lorelle.wordpress.com/3976/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/lorelle.wordpress.com/3976/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/lorelle.wordpress.com/3976/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/lorelle.wordpress.com/3976/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=lorelle.wordpress.com&blog=72&post=3976&subd=lorelle&ref=&feed=1\" /></div>\";}i:22;a:7:{s:5:\"title\";s:17:\"Matt: Ha Long Bay\";s:4:\"guid\";s:21:\"http://ma.tt/?p=12172\";s:4:\"link\";s:33:\"http://ma.tt/2009/03/ha-long-bay/\";s:11:\"description\";s:20822:\"<p>Driving to and on a cruise ship around Ha Long Bay, Vietnam.</p>\n<p><span id=\"more-12172\"></span></p>\n\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1045-2/\" title=\"mcm_1045\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1045-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"Irrigation system\" title=\"mcm_1045\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1050-2/\" title=\"mcm_1050\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1050-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"Tourists taking photos\" title=\"mcm_1050\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1051/\" title=\"mcm_1051\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1051-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1051\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1052-2/\" title=\"mcm_1052\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1052-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"Rice!\" title=\"mcm_1052\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1056-2/\" title=\"mcm_1056\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_1056-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1056\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1057-2/\" title=\"mcm_1057\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1057-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"No photos\" title=\"mcm_1057\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1058/\" title=\"mcm_1058\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1058-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1058\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1061-2/\" title=\"mcm_1061\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1061-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1061\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1062/\" title=\"mcm_1062\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1062-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1062\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1065-2/\" title=\"mcm_1065\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1065-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1065\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1068/\" title=\"mcm_1068\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1068-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1068\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1069-2/\" title=\"mcm_1069\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1069-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1069\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1070/\" title=\"mcm_1070\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1070-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1070\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1071/\" title=\"mcm_1071\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1071-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1071\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1073-2/\" title=\"mcm_1073\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1073-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1073\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1074-2/\" title=\"mcm_1074\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1074-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1074\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1077-2/\" title=\"mcm_1077\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1077-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1077\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1080-2/\" title=\"mcm_1080\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1080-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1080\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1081/\" title=\"mcm_1081\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_1081-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1081\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1082-2/\" title=\"mcm_1082\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1082-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1082\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1083-2/\" title=\"mcm_1083\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1083-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1083\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1085-2/\" title=\"mcm_1085\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1085-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1085\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1087-2/\" title=\"mcm_1087\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1087-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1087\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1088-2/\" title=\"mcm_1088\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1088-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1088\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1089-2/\" title=\"mcm_1089\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1089-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1089\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1093-2/\" title=\"mcm_1093\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_1093-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1093\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1094-2/\" title=\"mcm_1094\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1094-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1094\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1095-2/\" title=\"mcm_1095\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1095-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1095\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1096-2/\" title=\"mcm_1096\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1096-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1096\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1097-2/\" title=\"mcm_1097\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1097-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1097\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1098-2/\" title=\"mcm_1098\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1098-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1098\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1099/\" title=\"mcm_1099\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1099-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1099\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1100-2/\" title=\"mcm_1100\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1100-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1100\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1101-2/\" title=\"mcm_1101\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1101-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1101\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1102/\" title=\"mcm_1102\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1102-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1102\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1104/\" title=\"mcm_1104\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_1104-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1104\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1105/\" title=\"mcm_1105\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1105-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1105\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1106-2/\" title=\"mcm_1106\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1106-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1106\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1107-2/\" title=\"mcm_1107\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1107-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1107\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1109-2/\" title=\"mcm_1109\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1109-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1109\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1113/\" title=\"mcm_1113\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1113-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1113\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1114/\" title=\"mcm_1114\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1114-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1114\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1115/\" title=\"mcm_1115\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1115-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1115\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1116-2/\" title=\"mcm_1116\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1116-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1116\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1117-2/\" title=\"mcm_1117\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1117-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1117\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1118-2/\" title=\"mcm_1118\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1118-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1118\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1120-2/\" title=\"mcm_1120\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1120-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1120\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1122-2/\" title=\"mcm_1122\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1122-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1122\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1123-2/\" title=\"mcm_1123\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1123-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1123\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1124-2/\" title=\"mcm_1124\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1124-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1124\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1125-2/\" title=\"mcm_1125\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1125-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1125\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1126-2/\" title=\"mcm_1126\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1126-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1126\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1128-2/\" title=\"mcm_1128\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_1128-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1128\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1129-2/\" title=\"mcm_1129\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1129-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1129\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1131-2/\" title=\"mcm_1131\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1131-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1131\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1132/\" title=\"mcm_1132\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1132-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1132\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1136-2/\" title=\"mcm_1136\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1136-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1136\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1138/\" title=\"mcm_1138\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1138-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1138\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1139/\" title=\"mcm_1139\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1139-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1139\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1140/\" title=\"mcm_1140\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1140-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1140\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1143-2/\" title=\"mcm_1143\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1143-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1143\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1150-2/\" title=\"mcm_1150\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_1150-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1150\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1151-2/\" title=\"mcm_1151\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1151-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1151\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1152/\" title=\"mcm_1152\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1152-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1152\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1155-2/\" title=\"mcm_1155\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1155-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1155\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1158/\" title=\"mcm_1158\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1158-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1158\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1159-2/\" title=\"mcm_1159\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_1159-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1159\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1161-2/\" title=\"mcm_1161\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1161-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1161\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1162-2/\" title=\"mcm_1162\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1162-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1162\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1617-2/\" title=\"mcm_1617\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1617-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1617\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1618-2/\" title=\"mcm_1618\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1618-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1618\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1619-2/\" title=\"mcm_1619\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1619-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1619\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1620-2/\" title=\"mcm_1620\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1620-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1620\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1623-2/\" title=\"mcm_1623\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1623-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1623\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1625-2/\" title=\"mcm_1625\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1625-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1625\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1626/\" title=\"mcm_1626\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1626-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1626\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1627-2/\" title=\"mcm_1627\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1627-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1627\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1628/\" title=\"mcm_1628\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1628-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1628\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1629-2/\" title=\"mcm_1629\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_1629-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1629\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1630-2/\" title=\"mcm_1630\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1630-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1630\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1631-2/\" title=\"mcm_1631\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1631-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1631\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1635-2/\" title=\"mcm_1635\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1635-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1635\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1640-2/\" title=\"mcm_1640\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1640-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1640\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1643-2/\" title=\"mcm_1643\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1643-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1643\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1645-2/\" title=\"mcm_1645\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1645-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1645\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1646-2/\" title=\"mcm_1646\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1646-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1646\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1648-2/\" title=\"mcm_1648\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1648-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1648\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1650-2/\" title=\"mcm_1650\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1650-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1650\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1654/\" title=\"mcm_1654\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1654-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1654\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1655-2/\" title=\"mcm_1655\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1655-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1655\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1657-2/\" title=\"mcm_1657\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1657-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1657\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1659-2/\" title=\"mcm_1659\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1659-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1659\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1660-2/\" title=\"mcm_1660\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1660-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1660\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1662-2/\" title=\"mcm_1662\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1662-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1662\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1663-2/\" title=\"mcm_1663\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1663-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1663\" /></a>\";s:7:\"pubdate\";s:31:\"Thu, 12 Mar 2009 10:30:47 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:20822:\"<p>Driving to and on a cruise ship around Ha Long Bay, Vietnam.</p>\n<p><span id=\"more-12172\"></span></p>\n\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1045-2/\" title=\"mcm_1045\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1045-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"Irrigation system\" title=\"mcm_1045\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1050-2/\" title=\"mcm_1050\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1050-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"Tourists taking photos\" title=\"mcm_1050\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1051/\" title=\"mcm_1051\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1051-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1051\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1052-2/\" title=\"mcm_1052\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1052-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"Rice!\" title=\"mcm_1052\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1056-2/\" title=\"mcm_1056\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_1056-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1056\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1057-2/\" title=\"mcm_1057\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1057-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"No photos\" title=\"mcm_1057\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1058/\" title=\"mcm_1058\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1058-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1058\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1061-2/\" title=\"mcm_1061\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1061-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1061\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1062/\" title=\"mcm_1062\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1062-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1062\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1065-2/\" title=\"mcm_1065\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1065-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1065\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1068/\" title=\"mcm_1068\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1068-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1068\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1069-2/\" title=\"mcm_1069\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1069-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1069\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1070/\" title=\"mcm_1070\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1070-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1070\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1071/\" title=\"mcm_1071\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1071-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1071\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1073-2/\" title=\"mcm_1073\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1073-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1073\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1074-2/\" title=\"mcm_1074\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1074-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1074\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1077-2/\" title=\"mcm_1077\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1077-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1077\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1080-2/\" title=\"mcm_1080\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1080-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1080\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1081/\" title=\"mcm_1081\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_1081-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1081\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1082-2/\" title=\"mcm_1082\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1082-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1082\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1083-2/\" title=\"mcm_1083\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1083-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1083\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1085-2/\" title=\"mcm_1085\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1085-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1085\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1087-2/\" title=\"mcm_1087\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1087-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1087\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1088-2/\" title=\"mcm_1088\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1088-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1088\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1089-2/\" title=\"mcm_1089\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1089-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1089\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1093-2/\" title=\"mcm_1093\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_1093-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1093\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1094-2/\" title=\"mcm_1094\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1094-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1094\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1095-2/\" title=\"mcm_1095\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1095-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1095\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1096-2/\" title=\"mcm_1096\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1096-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1096\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1097-2/\" title=\"mcm_1097\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1097-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1097\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1098-2/\" title=\"mcm_1098\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1098-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1098\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1099/\" title=\"mcm_1099\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1099-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1099\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1100-2/\" title=\"mcm_1100\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1100-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1100\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1101-2/\" title=\"mcm_1101\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1101-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1101\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1102/\" title=\"mcm_1102\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1102-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1102\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1104/\" title=\"mcm_1104\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_1104-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1104\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1105/\" title=\"mcm_1105\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1105-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1105\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1106-2/\" title=\"mcm_1106\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1106-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1106\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1107-2/\" title=\"mcm_1107\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1107-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1107\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1109-2/\" title=\"mcm_1109\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1109-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1109\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1113/\" title=\"mcm_1113\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1113-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1113\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1114/\" title=\"mcm_1114\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1114-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1114\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1115/\" title=\"mcm_1115\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1115-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1115\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1116-2/\" title=\"mcm_1116\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1116-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1116\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1117-2/\" title=\"mcm_1117\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1117-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1117\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1118-2/\" title=\"mcm_1118\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1118-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1118\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1120-2/\" title=\"mcm_1120\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1120-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1120\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1122-2/\" title=\"mcm_1122\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1122-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1122\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1123-2/\" title=\"mcm_1123\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1123-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1123\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1124-2/\" title=\"mcm_1124\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1124-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1124\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1125-2/\" title=\"mcm_1125\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1125-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1125\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1126-2/\" title=\"mcm_1126\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1126-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1126\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1128-2/\" title=\"mcm_1128\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_1128-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1128\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1129-2/\" title=\"mcm_1129\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1129-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1129\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1131-2/\" title=\"mcm_1131\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1131-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1131\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1132/\" title=\"mcm_1132\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1132-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1132\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1136-2/\" title=\"mcm_1136\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1136-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1136\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1138/\" title=\"mcm_1138\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1138-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1138\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1139/\" title=\"mcm_1139\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1139-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1139\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1140/\" title=\"mcm_1140\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1140-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1140\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1143-2/\" title=\"mcm_1143\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1143-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1143\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1150-2/\" title=\"mcm_1150\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_1150-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1150\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1151-2/\" title=\"mcm_1151\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1151-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1151\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1152/\" title=\"mcm_1152\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1152-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1152\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1155-2/\" title=\"mcm_1155\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1155-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1155\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1158/\" title=\"mcm_1158\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1158-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1158\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1159-2/\" title=\"mcm_1159\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_1159-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1159\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1161-2/\" title=\"mcm_1161\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1161-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1161\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1162-2/\" title=\"mcm_1162\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1162-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1162\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1617-2/\" title=\"mcm_1617\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1617-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1617\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1618-2/\" title=\"mcm_1618\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1618-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1618\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1619-2/\" title=\"mcm_1619\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1619-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1619\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1620-2/\" title=\"mcm_1620\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1620-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1620\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1623-2/\" title=\"mcm_1623\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1623-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1623\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1625-2/\" title=\"mcm_1625\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1625-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1625\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1626/\" title=\"mcm_1626\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1626-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1626\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1627-2/\" title=\"mcm_1627\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1627-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1627\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1628/\" title=\"mcm_1628\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1628-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1628\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1629-2/\" title=\"mcm_1629\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/03/mcm_1629-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1629\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1630-2/\" title=\"mcm_1630\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1630-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1630\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1631-2/\" title=\"mcm_1631\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1631-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1631\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1635-2/\" title=\"mcm_1635\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1635-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1635\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1640-2/\" title=\"mcm_1640\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1640-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1640\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1643-2/\" title=\"mcm_1643\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1643-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1643\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1645-2/\" title=\"mcm_1645\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1645-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1645\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1646-2/\" title=\"mcm_1646\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1646-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1646\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1648-2/\" title=\"mcm_1648\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1648-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1648\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1650-2/\" title=\"mcm_1650\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1650-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1650\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1654/\" title=\"mcm_1654\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1654-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1654\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1655-2/\" title=\"mcm_1655\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1655-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1655\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1657-2/\" title=\"mcm_1657\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1657-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1657\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1659-2/\" title=\"mcm_1659\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1659-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1659\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1660-2/\" title=\"mcm_1660\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1660-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1660\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1662-2/\" title=\"mcm_1662\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1662-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1662\" /></a>\n<a href=\"http://ma.tt/2009/03/ha-long-bay/mcm_1663-2/\" title=\"mcm_1663\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/03/mcm_1663-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_1663\" /></a>\";}i:23;a:7:{s:5:\"title\";s:66:\"Weblog Tools Collection: Would you like to review plugins on WLTC?\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5308\";s:4:\"link\";s:94:\"http://weblogtoolscollection.com/archives/2009/03/11/would-you-like-to-review-plugins-on-wltc/\";s:11:\"description\";s:4419:\"<p>It&#8217;s been more than two months since we began our <a href=\"http://weblogtoolscollection.com/archives/category/apad/\">Weekly Plugin Review</a>. During this time, we&#8217;ve reviewed nine plugins. All of these posts received a good number of comments, with many requesting more features and with others being mini reviews of the commenter&#8217;s experience.</p>\n<p>So, why not take this a step further? Starting this week, we&#8217;re going to throw up the Plugin Review process to everyone.</p>\n<h3>How will it work?</h3>\n<p>As you know, every Sunday we pick one plugin to review. e.g. last Sunday, i.e. March 8, we reviewed the <a href=\"http://weblogtoolscollection.com/archives/2009/03/08/plugin-review-feed-reading-blogroll/\">Feed Reading Blogroll plugin</a>.</p>\n<p>After we publish our review, we&#8217;ll throw open the review process to all of you.</p>\n<p>You&#8217;ll need to publish a review of the plugin on your blog. <em>Your review should contain a link to the corresponding review post on WLTC</em>.</p>\n<p>After this, send an email to <strong>submissions AT wltc DOT net</strong> with the following information:</p>\n<p><strong>Subject line of the email:</strong> [APAD Plugin Review]: <em>plugin name</em>. Replace <em>plugin name</em> with the name of the plugin you reviewed.</p>\n<p><strong>Content of the Email:</strong></p>\n<ol>\n<li>URL of the review on your blog. Make sure this is a direct link to the post </li>\n<li>An excerpt of your post. Maximum 50 words. This will be used by us. </li>\n</ol>\n<p>You&#8217;ll have up to this <strong>Saturday, March 14 - 11.59pm </strong><a title=\"View the current time in EST\" href=\"http://wwp.greenwichmeantime.com/time-zone/usa/eastern-time/\"><strong>EST</strong></a> to send us an email with the link to the review.</p>\n<p>To be fair to all the plugins reviewed so far; this week, we&#8217;ll allow you to pick any of the nine plugins we have reviewed so far. The plugins are:</p>\n<ul>\n<li><a href=\"http://simplepressforum.com/\">Simple:Press Forum</a> </li>\n<li><a href=\"http://www.phoenixheart.net/2008/11/referrer-detector/\">Referrer Detector</a> </li>\n<li><a href=\"http://omninoggin.com/projects/wordpress-plugins/wp-greet-box-wordpress-plugin/\">WP Greet Box</a> </li>\n<li><a href=\"http://www.webmaster-source.com/wp125-ad-plugin-wordpress/\">WP125</a> </li>\n<li><a href=\"http://www.mailpress.org/\">MailPress</a> </li>\n<li><a href=\"http://www.svenkubiak.de/yawasp-en/\">Yawasp (Yet Another WordPress Anti-Spam Plugin)</a> </li>\n<li><a href=\"http://garinungkadol.com/downloads/post-avatar/\">Post Avatar</a> </li>\n<li><a href=\"http://www.improvingtheweb.com/wordpress-plugins/improved-plugin-installation/\">Improved Plugin Installation</a> </li>\n<li><a href=\"http://www.weinschenker.name/plugin-feed-reading-blogroll/\">Feed Reading Blogroll</a> </li>\n</ul>\n<p>So, pick any one plugin from the list above, write a review on your blog and send us an email with the URL of your review.</p>\n<h3>Email sent? What&#8217;s next?</h3>\n<p>On Sunday, i.e. March 15, we&#8217;ll make a post out here on Weblog Tools Collection with a summary of the emails we receive.</p>\n<p>Remember not every review will be featured out here. So, here&#8217;s some criteria used for selection:</p>\n<ul>\n<li>Your review should link to the corresponding plugin review post on WLTC</li>\n<li>Your review will have to be at least 250 words. (This may be relaxed if the review is really spectacular). </li>\n<li>You&#8217;re site should be fit for all ages (family friendly), i.e. sites featuring adult content or with an adult theme will not be listed </li>\n<li>Gambling, casino and similar sites will not be listed </li>\n</ul>\n<p>We may revise this criteria at a later juncture.</p>\n<h3>How will this help you?</h3>\n<p>How does tonnes of traffic sound to you?</p>\n<p>Weblog Tools Collection is a highly popular blog with tens of thousands of pageviews every single day. We have over 13,000 subscribers via our feed and our feed is delivered via email to 350+ subscribers.</p>\n<p>Writing a good review is a good way of attracting visitors to your blog and converting them to regular readers.</p>\n<p>Remember, the list will be formulated on a first come first serve basis. So, send in your email now! The clock is ticking&#8230;</p>\n<p>Are you a plugin author? <a href=\"http://weblogtoolscollection.com/submit-news\">Read how you can submit your plugin to be reviewed by us</a>.</p>\";s:7:\"pubdate\";s:31:\"Wed, 11 Mar 2009 21:14:29 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:4419:\"<p>It&#8217;s been more than two months since we began our <a href=\"http://weblogtoolscollection.com/archives/category/apad/\">Weekly Plugin Review</a>. During this time, we&#8217;ve reviewed nine plugins. All of these posts received a good number of comments, with many requesting more features and with others being mini reviews of the commenter&#8217;s experience.</p>\n<p>So, why not take this a step further? Starting this week, we&#8217;re going to throw up the Plugin Review process to everyone.</p>\n<h3>How will it work?</h3>\n<p>As you know, every Sunday we pick one plugin to review. e.g. last Sunday, i.e. March 8, we reviewed the <a href=\"http://weblogtoolscollection.com/archives/2009/03/08/plugin-review-feed-reading-blogroll/\">Feed Reading Blogroll plugin</a>.</p>\n<p>After we publish our review, we&#8217;ll throw open the review process to all of you.</p>\n<p>You&#8217;ll need to publish a review of the plugin on your blog. <em>Your review should contain a link to the corresponding review post on WLTC</em>.</p>\n<p>After this, send an email to <strong>submissions AT wltc DOT net</strong> with the following information:</p>\n<p><strong>Subject line of the email:</strong> [APAD Plugin Review]: <em>plugin name</em>. Replace <em>plugin name</em> with the name of the plugin you reviewed.</p>\n<p><strong>Content of the Email:</strong></p>\n<ol>\n<li>URL of the review on your blog. Make sure this is a direct link to the post </li>\n<li>An excerpt of your post. Maximum 50 words. This will be used by us. </li>\n</ol>\n<p>You&#8217;ll have up to this <strong>Saturday, March 14 - 11.59pm </strong><a title=\"View the current time in EST\" href=\"http://wwp.greenwichmeantime.com/time-zone/usa/eastern-time/\"><strong>EST</strong></a> to send us an email with the link to the review.</p>\n<p>To be fair to all the plugins reviewed so far; this week, we&#8217;ll allow you to pick any of the nine plugins we have reviewed so far. The plugins are:</p>\n<ul>\n<li><a href=\"http://simplepressforum.com/\">Simple:Press Forum</a> </li>\n<li><a href=\"http://www.phoenixheart.net/2008/11/referrer-detector/\">Referrer Detector</a> </li>\n<li><a href=\"http://omninoggin.com/projects/wordpress-plugins/wp-greet-box-wordpress-plugin/\">WP Greet Box</a> </li>\n<li><a href=\"http://www.webmaster-source.com/wp125-ad-plugin-wordpress/\">WP125</a> </li>\n<li><a href=\"http://www.mailpress.org/\">MailPress</a> </li>\n<li><a href=\"http://www.svenkubiak.de/yawasp-en/\">Yawasp (Yet Another WordPress Anti-Spam Plugin)</a> </li>\n<li><a href=\"http://garinungkadol.com/downloads/post-avatar/\">Post Avatar</a> </li>\n<li><a href=\"http://www.improvingtheweb.com/wordpress-plugins/improved-plugin-installation/\">Improved Plugin Installation</a> </li>\n<li><a href=\"http://www.weinschenker.name/plugin-feed-reading-blogroll/\">Feed Reading Blogroll</a> </li>\n</ul>\n<p>So, pick any one plugin from the list above, write a review on your blog and send us an email with the URL of your review.</p>\n<h3>Email sent? What&#8217;s next?</h3>\n<p>On Sunday, i.e. March 15, we&#8217;ll make a post out here on Weblog Tools Collection with a summary of the emails we receive.</p>\n<p>Remember not every review will be featured out here. So, here&#8217;s some criteria used for selection:</p>\n<ul>\n<li>Your review should link to the corresponding plugin review post on WLTC</li>\n<li>Your review will have to be at least 250 words. (This may be relaxed if the review is really spectacular). </li>\n<li>You&#8217;re site should be fit for all ages (family friendly), i.e. sites featuring adult content or with an adult theme will not be listed </li>\n<li>Gambling, casino and similar sites will not be listed </li>\n</ul>\n<p>We may revise this criteria at a later juncture.</p>\n<h3>How will this help you?</h3>\n<p>How does tonnes of traffic sound to you?</p>\n<p>Weblog Tools Collection is a highly popular blog with tens of thousands of pageviews every single day. We have over 13,000 subscribers via our feed and our feed is delivered via email to 350+ subscribers.</p>\n<p>Writing a good review is a good way of attracting visitors to your blog and converting them to regular readers.</p>\n<p>Remember, the list will be formulated on a first come first serve basis. So, send in your email now! The clock is ticking&#8230;</p>\n<p>Are you a plugin author? <a href=\"http://weblogtoolscollection.com/submit-news\">Read how you can submit your plugin to be reviewed by us</a>.</p>\";}i:24;a:7:{s:5:\"title\";s:37:\"Matt: Authentication in WordPress 2.8\";s:4:\"guid\";s:21:\"http://ma.tt/?p=12331\";s:4:\"link\";s:52:\"http://ma.tt/2009/03/authentication-in-wordpress-28/\";s:11:\"description\";s:144:\"<p><a href=\"http://willnorris.com/2009/03/authentication-in-wordpress-28\">Will Norris on the new authentication system in WordPress 2.8</a>.</p>\";s:7:\"pubdate\";s:31:\"Wed, 11 Mar 2009 03:07:37 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:144:\"<p><a href=\"http://willnorris.com/2009/03/authentication-in-wordpress-28\">Will Norris on the new authentication system in WordPress 2.8</a>.</p>\";}i:25;a:7:{s:5:\"title\";s:37:\"Matt: I Heart Blogging design contest\";s:4:\"guid\";s:21:\"http://ma.tt/?p=12040\";s:4:\"link\";s:38:\"http://ma.tt/2009/03/i-heart-blogging/\";s:11:\"description\";s:1897:\"<p>You may know of <a href=\"http://www.infectious.com/\">Infectious</a> as those guys who make the cool <a href=\"http://www.infectious.com/browse/car-decals\">vinyl decals for cars</a>. Now they have laptop and iPhone skins, too, and WordPress has partnered with Infectious for the launch with the &#8220;I &lt;3 Blogging&#8221; contest. </p>\n<p>The winners will be chosen by <a href=\"http://powazek.com/\">Derek Powazek</a>, <a href=\"http://iammattthomas.com/\">Matt Thomas</a>, Team Infectious, and yours truly, and <a href=\"http://www.infectious.com/wordpress\">the prizes</a> are sweet. If you nab the grand prize, your design will be printed on laptop and iPhone skins that will be sold in the Infectious store. You&#8217;ll also get a cut of the profit from their sales, $400 cash, some <a href=\"http://shop.wordpress.net/\">WordPress schwag</a>, and $400 to spend on merchandise in the Infectious store. </p>\n<p>The contest ends March 31, so hop on Photoshop or Illustrator and use your design chops to show us why you love blogging. The theme is completely open to interpretation, so feel free to <a href=\"http://www.infectious.com/voting/wordpress\">get creative</a>. You can submit your creations and vote on others <a href=\"http://www.infectious.com/wordpress\">here</a>. You might also want to check out the official WordPress <a href=\"http://wordpress.org/about/logos/\">logos and graphics</a> because <a href=\"http://s.ma.tt/files/2009/01/wordpress-logo.png\">friends don&#8217;t let friends use the incorrect WP logo</a>. <img src=\"http://ma.tt/blog/wp-includes/images/smilies/icon_wink.gif\" alt=\";)\" class=\"wp-smiley\" /> </p>\n<p>As a final bonus, I&#8217;ll be putting the winning design on my next laptop, so it&#8217;ll get exposure all over the world. (Last year I spoke in over 35 cities across 6 continents.) <a href=\"http://www.infectious.com/wordpress\">Enter your design here</a>.</p>\";s:7:\"pubdate\";s:31:\"Wed, 11 Mar 2009 02:33:12 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:1897:\"<p>You may know of <a href=\"http://www.infectious.com/\">Infectious</a> as those guys who make the cool <a href=\"http://www.infectious.com/browse/car-decals\">vinyl decals for cars</a>. Now they have laptop and iPhone skins, too, and WordPress has partnered with Infectious for the launch with the &#8220;I &lt;3 Blogging&#8221; contest. </p>\n<p>The winners will be chosen by <a href=\"http://powazek.com/\">Derek Powazek</a>, <a href=\"http://iammattthomas.com/\">Matt Thomas</a>, Team Infectious, and yours truly, and <a href=\"http://www.infectious.com/wordpress\">the prizes</a> are sweet. If you nab the grand prize, your design will be printed on laptop and iPhone skins that will be sold in the Infectious store. You&#8217;ll also get a cut of the profit from their sales, $400 cash, some <a href=\"http://shop.wordpress.net/\">WordPress schwag</a>, and $400 to spend on merchandise in the Infectious store. </p>\n<p>The contest ends March 31, so hop on Photoshop or Illustrator and use your design chops to show us why you love blogging. The theme is completely open to interpretation, so feel free to <a href=\"http://www.infectious.com/voting/wordpress\">get creative</a>. You can submit your creations and vote on others <a href=\"http://www.infectious.com/wordpress\">here</a>. You might also want to check out the official WordPress <a href=\"http://wordpress.org/about/logos/\">logos and graphics</a> because <a href=\"http://s.ma.tt/files/2009/01/wordpress-logo.png\">friends don&#8217;t let friends use the incorrect WP logo</a>. <img src=\"http://ma.tt/blog/wp-includes/images/smilies/icon_wink.gif\" alt=\";)\" class=\"wp-smiley\" /> </p>\n<p>As a final bonus, I&#8217;ll be putting the winning design on my next laptop, so it&#8217;ll get exposure all over the world. (Last year I spoke in over 35 cities across 6 continents.) <a href=\"http://www.infectious.com/wordpress\">Enter your design here</a>.</p>\";}i:26;a:7:{s:5:\"title\";s:60:\"Weblog Tools Collection: WordPress Plugin Releases for 03/10\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5273\";s:4:\"link\";s:88:\"http://weblogtoolscollection.com/archives/2009/03/10/wordpress-plugin-releases-for-0310/\";s:11:\"description\";s:5278:\"<h3>New Plugins</h3>\n<p><a href=\"http://ajaydsouza.com/wordpress/plugins/add-to-footer/\">Add to Footer</a></p>\n<p>A simple plugin that allows you to automatically add text or HTML to you theme’s footer. The plugin provides you with a simple text box into which you can copy your the HTML into. As an additional feature, Add to Footer also comes inbuilt with support for <a href=\"http://www.google.com/analytics/\">Google Analytics</a>, <a href=\"http://www.statcounter.com/\">StatCounter</a>, <a href=\"http://www.reinvigorate.com/\">Reinvigorate</a> and <a href=\"http://www.apture.com/\">Apture</a>.</p>\n<p><a href=\"http://la-passeggiata.com/?p=1&amp;lang=en\">QF-GetThumb</a></p>\n<p>This plug-in analyzes a certain image tag in an content and has a function to make only one point a reference former image thumbnail and cache file of those.</p>\n<p><a href=\"http://blog.clearskys.net/plugins/snipt-code-embedding-plugin/\">Snipt code embedding plugin</a></p>\n<p>The Snipt code embedding plugin provides a simple interface for embedding <a href=\"http://snipt.net\">Snipt.net</a> code samples within your blog posts. It allows you to quickly embed code samples by providing the plugin with the Snipt.net embed script (or URL) from the Visual or HTML content editor. When in visual editor mode, your codes location is marked with a small tag so you can immediately see where your code is within the documents body.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/simpler-css/\">Simpler CSS</a></p>\n<p>Simpler CSS is a simple (mu-)plugin that enables custom CSS on WordPress and WordPress µ blogs. A blogger may add CSS code using Simpler CSS that is stored in the options table; WordPress µ users can customize their sites without editing theme files.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/invisible-defender/\">Invisible Defender</a></p>\n<p>This plugin protects your registration, login and comment forms against spambots</p>\n<p><a href=\"http://www.subzane.com/projects/categorized-archive-widget/\">Subzane Categorized Archive Widget</a></p>\n<p>A widget that displays an archive for the current selected category. On non-category pages a standard archive is displayed.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/single-random-post/\">Single Random Post</a></p>\n<p>This plugin will allow you to display a single post selected at random from your post database</p>\n<p><a href=\"http://smallwebsitehost.com/collapsable-menu-plugin-for-wordpress/wordpress/\">Collapsable Menu</a></p>\n<p>Creates a collapsible menu for your categories</p>\n<p><a href=\"http://wpheatmap.oufel.com/\">Heatmap Plugin</a></p>\n<p>This plugin monitor user mouse movement and clicks.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/the-kontera-wordpress-plugin/\">Kontera Wordpress Plugin</a></p>\n<p>Enables instant addition of Kontera ContentLink ads to your WordPress 2.7 blog</p>\n<h3>Updated Plugins</h3>\n<p><a href=\"http://ajaydsouza.com/wordpress/plugins/contextual-related-posts/\">Contextual Related Posts</a></p>\n<p>Display a list of contextually related posts for the current post. You can select the number of posts to display and if you want to automatically display the related posts in your content / feed. You can choose to exclude posts from certain categories as well as exclude pages.</p>\n<p><a href=\"http://omninoggin.com/projects/wordpress-plugins/wp-greet-box-wordpress-plugin/\">WP Greet Box</a></p>\n<p>This plugin lets you show a different greeting message to your new visitors depending on their referrer url.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/author-avatars/\">Author Avatars List</a></p>\n<p>This plugin makes it easy to display lists of user avatars on your (multiuser) blog. It also allows to insert single avatars for blog users or any email address into a post or page. (Great for displaying an image of someone you&#8217;re talking about.)</p>\n<p><a href=\"http://wordpress.org/extend/plugins/wp-stats-dashboard/\">WP Stats Dashboard</a></p>\n<p>Displays the WordPress.com stats graph directly in your Dashboard. No more tiresomely opening the Blog Stats tab and manually logging in.</p>\n<p><a href=\"http://www.bebl.eu/zeug/hyphenator\">Hyphenator</a></p>\n<p>Soft hyphen are automatically added in the content for nicer automatic word wrap. Particularly suitable for justification. Uses Hyphenator.js.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/posts-compare/\">Posts Compare</a></p>\n<p>This plugin allows you to check your posts for getting copied.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/parallel-load/\">Parallel Load</a></p>\n<p>Load Javascript files in parallel by using document.write tag.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/antispam-bee/\">Antispam Bee</a></p>\n<p>Antispam Bee - The easy and effective Antispam Plugin for WordPress. <em>Page in German</em></p>\n<p><a href=\"http://blog.andreaolivato.net/software/translate-this-wordpress-plugin\">Translate This</a></p>\n<p>Translate This is a Wordpress plugins that allows users to translate their posts and pages directly from the input form.</p>\n<p><a href=\"http://yoast.com/wordpress/canonical/\">Canonical URL&#8217;s</a></p>\n<p>Adds rel=&#8221;canonical&#8221; links to the head of your site, which help to prevent duplicate content issues on your blog.</p>\";s:7:\"pubdate\";s:31:\"Tue, 10 Mar 2009 19:09:02 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:5278:\"<h3>New Plugins</h3>\n<p><a href=\"http://ajaydsouza.com/wordpress/plugins/add-to-footer/\">Add to Footer</a></p>\n<p>A simple plugin that allows you to automatically add text or HTML to you theme’s footer. The plugin provides you with a simple text box into which you can copy your the HTML into. As an additional feature, Add to Footer also comes inbuilt with support for <a href=\"http://www.google.com/analytics/\">Google Analytics</a>, <a href=\"http://www.statcounter.com/\">StatCounter</a>, <a href=\"http://www.reinvigorate.com/\">Reinvigorate</a> and <a href=\"http://www.apture.com/\">Apture</a>.</p>\n<p><a href=\"http://la-passeggiata.com/?p=1&amp;lang=en\">QF-GetThumb</a></p>\n<p>This plug-in analyzes a certain image tag in an content and has a function to make only one point a reference former image thumbnail and cache file of those.</p>\n<p><a href=\"http://blog.clearskys.net/plugins/snipt-code-embedding-plugin/\">Snipt code embedding plugin</a></p>\n<p>The Snipt code embedding plugin provides a simple interface for embedding <a href=\"http://snipt.net\">Snipt.net</a> code samples within your blog posts. It allows you to quickly embed code samples by providing the plugin with the Snipt.net embed script (or URL) from the Visual or HTML content editor. When in visual editor mode, your codes location is marked with a small tag so you can immediately see where your code is within the documents body.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/simpler-css/\">Simpler CSS</a></p>\n<p>Simpler CSS is a simple (mu-)plugin that enables custom CSS on WordPress and WordPress µ blogs. A blogger may add CSS code using Simpler CSS that is stored in the options table; WordPress µ users can customize their sites without editing theme files.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/invisible-defender/\">Invisible Defender</a></p>\n<p>This plugin protects your registration, login and comment forms against spambots</p>\n<p><a href=\"http://www.subzane.com/projects/categorized-archive-widget/\">Subzane Categorized Archive Widget</a></p>\n<p>A widget that displays an archive for the current selected category. On non-category pages a standard archive is displayed.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/single-random-post/\">Single Random Post</a></p>\n<p>This plugin will allow you to display a single post selected at random from your post database</p>\n<p><a href=\"http://smallwebsitehost.com/collapsable-menu-plugin-for-wordpress/wordpress/\">Collapsable Menu</a></p>\n<p>Creates a collapsible menu for your categories</p>\n<p><a href=\"http://wpheatmap.oufel.com/\">Heatmap Plugin</a></p>\n<p>This plugin monitor user mouse movement and clicks.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/the-kontera-wordpress-plugin/\">Kontera Wordpress Plugin</a></p>\n<p>Enables instant addition of Kontera ContentLink ads to your WordPress 2.7 blog</p>\n<h3>Updated Plugins</h3>\n<p><a href=\"http://ajaydsouza.com/wordpress/plugins/contextual-related-posts/\">Contextual Related Posts</a></p>\n<p>Display a list of contextually related posts for the current post. You can select the number of posts to display and if you want to automatically display the related posts in your content / feed. You can choose to exclude posts from certain categories as well as exclude pages.</p>\n<p><a href=\"http://omninoggin.com/projects/wordpress-plugins/wp-greet-box-wordpress-plugin/\">WP Greet Box</a></p>\n<p>This plugin lets you show a different greeting message to your new visitors depending on their referrer url.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/author-avatars/\">Author Avatars List</a></p>\n<p>This plugin makes it easy to display lists of user avatars on your (multiuser) blog. It also allows to insert single avatars for blog users or any email address into a post or page. (Great for displaying an image of someone you&#8217;re talking about.)</p>\n<p><a href=\"http://wordpress.org/extend/plugins/wp-stats-dashboard/\">WP Stats Dashboard</a></p>\n<p>Displays the WordPress.com stats graph directly in your Dashboard. No more tiresomely opening the Blog Stats tab and manually logging in.</p>\n<p><a href=\"http://www.bebl.eu/zeug/hyphenator\">Hyphenator</a></p>\n<p>Soft hyphen are automatically added in the content for nicer automatic word wrap. Particularly suitable for justification. Uses Hyphenator.js.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/posts-compare/\">Posts Compare</a></p>\n<p>This plugin allows you to check your posts for getting copied.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/parallel-load/\">Parallel Load</a></p>\n<p>Load Javascript files in parallel by using document.write tag.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/antispam-bee/\">Antispam Bee</a></p>\n<p>Antispam Bee - The easy and effective Antispam Plugin for WordPress. <em>Page in German</em></p>\n<p><a href=\"http://blog.andreaolivato.net/software/translate-this-wordpress-plugin\">Translate This</a></p>\n<p>Translate This is a Wordpress plugins that allows users to translate their posts and pages directly from the input form.</p>\n<p><a href=\"http://yoast.com/wordpress/canonical/\">Canonical URL&#8217;s</a></p>\n<p>Adds rel=&#8221;canonical&#8221; links to the head of your site, which help to prevent duplicate content issues on your blog.</p>\";}i:27;a:7:{s:5:\"title\";s:29:\"Matt: PollDaddy API & Twitter\";s:4:\"guid\";s:21:\"http://ma.tt/?p=12272\";s:4:\"link\";s:43:\"http://ma.tt/2009/03/polldaddy-api-twitter/\";s:11:\"description\";s:220:\"<p><a href=\"http://blog.polldaddy.com/2009/03/10/get-developing-on-our-api/\">PollDaddy has a new API</a>. Also check out their <a href=\"http://twitter.polldaddy.com/\">easy tool for polling your Twitter followers</a>.</p>\";s:7:\"pubdate\";s:31:\"Tue, 10 Mar 2009 17:57:06 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:220:\"<p><a href=\"http://blog.polldaddy.com/2009/03/10/get-developing-on-our-api/\">PollDaddy has a new API</a>. Also check out their <a href=\"http://twitter.polldaddy.com/\">easy tool for polling your Twitter followers</a>.</p>\";}i:28;a:7:{s:5:\"title\";s:55:\"Gravatar: Gravatar .NET control for Silverlight and WPF\";s:4:\"guid\";s:31:\"http://blog.gravatar.com/?p=148\";s:4:\"link\";s:81:\"http://blog.gravatar.com/2009/03/10/gravatar-net-control-for-silverlight-and-wpf/\";s:11:\"description\";s:1478:\"<div class=\"snap_preview\"><br /><p><a href=\"http://www.jeff.wilcox.name/\">Jeff</a> writes in to let us know that he has created an open source Gravatar control for Silverlight and WPF apps available here: <a href=\"http://www.jeff.wilcox.name/2009/03/gravatar-control/\">http://www.jeff.wilcox.name/2009/03/gravatar-control/</a></p>\n<p>Thanks, Jeff!</p>\n  <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/gravatar.wordpress.com/148/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/gravatar.wordpress.com/148/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/gravatar.wordpress.com/148/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/gravatar.wordpress.com/148/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/gravatar.wordpress.com/148/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/gravatar.wordpress.com/148/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/gravatar.wordpress.com/148/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/gravatar.wordpress.com/148/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/gravatar.wordpress.com/148/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/gravatar.wordpress.com/148/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=blog.gravatar.com&blog=1886259&post=148&subd=gravatar&ref=&feed=1\" /></div>\";s:7:\"pubdate\";s:31:\"Tue, 10 Mar 2009 17:01:38 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:11:\"apokalyptik\";}s:7:\"summary\";s:1478:\"<div class=\"snap_preview\"><br /><p><a href=\"http://www.jeff.wilcox.name/\">Jeff</a> writes in to let us know that he has created an open source Gravatar control for Silverlight and WPF apps available here: <a href=\"http://www.jeff.wilcox.name/2009/03/gravatar-control/\">http://www.jeff.wilcox.name/2009/03/gravatar-control/</a></p>\n<p>Thanks, Jeff!</p>\n  <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/gravatar.wordpress.com/148/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/gravatar.wordpress.com/148/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/gravatar.wordpress.com/148/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/gravatar.wordpress.com/148/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/gravatar.wordpress.com/148/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/gravatar.wordpress.com/148/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/gravatar.wordpress.com/148/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/gravatar.wordpress.com/148/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/gravatar.wordpress.com/148/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/gravatar.wordpress.com/148/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=blog.gravatar.com&blog=1886259&post=148&subd=gravatar&ref=&feed=1\" /></div>\";}i:29;a:7:{s:5:\"title\";s:63:\"Donncha: HOWTO: Make WordPress plugins work with WP Super Cache\";s:4:\"guid\";s:29:\"http://ocaoimh.ie/?p=89494635\";s:4:\"link\";s:83:\"http://ocaoimh.ie/2009/03/10/howto-make-wordpress-plugins-work-with-wp-super-cache/\";s:11:\"description\";s:3953:\"<p><a href=\"http://ocaoimh.ie/?attachment_id=3664\" rel=\"attachment wp-att-3664\"><img align=\"right\" src=\"http://inphotos.org/wp-content/uploads/2009/03/daffodil-snow-and-water-droplets-150x150.jpg\" alt=\"Daffodil, snow and water droplets\" title=\"Daffodil, snow and water droplets\" width=\"150\" height=\"150\" class=\"alignright size-thumbnail wp-image-3664\" /></a> Thaya Kareeson has written an <a href=\"http://omninoggin.com/wordpress-posts/make-any-plugin-work-with-wp-super-cache/\">excellent article</a> for plugin developers. It goes through how to make plugins work with WP Super Cache by using dynamic AJAX calls.</p>\n<p><a href=\"http://ocaoimh.ie/wp-super-cache/\">WP Super Cache</a> can make static html copies of pages served by WordPress which is great for performance. Unfortunately that means some plugins don&#8217;t work because they rely on executing PHP on each request. The plugins need to be rewritten to use AJAX calls by the visitor&#8217;s browser. There&#8217;s a FAQ in the readme.txt all about it!</p>\n<p>I previously wrote about <a href=\"http://ocaoimh.ie/2008/11/01/make-your-wordpress-plugin-talk-ajax/\">adding AJAX to WordPress plugins</a> but Thaya has worked through a simple example that will work perfectly with WP Super Cache. It&#8217;s a good foundation for plugin developers start from. </p>\n<p>He also has versions of <a href=\"http://omninoggin.com/wordpress-posts/make-wp-postviews-work-with-wp-super-cache/\">WP Postviews</a> and <a href=\"http://omninoggin.com/wordpress-posts/make-popularity-contest-work-with-wp-super-cache/\">Popularity Contest</a> that have been rewritten to support static caching. I haven&#8217;t tried either plugin so leave a comment on his blog if you need help!</p>\n<p>If you depend on a large portion of your content being dynamic this isn&#8217;t the solution for you as it will affect what search engines see. Those bots don&#8217;t speak Javascript, but for interactive purposes (ratings, stats etc) it&#8217;s the job.</p>\n<p><a href=\"http://ocaoimh.ie/?attachment_id=3657\" rel=\"attachment wp-att-3657\"><img align=\"right\" src=\"http://inphotos.org/wp-content/uploads/2009/03/reading-glasses-150x150.jpg\" alt=\"reading glasses\" title=\"reading glasses\" width=\"150\" height=\"150\" class=\"alignright size-thumbnail wp-image-3657\" /></a>  Further reading:\n<ul>\n<li><a href=\"http://codex.wordpress.org/AJAX_in_Plugins\">AJAX in Plugins</a> is a must-read starting point for developers.</li>\n<li><a href=\"http://codex.wordpress.org/Function_Reference/wp_enqueue_script\">wp_enqueue_script()</a> is the command WordPress uses to load Javascript files. That page links to a couple of good pages too including this <a href=\"http://www.prelovac.com/vladimir/best-practice-for-adding-javascript-code-to-wordpress-plugin\">best practices</a> post. As of this writing, Thaya&#8217;s example don&#8217;t use wp_enqueue_script() but it&#8217;s simple to use.</li>\n</ul>\n<p><br clear=\"all\" /><br />\nThe vast majority of plugins work just fine with <a href=\"http://ocaoimh.ie/wp-super-cache/\">WP Super Cache</a>, but some of the ones that don&#8217;t are quite popular. If your favourite plugin doesn&#8217;t work, why don&#8217;t <em>you</em> help the author out and fix it? You have all the source code after all and you&#8217;ll be helping everyone else who uses the plugin!</p>\n<p><img src=\"http://ocaoimh.ie/?voyeur=1\" /></p><p><strong>Related Posts</strong><ul><li><a href=\"http://ocaoimh.ie/2008/10/24/wp-super-cache-084-the-garbage-collector/\" rel=\"bookmark\" title=\"Permanent Link: WP Super Cache 0.8.4, the garbage collector\">WP Super Cache 0.8.4, the garbage collector</a></li><li><a href=\"http://ocaoimh.ie/2009/01/09/wp-super-cache-087/\" rel=\"bookmark\" title=\"Permanent Link: WP Super Cache 0.8.7\">WP Super Cache 0.8.7</a></li><li><a href=\"http://ocaoimh.ie/2007/11/05/wordpress-super-cache-01/\" rel=\"bookmark\" title=\"Permanent Link: WordPress Super Cache 0.1\">WordPress Super Cache 0.1</a></li></ul></p>\";s:7:\"pubdate\";s:31:\"Tue, 10 Mar 2009 14:00:11 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:7:\"Donncha\";}s:7:\"summary\";s:3953:\"<p><a href=\"http://ocaoimh.ie/?attachment_id=3664\" rel=\"attachment wp-att-3664\"><img align=\"right\" src=\"http://inphotos.org/wp-content/uploads/2009/03/daffodil-snow-and-water-droplets-150x150.jpg\" alt=\"Daffodil, snow and water droplets\" title=\"Daffodil, snow and water droplets\" width=\"150\" height=\"150\" class=\"alignright size-thumbnail wp-image-3664\" /></a> Thaya Kareeson has written an <a href=\"http://omninoggin.com/wordpress-posts/make-any-plugin-work-with-wp-super-cache/\">excellent article</a> for plugin developers. It goes through how to make plugins work with WP Super Cache by using dynamic AJAX calls.</p>\n<p><a href=\"http://ocaoimh.ie/wp-super-cache/\">WP Super Cache</a> can make static html copies of pages served by WordPress which is great for performance. Unfortunately that means some plugins don&#8217;t work because they rely on executing PHP on each request. The plugins need to be rewritten to use AJAX calls by the visitor&#8217;s browser. There&#8217;s a FAQ in the readme.txt all about it!</p>\n<p>I previously wrote about <a href=\"http://ocaoimh.ie/2008/11/01/make-your-wordpress-plugin-talk-ajax/\">adding AJAX to WordPress plugins</a> but Thaya has worked through a simple example that will work perfectly with WP Super Cache. It&#8217;s a good foundation for plugin developers start from. </p>\n<p>He also has versions of <a href=\"http://omninoggin.com/wordpress-posts/make-wp-postviews-work-with-wp-super-cache/\">WP Postviews</a> and <a href=\"http://omninoggin.com/wordpress-posts/make-popularity-contest-work-with-wp-super-cache/\">Popularity Contest</a> that have been rewritten to support static caching. I haven&#8217;t tried either plugin so leave a comment on his blog if you need help!</p>\n<p>If you depend on a large portion of your content being dynamic this isn&#8217;t the solution for you as it will affect what search engines see. Those bots don&#8217;t speak Javascript, but for interactive purposes (ratings, stats etc) it&#8217;s the job.</p>\n<p><a href=\"http://ocaoimh.ie/?attachment_id=3657\" rel=\"attachment wp-att-3657\"><img align=\"right\" src=\"http://inphotos.org/wp-content/uploads/2009/03/reading-glasses-150x150.jpg\" alt=\"reading glasses\" title=\"reading glasses\" width=\"150\" height=\"150\" class=\"alignright size-thumbnail wp-image-3657\" /></a>  Further reading:\n<ul>\n<li><a href=\"http://codex.wordpress.org/AJAX_in_Plugins\">AJAX in Plugins</a> is a must-read starting point for developers.</li>\n<li><a href=\"http://codex.wordpress.org/Function_Reference/wp_enqueue_script\">wp_enqueue_script()</a> is the command WordPress uses to load Javascript files. That page links to a couple of good pages too including this <a href=\"http://www.prelovac.com/vladimir/best-practice-for-adding-javascript-code-to-wordpress-plugin\">best practices</a> post. As of this writing, Thaya&#8217;s example don&#8217;t use wp_enqueue_script() but it&#8217;s simple to use.</li>\n</ul>\n<p><br clear=\"all\" /><br />\nThe vast majority of plugins work just fine with <a href=\"http://ocaoimh.ie/wp-super-cache/\">WP Super Cache</a>, but some of the ones that don&#8217;t are quite popular. If your favourite plugin doesn&#8217;t work, why don&#8217;t <em>you</em> help the author out and fix it? You have all the source code after all and you&#8217;ll be helping everyone else who uses the plugin!</p>\n<p><img src=\"http://ocaoimh.ie/?voyeur=1\" /></p><p><strong>Related Posts</strong><ul><li><a href=\"http://ocaoimh.ie/2008/10/24/wp-super-cache-084-the-garbage-collector/\" rel=\"bookmark\" title=\"Permanent Link: WP Super Cache 0.8.4, the garbage collector\">WP Super Cache 0.8.4, the garbage collector</a></li><li><a href=\"http://ocaoimh.ie/2009/01/09/wp-super-cache-087/\" rel=\"bookmark\" title=\"Permanent Link: WP Super Cache 0.8.7\">WP Super Cache 0.8.7</a></li><li><a href=\"http://ocaoimh.ie/2007/11/05/wordpress-super-cache-01/\" rel=\"bookmark\" title=\"Permanent Link: WordPress Super Cache 0.1\">WordPress Super Cache 0.1</a></li></ul></p>\";}i:30;a:7:{s:5:\"title\";s:61:\"Weblog Tools Collection: Plugin Review: Feed Reading Blogroll\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5270\";s:4:\"link\";s:89:\"http://weblogtoolscollection.com/archives/2009/03/08/plugin-review-feed-reading-blogroll/\";s:11:\"description\";s:3397:\"<p>Do you display a list of links a.k.a. blogroll in your sidebar? If you do, then <a href=\"http://www.weinschenker.name/plugin-feed-reading-blogroll/\">Feed Reading Blogroll</a> is one must have plugin on your WordPress blog.</p>\n<h3>Description</h3>\n<p>This plugin provides a sidebar-widget and a template-tag that add an enhanced blogroll to your sidebar. It checks on all your linked sites, when the most recent update has occurred.</p>\n<p>The check is performed by reading the date of the most recent feed-item. The feeds must be valid RSS2 or ATOM-feeds, otherwise the plugin cannot read the date-information provided by the feed. The Plugin uses the <a href=\"http://code.google.com/apis/ajaxfeeds/\">Google AJAX Feed API</a> to access the feeds.</p>\n<h3>Demo</h3>\n<p><img title=\"Feed Reading Blogroll\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/frb.gif\" border=\"0\" alt=\"Feed Reading Blogroll\" width=\"247\" height=\"282\" /></p>\n<p>Check out the sidebar of the <a href=\"http://www.weinschenker.name/\">author&#8217;s site</a>.</p>\n<h3>Review</h3>\n<p>For starters, what I love about the plugin is that the author has made an excellent effort to create a complete <a href=\"http://www.weinschenker.name/plugin-feed-reading-blogroll/\">plugin page on his site</a>. The page contains detailed information about the plugin, including instructions on installation, usage and customization.</p>\n<p>Installing Feed Reading Blogroll is just as you would any other plugin. However, you would require to get hold of <a href=\"http://code.google.com/apis/ajaxfeeds/signup.html\">Google API Key</a>.</p>\n<p>You&#8217;ll need to navigate to the Settings page of the plugin and start configuring all the options, mainly entering the Google API key. There are tonnes of other configuration options available as well like option to group by category, or to sort by last updated, choose which style to use for the blogroll etc.</p>\n<p>Adding links is through WordPress&#8217; inbuilt Links Manager, so you don&#8217;t need to worry in case you choose to install the plugin after this review.</p>\n<p>You can specify the feed URL that each link uses, which is recommended. If you&#8217;re just lazy, the plugin will try to fetch the correct URL using Google&#8217;s Feed Fetcher (that&#8217;s why you need the API key) and then use this URL.</p>\n<p>Once you&#8217;ve got everything setup, you&#8217;ll want to display the blogroll on your site. For that you can either use the sidebar widget or the template tag. What I&#8217;d like to see is some shortcode that I can use to insert the same on a separate page that will house my blogroll, since I don&#8217;t display the same in my sidebar.</p>\n<p>The plugin comes with internationalization support and is currently available in five languages. If you&#8217;re a translator and are willing to translate the plugin, do let the author know. I&#8217;m sure he would like that.</p>\n<p>A slight warning on using this plugin. It relies heavily on external sites especially for feed fetching and discovering the latest updated time of the feed. As a result, you may encounter some performance issues. I recommend turning off the JavaScript sorting feature and using a caching plugin if you face major problems.</p>\n<p>Are you an existing user of Feed Reading Blogroll? If so, do let us know your experience with the plugin. What are your suggestions for the same?</p>\";s:7:\"pubdate\";s:31:\"Sun, 08 Mar 2009 18:11:00 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:3397:\"<p>Do you display a list of links a.k.a. blogroll in your sidebar? If you do, then <a href=\"http://www.weinschenker.name/plugin-feed-reading-blogroll/\">Feed Reading Blogroll</a> is one must have plugin on your WordPress blog.</p>\n<h3>Description</h3>\n<p>This plugin provides a sidebar-widget and a template-tag that add an enhanced blogroll to your sidebar. It checks on all your linked sites, when the most recent update has occurred.</p>\n<p>The check is performed by reading the date of the most recent feed-item. The feeds must be valid RSS2 or ATOM-feeds, otherwise the plugin cannot read the date-information provided by the feed. The Plugin uses the <a href=\"http://code.google.com/apis/ajaxfeeds/\">Google AJAX Feed API</a> to access the feeds.</p>\n<h3>Demo</h3>\n<p><img title=\"Feed Reading Blogroll\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/frb.gif\" border=\"0\" alt=\"Feed Reading Blogroll\" width=\"247\" height=\"282\" /></p>\n<p>Check out the sidebar of the <a href=\"http://www.weinschenker.name/\">author&#8217;s site</a>.</p>\n<h3>Review</h3>\n<p>For starters, what I love about the plugin is that the author has made an excellent effort to create a complete <a href=\"http://www.weinschenker.name/plugin-feed-reading-blogroll/\">plugin page on his site</a>. The page contains detailed information about the plugin, including instructions on installation, usage and customization.</p>\n<p>Installing Feed Reading Blogroll is just as you would any other plugin. However, you would require to get hold of <a href=\"http://code.google.com/apis/ajaxfeeds/signup.html\">Google API Key</a>.</p>\n<p>You&#8217;ll need to navigate to the Settings page of the plugin and start configuring all the options, mainly entering the Google API key. There are tonnes of other configuration options available as well like option to group by category, or to sort by last updated, choose which style to use for the blogroll etc.</p>\n<p>Adding links is through WordPress&#8217; inbuilt Links Manager, so you don&#8217;t need to worry in case you choose to install the plugin after this review.</p>\n<p>You can specify the feed URL that each link uses, which is recommended. If you&#8217;re just lazy, the plugin will try to fetch the correct URL using Google&#8217;s Feed Fetcher (that&#8217;s why you need the API key) and then use this URL.</p>\n<p>Once you&#8217;ve got everything setup, you&#8217;ll want to display the blogroll on your site. For that you can either use the sidebar widget or the template tag. What I&#8217;d like to see is some shortcode that I can use to insert the same on a separate page that will house my blogroll, since I don&#8217;t display the same in my sidebar.</p>\n<p>The plugin comes with internationalization support and is currently available in five languages. If you&#8217;re a translator and are willing to translate the plugin, do let the author know. I&#8217;m sure he would like that.</p>\n<p>A slight warning on using this plugin. It relies heavily on external sites especially for feed fetching and discovering the latest updated time of the feed. As a result, you may encounter some performance issues. I recommend turning off the JavaScript sorting feature and using a caching plugin if you face major problems.</p>\n<p>Are you an existing user of Feed Reading Blogroll? If so, do let us know your experience with the plugin. What are your suggestions for the same?</p>\";}i:31;a:7:{s:5:\"title\";s:64:\"Lorelle on WP: Firewalling and Hack Proofing Your WordPress Blog\";s:4:\"guid\";s:36:\"http://lorelle.wordpress.com/?p=3968\";s:4:\"link\";s:90:\"http://lorelle.wordpress.com/2009/03/07/firewalling-and-hack-proofing-your-wordpress-blog/\";s:11:\"description\";s:10122:\"<div class=\"snap_preview\"><br /><p><a href=\"http://lorelle.wordpress.com/tag/wordpress-tips/\" title=\"WordPress Tips\"><img src=\"http://lorelle.files.wordpress.com/2006/11/wordpresstips.gif\" alt=\"\" align=\"right\" /></a><a href=\"http://blogsecurity.net/\" title=\"Blog Security\" rel=\"tag\">Blog Security</a> is one of the top security blogs out there keeping an eye on all things blog security and WordPress. They&#8217;ve just released two great articles WordPress fans need to check out.</p>\n<p>First is <a href=\"http://blogsecurity.net/wordpress/guvnr-10-steps-to-secure-wordpress-video\" title=\"Guvnr 10 Steps to Secure WordPress Video\">news</a> of a video and blog post by <a href=\"http://guvnr.com/web/blogging/10-tips-to-make-wordpress-hack-proof/\" title=\"Guvnr - Make WordPress Hack Proof Video\">Guvnr called &#8220;10 Tips to Make WordPress Hack Proof</a>. The effort involved tips from BlogSecurity&#8217;s popular <a href=\"http://blogsecurity.net/wordpress/wordpress-security-whitepaper/\" title=\"WordPress Security Whitepaper\">WordPress Security Whitepaper</a>, inspiring them to update and improve it soon.</p>\n<p>The second is &#8220;<a href=\"http://blogsecurity.net/wordpress/how-to-firewall-your-wordpress-blog\" title=\"How to Firewall Your WordPress Blog\">How to Firewall Your WordPress Blog</a>&#8221; by <a href=\"http://www.seoegghead.com/blog/\" title=\"Jaimie Sirovich\">Jaimie Sirovich of SEO Egghead</a> guest blogging on BlogSecurity. He covers options to help you make your WordPress blog more secure with a variety of WordPress Plugins.</p>\n<p>Don&#8217;t forget that the best line of defense protection for your WordPress blog begins with a <a href=\"http://www.blogherald.com/2007/05/08/protect-your-blog-with-a-solid-password/\" title=\"Protect Your Blog With a Solid Password\">strong password</a>, followed by regularly upgrading your WordPress blog, especially after mandatory security alerts. </p>\n<p>There is a lot of misinformation on the web about blog and WordPress Security. Many will tell you that CAPTCHAs and their paid services will protect you and your WordPress blog. They will give you a lot of out-dated steps to take. Don&#8217;t be fooled. Get your information from the official and reputable WordPress resources. WordPress is inherently secure. It should be. It is used by <a href=\"http://markjaquith.wordpress.com/2008/08/18/us-government-agencies-using-wordpress/\" title=\"U.S. Government Agencies Using WordPress\">some of the top government agencies in the United States</a> and around the world.  </p>\n<p>The current version of WordPress is very secure with no critical security vulnerabilities reported since its release. There are, however, some security issues with WordPress Plugins so make sure you check in with your favorite WordPress Plugin authors and your Plugins Panel for updates on a regular basis. </p>\n<p>Here are some reliable articles on blog and WordPress security:</p>\n<ul>\n<li><a href=\"http://www.blogherald.com/2007/05/08/protect-your-blog-with-a-solid-password/\" title=\"Protect Your Blog With a Solid Password\">Lorelle on The Blog Herald - Protect Your Blog With a Solid Password</a></li>\n<li><a href=\"http://www.smashingmagazine.com/2009/01/26/10-steps-to-protect-the-admin-area-in-wordpress/\" title=\"10 Steps To Protect The Admin Area In WordPress\">Smashing Magazine - 10 Steps To Protect The Admin Area In WordPress</a></li>\n<li><a href=\"http://www.prelovac.com/vladimir/improving-security-in-wordpress-plugins-using-nonces\" title=\"Improving security in WordPress Plugins using Nonces\">Vladimir Prelovac - Improving security in WordPress Plugins using Nonces</a></li>\n<li><a href=\"http://www.mattcutts.com/blog/hacked-site-alerts/\" title=\"Alerting webmasters to webserver vulnerabilities\">Matt Cutts - Alerting Webmasters to Webserver Vulnerabilities</a></li>\n<li><a href=\"http://wordpress.tv/2008/10/04/wordcamp-toronto-2008-wordpress-security-with-mark-jaquith/\" title=\"WordCamp Toronto 2008 - WordPress Security with Mark Jaquith\">WordCamp Toronto 2008 - WordPress Security with Mark Jaquith</a></li>\n<li><a href=\"http://weblogtoolscollection.com/archives/2009/01/03/maximum-wordpress-security/\" title=\"Maximum WordPress Security\">Weblog Tools Collection - Maximum WordPress Security</a></li>\n<li><a href=\"http://weblogtoolscollection.com/archives/2008/11/06/fake-wordpress-site/\" title=\"Fake WordPress Site\">Weblog Tools Collection - Fake WordPress Site</a></li>\n<li><a href=\"http://technorati.com/weblog/2008/04/424.html\" title=\"Vulnerable WordPress Blogs Not Being Indexed\">Technorati - Vulnerable WordPress Blogs Not Being Indexed</a></li>\n<li><a href=\"http://markjaquith.wordpress.com/2008/08/18/us-government-agencies-using-wordpress/\" title=\"U.S. Government Agencies Using WordPress\">Mark Jaquith - US Government Agencies Using WordPress</a></li>\n<li><a href=\"http://lorelle.wordpress.com/2008/04/28/wordpress-security-prevention-reactions-and-scares/\" title=\"WordPress Security Prevention, Reactions, and Scares « Lorelle on ...\">Lorelle on WordPress - WordPress Security Prevention, Reactions, and Scares</a></li>\n<li><a href=\"http://feeds.feedburner.com/~r/BlogSecurity/~3/512792429/\" title=\"WordPress Security Predictions in 2009\">Blog Security - WordPress Security Predictions in 2009</a></li>\n<li><a href=\"http://arachna.com/roller/spidaman/entry/fear_uncertainty_and_disinformation_about\" title=\"Fear, Uncertainty and Disinformation About The WordPress Exploits and Spam\">Arachna - Fear, Uncertainty and Disinformation About The WordPress Exploits and Spam</a></li>\n<li><a href=\"http://www.blogherald.com/2008/09/08/wtf-blog-clutter-the-death-of-the-captcha/\" title=\"WTF Blog Clutter: The Death of the CAPTCHA | The Blog Herald\">Lorelle on The Blog Herald - WTF Blog Clutter: The Death of the CAPTCHA</a></li>\n<li><a href=\"http://www.dailyblogtips.com/make-sure-your-wordpress-is-not-hacked/\" title=\"Make Sure Your WordPress is Not Hacked\">Daily Blog Tips - Make Sure Your WordPress is Not Hacked</a></li>\n<li><a href=\"http://feeds.feedburner.com/~r/HolyShmoly/~3/259733785/\" title=\"There’s never been a better time to upgrade WordPress\">Donncha - There’s Never Been A Better Time To Upgrade WordPress</a></li>\n<li><a href=\"http://feeds.feedburner.com/~r/BlogSecurity/~3/253542937/\" title=\"Interview with Hacker S@BUN\">Blog Security - Interview of a WordPress Hacker</a></li>\n<li><a href=\"http://www.noupe.com/how-tos/wordpress-security-tips-and-hacks.html\" title=\"WordPress Security Tips and Hacks\">Noupe - WordPress Security Tips and Hacks</a></li>\n</ul>\n<p><img src=\"http://lorelle.files.wordpress.com/2006/08/sig.gif\" alt=\"\" /><br />\n<hr />\n<p><font size=\"-1\"><b>Site Search Tags:</b> <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+news\" rel=\"tag\">wordpress news</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+security\" rel=\"tag\">wordpress security</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+vulnerabilities\" rel=\"tag\">wordpress vulnerabilities</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=security+vulnerabilities\" rel=\"tag\">security vulnerabilities</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+risk\" rel=\"tag\">wordpress risk</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=is+wordpress+safe\" rel=\"tag\">is wordpress safe</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+tips\" rel=\"tag\">wordpress tips</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=security\" rel=\"tag\">security</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=safety\" rel=\"tag\">safety</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=blog+security\" rel=\"tag\">blog security</a> </p>\n<p><a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/02/rss.png\" alt=\"Feed on Lorelle on WordPress\" /></a> <a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\">Subscribe</a>  <a href=\"http://feeds.feedburner.com/LorelleOnWordPress\" title=\"Feedburner Lorelle on WordPress Feed\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/04/feedburnericon.gif\" alt=\"Feedburner icon\" />Via Feedburner</a>  <a href=\"http://www.feedblitz.com/f/?Sub=182399\" title=\"Lorelle on WordPress - full site feed email subscription\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/03/email.gif\" alt=\"\" />Subscribe by Email</a> <a href=\"http://lorelle.wordpress.com/\" title=\"Visit Lorelle on WordPress\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2008/03/pointer.gif\" alt=\"\" />Visit</a><br /><a href=\"http://lorelle.wordpress.com/about/\" title=\"Copyright Protected by Brent and Lorelle VanFossen\">Copyright Lorelle VanFossen</a>, the author of <a href=\"http://lorelle.wordpress.com/books/blogging-tips/\" title=\"Blogging Tips Book By Lorelle VanFossen\"><em>Blogging Tips, What Bloggers Won\'t Tell You About Blogging</em></a>.</font></p>\nPosted in WordPress News, WordPress Tips  <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/lorelle.wordpress.com/3968/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/lorelle.wordpress.com/3968/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/lorelle.wordpress.com/3968/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/lorelle.wordpress.com/3968/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/lorelle.wordpress.com/3968/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/lorelle.wordpress.com/3968/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/lorelle.wordpress.com/3968/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/lorelle.wordpress.com/3968/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/lorelle.wordpress.com/3968/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/lorelle.wordpress.com/3968/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=lorelle.wordpress.com&blog=72&post=3968&subd=lorelle&ref=&feed=1\" /></div>\";s:7:\"pubdate\";s:31:\"Sun, 08 Mar 2009 07:15:12 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:17:\"Lorelle VanFossen\";}s:7:\"summary\";s:10122:\"<div class=\"snap_preview\"><br /><p><a href=\"http://lorelle.wordpress.com/tag/wordpress-tips/\" title=\"WordPress Tips\"><img src=\"http://lorelle.files.wordpress.com/2006/11/wordpresstips.gif\" alt=\"\" align=\"right\" /></a><a href=\"http://blogsecurity.net/\" title=\"Blog Security\" rel=\"tag\">Blog Security</a> is one of the top security blogs out there keeping an eye on all things blog security and WordPress. They&#8217;ve just released two great articles WordPress fans need to check out.</p>\n<p>First is <a href=\"http://blogsecurity.net/wordpress/guvnr-10-steps-to-secure-wordpress-video\" title=\"Guvnr 10 Steps to Secure WordPress Video\">news</a> of a video and blog post by <a href=\"http://guvnr.com/web/blogging/10-tips-to-make-wordpress-hack-proof/\" title=\"Guvnr - Make WordPress Hack Proof Video\">Guvnr called &#8220;10 Tips to Make WordPress Hack Proof</a>. The effort involved tips from BlogSecurity&#8217;s popular <a href=\"http://blogsecurity.net/wordpress/wordpress-security-whitepaper/\" title=\"WordPress Security Whitepaper\">WordPress Security Whitepaper</a>, inspiring them to update and improve it soon.</p>\n<p>The second is &#8220;<a href=\"http://blogsecurity.net/wordpress/how-to-firewall-your-wordpress-blog\" title=\"How to Firewall Your WordPress Blog\">How to Firewall Your WordPress Blog</a>&#8221; by <a href=\"http://www.seoegghead.com/blog/\" title=\"Jaimie Sirovich\">Jaimie Sirovich of SEO Egghead</a> guest blogging on BlogSecurity. He covers options to help you make your WordPress blog more secure with a variety of WordPress Plugins.</p>\n<p>Don&#8217;t forget that the best line of defense protection for your WordPress blog begins with a <a href=\"http://www.blogherald.com/2007/05/08/protect-your-blog-with-a-solid-password/\" title=\"Protect Your Blog With a Solid Password\">strong password</a>, followed by regularly upgrading your WordPress blog, especially after mandatory security alerts. </p>\n<p>There is a lot of misinformation on the web about blog and WordPress Security. Many will tell you that CAPTCHAs and their paid services will protect you and your WordPress blog. They will give you a lot of out-dated steps to take. Don&#8217;t be fooled. Get your information from the official and reputable WordPress resources. WordPress is inherently secure. It should be. It is used by <a href=\"http://markjaquith.wordpress.com/2008/08/18/us-government-agencies-using-wordpress/\" title=\"U.S. Government Agencies Using WordPress\">some of the top government agencies in the United States</a> and around the world.  </p>\n<p>The current version of WordPress is very secure with no critical security vulnerabilities reported since its release. There are, however, some security issues with WordPress Plugins so make sure you check in with your favorite WordPress Plugin authors and your Plugins Panel for updates on a regular basis. </p>\n<p>Here are some reliable articles on blog and WordPress security:</p>\n<ul>\n<li><a href=\"http://www.blogherald.com/2007/05/08/protect-your-blog-with-a-solid-password/\" title=\"Protect Your Blog With a Solid Password\">Lorelle on The Blog Herald - Protect Your Blog With a Solid Password</a></li>\n<li><a href=\"http://www.smashingmagazine.com/2009/01/26/10-steps-to-protect-the-admin-area-in-wordpress/\" title=\"10 Steps To Protect The Admin Area In WordPress\">Smashing Magazine - 10 Steps To Protect The Admin Area In WordPress</a></li>\n<li><a href=\"http://www.prelovac.com/vladimir/improving-security-in-wordpress-plugins-using-nonces\" title=\"Improving security in WordPress Plugins using Nonces\">Vladimir Prelovac - Improving security in WordPress Plugins using Nonces</a></li>\n<li><a href=\"http://www.mattcutts.com/blog/hacked-site-alerts/\" title=\"Alerting webmasters to webserver vulnerabilities\">Matt Cutts - Alerting Webmasters to Webserver Vulnerabilities</a></li>\n<li><a href=\"http://wordpress.tv/2008/10/04/wordcamp-toronto-2008-wordpress-security-with-mark-jaquith/\" title=\"WordCamp Toronto 2008 - WordPress Security with Mark Jaquith\">WordCamp Toronto 2008 - WordPress Security with Mark Jaquith</a></li>\n<li><a href=\"http://weblogtoolscollection.com/archives/2009/01/03/maximum-wordpress-security/\" title=\"Maximum WordPress Security\">Weblog Tools Collection - Maximum WordPress Security</a></li>\n<li><a href=\"http://weblogtoolscollection.com/archives/2008/11/06/fake-wordpress-site/\" title=\"Fake WordPress Site\">Weblog Tools Collection - Fake WordPress Site</a></li>\n<li><a href=\"http://technorati.com/weblog/2008/04/424.html\" title=\"Vulnerable WordPress Blogs Not Being Indexed\">Technorati - Vulnerable WordPress Blogs Not Being Indexed</a></li>\n<li><a href=\"http://markjaquith.wordpress.com/2008/08/18/us-government-agencies-using-wordpress/\" title=\"U.S. Government Agencies Using WordPress\">Mark Jaquith - US Government Agencies Using WordPress</a></li>\n<li><a href=\"http://lorelle.wordpress.com/2008/04/28/wordpress-security-prevention-reactions-and-scares/\" title=\"WordPress Security Prevention, Reactions, and Scares « Lorelle on ...\">Lorelle on WordPress - WordPress Security Prevention, Reactions, and Scares</a></li>\n<li><a href=\"http://feeds.feedburner.com/~r/BlogSecurity/~3/512792429/\" title=\"WordPress Security Predictions in 2009\">Blog Security - WordPress Security Predictions in 2009</a></li>\n<li><a href=\"http://arachna.com/roller/spidaman/entry/fear_uncertainty_and_disinformation_about\" title=\"Fear, Uncertainty and Disinformation About The WordPress Exploits and Spam\">Arachna - Fear, Uncertainty and Disinformation About The WordPress Exploits and Spam</a></li>\n<li><a href=\"http://www.blogherald.com/2008/09/08/wtf-blog-clutter-the-death-of-the-captcha/\" title=\"WTF Blog Clutter: The Death of the CAPTCHA | The Blog Herald\">Lorelle on The Blog Herald - WTF Blog Clutter: The Death of the CAPTCHA</a></li>\n<li><a href=\"http://www.dailyblogtips.com/make-sure-your-wordpress-is-not-hacked/\" title=\"Make Sure Your WordPress is Not Hacked\">Daily Blog Tips - Make Sure Your WordPress is Not Hacked</a></li>\n<li><a href=\"http://feeds.feedburner.com/~r/HolyShmoly/~3/259733785/\" title=\"There’s never been a better time to upgrade WordPress\">Donncha - There’s Never Been A Better Time To Upgrade WordPress</a></li>\n<li><a href=\"http://feeds.feedburner.com/~r/BlogSecurity/~3/253542937/\" title=\"Interview with Hacker S@BUN\">Blog Security - Interview of a WordPress Hacker</a></li>\n<li><a href=\"http://www.noupe.com/how-tos/wordpress-security-tips-and-hacks.html\" title=\"WordPress Security Tips and Hacks\">Noupe - WordPress Security Tips and Hacks</a></li>\n</ul>\n<p><img src=\"http://lorelle.files.wordpress.com/2006/08/sig.gif\" alt=\"\" /><br />\n<hr />\n<p><font size=\"-1\"><b>Site Search Tags:</b> <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+news\" rel=\"tag\">wordpress news</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+security\" rel=\"tag\">wordpress security</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+vulnerabilities\" rel=\"tag\">wordpress vulnerabilities</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=security+vulnerabilities\" rel=\"tag\">security vulnerabilities</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+risk\" rel=\"tag\">wordpress risk</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=is+wordpress+safe\" rel=\"tag\">is wordpress safe</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=wordpress+tips\" rel=\"tag\">wordpress tips</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=security\" rel=\"tag\">security</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=safety\" rel=\"tag\">safety</a>, <a href=\"http://lorelle.wordpress.com/index.php?s=blog+security\" rel=\"tag\">blog security</a> </p>\n<p><a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/02/rss.png\" alt=\"Feed on Lorelle on WordPress\" /></a> <a href=\"http://lorelle.wordpress.com/feed/\" title=\"Feed on Lorelle on WordPress\">Subscribe</a>  <a href=\"http://feeds.feedburner.com/LorelleOnWordPress\" title=\"Feedburner Lorelle on WordPress Feed\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/04/feedburnericon.gif\" alt=\"Feedburner icon\" />Via Feedburner</a>  <a href=\"http://www.feedblitz.com/f/?Sub=182399\" title=\"Lorelle on WordPress - full site feed email subscription\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2007/03/email.gif\" alt=\"\" />Subscribe by Email</a> <a href=\"http://lorelle.wordpress.com/\" title=\"Visit Lorelle on WordPress\"><img class=\"wp-smiley\" src=\"http://lorelle.files.wordpress.com/2008/03/pointer.gif\" alt=\"\" />Visit</a><br /><a href=\"http://lorelle.wordpress.com/about/\" title=\"Copyright Protected by Brent and Lorelle VanFossen\">Copyright Lorelle VanFossen</a>, the author of <a href=\"http://lorelle.wordpress.com/books/blogging-tips/\" title=\"Blogging Tips Book By Lorelle VanFossen\"><em>Blogging Tips, What Bloggers Won\'t Tell You About Blogging</em></a>.</font></p>\nPosted in WordPress News, WordPress Tips  <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/lorelle.wordpress.com/3968/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/lorelle.wordpress.com/3968/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/lorelle.wordpress.com/3968/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/lorelle.wordpress.com/3968/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/lorelle.wordpress.com/3968/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/lorelle.wordpress.com/3968/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/lorelle.wordpress.com/3968/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/lorelle.wordpress.com/3968/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/lorelle.wordpress.com/3968/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/lorelle.wordpress.com/3968/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=lorelle.wordpress.com&blog=72&post=3968&subd=lorelle&ref=&feed=1\" /></div>\";}i:32;a:7:{s:5:\"title\";s:59:\"Weblog Tools Collection: WordPress Theme Releases for 03/07\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5267\";s:4:\"link\";s:87:\"http://weblogtoolscollection.com/archives/2009/03/07/wordpress-theme-releases-for-0307/\";s:11:\"description\";s:1996:\"<p><a href=\"http://wp-content-themes.com/orangejuice-a-free-fluid-wordpress-27-theme/109\">OrangeJuice</a></p>\n<p><a href=\"http://www.gavagai.ro/blues/\"><img title=\"OrangeJuice\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/orangejuice.jpg\" alt=\"OrangeJuice\" width=\"138\" height=\"150\" /></a></p>\n<p>OrangeJuice is a two-columns free theme, specially designed for WordPress 2.7, with a liquid layout (based on a grid using percents) and some CSS3 and typographic accents. It has a light color scheme, combining orange and tones of grey. Features include valid strict XHTML, styled sticky posts, threaded comments, widgetized sidebar.</p>\n<p><a href=\"http://wpcult.com/working-on-a-new-theme-called-wordcult/\">WordCult</a></p>\n<p><img title=\"WordCult\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/wordcult.jpg\" alt=\"WordCult\" width=\"150\" height=\"125\" /></p>\n<p>Two column theme with a big footer and jQuery “featured posts” loader and the option for sticky posts.</p>\n<p><a href=\"http://www.altamentedecorativo.com/en/smoking-blue-child-theme-per-thematic/\">Smoking Blue</a></p>\n<p><img title=\"Smoking-Blue\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/smokingblue.jpg\" alt=\"Smoking-Blue\" width=\"150\" height=\"117\" /></p>\n<p>Three column, blue child theme built on <a href=\"http://themeshaper.com/thematic-for-wordpress/\">Thematic Framework per WordPress</a> 0.9.</p>\n<p><a href=\"http://www.armandbook.com/theme/curious-orange-wordpress-theme-v100/\">Curious Orange</a></p>\n<p><a href=\"http://www.armandbook.com/themes/?wptheme=Curious%20Orange%20Theme\"><img title=\"Curious Orange\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/curiousorange.png\" alt=\"Curious Orange\" width=\"150\" height=\"140\" /></a></p>\n<p>A simple black, orange, and white colors widgetized free Wordpress theme with 3 columns and avatar enabled.</p>\n<p>Are you a theme author? <a href=\"http://weblogtoolscollection.com/submit-news\">Submit your theme</a> for inclusion in our daily release posts.</p>\";s:7:\"pubdate\";s:31:\"Sat, 07 Mar 2009 18:44:15 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:1996:\"<p><a href=\"http://wp-content-themes.com/orangejuice-a-free-fluid-wordpress-27-theme/109\">OrangeJuice</a></p>\n<p><a href=\"http://www.gavagai.ro/blues/\"><img title=\"OrangeJuice\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/orangejuice.jpg\" alt=\"OrangeJuice\" width=\"138\" height=\"150\" /></a></p>\n<p>OrangeJuice is a two-columns free theme, specially designed for WordPress 2.7, with a liquid layout (based on a grid using percents) and some CSS3 and typographic accents. It has a light color scheme, combining orange and tones of grey. Features include valid strict XHTML, styled sticky posts, threaded comments, widgetized sidebar.</p>\n<p><a href=\"http://wpcult.com/working-on-a-new-theme-called-wordcult/\">WordCult</a></p>\n<p><img title=\"WordCult\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/wordcult.jpg\" alt=\"WordCult\" width=\"150\" height=\"125\" /></p>\n<p>Two column theme with a big footer and jQuery “featured posts” loader and the option for sticky posts.</p>\n<p><a href=\"http://www.altamentedecorativo.com/en/smoking-blue-child-theme-per-thematic/\">Smoking Blue</a></p>\n<p><img title=\"Smoking-Blue\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/smokingblue.jpg\" alt=\"Smoking-Blue\" width=\"150\" height=\"117\" /></p>\n<p>Three column, blue child theme built on <a href=\"http://themeshaper.com/thematic-for-wordpress/\">Thematic Framework per WordPress</a> 0.9.</p>\n<p><a href=\"http://www.armandbook.com/theme/curious-orange-wordpress-theme-v100/\">Curious Orange</a></p>\n<p><a href=\"http://www.armandbook.com/themes/?wptheme=Curious%20Orange%20Theme\"><img title=\"Curious Orange\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/curiousorange.png\" alt=\"Curious Orange\" width=\"150\" height=\"140\" /></a></p>\n<p>A simple black, orange, and white colors widgetized free Wordpress theme with 3 columns and avatar enabled.</p>\n<p>Are you a theme author? <a href=\"http://weblogtoolscollection.com/submit-news\">Submit your theme</a> for inclusion in our daily release posts.</p>\";}i:33;a:7:{s:5:\"title\";s:73:\"Weblog Tools Collection: WPLookup - Find Functions and Template Tags Fast\";s:4:\"guid\";s:100:\"http://weblogtoolscollection.com/archives/2009/03/07/wplookup-find-functions-and-template-tags-fast/\";s:4:\"link\";s:100:\"http://weblogtoolscollection.com/archives/2009/03/07/wplookup-find-functions-and-template-tags-fast/\";s:11:\"description\";s:1238:\"<p>Are you constantly hunting the WordPress Codex for functions and template tags? I know I spend a lot of time doing this whenever I am working on a new plugin. <a href=\"http://theandystratton.com/\">Andy Stratton</a> too did the same until he created WPLookup.</p>\n<p><a href=\"http://wplookup.com/\">WPLookup</a> will take your query and take you to the corresponding <a href=\"http://codex.wordpress.org\">Wordpress Codex</a> documentation in the <a href=\"http://codex.wordpress.org/Function_Reference\">function reference</a> and <a href=\"http://codex.wordpress.org/Template_Tags\">template tags reference</a>. If your search terms are not found, it will send you directly to a documentation search for your terms. </p>\n<p>The site is very much in the nascent stages. And, I&#8217;m sure there is a lot more that can be added.</p>\n<p>One suggestion could be that instead of sending the user directly to WordPress Codex, WPLookup can generate a search results page with a link to the codex article as well a link to the function declaration in the WordPress code using PHPXref.</p>\n<p>The search results page can contain other related tags and links to their specific pages as well.</p>\n<p>Any other features you would like to see added?</p>\";s:7:\"pubdate\";s:31:\"Sat, 07 Mar 2009 04:35:25 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:1238:\"<p>Are you constantly hunting the WordPress Codex for functions and template tags? I know I spend a lot of time doing this whenever I am working on a new plugin. <a href=\"http://theandystratton.com/\">Andy Stratton</a> too did the same until he created WPLookup.</p>\n<p><a href=\"http://wplookup.com/\">WPLookup</a> will take your query and take you to the corresponding <a href=\"http://codex.wordpress.org\">Wordpress Codex</a> documentation in the <a href=\"http://codex.wordpress.org/Function_Reference\">function reference</a> and <a href=\"http://codex.wordpress.org/Template_Tags\">template tags reference</a>. If your search terms are not found, it will send you directly to a documentation search for your terms. </p>\n<p>The site is very much in the nascent stages. And, I&#8217;m sure there is a lot more that can be added.</p>\n<p>One suggestion could be that instead of sending the user directly to WordPress Codex, WPLookup can generate a search results page with a link to the codex article as well a link to the function declaration in the WordPress code using PHPXref.</p>\n<p>The search results page can contain other related tags and links to their specific pages as well.</p>\n<p>Any other features you would like to see added?</p>\";}i:34;a:7:{s:5:\"title\";s:37:\"Alex King: Carrington Blog 2.0 beta 1\";s:4:\"guid\";s:61:\"http://alexking.org/blog/2009/03/06/carrington-blog-20-beta-1\";s:4:\"link\";s:61:\"http://alexking.org/blog/2009/03/06/carrington-blog-20-beta-1\";s:11:\"description\";s:717:\"<p>My team and I at <a href=\"http://crowdfavorite.com\">Crowd Favorite</a> have gotten a <a href=\"http://carringtontheme.com/2009/03/carrington-blog-20-beta-1/\">new version of our Carrington Blog theme</a> ready for testing. This has a bunch of new features, and we&#8217;ve tried to improve the <a href=\"http://crowdfavorite.com/wordpress/carrington/readme/\">documentation</a> as well.</p>\n<p>Full details are on the Carrington web site - looking forward to your feedback.</p>\n<p><a href=\"http://sharethis.com/item?&wp=2.2.3&amp;publisher=a1583af8-28eb-4210-97bd-2bb5c02bc265&amp;title=Carrington+Blog+2.0+beta+1&amp;url=http%3A%2F%2Falexking.org%2Fblog%2F2009%2F03%2F06%2Fcarrington-blog-20-beta-1\">ShareThis</a></p>\";s:7:\"pubdate\";s:31:\"Fri, 06 Mar 2009 20:43:25 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Alex\";}s:7:\"summary\";s:717:\"<p>My team and I at <a href=\"http://crowdfavorite.com\">Crowd Favorite</a> have gotten a <a href=\"http://carringtontheme.com/2009/03/carrington-blog-20-beta-1/\">new version of our Carrington Blog theme</a> ready for testing. This has a bunch of new features, and we&#8217;ve tried to improve the <a href=\"http://crowdfavorite.com/wordpress/carrington/readme/\">documentation</a> as well.</p>\n<p>Full details are on the Carrington web site - looking forward to your feedback.</p>\n<p><a href=\"http://sharethis.com/item?&wp=2.2.3&amp;publisher=a1583af8-28eb-4210-97bd-2bb5c02bc265&amp;title=Carrington+Blog+2.0+beta+1&amp;url=http%3A%2F%2Falexking.org%2Fblog%2F2009%2F03%2F06%2Fcarrington-blog-20-beta-1\">ShareThis</a></p>\";}i:35;a:7:{s:5:\"title\";s:60:\"Weblog Tools Collection: WordPress Plugin Releases for 03/06\";s:4:\"guid\";s:88:\"http://weblogtoolscollection.com/archives/2009/03/06/wordpress-plugin-releases-for-0306/\";s:4:\"link\";s:88:\"http://weblogtoolscollection.com/archives/2009/03/06/wordpress-plugin-releases-for-0306/\";s:11:\"description\";s:3262:\"<h3>New Plugins</h3>\n<p><a href=\"http://dentedreality.com.au/projects/wp-sparkplug/\">Sparkplug</a></p>\n<p>Sparkplug is a very simple plugin which provides you with an easy-to-read indication of how active the “current view” of a blog is. On the homepage, it provides a sparkline chart showing total posts per day for the (by default) last 30 days. On a tag, category or author-specific page, it shows bars representing how many posts were made with that tag/category or by that author per day, with a line showing the total posts per day for comparison.</p>\n<p><a href=\"http://www.paulmc.org/whatithink/wordpress/plugins/email-post-activation/\">Email Post Activation</a></p>\n<p>Adds an iFrame to your blog footer to automatically activate any posts written by email. </p>\n<p><a href=\"http://lud.icro.us/wordpress-plugin-info/\">Plugin Info</a></p>\n<p>This plugin provides a simple way of displaying up-to-date information about specific plugins hosted on the WordPress Plugin Directory in your blog posts and pages.</p>\n<p><a href=\"http://www.agarassino.com/wordpress-plugin-nofollow-filter/\">NoFollow Filter</a></p>\n<p>The plugin allows you to automatically add nofollow attribute to a list of links that you define on the admin.</p>\n<p><a href=\"http://lud.icro.us/wordpress-plugin-user-switching/\">User Switching</a></p>\n<p>Enables you to instantly swap between users in WordPress.</p>\n<p><a href=\"http://htmlblog.net/wp-to-top/\">WP to Top</a></p>\n<p>Adds a \"Back to top\" link in your blog without modifying your template files. This is useful especially if you have long posts or long pages. You will have a nice \"Back to top\" or whatever-text-you-want link floating at the bottom right/left of your page.</p>\n<h3>Updated Plugins</h3>\n<p><a href=\"http://www.weinschenker.name/plugin-feed-reading-blogroll/\">Feed Reading Blogroll</a></p>\n<p>This plugin provides a sidebar-widget and a template-tag that add an enhanced blogroll to your sidebar. It checks on all your linked sites, when the most recent update has occurred.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/apture/\">Apture</a></p>\n<p>Apture makes it easy to add contextual images, videos, reference guides, links, maps, music, news, documents and books to your blog to create a connected media experience that keeps readers engaged on your site.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/wp-stats-dashboard/\">WP Stats Dashboard</a></p>\n<p>Displays the WordPress.com stats graph directly in your Dashboard. No more tiresomely opening the Blog Stats tab and manually logging in.</p>\n<p><a href=\"http://blog.avirtualhome.com/2009/03/05/update-wordpress-plugin-avh-extended-categories/\">Extended Categories</a></p>\n<p>Replacement of the default category widget to allow for greater customization of the category widget.</p>\n<p><a href=\"http://davidebenini.it/wordpress-plugins/plugins-list/\">Plugins List</a></p>\n<p>Plugins List allows you to insert a list of the plugins you are using on any post/page of your blog.</p>\n<p><a href=\"http://alexking.org/projects/wordpress/readme?project=wordpress-mobile-edition\">WordPress Mobile Edition</a></p>\n<p>This is a WordPress plugin that will display a mobile-friendly theme for your site if your site visitor is using a mobile browser.</p>\";s:7:\"pubdate\";s:31:\"Fri, 06 Mar 2009 17:33:26 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:3262:\"<h3>New Plugins</h3>\n<p><a href=\"http://dentedreality.com.au/projects/wp-sparkplug/\">Sparkplug</a></p>\n<p>Sparkplug is a very simple plugin which provides you with an easy-to-read indication of how active the “current view” of a blog is. On the homepage, it provides a sparkline chart showing total posts per day for the (by default) last 30 days. On a tag, category or author-specific page, it shows bars representing how many posts were made with that tag/category or by that author per day, with a line showing the total posts per day for comparison.</p>\n<p><a href=\"http://www.paulmc.org/whatithink/wordpress/plugins/email-post-activation/\">Email Post Activation</a></p>\n<p>Adds an iFrame to your blog footer to automatically activate any posts written by email. </p>\n<p><a href=\"http://lud.icro.us/wordpress-plugin-info/\">Plugin Info</a></p>\n<p>This plugin provides a simple way of displaying up-to-date information about specific plugins hosted on the WordPress Plugin Directory in your blog posts and pages.</p>\n<p><a href=\"http://www.agarassino.com/wordpress-plugin-nofollow-filter/\">NoFollow Filter</a></p>\n<p>The plugin allows you to automatically add nofollow attribute to a list of links that you define on the admin.</p>\n<p><a href=\"http://lud.icro.us/wordpress-plugin-user-switching/\">User Switching</a></p>\n<p>Enables you to instantly swap between users in WordPress.</p>\n<p><a href=\"http://htmlblog.net/wp-to-top/\">WP to Top</a></p>\n<p>Adds a \"Back to top\" link in your blog without modifying your template files. This is useful especially if you have long posts or long pages. You will have a nice \"Back to top\" or whatever-text-you-want link floating at the bottom right/left of your page.</p>\n<h3>Updated Plugins</h3>\n<p><a href=\"http://www.weinschenker.name/plugin-feed-reading-blogroll/\">Feed Reading Blogroll</a></p>\n<p>This plugin provides a sidebar-widget and a template-tag that add an enhanced blogroll to your sidebar. It checks on all your linked sites, when the most recent update has occurred.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/apture/\">Apture</a></p>\n<p>Apture makes it easy to add contextual images, videos, reference guides, links, maps, music, news, documents and books to your blog to create a connected media experience that keeps readers engaged on your site.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/wp-stats-dashboard/\">WP Stats Dashboard</a></p>\n<p>Displays the WordPress.com stats graph directly in your Dashboard. No more tiresomely opening the Blog Stats tab and manually logging in.</p>\n<p><a href=\"http://blog.avirtualhome.com/2009/03/05/update-wordpress-plugin-avh-extended-categories/\">Extended Categories</a></p>\n<p>Replacement of the default category widget to allow for greater customization of the category widget.</p>\n<p><a href=\"http://davidebenini.it/wordpress-plugins/plugins-list/\">Plugins List</a></p>\n<p>Plugins List allows you to insert a list of the plugins you are using on any post/page of your blog.</p>\n<p><a href=\"http://alexking.org/projects/wordpress/readme?project=wordpress-mobile-edition\">WordPress Mobile Edition</a></p>\n<p>This is a WordPress plugin that will display a mobile-friendly theme for your site if your site visitor is using a mobile browser.</p>\";}i:36;a:7:{s:5:\"title\";s:29:\"Matt: Awesome Comment Plugins\";s:4:\"guid\";s:21:\"http://ma.tt/?p=12168\";s:4:\"link\";s:45:\"http://ma.tt/2009/03/awesome-comment-plugins/\";s:11:\"description\";s:459:\"<p><a href=\"http://blog.intensedebate.com/2009/03/05/introducing-intensedebate-plugins-add-the-features-you-want/#idc-ctools\">Introducing IntenseDebate Plugins: add the features you want</a>. Now ID has a plugin architecture (just like WordPress) that allows you to enhance the functionality of comments. First ones out the gate are polls, Youtube, Seesmic, and of course smileys. <a href=\"http://intensedebate.com/\">Want to supercharge your comments</a>?</p>\";s:7:\"pubdate\";s:31:\"Fri, 06 Mar 2009 10:18:10 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:459:\"<p><a href=\"http://blog.intensedebate.com/2009/03/05/introducing-intensedebate-plugins-add-the-features-you-want/#idc-ctools\">Introducing IntenseDebate Plugins: add the features you want</a>. Now ID has a plugin architecture (just like WordPress) that allows you to enhance the functionality of comments. First ones out the gate are polls, Youtube, Seesmic, and of course smileys. <a href=\"http://intensedebate.com/\">Want to supercharge your comments</a>?</p>\";}i:37;a:7:{s:5:\"title\";s:43:\"Peter Westwood: WordPress plugins milestone\";s:4:\"guid\";s:32:\"http://westi.wordpress.com/?p=79\";s:4:\"link\";s:66:\"http://westi.wordpress.com/2009/03/06/wordpress-plugins-milestone/\";s:11:\"description\";s:1559:\"<div class=\"snap_preview\"><br /><p>At 8:17am GMT today another WordPress milestone was reached.  The WordPress plugins subversion repository received it&#8217;s <a href=\"http://plugins.trac.wordpress.org/changeset/100000\">100000</a> check-in.</p>\n<p>Congratulations to <a href=\"http://blog.jeffyen.com/\">Jeff Yen</a> for achieving this.  Maybe you should go check out his <a href=\"http://wordpress.org/extend/plugins/google-maps-gps-link/\">Google Maps GPS Link</a> plugin.</p>\n  <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/westi.wordpress.com/79/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/westi.wordpress.com/79/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/westi.wordpress.com/79/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/westi.wordpress.com/79/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/westi.wordpress.com/79/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/westi.wordpress.com/79/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/westi.wordpress.com/79/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/westi.wordpress.com/79/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/westi.wordpress.com/79/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/westi.wordpress.com/79/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=westi.wordpress.com&blog=15396&post=79&subd=westi&ref=&feed=1\" /></div>\";s:7:\"pubdate\";s:31:\"Fri, 06 Mar 2009 10:06:40 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:14:\"Peter Westwood\";}s:7:\"summary\";s:1559:\"<div class=\"snap_preview\"><br /><p>At 8:17am GMT today another WordPress milestone was reached.  The WordPress plugins subversion repository received it&#8217;s <a href=\"http://plugins.trac.wordpress.org/changeset/100000\">100000</a> check-in.</p>\n<p>Congratulations to <a href=\"http://blog.jeffyen.com/\">Jeff Yen</a> for achieving this.  Maybe you should go check out his <a href=\"http://wordpress.org/extend/plugins/google-maps-gps-link/\">Google Maps GPS Link</a> plugin.</p>\n  <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/westi.wordpress.com/79/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/westi.wordpress.com/79/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/westi.wordpress.com/79/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/westi.wordpress.com/79/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/westi.wordpress.com/79/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/westi.wordpress.com/79/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/westi.wordpress.com/79/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/westi.wordpress.com/79/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/westi.wordpress.com/79/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/westi.wordpress.com/79/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=westi.wordpress.com&blog=15396&post=79&subd=westi&ref=&feed=1\" /></div>\";}i:38;a:7:{s:5:\"title\";s:23:\"Matt: New Spring Design\";s:4:\"guid\";s:21:\"http://ma.tt/?p=12160\";s:4:\"link\";s:41:\"http://ma.tt/2009/03/new-spring-design-2/\";s:11:\"description\";s:1908:\"<p>Time to break out of your RSS readers: there&#8217;s a new design on <a href=\"http://ma.tt/\">Ma.tt</a>! Recommended only for the high-bandwidth and the open-minded. There was nothing wrong with my old theme, I just get an itch for something new every now and then and wanted a totally different direction &#8212; especially now that every site has copped the worn paper look / colorful flourish. Also it&#8217;s refreshing to be able to have a design where the only person in the world it needs to please is me. Here&#8217;s a before and after:</p>\n\n<a href=\"http://ma.tt/2009/03/new-spring-design-2/mahtete-old/\" title=\"mahtete-old\"><img width=\"195\" height=\"146\" src=\"http://s.ma.tt/files/2009/03/mahtete-old-195x146.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mahtete-old\" /></a>\n<a href=\"http://ma.tt/2009/03/new-spring-design-2/mahjoolz/\" title=\"March 5, 2009 Redesign of Ma.tt\"><img width=\"195\" height=\"146\" src=\"http://s.ma.tt/files/2009/03/mahjoolz-195x146.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"March 5, 2009 Redesign of Ma.tt\" /></a>\n\n<p>For fans of the old design, I&#8217;m going to abstract it into a regular WordPress theme &#8212; gallery features and all &#8212; that will be available to the entire world, including WordPress.com. It&#8217;s amazing to me how many great designs are thrown away, never to be used again, when as a WP theme they could live forever.</p>\n<p>I wanted to thank <a href=\"http://www.joolz.fr/\">Julien Morel</a>, the creative mind behind this iteration, and <a href=\"http://colinger.com/\">Brian Colinger</a>, who turned the vision into HTML, CSS, and PHP.</p>\n<p>If I could I would redesign the site every season: Winter, Spring, Summer, Fall. It just always takes longer than I planned (this was supposed to launch in Winter). The cobbler&#8217;s sons go shoeless.</p>\n<p><a href=\"http://ma.tt/2009/03/new-spring-design-2/\">What do you think</a>?</p>\";s:7:\"pubdate\";s:31:\"Thu, 05 Mar 2009 16:56:13 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:1908:\"<p>Time to break out of your RSS readers: there&#8217;s a new design on <a href=\"http://ma.tt/\">Ma.tt</a>! Recommended only for the high-bandwidth and the open-minded. There was nothing wrong with my old theme, I just get an itch for something new every now and then and wanted a totally different direction &#8212; especially now that every site has copped the worn paper look / colorful flourish. Also it&#8217;s refreshing to be able to have a design where the only person in the world it needs to please is me. Here&#8217;s a before and after:</p>\n\n<a href=\"http://ma.tt/2009/03/new-spring-design-2/mahtete-old/\" title=\"mahtete-old\"><img width=\"195\" height=\"146\" src=\"http://s.ma.tt/files/2009/03/mahtete-old-195x146.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mahtete-old\" /></a>\n<a href=\"http://ma.tt/2009/03/new-spring-design-2/mahjoolz/\" title=\"March 5, 2009 Redesign of Ma.tt\"><img width=\"195\" height=\"146\" src=\"http://s.ma.tt/files/2009/03/mahjoolz-195x146.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"March 5, 2009 Redesign of Ma.tt\" /></a>\n\n<p>For fans of the old design, I&#8217;m going to abstract it into a regular WordPress theme &#8212; gallery features and all &#8212; that will be available to the entire world, including WordPress.com. It&#8217;s amazing to me how many great designs are thrown away, never to be used again, when as a WP theme they could live forever.</p>\n<p>I wanted to thank <a href=\"http://www.joolz.fr/\">Julien Morel</a>, the creative mind behind this iteration, and <a href=\"http://colinger.com/\">Brian Colinger</a>, who turned the vision into HTML, CSS, and PHP.</p>\n<p>If I could I would redesign the site every season: Winter, Spring, Summer, Fall. It just always takes longer than I planned (this was supposed to launch in Winter). The cobbler&#8217;s sons go shoeless.</p>\n<p><a href=\"http://ma.tt/2009/03/new-spring-design-2/\">What do you think</a>?</p>\";}i:39;a:7:{s:5:\"title\";s:72:\"Weblog Tools Collection: WordPress Plugin Development Beginner’s Guide\";s:4:\"guid\";s:98:\"http://weblogtoolscollection.com/archives/2009/03/05/wordpress-plugin-development-beginners-guide/\";s:4:\"link\";s:98:\"http://weblogtoolscollection.com/archives/2009/03/05/wordpress-plugin-development-beginners-guide/\";s:11:\"description\";s:1882:\"<p><a href=\"http://www.prelovac.com/vladimir/\">Vladimir Prevolac</a>, the developer of several plugins and themes for WordPress has released a book titled <a href=\"http://www.prelovac.com/vladimir/wordpress-plugin-development-book\">WordPress Plugin Development (Beginners&#8217; Guide)</a>.</p>\n<p>The book, written for anyone who wishes to author WordPress plugins, consists of eight chapters, six of which are dealing with development of actual plugins from scratch.</p>\n<p>Here&#8217;s what you can learn:</p>\n<ul>\n<li>Get to know the WordPress code base, WordPress&#8217;s plug-in architecture, and the plug-in application programming interface (API) and learn how to hack it </li>\n<li>Master the WordPress database and the API - access and manipulate data, handle user roles and permissions, posts, and so on </li>\n<li>Hook into the rest of WordPress using actions and filters </li>\n<li>Change the way your WordPress backend looks by customizing menus, submenus, and the plug-in admin panel </li>\n<li>Integrate AJAX and jQuery into your plug-ins to dynamically generate content </li>\n<li>Hook directly to WordPress edit pages and use AJAX to generate fast searches </li>\n<li>Integrate your plug-in with WordPress panels and the tinyMCE editor </li>\n<li>Access and work with third-party APIs like Flickr </li>\n<li>Implement localization support for users of other languages </li>\n<li>Maintain and manage your plug-in using SVN and publish it to the WordPress Plugin Repository </li>\n<li>Handle security issues and make your plug-ins safer to use </li>\n</ul>\n<p>The book retails for $39.99 for the hard copy and $31.99 for the eBook. You can order the same from <a href=\"http://www.packtpub.com/wordpress-plug-in-development/book/mid/11020930cx0a\">Packt Publishing</a> or <a href=\"http://www.amazon.com/WordPress-Plugin-Development-Beginners-Guide/dp/1847193595/\">Amazon</a>.</p>\";s:7:\"pubdate\";s:31:\"Thu, 05 Mar 2009 15:55:59 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:1882:\"<p><a href=\"http://www.prelovac.com/vladimir/\">Vladimir Prevolac</a>, the developer of several plugins and themes for WordPress has released a book titled <a href=\"http://www.prelovac.com/vladimir/wordpress-plugin-development-book\">WordPress Plugin Development (Beginners&#8217; Guide)</a>.</p>\n<p>The book, written for anyone who wishes to author WordPress plugins, consists of eight chapters, six of which are dealing with development of actual plugins from scratch.</p>\n<p>Here&#8217;s what you can learn:</p>\n<ul>\n<li>Get to know the WordPress code base, WordPress&#8217;s plug-in architecture, and the plug-in application programming interface (API) and learn how to hack it </li>\n<li>Master the WordPress database and the API - access and manipulate data, handle user roles and permissions, posts, and so on </li>\n<li>Hook into the rest of WordPress using actions and filters </li>\n<li>Change the way your WordPress backend looks by customizing menus, submenus, and the plug-in admin panel </li>\n<li>Integrate AJAX and jQuery into your plug-ins to dynamically generate content </li>\n<li>Hook directly to WordPress edit pages and use AJAX to generate fast searches </li>\n<li>Integrate your plug-in with WordPress panels and the tinyMCE editor </li>\n<li>Access and work with third-party APIs like Flickr </li>\n<li>Implement localization support for users of other languages </li>\n<li>Maintain and manage your plug-in using SVN and publish it to the WordPress Plugin Repository </li>\n<li>Handle security issues and make your plug-ins safer to use </li>\n</ul>\n<p>The book retails for $39.99 for the hard copy and $31.99 for the eBook. You can order the same from <a href=\"http://www.packtpub.com/wordpress-plug-in-development/book/mid/11020930cx0a\">Packt Publishing</a> or <a href=\"http://www.amazon.com/WordPress-Plugin-Development-Beginners-Guide/dp/1847193595/\">Amazon</a>.</p>\";}i:40;a:7:{s:5:\"title\";s:59:\"Weblog Tools Collection: WordPress Theme Releases for 03/05\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5258\";s:4:\"link\";s:87:\"http://weblogtoolscollection.com/archives/2009/03/05/wordpress-theme-releases-for-0305/\";s:11:\"description\";s:1294:\"<p><a href=\"http://www.ewebsite.biz/2009/03/blue-sea-wordpress-theme/\">Blue Sea</a></p>\n<p><a href=\"http://www.ewebsite.biz/?preview_theme=Blue_Sea\"><img title=\"BlueSea\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/bluesea.png\" alt=\"BlueSea\" width=\"150\" height=\"150\" /></a></p>\n<p>Two column, widget ready blue theme.</p>\n<p><a href=\"http://blogigs.com/2-column-neoclassical-theme/\">2 Column Neoclassical Theme</a></p>\n<p><img title=\"Neoclassical\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/neoclassical.gif\" alt=\"Neoclassical\" width=\"150\" height=\"101\" /></p>\n<p>Based on the 3 Column Neoclassical Theme by Chris Pearson, this modified version has a 300 pixels right sidebar to accommodate all kinds of ad sizes and many new features not found in the original.</p>\n<p><a href=\"http://www.altamentedecorativo.com/en/second-to-none-child-theme-for-thematic/\">Second to None</a></p>\n<p><img title=\"Second to None\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/secondtonone.gif\" alt=\"Second to None\" width=\"150\" height=\"124\" /></p>\n<p>Three column child theme built on <a href=\"http://themeshaper.com/thematic-for-wordpress/\">Thematic Framework</a> 0.9.</p>\n<p>Are you a theme author? <a href=\"http://weblogtoolscollection.com/submit-news/\">Submit your theme</a> to us.</p>\";s:7:\"pubdate\";s:31:\"Thu, 05 Mar 2009 15:31:20 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:1294:\"<p><a href=\"http://www.ewebsite.biz/2009/03/blue-sea-wordpress-theme/\">Blue Sea</a></p>\n<p><a href=\"http://www.ewebsite.biz/?preview_theme=Blue_Sea\"><img title=\"BlueSea\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/bluesea.png\" alt=\"BlueSea\" width=\"150\" height=\"150\" /></a></p>\n<p>Two column, widget ready blue theme.</p>\n<p><a href=\"http://blogigs.com/2-column-neoclassical-theme/\">2 Column Neoclassical Theme</a></p>\n<p><img title=\"Neoclassical\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/neoclassical.gif\" alt=\"Neoclassical\" width=\"150\" height=\"101\" /></p>\n<p>Based on the 3 Column Neoclassical Theme by Chris Pearson, this modified version has a 300 pixels right sidebar to accommodate all kinds of ad sizes and many new features not found in the original.</p>\n<p><a href=\"http://www.altamentedecorativo.com/en/second-to-none-child-theme-for-thematic/\">Second to None</a></p>\n<p><img title=\"Second to None\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/secondtonone.gif\" alt=\"Second to None\" width=\"150\" height=\"124\" /></p>\n<p>Three column child theme built on <a href=\"http://themeshaper.com/thematic-for-wordpress/\">Thematic Framework</a> 0.9.</p>\n<p>Are you a theme author? <a href=\"http://weblogtoolscollection.com/submit-news/\">Submit your theme</a> to us.</p>\";}i:41;a:7:{s:5:\"title\";s:21:\"Matt: WordCamp Denver\";s:4:\"guid\";s:21:\"http://ma.tt/?p=12093\";s:4:\"link\";s:37:\"http://ma.tt/2009/02/wordcamp-denver/\";s:11:\"description\";s:14351:\"<p>WordCamp Denver at the Art Museum, which was a fantastic venue.</p>\n<p><span id=\"more-12093\"></span></p>\n\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0189-2/\" title=\"mcm_0189\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0189-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0189\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0190/\" title=\"mcm_0190\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0190-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0190\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0192/\" title=\"mcm_0192\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0192-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0192\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0194-2/\" title=\"mcm_0194\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0194-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0194\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0195-2/\" title=\"mcm_0195\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0195-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0195\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0196-2/\" title=\"mcm_0196\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0196-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0196\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0197/\" title=\"mcm_0197\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0197-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0197\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0198/\" title=\"mcm_0198\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0198-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0198\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0200-2/\" title=\"mcm_0200\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0200-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"Why did we go to WordCamp in a Roll-Royce Phantom? We were running late and Jane commandeered the \" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0210-2/\" title=\"mcm_0210\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0210-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0210\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0213/\" title=\"mcm_0213\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0213-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0213\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0214/\" title=\"mcm_0214\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0214-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0214\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0216-2/\" title=\"mcm_0216\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0216-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0216\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0217-2/\" title=\"mcm_0217\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0217-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0217\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0218/\" title=\"mcm_0218\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0218-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0218\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0219-2/\" title=\"mcm_0219\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0219-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0219\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0221/\" title=\"mcm_0221\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0221-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0221\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0224-2/\" title=\"mcm_0224\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0224-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0224\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0228-2/\" title=\"mcm_0228\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0228-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0228\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0229-2/\" title=\"mcm_0229\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0229-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0229\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0231-2/\" title=\"mcm_0231\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0231-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0231\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0234-2/\" title=\"mcm_0234\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0234-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0234\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0236-2/\" title=\"mcm_0236\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0236-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0236\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0242-2/\" title=\"mcm_0242\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0242-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0242\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0243-2/\" title=\"mcm_0243\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0243-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0243\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0244-2/\" title=\"mcm_0244\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0244-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0244\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0248-2/\" title=\"mcm_0248\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0248-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0248\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0249-2/\" title=\"mcm_0249\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0249-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0249\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0253-2/\" title=\"mcm_0253\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0253-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0253\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0257-2/\" title=\"mcm_0257\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0257-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0257\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0261-2/\" title=\"mcm_0261\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0261-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0261\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0263-2/\" title=\"mcm_0263\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0263-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0263\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0264-2/\" title=\"mcm_0264\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0264-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0264\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0267-2/\" title=\"mcm_0267\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0267-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0267\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0268-2/\" title=\"mcm_0268\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0268-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0268\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0269-2/\" title=\"mcm_0269\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0269-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0269\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0270-2/\" title=\"mcm_0270\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0270-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0270\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0275-2/\" title=\"mcm_0275\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0275-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0275\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0276/\" title=\"mcm_0276\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0276-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0276\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0279-2/\" title=\"mcm_0279\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0279-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0279\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0281/\" title=\"mcm_0281\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0281-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0281\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0286/\" title=\"mcm_0286\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0286-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0286\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0288/\" title=\"mcm_0288\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0288-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0288\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0293/\" title=\"mcm_0293\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0293-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0293\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0297/\" title=\"mcm_0297\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0297-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0297\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0298-2/\" title=\"mcm_0298\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0298-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0298\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0302/\" title=\"mcm_0302\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0302-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0302\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0304-2/\" title=\"mcm_0304\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0304-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0304\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0309/\" title=\"mcm_0309\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0309-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0309\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0310-2/\" title=\"mcm_0310\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0310-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0310\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0314/\" title=\"mcm_0314\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0314-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0314\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0317-2/\" title=\"mcm_0317\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0317-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0317\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0321/\" title=\"mcm_0321\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0321-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0321\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0322-2/\" title=\"mcm_0322\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0322-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0322\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0324-2/\" title=\"mcm_0324\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0324-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0324\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0325/\" title=\"mcm_0325\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0325-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0325\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0328/\" title=\"mcm_0328\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0328-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0328\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0329-2/\" title=\"mcm_0329\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0329-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0329\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0330-2/\" title=\"mcm_0330\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0330-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0330\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0336-2/\" title=\"mcm_0336\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0336-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0336\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0277/\" title=\"mcm_0277\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0277-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0277\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0282/\" title=\"mcm_0282\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0282-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0282\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0294-2/\" title=\"mcm_0294\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0294-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0294\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0323/\" title=\"mcm_0323\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0323-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0323\" /></a>\";s:7:\"pubdate\";s:31:\"Thu, 05 Mar 2009 14:45:42 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:14351:\"<p>WordCamp Denver at the Art Museum, which was a fantastic venue.</p>\n<p><span id=\"more-12093\"></span></p>\n\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0189-2/\" title=\"mcm_0189\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0189-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0189\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0190/\" title=\"mcm_0190\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0190-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0190\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0192/\" title=\"mcm_0192\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0192-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0192\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0194-2/\" title=\"mcm_0194\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0194-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0194\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0195-2/\" title=\"mcm_0195\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0195-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0195\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0196-2/\" title=\"mcm_0196\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0196-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0196\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0197/\" title=\"mcm_0197\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0197-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0197\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0198/\" title=\"mcm_0198\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0198-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0198\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0200-2/\" title=\"mcm_0200\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0200-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"Why did we go to WordCamp in a Roll-Royce Phantom? We were running late and Jane commandeered the \" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0210-2/\" title=\"mcm_0210\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0210-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0210\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0213/\" title=\"mcm_0213\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0213-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0213\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0214/\" title=\"mcm_0214\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0214-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0214\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0216-2/\" title=\"mcm_0216\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0216-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0216\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0217-2/\" title=\"mcm_0217\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0217-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0217\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0218/\" title=\"mcm_0218\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0218-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0218\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0219-2/\" title=\"mcm_0219\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0219-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0219\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0221/\" title=\"mcm_0221\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0221-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0221\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0224-2/\" title=\"mcm_0224\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0224-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0224\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0228-2/\" title=\"mcm_0228\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0228-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0228\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0229-2/\" title=\"mcm_0229\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0229-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0229\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0231-2/\" title=\"mcm_0231\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0231-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0231\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0234-2/\" title=\"mcm_0234\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0234-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0234\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0236-2/\" title=\"mcm_0236\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0236-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0236\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0242-2/\" title=\"mcm_0242\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0242-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0242\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0243-2/\" title=\"mcm_0243\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0243-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0243\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0244-2/\" title=\"mcm_0244\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0244-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0244\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0248-2/\" title=\"mcm_0248\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0248-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0248\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0249-2/\" title=\"mcm_0249\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0249-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0249\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0253-2/\" title=\"mcm_0253\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0253-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0253\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0257-2/\" title=\"mcm_0257\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0257-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0257\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0261-2/\" title=\"mcm_0261\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0261-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0261\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0263-2/\" title=\"mcm_0263\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0263-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0263\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0264-2/\" title=\"mcm_0264\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0264-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0264\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0267-2/\" title=\"mcm_0267\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0267-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0267\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0268-2/\" title=\"mcm_0268\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0268-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0268\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0269-2/\" title=\"mcm_0269\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0269-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0269\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0270-2/\" title=\"mcm_0270\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0270-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0270\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0275-2/\" title=\"mcm_0275\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0275-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0275\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0276/\" title=\"mcm_0276\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0276-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0276\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0279-2/\" title=\"mcm_0279\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0279-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0279\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0281/\" title=\"mcm_0281\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0281-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0281\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0286/\" title=\"mcm_0286\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0286-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0286\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0288/\" title=\"mcm_0288\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0288-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0288\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0293/\" title=\"mcm_0293\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0293-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0293\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0297/\" title=\"mcm_0297\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0297-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0297\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0298-2/\" title=\"mcm_0298\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0298-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0298\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0302/\" title=\"mcm_0302\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0302-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0302\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0304-2/\" title=\"mcm_0304\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0304-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0304\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0309/\" title=\"mcm_0309\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0309-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0309\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0310-2/\" title=\"mcm_0310\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0310-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0310\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0314/\" title=\"mcm_0314\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0314-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0314\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0317-2/\" title=\"mcm_0317\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0317-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0317\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0321/\" title=\"mcm_0321\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0321-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0321\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0322-2/\" title=\"mcm_0322\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0322-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0322\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0324-2/\" title=\"mcm_0324\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0324-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0324\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0325/\" title=\"mcm_0325\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0325-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0325\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0328/\" title=\"mcm_0328\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0328-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0328\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0329-2/\" title=\"mcm_0329\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0329-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0329\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0330-2/\" title=\"mcm_0330\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0330-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0330\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0336-2/\" title=\"mcm_0336\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0336-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0336\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0277/\" title=\"mcm_0277\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0277-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0277\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0282/\" title=\"mcm_0282\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0282-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0282\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0294-2/\" title=\"mcm_0294\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0294-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0294\" /></a>\n<a href=\"http://ma.tt/2009/02/wordcamp-denver/mcm_0323/\" title=\"mcm_0323\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0323-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0323\" /></a>\";}i:42;a:7:{s:5:\"title\";s:19:\"Matt: Denver Dinner\";s:4:\"guid\";s:21:\"http://ma.tt/?p=12060\";s:4:\"link\";s:35:\"http://ma.tt/2009/02/denver-dinner/\";s:11:\"description\";s:6893:\"<p>Pre-WordCamp dinner in Denver, where it was very cold.</p>\n<p><span id=\"more-12060\"></span></p>\n\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0119/\" title=\"mcm_0119\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0119-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0119\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0121/\" title=\"mcm_0121\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0121-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0121\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0123-2/\" title=\"mcm_0123\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0123-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0123\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0126-2/\" title=\"mcm_0126\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0126-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0126\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0130-3/\" title=\"mcm_0130\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0130-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0130\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0134-2/\" title=\"mcm_0134\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0134-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0134\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0137-3/\" title=\"mcm_0137\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0137-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0137\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0140/\" title=\"mcm_0140\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0140-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0140\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0141-2/\" title=\"mcm_0141\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0141-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0141\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0145-2/\" title=\"mcm_0145\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0145-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0145\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0149-2/\" title=\"mcm_0149\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0149-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0149\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0151/\" title=\"mcm_0151\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0151-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0151\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0152/\" title=\"mcm_0152\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0152-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0152\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0154/\" title=\"mcm_0154\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0154-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0154\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0156-2/\" title=\"mcm_0156\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0156-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0156\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0159-2/\" title=\"mcm_0159\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0159-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0159\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0162-3/\" title=\"mcm_0162\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0162-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0162\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0164-3/\" title=\"mcm_0164\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0164-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0164\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0167-2/\" title=\"mcm_0167\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0167-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0167\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0169/\" title=\"mcm_0169\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0169-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0169\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0170/\" title=\"mcm_0170\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0170-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0170\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0173/\" title=\"mcm_0173\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0173-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0173\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0176/\" title=\"mcm_0176\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0176-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0176\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0177/\" title=\"mcm_0177\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0177-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0177\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0179/\" title=\"mcm_0179\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0179-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0179\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0182/\" title=\"mcm_0182\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0182-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0182\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0184-2/\" title=\"mcm_0184\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0184-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0184\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0185-2/\" title=\"mcm_0185\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0185-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0185\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0186-2/\" title=\"mcm_0186\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0186-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0186\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0187-2/\" title=\"mcm_0187\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0187-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0187\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0188-2/\" title=\"mcm_0188\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0188-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0188\" /></a>\";s:7:\"pubdate\";s:31:\"Thu, 05 Mar 2009 10:31:00 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:6893:\"<p>Pre-WordCamp dinner in Denver, where it was very cold.</p>\n<p><span id=\"more-12060\"></span></p>\n\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0119/\" title=\"mcm_0119\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0119-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0119\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0121/\" title=\"mcm_0121\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0121-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0121\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0123-2/\" title=\"mcm_0123\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0123-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0123\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0126-2/\" title=\"mcm_0126\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0126-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0126\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0130-3/\" title=\"mcm_0130\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0130-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0130\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0134-2/\" title=\"mcm_0134\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0134-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0134\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0137-3/\" title=\"mcm_0137\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0137-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0137\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0140/\" title=\"mcm_0140\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0140-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0140\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0141-2/\" title=\"mcm_0141\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0141-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0141\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0145-2/\" title=\"mcm_0145\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0145-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0145\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0149-2/\" title=\"mcm_0149\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0149-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0149\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0151/\" title=\"mcm_0151\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0151-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0151\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0152/\" title=\"mcm_0152\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0152-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0152\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0154/\" title=\"mcm_0154\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0154-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0154\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0156-2/\" title=\"mcm_0156\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0156-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0156\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0159-2/\" title=\"mcm_0159\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0159-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0159\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0162-3/\" title=\"mcm_0162\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0162-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0162\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0164-3/\" title=\"mcm_0164\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0164-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0164\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0167-2/\" title=\"mcm_0167\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0167-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0167\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0169/\" title=\"mcm_0169\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0169-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0169\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0170/\" title=\"mcm_0170\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0170-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0170\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0173/\" title=\"mcm_0173\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0173-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0173\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0176/\" title=\"mcm_0176\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0176-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0176\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0177/\" title=\"mcm_0177\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0177-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0177\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0179/\" title=\"mcm_0179\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0179-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0179\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0182/\" title=\"mcm_0182\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0182-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0182\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0184-2/\" title=\"mcm_0184\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0184-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0184\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0185-2/\" title=\"mcm_0185\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0185-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0185\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0186-2/\" title=\"mcm_0186\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0186-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0186\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0187-2/\" title=\"mcm_0187\"><img width=\"139\" height=\"210\" src=\"http://s.ma.tt/files/2009/02/mcm_0187-139x210.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0187\" /></a>\n<a href=\"http://ma.tt/2009/02/denver-dinner/mcm_0188-2/\" title=\"mcm_0188\"><img width=\"195\" height=\"129\" src=\"http://s.ma.tt/files/2009/02/mcm_0188-195x129.jpg\" class=\"attachment-thumbnail\" alt=\"\" title=\"mcm_0188\" /></a>\";}i:43;a:7:{s:5:\"title\";s:32:\"Alex King: WordCamp Denver Recap\";s:4:\"guid\";s:57:\"http://alexking.org/blog/2009/03/04/wordcamp-denver-recap\";s:4:\"link\";s:57:\"http://alexking.org/blog/2009/03/04/wordcamp-denver-recap\";s:11:\"description\";s:4008:\"<p>This past weekend WordCamp made it&#8217;s first appearance in <a href=\"http://denver.wordcamp.org\" rel=\"external\">Denver</a>. All in all, I believe it went pretty well.</p>\n<p>If you attended, you should have received a feedback survey today. I&#8217;m looking forward to seeing the responses and ideas people have to make WordCamp Denver 2010 even better (yes, I know - better WiFi).</p>\n<p>We had around 300 people at the event, which we packed into the Denver Art Museum and squeezed in to <a href=\"http://denver.wordcamp.org/schedule/\" rel=\"external\">14 sessions</a> with some fantastic <a href=\"http://denver.wordcamp.org/speakers/\" rel=\"external\">speakers</a>. This may have been too ambitous a schedule - we&#8217;ll see what the feedback says.</p>\n<p>This was the first conference <a href=\"http://crowdfavorite.com\">Crowd Favorite</a> has organized, and it was definitely a learning experience. I&#8217;ll post some of the specific lessons learned (along with notes we&#8217;ve gathered from some other WordCamp organizers) in a follow-up post.</p>\n<p>It was fun to see <a href=\"http://search.twitter.com/search?q=wordcampdenver\" rel=\"external\">#wordcampdenver</a> race up the &#8220;trending topics&#8221; on Twitter throughout the day. There are some <a href=\"http://flickr.com/photos/tags/wordcampdenver/\" rel=\"external\">great photos up on Flickr</a> - my little set is <a href=\"http://flickr.com/photos/alexkingorg/sets/72157614809356768/\" rel=\"external\">here</a>. As usual, I wish I&#8217;d taken more shots.</p>\n<p>I was pleased to get some positive feedback on my presentation on <a href=\"http://carringtontheme.com\" rel=\"external\">Carrington</a> - our CMS theme framework for WordPress. With much help from <a href=\"http://betterelevation.com\" rel=\"external\">Dave Wiskus</a>, I retooled my presentation to be a lot simpler and attempted to add some funny. Better structure in the message seems to have resulted in a better understanding by the audience - I saw lots of heads nodding and people seemed to understand the benefits of Carrington a lot better than my previous attempts to explain how the framework functions.</p>\n<p>Here are the slides - although with the new presentation style they are no longer as useful without the audio (and code examples). The full presentation video should be on WordPress.tv in the near future.</p>\n<div id=\"__ss_1089149\"><a href=\"http://www.slideshare.net/alexkingorg/carrington?type=powerpoint\" title=\"Carrington CMS Theme Framework for WordPress\">Carrington CMS Theme Framework for WordPress</a>\n\n\n\n<div>View more <a href=\"http://www.slideshare.net/\">presentations</a> from <a href=\"http://www.slideshare.net/alexkingorg\">alexkingorg</a>. (tags: <a href=\"http://slideshare.net/tag/framework\">framework</a> <a href=\"http://slideshare.net/tag/theme\">theme</a>)</div>\n</div>\n<p>Finally - A big thank you to all of our attendees, the wonderful <a href=\"http://denver.wordcamp.org/speakers/\" rel=\"external\">speakers</a> that graciously donated their time, the sponsors that made everything possible financially: <a href=\"http://www.feld.com\">Brad Feld</a>, <a href=\"http://www.techstars.org\">TechStars</a>, <a href=\"http://www.brightkite.com\">BrightKite</a>, <a href=\"http://sliceoflime.com\">Slice of Lime</a>, <a href=\"http://intensedebate.com\">IntenseDebate</a>, <a href=\"http://www.blubrry.com/\">blubrry</a>, <a href=\"http://www.lijit.com\">Lijit</a>, <a href=\"http://www.bumpertunes.net/\">BumperTunes</a>, <a href=\"http://redmonk.com\">RedMonk</a>, <a href=\"http://www.mtmconcepts.com/\">MTM Concepts</a>, <a href=\"http://gigbot.com\">Gigbot</a>, <a href=\"http://www.flyingdogales.com/\">Flying Dog Brewery</a> and the great folks at the <a href=\"http://www.denverartmuseum.org/\" rel=\"external\">Denver Art Museum</a>.</p>\n<p><a href=\"http://sharethis.com/item?&wp=2.2.3&amp;publisher=a1583af8-28eb-4210-97bd-2bb5c02bc265&amp;title=WordCamp+Denver+Recap&amp;url=http%3A%2F%2Falexking.org%2Fblog%2F2009%2F03%2F04%2Fwordcamp-denver-recap\">ShareThis</a></p>\";s:7:\"pubdate\";s:31:\"Wed, 04 Mar 2009 22:36:24 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Alex\";}s:7:\"summary\";s:4008:\"<p>This past weekend WordCamp made it&#8217;s first appearance in <a href=\"http://denver.wordcamp.org\" rel=\"external\">Denver</a>. All in all, I believe it went pretty well.</p>\n<p>If you attended, you should have received a feedback survey today. I&#8217;m looking forward to seeing the responses and ideas people have to make WordCamp Denver 2010 even better (yes, I know - better WiFi).</p>\n<p>We had around 300 people at the event, which we packed into the Denver Art Museum and squeezed in to <a href=\"http://denver.wordcamp.org/schedule/\" rel=\"external\">14 sessions</a> with some fantastic <a href=\"http://denver.wordcamp.org/speakers/\" rel=\"external\">speakers</a>. This may have been too ambitous a schedule - we&#8217;ll see what the feedback says.</p>\n<p>This was the first conference <a href=\"http://crowdfavorite.com\">Crowd Favorite</a> has organized, and it was definitely a learning experience. I&#8217;ll post some of the specific lessons learned (along with notes we&#8217;ve gathered from some other WordCamp organizers) in a follow-up post.</p>\n<p>It was fun to see <a href=\"http://search.twitter.com/search?q=wordcampdenver\" rel=\"external\">#wordcampdenver</a> race up the &#8220;trending topics&#8221; on Twitter throughout the day. There are some <a href=\"http://flickr.com/photos/tags/wordcampdenver/\" rel=\"external\">great photos up on Flickr</a> - my little set is <a href=\"http://flickr.com/photos/alexkingorg/sets/72157614809356768/\" rel=\"external\">here</a>. As usual, I wish I&#8217;d taken more shots.</p>\n<p>I was pleased to get some positive feedback on my presentation on <a href=\"http://carringtontheme.com\" rel=\"external\">Carrington</a> - our CMS theme framework for WordPress. With much help from <a href=\"http://betterelevation.com\" rel=\"external\">Dave Wiskus</a>, I retooled my presentation to be a lot simpler and attempted to add some funny. Better structure in the message seems to have resulted in a better understanding by the audience - I saw lots of heads nodding and people seemed to understand the benefits of Carrington a lot better than my previous attempts to explain how the framework functions.</p>\n<p>Here are the slides - although with the new presentation style they are no longer as useful without the audio (and code examples). The full presentation video should be on WordPress.tv in the near future.</p>\n<div id=\"__ss_1089149\"><a href=\"http://www.slideshare.net/alexkingorg/carrington?type=powerpoint\" title=\"Carrington CMS Theme Framework for WordPress\">Carrington CMS Theme Framework for WordPress</a>\n\n\n\n<div>View more <a href=\"http://www.slideshare.net/\">presentations</a> from <a href=\"http://www.slideshare.net/alexkingorg\">alexkingorg</a>. (tags: <a href=\"http://slideshare.net/tag/framework\">framework</a> <a href=\"http://slideshare.net/tag/theme\">theme</a>)</div>\n</div>\n<p>Finally - A big thank you to all of our attendees, the wonderful <a href=\"http://denver.wordcamp.org/speakers/\" rel=\"external\">speakers</a> that graciously donated their time, the sponsors that made everything possible financially: <a href=\"http://www.feld.com\">Brad Feld</a>, <a href=\"http://www.techstars.org\">TechStars</a>, <a href=\"http://www.brightkite.com\">BrightKite</a>, <a href=\"http://sliceoflime.com\">Slice of Lime</a>, <a href=\"http://intensedebate.com\">IntenseDebate</a>, <a href=\"http://www.blubrry.com/\">blubrry</a>, <a href=\"http://www.lijit.com\">Lijit</a>, <a href=\"http://www.bumpertunes.net/\">BumperTunes</a>, <a href=\"http://redmonk.com\">RedMonk</a>, <a href=\"http://www.mtmconcepts.com/\">MTM Concepts</a>, <a href=\"http://gigbot.com\">Gigbot</a>, <a href=\"http://www.flyingdogales.com/\">Flying Dog Brewery</a> and the great folks at the <a href=\"http://www.denverartmuseum.org/\" rel=\"external\">Denver Art Museum</a>.</p>\n<p><a href=\"http://sharethis.com/item?&wp=2.2.3&amp;publisher=a1583af8-28eb-4210-97bd-2bb5c02bc265&amp;title=WordCamp+Denver+Recap&amp;url=http%3A%2F%2Falexking.org%2Fblog%2F2009%2F03%2F04%2Fwordcamp-denver-recap\">ShareThis</a></p>\";}i:44;a:7:{s:5:\"title\";s:41:\"Alex King: WordPress Mobile Edition 3.0b1\";s:4:\"guid\";s:65:\"http://alexking.org/blog/2009/03/04/wordpress-mobile-edition-30b1\";s:4:\"link\";s:65:\"http://alexking.org/blog/2009/03/04/wordpress-mobile-edition-30b1\";s:11:\"description\";s:2024:\"<p>A brand spankin&#8217; new version of WordPress Mobile Edition is now available. This is a <a href=\"http://wordpress.org/\" rel=\"external\">WordPress</a> plugin that will display a mobile-friendly theme for your site if your site visitor is using a mobile browser.</p>\n<p class=\"center\"><a href=\"http://www.flickr.com/photos/alexkingorg/3328573237/\" title=\"Carrington Mobile by alexkingorg, on Flickr\"><img src=\"http://farm4.static.flickr.com/3542/3328573237_009b81e306_o.png\" width=\"240\" height=\"180\" alt=\"Carrington Mobile\" /></a></p>\n<p>Here are some of the changes since the 2.x releases:</p>\n<ul>\n<li>New (<a href=\"http://carringtontheme.com\">Carrington</a>-based) theme with more advanced display for advanced mobile browsers. You can see a <a href=\"http://mobile.carringtontheme.com\">preview of the theme here</a>.</li>\n<li>Advanced mobile browsers (iPhone, Android, etc.) are now shown the mobile theme by default.</li>\n<li>Special CSS for &#8220;touch&#8221; browsers like the iPhone, Android, BlackBerry Storm, etc. that make links and buttons nicely finger-sized.</li>\n<li>Admin page to enable adding/editing the list of detected mobile and touch browsers.</li>\n<li>Compatible with the excellent WP SuperCache (latest version).</li>\n</ul>\n<p>This is a beta release as we&#8217;ve only done internal testing on the new version so far, so be sure to let us know if you run into any trouble with it.</p>\n<p>The download and more information are available on my <a href=\"http://alexking.org/projects/wordpress\">WordPress Plugins page</a>.</p>\n<p>If you have any trouble with this, please open a thread in the <a href=\"http://wordpress.org/support/\" rel=\"external\">WP Support Forums</a> and <a href=\"http://alexking.org/contact\">e-mail</a> me a link to the thread.</p>\n<p><a href=\"http://sharethis.com/item?&wp=2.2.3&amp;publisher=a1583af8-28eb-4210-97bd-2bb5c02bc265&amp;title=WordPress+Mobile+Edition+3.0b1&amp;url=http%3A%2F%2Falexking.org%2Fblog%2F2009%2F03%2F04%2Fwordpress-mobile-edition-30b1\">ShareThis</a></p>\";s:7:\"pubdate\";s:31:\"Wed, 04 Mar 2009 21:25:05 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Alex\";}s:7:\"summary\";s:2024:\"<p>A brand spankin&#8217; new version of WordPress Mobile Edition is now available. This is a <a href=\"http://wordpress.org/\" rel=\"external\">WordPress</a> plugin that will display a mobile-friendly theme for your site if your site visitor is using a mobile browser.</p>\n<p class=\"center\"><a href=\"http://www.flickr.com/photos/alexkingorg/3328573237/\" title=\"Carrington Mobile by alexkingorg, on Flickr\"><img src=\"http://farm4.static.flickr.com/3542/3328573237_009b81e306_o.png\" width=\"240\" height=\"180\" alt=\"Carrington Mobile\" /></a></p>\n<p>Here are some of the changes since the 2.x releases:</p>\n<ul>\n<li>New (<a href=\"http://carringtontheme.com\">Carrington</a>-based) theme with more advanced display for advanced mobile browsers. You can see a <a href=\"http://mobile.carringtontheme.com\">preview of the theme here</a>.</li>\n<li>Advanced mobile browsers (iPhone, Android, etc.) are now shown the mobile theme by default.</li>\n<li>Special CSS for &#8220;touch&#8221; browsers like the iPhone, Android, BlackBerry Storm, etc. that make links and buttons nicely finger-sized.</li>\n<li>Admin page to enable adding/editing the list of detected mobile and touch browsers.</li>\n<li>Compatible with the excellent WP SuperCache (latest version).</li>\n</ul>\n<p>This is a beta release as we&#8217;ve only done internal testing on the new version so far, so be sure to let us know if you run into any trouble with it.</p>\n<p>The download and more information are available on my <a href=\"http://alexking.org/projects/wordpress\">WordPress Plugins page</a>.</p>\n<p>If you have any trouble with this, please open a thread in the <a href=\"http://wordpress.org/support/\" rel=\"external\">WP Support Forums</a> and <a href=\"http://alexking.org/contact\">e-mail</a> me a link to the thread.</p>\n<p><a href=\"http://sharethis.com/item?&wp=2.2.3&amp;publisher=a1583af8-28eb-4210-97bd-2bb5c02bc265&amp;title=WordPress+Mobile+Edition+3.0b1&amp;url=http%3A%2F%2Falexking.org%2Fblog%2F2009%2F03%2F04%2Fwordpress-mobile-edition-30b1\">ShareThis</a></p>\";}i:45;a:7:{s:5:\"title\";s:60:\"Weblog Tools Collection: WordPress Plugin Releases for 03/04\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5252\";s:4:\"link\";s:88:\"http://weblogtoolscollection.com/archives/2009/03/04/wordpress-plugin-releases-for-0304/\";s:11:\"description\";s:4246:\"<h3>New Plugins</h3>\n<p><a href=\"http://justintadlock.com/archives/2009/03/03/widgets-reset-wordpress-plugin\">Widgets Reset</a></p>\n<p>Widgets Reset is a plugin that completely resets all of your WordPress widgets to the factory default. Basically, it wipes the slate completely clean. This plugin is ideal for people that lose widgets when they switch themes.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/zannel-tools/\">Zannel Tools</a></p>\n<p>A complete integration between your WordPress blog and Zannel. Bring your Zannel Updates into your blog and pass your blog posts back to Zannel.</p>\n<p><a href=\"http://blog.urosevic.net/wordpress/posts-per-cat/\">Posts per Cat</a></p>\n<p>List latests N article titles from all or top level only categories and group them in category boxes organized in two columns. <em>Page not in English</em></p>\n<p><a href=\"http://dev.iamntz.com/158/ntz-antispam-plugin\">NtzAntispam</a></p>\n<p>This plugin will block almost all spam comments. It use a very ingenious method to catch a bot: a new form element is inserted into your comment form.</p>\n<p><a href=\"http://blog.rswr.net/2009/03/02/hlogoz-logo-changer-wordpress-plugin/\">HLogoZ-WP</a></p>\n<p>Automatically changes your logo based on the date. Images and flash (swf files) supported.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/list-pages-shortcode/\">List Pages Shortcode</a></p>\n<p>Use [list-pages] and [child-pages] shortcodes for easily displaying a list of pages within a post or page.</p>\n<p><a href=\"http://deceblog.net/2009/03/add-drafts-wordpress-plugin/\">Add drafts</a></p>\n<p>Displays a box with the last 10 recent drafts in the edit post page.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/wp-plugin-data/\">WP Plugin Data</a></p>\n<p>Provides abstracted data about plugins using the WordPress.org API</p>\n<p><a href=\"http://wordpress.org/extend/plugins/wp-sifr/\">WP sIFR</a></p>\n<p>WP sIFR was created to remove the complications from getting custom fonts on a Wordpress site. With WP sIFR, you only have to upload your SWF font file to the plugin directory and then login, activate it, and configure its styles all in the Settings panel.</p>\n<h3>Updated Plugins</h3>\n<p><a href=\"http://ajaydsouza.com/wordpress/plugins/top-10/\">Top 10</a></p>\n<p>Top 10 will count the number of page views on your single posts on a daily as well as overall basis. You can then display the page view count on individual posts and pages as well as display a list of most popular posts based on page views. This version has adds support for tracking and display of daily popular posts.</p>\n<p><a href=\"http://www.gdstarrating.com/2009/03/02/gd-star-rating-116/\">GD Star Rating</a></p>\n<p>GD Star Rating is post, page and comment rating plugin for WordPress. Plugin supports different image sets, rating moderation, vote rules, time restricted voting, templates, trend calculations, has a widgets build in and shortcode support.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/wp-stats-dashboard/\">WP Stats Dashboard</a></p>\n<p>Displays the WordPress.com stats graph directly in your Dashboard. No more tiresomely opening the Blog Stats tab and manually logging in.</p>\n<p><a href=\"http://www.thaslayer.com/2009/03/03/ts-custom-widgets-v-20-sexier-than-ever/\">TS Custom Widgets v2.0</a></p>\n<p>This plugin enables you to select which widgets appear on specific posts, pages, categories,author’s posts and tag pages. By default, all widgets appear wherever the sidebar is loaded within your theme.</p>\n<p><a href=\"http://scribu.net/wordpress/custom-field-taxonomies\">Custom Field Taxonomies</a></p>\n<p>Use custom fields as ad-hoc taxonomies.</p>\n<p><a href=\"http://www.botproof.com/wordpress.html\">BotProof Captcha 2.0</a></p>\n<p>The plugin gives the next generation in captcha, BotProof Captcha 2.0, to a WordPress blog comment form.</p>\n<p><a href=\"http://www.mailpress.org/\">MailPress</a></p>\n<p>Allows you to send beautiful and styled html and plain text mails based on dedicated themes and templates.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/minimeta-widget/\">MiniMeta Widget</a></p>\n<p>&#8220;Mini&#8221; Version of the WordPress Meta Widget with differnt logon types (Form,Link) and additional Admin Links, Blog Links.</p>\";s:7:\"pubdate\";s:31:\"Wed, 04 Mar 2009 20:50:17 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:4246:\"<h3>New Plugins</h3>\n<p><a href=\"http://justintadlock.com/archives/2009/03/03/widgets-reset-wordpress-plugin\">Widgets Reset</a></p>\n<p>Widgets Reset is a plugin that completely resets all of your WordPress widgets to the factory default. Basically, it wipes the slate completely clean. This plugin is ideal for people that lose widgets when they switch themes.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/zannel-tools/\">Zannel Tools</a></p>\n<p>A complete integration between your WordPress blog and Zannel. Bring your Zannel Updates into your blog and pass your blog posts back to Zannel.</p>\n<p><a href=\"http://blog.urosevic.net/wordpress/posts-per-cat/\">Posts per Cat</a></p>\n<p>List latests N article titles from all or top level only categories and group them in category boxes organized in two columns. <em>Page not in English</em></p>\n<p><a href=\"http://dev.iamntz.com/158/ntz-antispam-plugin\">NtzAntispam</a></p>\n<p>This plugin will block almost all spam comments. It use a very ingenious method to catch a bot: a new form element is inserted into your comment form.</p>\n<p><a href=\"http://blog.rswr.net/2009/03/02/hlogoz-logo-changer-wordpress-plugin/\">HLogoZ-WP</a></p>\n<p>Automatically changes your logo based on the date. Images and flash (swf files) supported.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/list-pages-shortcode/\">List Pages Shortcode</a></p>\n<p>Use [list-pages] and [child-pages] shortcodes for easily displaying a list of pages within a post or page.</p>\n<p><a href=\"http://deceblog.net/2009/03/add-drafts-wordpress-plugin/\">Add drafts</a></p>\n<p>Displays a box with the last 10 recent drafts in the edit post page.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/wp-plugin-data/\">WP Plugin Data</a></p>\n<p>Provides abstracted data about plugins using the WordPress.org API</p>\n<p><a href=\"http://wordpress.org/extend/plugins/wp-sifr/\">WP sIFR</a></p>\n<p>WP sIFR was created to remove the complications from getting custom fonts on a Wordpress site. With WP sIFR, you only have to upload your SWF font file to the plugin directory and then login, activate it, and configure its styles all in the Settings panel.</p>\n<h3>Updated Plugins</h3>\n<p><a href=\"http://ajaydsouza.com/wordpress/plugins/top-10/\">Top 10</a></p>\n<p>Top 10 will count the number of page views on your single posts on a daily as well as overall basis. You can then display the page view count on individual posts and pages as well as display a list of most popular posts based on page views. This version has adds support for tracking and display of daily popular posts.</p>\n<p><a href=\"http://www.gdstarrating.com/2009/03/02/gd-star-rating-116/\">GD Star Rating</a></p>\n<p>GD Star Rating is post, page and comment rating plugin for WordPress. Plugin supports different image sets, rating moderation, vote rules, time restricted voting, templates, trend calculations, has a widgets build in and shortcode support.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/wp-stats-dashboard/\">WP Stats Dashboard</a></p>\n<p>Displays the WordPress.com stats graph directly in your Dashboard. No more tiresomely opening the Blog Stats tab and manually logging in.</p>\n<p><a href=\"http://www.thaslayer.com/2009/03/03/ts-custom-widgets-v-20-sexier-than-ever/\">TS Custom Widgets v2.0</a></p>\n<p>This plugin enables you to select which widgets appear on specific posts, pages, categories,author’s posts and tag pages. By default, all widgets appear wherever the sidebar is loaded within your theme.</p>\n<p><a href=\"http://scribu.net/wordpress/custom-field-taxonomies\">Custom Field Taxonomies</a></p>\n<p>Use custom fields as ad-hoc taxonomies.</p>\n<p><a href=\"http://www.botproof.com/wordpress.html\">BotProof Captcha 2.0</a></p>\n<p>The plugin gives the next generation in captcha, BotProof Captcha 2.0, to a WordPress blog comment form.</p>\n<p><a href=\"http://www.mailpress.org/\">MailPress</a></p>\n<p>Allows you to send beautiful and styled html and plain text mails based on dedicated themes and templates.</p>\n<p><a href=\"http://wordpress.org/extend/plugins/minimeta-widget/\">MiniMeta Widget</a></p>\n<p>&#8220;Mini&#8221; Version of the WordPress Meta Widget with differnt logon types (Form,Link) and additional Admin Links, Blog Links.</p>\";}i:46;a:7:{s:5:\"title\";s:27:\"Matt: Open Source Usability\";s:4:\"guid\";s:21:\"http://ma.tt/?p=12057\";s:4:\"link\";s:45:\"http://ma.tt/2009/03/open-source-usability-3/\";s:11:\"description\";s:372:\"<p><a href=\"http://developers.slashdot.org/article.pl?sid=09/03/03/0152241&amp;from=rss\">Open Source Usability — Joomla! Vs. WordPress</a>. We&#8217;re on Slashdot again, with of course the predictable comments somehow ending up in an argument about Vim and Emacs. <img src=\"http://ma.tt/blog/wp-includes/images/smilies/icon_smile.gif\" alt=\":)\" class=\"wp-smiley\" /> </p>\";s:7:\"pubdate\";s:31:\"Tue, 03 Mar 2009 22:28:22 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Matt\";}s:7:\"summary\";s:372:\"<p><a href=\"http://developers.slashdot.org/article.pl?sid=09/03/03/0152241&amp;from=rss\">Open Source Usability — Joomla! Vs. WordPress</a>. We&#8217;re on Slashdot again, with of course the predictable comments somehow ending up in an argument about Vim and Emacs. <img src=\"http://ma.tt/blog/wp-includes/images/smilies/icon_smile.gif\" alt=\":)\" class=\"wp-smiley\" /> </p>\";}i:47;a:7:{s:5:\"title\";s:59:\"Weblog Tools Collection: WordPress Theme Releases for 03/03\";s:4:\"guid\";s:40:\"http://weblogtoolscollection.com/?p=5250\";s:4:\"link\";s:87:\"http://weblogtoolscollection.com/archives/2009/03/03/wordpress-theme-releases-for-0303/\";s:11:\"description\";s:1631:\"<p><a href=\"http://www.harrr.org/rrr/admiral-theme/\">Admiral</a></p>\n<p><a href=\"http://www.harrr.org/rrr/admiral-theme/\"><img title=\"Admiral\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/admiral.jpg\" alt=\"Admiral\" width=\"150\" height=\"150\" /></a></p>\n<p>Two column, widget and gravatar ready theme, with detection of visitors from search engines</p>\n<p><a href=\"http://copacetix.com/\">Copacetix</a></p>\n<p><img title=\"Copacetix\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/copacetix.gif\" alt=\"Copacetix\" width=\"150\" height=\"95\" /></p>\n<p>This theme features Widgets, a clean readable css file, and printer friendly style sheet, variable title tags, multiple layouts, random homepage photos, minimal images to load, h1 titles on pages and posts, and many other specific things that I think make up a usable WordPress theme.</p>\n<p><a href=\"http://themeshaper.com/thematic-for-wordpress/\">The Thematic Theme Framework</a></p>\n<p><img title=\"Thematic\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/thematic.jpg\" alt=\"Thematic\" width=\"150\" height=\"92\" /></p>\n<p>Thematic is a WordPress Theme Framework perfect for the beginner blogger and experienced developers looking for a solid design platform. Version 0.9 is a complete re-think of the front end and a major refinement of the back end. 13 Widget ready areas (with options for more). It supports gravatars, threaded comments, and sticky posts. There’s a simple Theme Options page. And layout possibilities for 1, 2 or 3-column layouts.</p>\n<p>Are you a theme author? <a href=\"http://weblogtoolscollection.com/submit-news/\">Submit your theme</a> to us.</p>\";s:7:\"pubdate\";s:31:\"Tue, 03 Mar 2009 18:27:17 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:4:\"Ajay\";}s:7:\"summary\";s:1631:\"<p><a href=\"http://www.harrr.org/rrr/admiral-theme/\">Admiral</a></p>\n<p><a href=\"http://www.harrr.org/rrr/admiral-theme/\"><img title=\"Admiral\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/admiral.jpg\" alt=\"Admiral\" width=\"150\" height=\"150\" /></a></p>\n<p>Two column, widget and gravatar ready theme, with detection of visitors from search engines</p>\n<p><a href=\"http://copacetix.com/\">Copacetix</a></p>\n<p><img title=\"Copacetix\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/copacetix.gif\" alt=\"Copacetix\" width=\"150\" height=\"95\" /></p>\n<p>This theme features Widgets, a clean readable css file, and printer friendly style sheet, variable title tags, multiple layouts, random homepage photos, minimal images to load, h1 titles on pages and posts, and many other specific things that I think make up a usable WordPress theme.</p>\n<p><a href=\"http://themeshaper.com/thematic-for-wordpress/\">The Thematic Theme Framework</a></p>\n<p><img title=\"Thematic\" src=\"http://weblogtoolscollection.com/b2-img/2009/03/thematic.jpg\" alt=\"Thematic\" width=\"150\" height=\"92\" /></p>\n<p>Thematic is a WordPress Theme Framework perfect for the beginner blogger and experienced developers looking for a solid design platform. Version 0.9 is a complete re-think of the front end and a major refinement of the back end. 13 Widget ready areas (with options for more). It supports gravatars, threaded comments, and sticky posts. There’s a simple Theme Options page. And layout possibilities for 1, 2 or 3-column layouts.</p>\n<p>Are you a theme author? <a href=\"http://weblogtoolscollection.com/submit-news/\">Submit your theme</a> to us.</p>\";}i:48;a:7:{s:5:\"title\";s:51:\"Ping-O-Matic: Ping-o-matic has received a makeover!\";s:4:\"guid\";s:32:\"http://blog.pingomatic.com/?p=15\";s:4:\"link\";s:75:\"http://blog.pingomatic.com/2009/03/03/ping-o-matic-has-received-a-makeover/\";s:11:\"description\";s:3023:\"<div class=\"snap_preview\"><br /><p>Dear Ping-o-matic users, I&#8217;m Isaac from Automattic. It was a while since anyone wrote on this blog, and I thought I&#8217;d fill you in on what&#8217;s been going on lately.</p>\n<p>I&#8217;ve just performed a redesign on the Ping-o-matic website. The new look was launched a few weeks ago, and is meant to increase the usability of the service and make it look a bit more modern and well fitted for the WordPress/Automattic family.</p>\n<p>For newcomers, there&#8217;s now a welcome message on top of the front page which gives you a Ping-o-matic crash course. Below this, you&#8217;ll find the familiar pinging form where you supply your blog details and select the services you want ping. The whole form has been redesigned to stand out more from the rest of the content on the page, making it easier to see how it all fits together. The vertical space for the services list has been compressed. This list took up a big chunk of the screen before, but has now been compressed to 4 columns which saves a lot of space. &#8230;And the action button is now bigger than ever, so you can&#8217;t possibly miss it!</p>\n<p>As for the Stats page, it&#8217;s received a minor update. The graph has been modified to fit with the new color scheme of Ping-o-matic.</p>\n<p>The spirit behind the redesign was to give Ping-o-matic a graphical profile on it&#8217;s own, with bold colors that makes the service memorable. I also wanted to make it better tied in to the WordPress/Automattic family&#8217;s graphical profile and user interface ideas. You&#8217;ll notice similar fonts, navigation solutions and a fancy looking footer, as well as a good deal of &#8220;under the hood&#8221; similarities. Among those are the uses of CSS3 rules like border-radius, which gives people browsing Ping-o-matic in modern browsers a richer (and rounder!) experience.</p>\n  <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/pingomatic.wordpress.com/15/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/pingomatic.wordpress.com/15/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/pingomatic.wordpress.com/15/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/pingomatic.wordpress.com/15/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/pingomatic.wordpress.com/15/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/pingomatic.wordpress.com/15/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/pingomatic.wordpress.com/15/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/pingomatic.wordpress.com/15/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/pingomatic.wordpress.com/15/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/pingomatic.wordpress.com/15/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=blog.pingomatic.com&blog=68432&post=15&subd=pingomatic&ref=&feed=1\" /></div>\";s:7:\"pubdate\";s:31:\"Tue, 03 Mar 2009 12:00:20 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:5:\"Isaac\";}s:7:\"summary\";s:3023:\"<div class=\"snap_preview\"><br /><p>Dear Ping-o-matic users, I&#8217;m Isaac from Automattic. It was a while since anyone wrote on this blog, and I thought I&#8217;d fill you in on what&#8217;s been going on lately.</p>\n<p>I&#8217;ve just performed a redesign on the Ping-o-matic website. The new look was launched a few weeks ago, and is meant to increase the usability of the service and make it look a bit more modern and well fitted for the WordPress/Automattic family.</p>\n<p>For newcomers, there&#8217;s now a welcome message on top of the front page which gives you a Ping-o-matic crash course. Below this, you&#8217;ll find the familiar pinging form where you supply your blog details and select the services you want ping. The whole form has been redesigned to stand out more from the rest of the content on the page, making it easier to see how it all fits together. The vertical space for the services list has been compressed. This list took up a big chunk of the screen before, but has now been compressed to 4 columns which saves a lot of space. &#8230;And the action button is now bigger than ever, so you can&#8217;t possibly miss it!</p>\n<p>As for the Stats page, it&#8217;s received a minor update. The graph has been modified to fit with the new color scheme of Ping-o-matic.</p>\n<p>The spirit behind the redesign was to give Ping-o-matic a graphical profile on it&#8217;s own, with bold colors that makes the service memorable. I also wanted to make it better tied in to the WordPress/Automattic family&#8217;s graphical profile and user interface ideas. You&#8217;ll notice similar fonts, navigation solutions and a fancy looking footer, as well as a good deal of &#8220;under the hood&#8221; similarities. Among those are the uses of CSS3 rules like border-radius, which gives people browsing Ping-o-matic in modern browsers a richer (and rounder!) experience.</p>\n  <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gocomments/pingomatic.wordpress.com/15/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/comments/pingomatic.wordpress.com/15/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godelicious/pingomatic.wordpress.com/15/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/delicious/pingomatic.wordpress.com/15/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/gostumble/pingomatic.wordpress.com/15/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/stumble/pingomatic.wordpress.com/15/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/godigg/pingomatic.wordpress.com/15/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/digg/pingomatic.wordpress.com/15/\" /></a> <a rel=\"nofollow\" href=\"http://feeds.wordpress.com/1.0/goreddit/pingomatic.wordpress.com/15/\"><img alt=\"\" border=\"0\" src=\"http://feeds.wordpress.com/1.0/reddit/pingomatic.wordpress.com/15/\" /></a> <img alt=\"\" border=\"0\" src=\"http://stats.wordpress.com/b.gif?host=blog.pingomatic.com&blog=68432&post=15&subd=pingomatic&ref=&feed=1\" /></div>\";}i:49;a:7:{s:5:\"title\";s:47:\"Dougal Campbell: The Future of WordPress Themes\";s:4:\"guid\";s:33:\"http://dougal.gunters.org/?p=1468\";s:4:\"link\";s:72:\"http://dougal.gunters.org/blog/2009/03/02/the-future-of-wordpress-themes\";s:11:\"description\";s:942:\"<p><img class=\"alignright size-thumbnail wp-image-1222\" title=\"WordPress\" src=\"http://dougal.gunters.org/wordpress/wp-content/uploads/2008/11/wplogo-notext-rgb-150x150.png\" alt=\"WordPress\" width=\"150\" height=\"150\" /></p>\n<p>A couple of months ago, Ian Stewart asked me to be one of the voices for this year&#8217;s roundup on <a href=\"http://themeshaper.com/future-wordpress-themes-2009/\">The Future of WordPress Themes 2009</a>. There were a variety of angles from which to look at the subject, so it&#8217;s interesting to see how everyone interpreted the question.</p>\n<p>There are discussions about &#8220;Premium&#8221; themes and the <acronym title=\"Gnu General Public License\"><span class=\"caps\">GPL</span></acronym>, about whether plugin functionality belongs in themes, and about seperation of presentation and content, among other things. Give it a read to learn what I (and 14 other WordPress community influencers) had to say.</p>\";s:7:\"pubdate\";s:31:\"Mon, 02 Mar 2009 21:21:04 +0000\";s:2:\"dc\";a:1:{s:7:\"creator\";s:6:\"Dougal\";}s:7:\"summary\";s:942:\"<p><img class=\"alignright size-thumbnail wp-image-1222\" title=\"WordPress\" src=\"http://dougal.gunters.org/wordpress/wp-content/uploads/2008/11/wplogo-notext-rgb-150x150.png\" alt=\"WordPress\" width=\"150\" height=\"150\" /></p>\n<p>A couple of months ago, Ian Stewart asked me to be one of the voices for this year&#8217;s roundup on <a href=\"http://themeshaper.com/future-wordpress-themes-2009/\">The Future of WordPress Themes 2009</a>. There were a variety of angles from which to look at the subject, so it&#8217;s interesting to see how everyone interpreted the question.</p>\n<p>There are discussions about &#8220;Premium&#8221; themes and the <acronym title=\"Gnu General Public License\"><span class=\"caps\">GPL</span></acronym>, about whether plugin functionality belongs in themes, and about seperation of presentation and content, among other things. Give it a read to learn what I (and 14 other WordPress community influencers) had to say.</p>\";}}s:7:\"channel\";a:5:{s:5:\"title\";s:16:\"WordPress Planet\";s:4:\"link\";s:28:\"http://planet.wordpress.org/\";s:8:\"language\";s:2:\"en\";s:11:\"description\";s:47:\"WordPress Planet - http://planet.wordpress.org/\";s:7:\"tagline\";s:47:\"WordPress Planet - http://planet.wordpress.org/\";}s:9:\"textinput\";a:0:{}s:5:\"image\";a:0:{}s:9:\"feed_type\";s:3:\"RSS\";s:12:\"feed_version\";s:3:\"2.0\";s:5:\"stack\";a:0:{}s:9:\"inchannel\";b:0;s:6:\"initem\";b:0;s:9:\"incontent\";b:0;s:11:\"intextinput\";b:0;s:7:\"inimage\";b:0;s:13:\"current_field\";s:0:\"\";s:17:\"current_namespace\";b:0;s:19:\"_CONTENT_CONSTRUCTS\";a:6:{i:0;s:7:\"content\";i:1;s:7:\"summary\";i:2;s:4:\"info\";i:3;s:5:\"title\";i:4;s:7:\"tagline\";i:5;s:9:\"copyright\";}s:4:\"etag\";s:25:\"\"544de-49c35eaa-17429c\"\r\n\";s:13:\"last_modified\";s:31:\"Fri, 20 Mar 2009 09:15:22 GMT\r\n\";}','no'),(117,0,'rss_867bd5c64f85878d03a060509cd2f92c_ts','1237540699','no'),(267,0,'A2A_SHARE_SAVE_button_text','Share/Save','yes'),(268,0,'A2A_SHARE_SAVE_additional_js_variables','','yes'),(269,0,'feedsmith_token','427875a39755408e25d860de66a69246','yes'),(190,0,'wordpress_api_key','b83ceaf13fa4','yes'),(191,0,'akismet_discard_month','true','yes'),(265,0,'A2A_SHARE_SAVE_button','share_save_120_16.png|120|16','yes'),(266,0,'A2A_SHARE_SAVE_button_custom','','yes'),(258,0,'A2A_SHARE_SAVE_display_in_posts','1','yes'),(259,0,'A2A_SHARE_SAVE_display_in_pages','1','yes'),(260,0,'A2A_SHARE_SAVE_display_in_feed','1','yes'),(261,0,'A2A_SHARE_SAVE_hide_embeds','1','yes'),(262,0,'A2A_SHARE_SAVE_show_title','1','yes'),(263,0,'A2A_SHARE_SAVE_onclick','1','yes'),(264,0,'A2A_SHARE_SAVE_button_opens_new_window','-1','yes'),(212,0,'akismet_spam_count','1','yes'),(257,0,'A2A_SHARE_SAVE_display_in_posts_on_front_page','1','yes'),(251,0,'sm_status','O:28:\"GoogleSitemapGeneratorStatus\":34:{s:10:\"_startTime\";d:1232186482.941638946533203125;s:8:\"_endTime\";d:1232186483.6158440113067626953125;s:11:\"_hasChanged\";b:1;s:12:\"_memoryUsage\";i:14155776;s:9:\"_lastPost\";i:24;s:9:\"_lastTime\";d:1232186482.999946117401123046875;s:8:\"_usedXml\";b:1;s:11:\"_xmlSuccess\";b:1;s:8:\"_xmlPath\";s:38:\"/home/moztroni/public_html/sitemap.xml\";s:7:\"_xmlUrl\";s:36:\"http://moztronics.com.au/sitemap.xml\";s:8:\"_usedZip\";b:1;s:11:\"_zipSuccess\";b:1;s:8:\"_zipPath\";s:41:\"/home/moztroni/public_html/sitemap.xml.gz\";s:7:\"_zipUrl\";s:39:\"http://moztronics.com.au/sitemap.xml.gz\";s:11:\"_usedGoogle\";b:1;s:10:\"_googleUrl\";b:1;s:15:\"_gooogleSuccess\";b:1;s:16:\"_googleStartTime\";d:1232186483.0038890838623046875;s:14:\"_googleEndTime\";d:1232186483.1337718963623046875;s:10:\"_usedYahoo\";b:0;s:9:\"_yahooUrl\";s:0:\"\";s:13:\"_yahooSuccess\";b:0;s:15:\"_yahooStartTime\";i:0;s:13:\"_yahooEndTime\";i:0;s:8:\"_usedAsk\";b:1;s:7:\"_askUrl\";s:87:\"http://submissions.ask.com/ping?sitemap=http%3A%2F%2Fmoztronics.com.au%2Fsitemap.xml.gz\";s:11:\"_askSuccess\";b:1;s:13:\"_askStartTime\";d:1232186483.13533496856689453125;s:11:\"_askEndTime\";d:1232186483.5589349269866943359375;s:8:\"_usedMsn\";b:1;s:7:\"_msnUrl\";s:91:\"http://webmaster.live.com/ping.aspx?siteMap=http%3A%2F%2Fmoztronics.com.au%2Fsitemap.xml.gz\";s:11:\"_msnSuccess\";b:1;s:13:\"_msnStartTime\";d:1232186483.5603649616241455078125;s:11:\"_msnEndTime\";d:1232186483.6147439479827880859375;}','no'),(247,0,'sm_options','a:55:{s:18:\"sm_b_prio_provider\";s:41:\"GoogleSitemapGeneratorPrioByCountProvider\";s:13:\"sm_b_filename\";s:11:\"sitemap.xml\";s:10:\"sm_b_debug\";b:1;s:8:\"sm_b_xml\";b:1;s:9:\"sm_b_gzip\";b:1;s:9:\"sm_b_ping\";b:1;s:14:\"sm_b_pingyahoo\";b:0;s:13:\"sm_b_yahookey\";s:0:\"\";s:12:\"sm_b_pingask\";b:1;s:12:\"sm_b_pingmsn\";b:1;s:19:\"sm_b_manual_enabled\";b:0;s:17:\"sm_b_auto_enabled\";b:1;s:15:\"sm_b_auto_delay\";b:1;s:15:\"sm_b_manual_key\";s:32:\"500e661450ac31f592573e35250812ce\";s:11:\"sm_b_memory\";s:0:\"\";s:9:\"sm_b_time\";i:-1;s:14:\"sm_b_max_posts\";i:-1;s:13:\"sm_b_safemode\";b:0;s:18:\"sm_b_style_default\";b:1;s:10:\"sm_b_style\";s:0:\"\";s:11:\"sm_b_robots\";b:1;s:12:\"sm_b_exclude\";a:0:{}s:17:\"sm_b_exclude_cats\";a:0:{}s:18:\"sm_b_location_mode\";s:4:\"auto\";s:20:\"sm_b_filename_manual\";s:0:\"\";s:19:\"sm_b_fileurl_manual\";s:0:\"\";s:10:\"sm_in_home\";b:1;s:11:\"sm_in_posts\";b:1;s:15:\"sm_in_posts_sub\";b:0;s:11:\"sm_in_pages\";b:1;s:10:\"sm_in_cats\";b:0;s:10:\"sm_in_arch\";b:0;s:10:\"sm_in_auth\";b:0;s:10:\"sm_in_tags\";b:0;s:10:\"sm_cf_home\";s:5:\"daily\";s:11:\"sm_cf_posts\";s:7:\"monthly\";s:11:\"sm_cf_pages\";s:6:\"weekly\";s:10:\"sm_cf_cats\";s:6:\"weekly\";s:10:\"sm_cf_auth\";s:6:\"weekly\";s:15:\"sm_cf_arch_curr\";s:5:\"daily\";s:14:\"sm_cf_arch_old\";s:6:\"yearly\";s:10:\"sm_cf_tags\";s:6:\"weekly\";s:10:\"sm_pr_home\";d:1;s:11:\"sm_pr_posts\";d:0.59999999999999997779553950749686919152736663818359375;s:15:\"sm_pr_posts_min\";d:0.200000000000000011102230246251565404236316680908203125;s:11:\"sm_pr_pages\";d:0.59999999999999997779553950749686919152736663818359375;s:10:\"sm_pr_cats\";d:0.299999999999999988897769753748434595763683319091796875;s:10:\"sm_pr_arch\";d:0.299999999999999988897769753748434595763683319091796875;s:10:\"sm_pr_auth\";d:0.299999999999999988897769753748434595763683319091796875;s:10:\"sm_pr_tags\";d:0.299999999999999988897769753748434595763683319091796875;s:12:\"sm_i_donated\";b:0;s:17:\"sm_i_hide_donated\";b:0;s:17:\"sm_i_install_date\";i:1231830096;s:14:\"sm_i_hide_note\";b:0;s:16:\"sm_i_hide_donors\";b:0;}','yes'),(236,0,'update_plugins','O:8:\"stdClass\":3:{s:12:\"last_checked\";i:1237507057;s:7:\"checked\";a:20:{s:25:\"add-to-any/add-to-any.php\";s:6:\".9.8.7\";s:19:\"akismet/akismet.php\";s:5:\"2.2.1\";s:43:\"all-in-one-seo-pack/all_in_one_seo_pack.php\";s:8:\"1.4.6.16\";s:17:\"cforms/cforms.php\";s:4:\"10.0\";s:36:\"contact-form-7/wp-contact-form-7.php\";s:5:\"1.9.1\";s:63:\"feedburner_feedsmith_plugin_2.3/FeedBurner_FeedSmith_Plugin.php\";s:5:\"2.3.1\";s:29:\"feedstats-de/feedstats-de.php\";s:5:\"3.7.2\";s:43:\"google-analyticator/google-analyticator.php\";s:3:\"2.3\";s:50:\"google-analytics-for-wordpress/googleanalytics.php\";s:3:\"2.7\";s:36:\"google-sitemap-generator/sitemap.php\";s:5:\"3.1.2\";s:24:\"headspace2/headspace.php\";s:5:\"3.6.9\";s:9:\"hello.php\";s:3:\"1.5\";s:29:\"nextgen-gallery/nggallery.php\";s:5:\"1.0.2\";s:41:\"popularity-contest/popularity-contest.php\";s:5:\"1.3b3\";s:24:\"share-this/sharethis.php\";s:3:\"2.3\";s:30:\"smart-youtube/smartyoutube.php\";s:5:\"2.7.2\";s:31:\"twitter-tools/twitter-tools.php\";s:6:\"1.5.1a\";s:15:\"stats/stats.php\";s:5:\"1.3.5\";s:25:\"wp-cumulus/wp-cumulus.php\";s:4:\"1.13\";s:27:\"wp-pagenavi/wp-pagenavi.php\";s:4:\"2.40\";}s:8:\"response\";a:10:{s:25:\"add-to-any/add-to-any.php\";O:8:\"stdClass\":5:{s:2:\"id\";s:3:\"429\";s:4:\"slug\";s:10:\"add-to-any\";s:11:\"new_version\";s:8:\".9.8.9.2\";s:3:\"url\";s:47:\"http://wordpress.org/extend/plugins/add-to-any/\";s:7:\"package\";s:62:\"http://downloads.wordpress.org/plugin/add-to-any.0.9.8.9.2.zip\";}s:19:\"akismet/akismet.php\";O:8:\"stdClass\":5:{s:2:\"id\";s:2:\"15\";s:4:\"slug\";s:7:\"akismet\";s:11:\"new_version\";s:5:\"2.2.3\";s:3:\"url\";s:44:\"http://wordpress.org/extend/plugins/akismet/\";s:7:\"package\";s:49:\"http://downloads.wordpress.org/plugin/akismet.zip\";}s:43:\"all-in-one-seo-pack/all_in_one_seo_pack.php\";O:8:\"stdClass\":5:{s:2:\"id\";s:3:\"520\";s:4:\"slug\";s:19:\"all-in-one-seo-pack\";s:11:\"new_version\";s:7:\"1.4.7.4\";s:3:\"url\";s:56:\"http://wordpress.org/extend/plugins/all-in-one-seo-pack/\";s:7:\"package\";s:61:\"http://downloads.wordpress.org/plugin/all-in-one-seo-pack.zip\";}s:36:\"contact-form-7/wp-contact-form-7.php\";O:8:\"stdClass\":5:{s:2:\"id\";s:3:\"790\";s:4:\"slug\";s:14:\"contact-form-7\";s:11:\"new_version\";s:5:\"1.9.3\";s:3:\"url\";s:51:\"http://wordpress.org/extend/plugins/contact-form-7/\";s:7:\"package\";s:62:\"http://downloads.wordpress.org/plugin/contact-form-7.1.9.3.zip\";}s:43:\"google-analyticator/google-analyticator.php\";O:8:\"stdClass\":5:{s:2:\"id\";s:3:\"130\";s:4:\"slug\";s:19:\"google-analyticator\";s:11:\"new_version\";s:4:\"2.40\";s:3:\"url\";s:56:\"http://wordpress.org/extend/plugins/google-analyticator/\";s:7:\"package\";s:66:\"http://downloads.wordpress.org/plugin/google-analyticator.2.40.zip\";}s:50:\"google-analytics-for-wordpress/googleanalytics.php\";O:8:\"stdClass\":5:{s:2:\"id\";s:3:\"965\";s:4:\"slug\";s:30:\"google-analytics-for-wordpress\";s:11:\"new_version\";s:3:\"2.9\";s:3:\"url\";s:67:\"http://wordpress.org/extend/plugins/google-analytics-for-wordpress/\";s:7:\"package\";s:76:\"http://downloads.wordpress.org/plugin/google-analytics-for-wordpress.2.9.zip\";}s:30:\"smart-youtube/smartyoutube.php\";O:8:\"stdClass\":5:{s:2:\"id\";s:4:\"1584\";s:4:\"slug\";s:13:\"smart-youtube\";s:11:\"new_version\";s:5:\"2.8.1\";s:3:\"url\";s:50:\"http://wordpress.org/extend/plugins/smart-youtube/\";s:7:\"package\";s:55:\"http://downloads.wordpress.org/plugin/smart-youtube.zip\";}s:31:\"twitter-tools/twitter-tools.php\";O:8:\"stdClass\":5:{s:2:\"id\";s:3:\"313\";s:4:\"slug\";s:13:\"twitter-tools\";s:11:\"new_version\";s:3:\"1.6\";s:3:\"url\";s:50:\"http://wordpress.org/extend/plugins/twitter-tools/\";s:7:\"package\";s:59:\"http://downloads.wordpress.org/plugin/twitter-tools.1.6.zip\";}s:15:\"stats/stats.php\";O:8:\"stdClass\":5:{s:2:\"id\";s:3:\"626\";s:4:\"slug\";s:5:\"stats\";s:11:\"new_version\";s:5:\"1.3.7\";s:3:\"url\";s:42:\"http://wordpress.org/extend/plugins/stats/\";s:7:\"package\";s:53:\"http://downloads.wordpress.org/plugin/stats.1.3.7.zip\";}s:25:\"wp-cumulus/wp-cumulus.php\";O:8:\"stdClass\":5:{s:2:\"id\";s:4:\"4210\";s:4:\"slug\";s:10:\"wp-cumulus\";s:11:\"new_version\";s:4:\"1.20\";s:3:\"url\";s:47:\"http://wordpress.org/extend/plugins/wp-cumulus/\";s:7:\"package\";s:57:\"http://downloads.wordpress.org/plugin/wp-cumulus.1.20.zip\";}}}','yes'),(221,0,'feedburner_settings','a:2:{s:14:\"feedburner_url\";s:35:\"http://moztronics.com.au/?feed=rss2\";s:23:\"feedburner_comments_url\";s:0:\"\";}','yes'),(222,0,'pagenavi_options','a:12:{s:10:\"pages_text\";s:36:\"Page %CURRENT_PAGE% of %TOTAL_PAGES%\";s:12:\"current_text\";s:13:\"%PAGE_NUMBER%\";s:9:\"page_text\";s:13:\"%PAGE_NUMBER%\";s:10:\"first_text\";s:13:\"&laquo; First\";s:9:\"last_text\";s:12:\"Last &raquo;\";s:9:\"next_text\";s:7:\"&raquo;\";s:9:\"prev_text\";s:7:\"&laquo;\";s:13:\"dotright_text\";s:3:\"...\";s:12:\"dotleft_text\";s:3:\"...\";s:5:\"style\";i:1;s:9:\"num_pages\";i:5;s:11:\"always_show\";i:0;}','yes'),(233,0,'recently_activated','a:9:{s:25:\"add-to-any/add-to-any.php\";i:1237541068;s:19:\"akismet/akismet.php\";i:1237541068;s:63:\"feedburner_feedsmith_plugin_2.3/FeedBurner_FeedSmith_Plugin.php\";i:1237541068;s:43:\"google-analyticator/google-analyticator.php\";i:1237541068;s:36:\"google-sitemap-generator/sitemap.php\";i:1237541068;s:30:\"smart-youtube/smartyoutube.php\";i:1237541068;s:15:\"stats/stats.php\";i:1237541068;s:25:\"wp-cumulus/wp-cumulus.php\";i:1237541068;s:27:\"wp-pagenavi/wp-pagenavi.php\";i:1237541068;}','yes'),(223,0,'smart_yt_posts','on','yes'),(224,0,'smart_yt_width','425','yes'),(225,0,'smart_yt_height','355','yes'),(226,0,'smart_yt_widthhq','480','yes'),(227,0,'smart_yt_heighthq','360','yes'),(228,0,'smart_yt_rel','1','yes'),(229,0,'smart_yt_color','blank','yes'),(230,0,'smart_yt_link','on','yes'),(231,0,'smart_yt_valid','off','yes'),(232,0,'smart_yt_search','off','yes'),(235,0,'cforms_settings','a:2:{s:6:\"global\";a:43:{s:9:\"plugindir\";s:6:\"cforms\";s:11:\"cforms_root\";s:50:\"http://moztronics.com.au/wp-content/plugins/cforms\";s:7:\"tinyURI\";s:47:\"http://moztronics.com.au/wp-includes/js/tinymce\";s:15:\"cforms_root_dir\";s:52:\"/home/moztroni/public_html/wp-content/plugins/cforms\";s:10:\"cforms_IIS\";s:1:\"/\";s:18:\"cforms_style_title\";s:69:\"font:normal 0.8em Verdana; text-align:right; color:#777; margin:3px 0\";s:18:\"cforms_style_table\";s:67:\"background:#F4F5FB; color:#666; font-size:1em; font-family:verdana;\";s:18:\"cforms_style_fs_td\";s:138:\"font-size:105%; font-variant:small-caps; letter-spacing:2px; border-bottom:2px solid #E6E8F7; padding:6px 2px 6px 4px; background:#EFF0FA;\";s:21:\"cforms_style_fsend_td\";s:63:\"background:#E6E8F7; font-size:0px; line-height:2px; height:2px;\";s:23:\"cforms_style_fsendSP_td\";s:43:\"font-size:0px; line-height:2px; height:4px;\";s:19:\"cforms_style_key_td\";s:93:\"color:#000; font-size:90%; white-space:nowrap; padding:4px 20px 4px 15px; vertical-align:top;\";s:19:\"cforms_style_val_td\";s:26:\"font-size:90%; width:100%;\";s:19:\"cforms_style_cforms\";s:35:\"font:normal 10px Arial; color:#777;\";s:16:\"cforms_formcount\";s:1:\"1\";s:18:\"cforms_upload_err1\";s:43:\"Generic file upload error. Please try again\";s:18:\"cforms_upload_err2\";s:56:\"File is empty. Please upload something more substantial.\";s:18:\"cforms_upload_err3\";s:55:\"Sorry, file is too large. You may try to zip your file.\";s:18:\"cforms_upload_err4\";s:63:\"File upload failed. Please try again or contact the blog admin.\";s:18:\"cforms_upload_err5\";s:41:\"File not accepted, file type not allowed.\";s:16:\"cforms_rsskeyall\";s:32:\"421e1fa51d83d3d92ea33a7a986c9146\";s:13:\"cforms_rssall\";b:0;s:19:\"cforms_rssall_count\";i:5;s:18:\"cforms_captcha_def\";a:14:{s:1:\"h\";i:25;s:1:\"w\";i:115;s:1:\"c\";s:6:\"000066\";s:1:\"l\";s:6:\"000066\";s:1:\"f\";s:9:\"font4.ttf\";s:2:\"a1\";i:-12;s:2:\"a2\";i:12;s:2:\"f1\";i:17;s:2:\"f2\";i:19;s:2:\"bg\";s:5:\"1.gif\";s:2:\"c1\";i:4;s:2:\"c2\";i:5;s:2:\"ac\";s:32:\"abcdefghijkmnpqrstuvwxyz23456789\";s:1:\"i\";s:1:\"i\";}s:13:\"cforms_sec_qa\";s:82:\"What color is snow?=white\r\nThe color of grass is=green\r\nTen minus five equals=five\";s:14:\"cforms_codeerr\";s:43:\"Please double-check your verification code.\";s:20:\"cforms_show_quicktag\";s:1:\"1\";s:23:\"cforms_show_quicktag_js\";b:0;s:21:\"cforms_commentsuccess\";s:32:\"Thank you for leaving a comment.\";s:18:\"cforms_commentWait\";s:2:\"15\";s:20:\"cforms_commentParent\";s:13:\"mycommentlist\";s:18:\"cforms_commentHTML\";s:199:\"<li id=\"comment-{id}\">{moderation}\n<p>{usercomment}</p>\n<p>\n<cite>Comment by <a href=\"{url}\" rel=\"external nofollow\">{author}</a> &mdash; {date} @ <a href=\"#comment-{id}\">{time}</a></cite>\n</p>\n</li>\";s:19:\"cforms_commentInMod\";s:45:\"<em>Your comment is awaiting moderation.</em>\";s:13:\"cforms_avatar\";s:2:\"32\";s:10:\"cforms_css\";s:10:\"cforms.css\";s:14:\"cforms_labelID\";s:1:\"0\";s:11:\"cforms_liID\";s:1:\"0\";s:15:\"cforms_database\";s:1:\"0\";s:17:\"cforms_datepicker\";s:1:\"0\";s:15:\"cforms_dp_start\";s:1:\"0\";s:14:\"cforms_dp_date\";s:10:\"MM/dd/yyyy\";s:14:\"cforms_dp_days\";s:27:\"\"S\",\"M\",\"T\",\"W\",\"T\",\"F\",\"S\"\";s:16:\"cforms_dp_months\";s:109:\"\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"\";s:13:\"cforms_dp_nav\";a:6:{i:0;s:13:\"Previous Year\";i:1;s:14:\"Previous Month\";i:2;s:9:\"Next Year\";i:3;s:10:\"Next Month\";i:4;s:5:\"Close\";i:5;s:11:\"Choose Date\";}}s:4:\"form\";a:50:{s:17:\"cforms_upload_dir\";s:55:\"/home/moztroni/public_html/wp-content/plugins/cforms$#$\";s:17:\"cforms_upload_ext\";s:19:\"txt,zip,doc,rtf,xls\";s:18:\"cforms_upload_size\";s:4:\"1024\";s:16:\"cforms_dontclear\";b:0;s:13:\"cforms_rsskey\";s:32:\"edde3823741ef12a9c60aa744645a786\";s:10:\"cforms_rss\";b:0;s:16:\"cforms_rss_count\";N;s:19:\"cforms_count_fields\";i:5;s:20:\"cforms_count_field_1\";s:43:\"My Fieldset$#$fieldsetstart$#$0$#$0$#$0$#$0\";s:20:\"cforms_count_field_2\";s:47:\"Your Name|Your Name$#$textfield$#$1$#$0$#$1$#$0\";s:20:\"cforms_count_field_3\";s:33:\"Email$#$textfield$#$1$#$1$#$0$#$0\";s:20:\"cforms_count_field_4\";s:43:\"Website|http://$#$textfield$#$0$#$0$#$0$#$0\";s:20:\"cforms_count_field_5\";s:34:\"Message$#$textarea$#$0$#$0$#$0$#$0\";s:15:\"cforms_required\";s:10:\"(required)\";s:20:\"cforms_emailrequired\";s:22:\"(valid email required)\";s:14:\"cforms_confirm\";s:1:\"0\";s:11:\"cforms_ajax\";s:1:\"1\";s:12:\"cforms_fname\";s:12:\"Contact Form\";s:15:\"cforms_csubject\";s:28:\"$#$Re: Submitted form (copy)\";s:11:\"cforms_cmsg\";s:0:\"\";s:16:\"cforms_cmsg_html\";s:0:\"\";s:12:\"cforms_email\";s:21:\"moz@moztronics.com.au\";s:16:\"cforms_fromemail\";s:21:\"moz@moztronics.com.au\";s:10:\"cforms_bcc\";s:0:\"\";s:13:\"cforms_header\";s:149:\"A new submission (form: \\\"{Form Name}\\\")\r\n============================================\r\nSubmitted on: {Date}\r\nVia: {Page}\r\nBy {IP} (visitor IP).\r\n.\r\n\";s:18:\"cforms_header_html\";s:145:\"<p style=\\\"font:normal 0.8em Verdana; text-align:right; color:#777; margin:3px 0\\\">a form has been submitted on {Date}, via: {Page} [IP {IP}]</p>\";s:15:\"cforms_formdata\";s:4:\"1110\";s:12:\"cforms_space\";s:2:\"30\";s:20:\"cforms_noattachments\";s:1:\"0\";s:14:\"cforms_subject\";s:26:\"A comment from {Your Name}\";s:18:\"cforms_submit_text\";s:6:\"Submit\";s:14:\"cforms_success\";s:27:\"Thank you for your comment!\";s:14:\"cforms_failure\";s:39:\"Please fill in all the required fields.\";s:15:\"cforms_limittxt\";s:59:\"<strong>No more submissions accepted at this time.</strong>\";s:14:\"cforms_working\";s:20:\"One moment please...\";s:12:\"cforms_popup\";s:2:\"nn\";s:14:\"cforms_showpos\";s:5:\"ynyyy\";s:15:\"cforms_redirect\";s:1:\"0\";s:20:\"cforms_redirect_page\";s:28:\"http://redirect.to.this.page\";s:13:\"cforms_action\";s:1:\"0\";s:18:\"cforms_action_page\";s:7:\"http://\";s:15:\"cforms_tracking\";s:0:\"\";s:20:\"cforms_showdashboard\";s:1:\"1\";s:17:\"cforms_maxentries\";s:0:\"\";s:18:\"cforms_tellafriend\";s:1:\"0\";s:16:\"cforms_dashboard\";s:1:\"0\";s:2:\"mp\";a:8:{s:14:\"cforms_mp_form\";b:0;s:14:\"cforms_mp_next\";N;s:15:\"cforms_mp_first\";b:0;s:15:\"cforms_mp_email\";b:0;s:15:\"cforms_mp_reset\";b:0;s:19:\"cforms_mp_resettext\";N;s:14:\"cforms_mp_back\";b:0;s:18:\"cforms_mp_backtext\";N;}s:18:\"cforms_customnames\";s:1:\"0\";s:16:\"cforms_startdate\";s:1:\" \";s:14:\"cforms_enddate\";s:1:\" \";}}','yes'),(239,0,'ga_admin_status','enabled','yes'),(240,0,'ga_admin_level','8','yes'),(241,0,'ga_extra','','yes'),(242,0,'ga_extra_after','','yes'),(243,0,'ga_outbound','enabled','yes'),(244,0,'ga_downloads','','yes'),(245,0,'ga_footer','enabled','yes'),(246,0,'ga_specify_http','auto','yes'),(181,0,'widget_pages','a:3:{s:5:\"title\";s:0:\"\";s:6:\"sortby\";s:10:\"post_title\";s:7:\"exclude\";s:0:\"\";}','yes'),(182,0,'widget_meta','a:1:{s:5:\"title\";s:0:\"\";}','yes'),(183,0,'widget_tag_cloud','a:1:{s:5:\"title\";s:0:\"\";}','yes'),(184,0,'widget_categories','a:1:{i:326691521;a:4:{s:5:\"title\";s:0:\"\";s:5:\"count\";b:1;s:12:\"hierarchical\";b:0;s:8:\"dropdown\";b:0;}}','yes'),(185,0,'widget_text','a:0:{}','yes'),(186,0,'widget_rss','a:0:{}','yes'),(123,0,'remedy_story_category','Featured','yes'),(124,0,'remedy_story_count','Select a Number:','yes'),(125,0,'remedy_mini_category1','Networking','yes'),(126,0,'remedy_mini_category2','Media Center','yes'),(127,0,'remedy_mini_category3','Telephony','yes'),(128,0,'remedy_mini_category4','VoIP','yes'),(129,0,'remedy_mini_category5','Electrical','yes'),(130,0,'remedy_mini_category6','Fire Solutions','yes'),(131,0,'remedy_video_category','Featured','yes'),(132,0,'remedy_feed','2861084','yes'),(133,0,'remedy_banner1','Banner-1 image','yes'),(134,0,'remedy_url1','Banner-1 url','yes'),(135,0,'remedy_banner2','Banner-2 image','yes'),(136,0,'remedy_url2','Banner-2 url','yes'),(137,0,'remedy_banner3','Banner-3 image','yes'),(138,0,'remedy_url3','Banner-3 url','yes'),(139,0,'remedy_banner4','Banner-4 image','yes'),(140,0,'remedy_url4','Banner-4 url','yes'),(141,0,'remedy_ad','Adsense Code','yes'),(237,0,'ga_status','enabled','yes'),(238,0,'ga_uid','UA-4163099-6','yes'),(144,0,'wpcumulus_options','a:11:{s:5:\"width\";s:3:\"336\";s:6:\"height\";s:3:\"270\";s:6:\"tcolor\";s:6:\"c5c5c5\";s:7:\"bgcolor\";s:6:\"2e3335\";s:5:\"speed\";s:3:\"100\";s:5:\"trans\";s:0:\"\";s:5:\"distr\";s:0:\"\";s:4:\"args\";s:0:\"\";s:4:\"mode\";s:4:\"cats\";s:7:\"tcolor2\";s:0:\"\";s:7:\"hicolor\";s:0:\"\";}','yes'),(145,0,'wpcumulus_widget','a:12:{s:5:\"width\";s:3:\"160\";s:6:\"height\";s:3:\"160\";s:6:\"tcolor\";s:6:\"333333\";s:7:\"bgcolor\";s:6:\"ffffff\";s:5:\"speed\";s:3:\"100\";s:5:\"trans\";s:0:\"\";s:5:\"distr\";s:0:\"\";s:4:\"args\";s:0:\"\";s:4:\"mode\";s:4:\"tags\";s:5:\"title\";s:0:\"\";s:7:\"tcolor2\";s:0:\"\";s:7:\"hicolor\";s:0:\"\";}','yes'),(348,0,'rewrite_rules','a:65:{s:11:\"robots.txt$\";s:18:\"index.php?robots=1\";s:14:\".*wp-atom.php$\";s:19:\"index.php?feed=atom\";s:13:\".*wp-rdf.php$\";s:18:\"index.php?feed=rdf\";s:13:\".*wp-rss.php$\";s:18:\"index.php?feed=rss\";s:14:\".*wp-rss2.php$\";s:19:\"index.php?feed=rss2\";s:14:\".*wp-feed.php$\";s:19:\"index.php?feed=feed\";s:22:\".*wp-commentsrss2.php$\";s:34:\"index.php?feed=rss2&withcomments=1\";s:32:\"feed/(feed|rdf|rss|rss2|atom)/?$\";s:27:\"index.php?&feed=$matches[1]\";s:27:\"(feed|rdf|rss|rss2|atom)/?$\";s:27:\"index.php?&feed=$matches[1]\";s:20:\"page/?([0-9]{1,})/?$\";s:28:\"index.php?&paged=$matches[1]\";s:41:\"comments/feed/(feed|rdf|rss|rss2|atom)/?$\";s:42:\"index.php?&feed=$matches[1]&withcomments=1\";s:36:\"comments/(feed|rdf|rss|rss2|atom)/?$\";s:42:\"index.php?&feed=$matches[1]&withcomments=1\";s:29:\"comments/page/?([0-9]{1,})/?$\";s:28:\"index.php?&paged=$matches[1]\";s:44:\"search/(.+)/feed/(feed|rdf|rss|rss2|atom)/?$\";s:40:\"index.php?s=$matches[1]&feed=$matches[2]\";s:39:\"search/(.+)/(feed|rdf|rss|rss2|atom)/?$\";s:40:\"index.php?s=$matches[1]&feed=$matches[2]\";s:32:\"search/(.+)/page/?([0-9]{1,})/?$\";s:41:\"index.php?s=$matches[1]&paged=$matches[2]\";s:14:\"search/(.+)/?$\";s:23:\"index.php?s=$matches[1]\";s:47:\"category/(.+?)/feed/(feed|rdf|rss|rss2|atom)/?$\";s:52:\"index.php?category_name=$matches[1]&feed=$matches[2]\";s:42:\"category/(.+?)/(feed|rdf|rss|rss2|atom)/?$\";s:52:\"index.php?category_name=$matches[1]&feed=$matches[2]\";s:35:\"category/(.+?)/page/?([0-9]{1,})/?$\";s:53:\"index.php?category_name=$matches[1]&paged=$matches[2]\";s:17:\"category/(.+?)/?$\";s:35:\"index.php?category_name=$matches[1]\";s:42:\"tag/(.+?)/feed/(feed|rdf|rss|rss2|atom)/?$\";s:42:\"index.php?tag=$matches[1]&feed=$matches[2]\";s:37:\"tag/(.+?)/(feed|rdf|rss|rss2|atom)/?$\";s:42:\"index.php?tag=$matches[1]&feed=$matches[2]\";s:30:\"tag/(.+?)/page/?([0-9]{1,})/?$\";s:43:\"index.php?tag=$matches[1]&paged=$matches[2]\";s:12:\"tag/(.+?)/?$\";s:25:\"index.php?tag=$matches[1]\";s:47:\"author/([^/]+)/feed/(feed|rdf|rss|rss2|atom)/?$\";s:50:\"index.php?author_name=$matches[1]&feed=$matches[2]\";s:42:\"author/([^/]+)/(feed|rdf|rss|rss2|atom)/?$\";s:50:\"index.php?author_name=$matches[1]&feed=$matches[2]\";s:35:\"author/([^/]+)/page/?([0-9]{1,})/?$\";s:51:\"index.php?author_name=$matches[1]&paged=$matches[2]\";s:17:\"author/([^/]+)/?$\";s:33:\"index.php?author_name=$matches[1]\";s:69:\"([0-9]{4})/([0-9]{1,2})/([0-9]{1,2})/feed/(feed|rdf|rss|rss2|atom)/?$\";s:80:\"index.php?year=$matches[1]&monthnum=$matches[2]&day=$matches[3]&feed=$matches[4]\";s:64:\"([0-9]{4})/([0-9]{1,2})/([0-9]{1,2})/(feed|rdf|rss|rss2|atom)/?$\";s:80:\"index.php?year=$matches[1]&monthnum=$matches[2]&day=$matches[3]&feed=$matches[4]\";s:57:\"([0-9]{4})/([0-9]{1,2})/([0-9]{1,2})/page/?([0-9]{1,})/?$\";s:81:\"index.php?year=$matches[1]&monthnum=$matches[2]&day=$matches[3]&paged=$matches[4]\";s:39:\"([0-9]{4})/([0-9]{1,2})/([0-9]{1,2})/?$\";s:63:\"index.php?year=$matches[1]&monthnum=$matches[2]&day=$matches[3]\";s:56:\"([0-9]{4})/([0-9]{1,2})/feed/(feed|rdf|rss|rss2|atom)/?$\";s:64:\"index.php?year=$matches[1]&monthnum=$matches[2]&feed=$matches[3]\";s:51:\"([0-9]{4})/([0-9]{1,2})/(feed|rdf|rss|rss2|atom)/?$\";s:64:\"index.php?year=$matches[1]&monthnum=$matches[2]&feed=$matches[3]\";s:44:\"([0-9]{4})/([0-9]{1,2})/page/?([0-9]{1,})/?$\";s:65:\"index.php?year=$matches[1]&monthnum=$matches[2]&paged=$matches[3]\";s:26:\"([0-9]{4})/([0-9]{1,2})/?$\";s:47:\"index.php?year=$matches[1]&monthnum=$matches[2]\";s:43:\"([0-9]{4})/feed/(feed|rdf|rss|rss2|atom)/?$\";s:43:\"index.php?year=$matches[1]&feed=$matches[2]\";s:38:\"([0-9]{4})/(feed|rdf|rss|rss2|atom)/?$\";s:43:\"index.php?year=$matches[1]&feed=$matches[2]\";s:31:\"([0-9]{4})/page/?([0-9]{1,})/?$\";s:44:\"index.php?year=$matches[1]&paged=$matches[2]\";s:13:\"([0-9]{4})/?$\";s:26:\"index.php?year=$matches[1]\";s:77:\"http:/moztronics.com.au/category/post-name/ /feed/(feed|rdf|rss|rss2|atom)/?$\";s:27:\"index.php?&feed=$matches[1]\";s:72:\"http:/moztronics.com.au/category/post-name/ /(feed|rdf|rss|rss2|atom)/?$\";s:27:\"index.php?&feed=$matches[1]\";s:65:\"http:/moztronics.com.au/category/post-name/ /page/?([0-9]{1,})/?$\";s:28:\"index.php?&paged=$matches[1]\";s:75:\"http:/moztronics.com.au/category/post-name/feed/(feed|rdf|rss|rss2|atom)/?$\";s:27:\"index.php?&feed=$matches[1]\";s:70:\"http:/moztronics.com.au/category/post-name/(feed|rdf|rss|rss2|atom)/?$\";s:27:\"index.php?&feed=$matches[1]\";s:63:\"http:/moztronics.com.au/category/post-name/page/?([0-9]{1,})/?$\";s:28:\"index.php?&paged=$matches[1]\";s:65:\"http:/moztronics.com.au/category/feed/(feed|rdf|rss|rss2|atom)/?$\";s:27:\"index.php?&feed=$matches[1]\";s:60:\"http:/moztronics.com.au/category/(feed|rdf|rss|rss2|atom)/?$\";s:27:\"index.php?&feed=$matches[1]\";s:53:\"http:/moztronics.com.au/category/page/?([0-9]{1,})/?$\";s:28:\"index.php?&paged=$matches[1]\";s:56:\"http:/moztronics.com.au/feed/(feed|rdf|rss|rss2|atom)/?$\";s:27:\"index.php?&feed=$matches[1]\";s:51:\"http:/moztronics.com.au/(feed|rdf|rss|rss2|atom)/?$\";s:27:\"index.php?&feed=$matches[1]\";s:44:\"http:/moztronics.com.au/page/?([0-9]{1,})/?$\";s:28:\"index.php?&paged=$matches[1]\";s:38:\"http:/feed/(feed|rdf|rss|rss2|atom)/?$\";s:27:\"index.php?&feed=$matches[1]\";s:33:\"http:/(feed|rdf|rss|rss2|atom)/?$\";s:27:\"index.php?&feed=$matches[1]\";s:26:\"http:/page/?([0-9]{1,})/?$\";s:28:\"index.php?&paged=$matches[1]\";s:25:\".+?/attachment/([^/]+)/?$\";s:32:\"index.php?attachment=$matches[1]\";s:35:\".+?/attachment/([^/]+)/trackback/?$\";s:37:\"index.php?attachment=$matches[1]&tb=1\";s:55:\".+?/attachment/([^/]+)/feed/(feed|rdf|rss|rss2|atom)/?$\";s:49:\"index.php?attachment=$matches[1]&feed=$matches[2]\";s:50:\".+?/attachment/([^/]+)/(feed|rdf|rss|rss2|atom)/?$\";s:49:\"index.php?attachment=$matches[1]&feed=$matches[2]\";s:18:\"(.+?)/trackback/?$\";s:35:\"index.php?pagename=$matches[1]&tb=1\";s:38:\"(.+?)/feed/(feed|rdf|rss|rss2|atom)/?$\";s:47:\"index.php?pagename=$matches[1]&feed=$matches[2]\";s:33:\"(.+?)/(feed|rdf|rss|rss2|atom)/?$\";s:47:\"index.php?pagename=$matches[1]&feed=$matches[2]\";s:26:\"(.+?)/page/?([0-9]{1,})/?$\";s:48:\"index.php?pagename=$matches[1]&paged=$matches[2]\";s:18:\"(.+?)(/[0-9]+)?/?$\";s:47:\"index.php?pagename=$matches[1]&page=$matches[2]\";}','yes');
/*!40000 ALTER TABLE `wp_options` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `wp_postmeta`
--

DROP TABLE IF EXISTS `wp_postmeta`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `wp_postmeta` (
  `meta_id` bigint(20) NOT NULL auto_increment,
  `post_id` bigint(20) NOT NULL default '0',
  `meta_key` varchar(255) default NULL,
  `meta_value` longtext,
  PRIMARY KEY  (`meta_id`),
  KEY `post_id` (`post_id`),
  KEY `meta_key` (`meta_key`)
) ENGINE=MyISAM AUTO_INCREMENT=202 DEFAULT CHARSET=latin1;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `wp_postmeta`
--

LOCK TABLES `wp_postmeta` WRITE;
/*!40000 ALTER TABLE `wp_postmeta` DISABLE KEYS */;
INSERT INTO `wp_postmeta` VALUES (31,17,'_edit_lock','1231844531'),(3,4,'_edit_lock','1231852080'),(4,4,'_edit_last','1'),(7,6,'_edit_lock','1231852269'),(8,6,'_edit_last','1'),(11,8,'_edit_lock','1231844330'),(12,8,'_edit_last','1'),(15,10,'_edit_lock','1231844464'),(16,10,'_edit_last','1'),(19,12,'_edit_lock','1231844496'),(20,12,'_edit_last','1'),(23,1,'_edit_lock','1231844699'),(24,1,'_edit_last','1'),(32,17,'_edit_last','1'),(35,19,'_edit_lock','1231844204'),(36,19,'_edit_last','1'),(39,21,'_edit_lock','1231844266'),(40,21,'_edit_last','1'),(43,23,'_edit_lock','1231844232'),(44,23,'_edit_last','1'),(47,25,'_edit_lock','1231844295'),(48,25,'_edit_last','1'),(51,27,'_edit_lock','1231844179'),(52,27,'_edit_last','1'),(55,29,'_edit_lock','1231844124'),(56,29,'_edit_last','1'),(59,31,'_edit_lock','1231844069'),(60,31,'_edit_last','1'),(63,33,'_edit_lock','1231844153'),(64,33,'_edit_last','1'),(72,38,'_edit_last','1'),(71,38,'_edit_lock','1231844102'),(75,40,'_edit_lock','1231844563'),(76,40,'_edit_last','1'),(81,44,'_edit_lock','1231844041'),(82,44,'_edit_last','1'),(85,46,'_edit_lock','1231844005'),(86,46,'_edit_last','1'),(94,51,'_edit_last','1'),(93,51,'_edit_lock','1231843982'),(97,53,'_edit_lock','1231843958'),(98,53,'_edit_last','1'),(101,55,'_edit_lock','1231844593'),(102,55,'_edit_last','1'),(105,2,'_edit_lock','1231843925'),(106,2,'_edit_last','1'),(107,59,'_wp_attached_file','/home/moztroni/public_html/wp-content/uploads/2009/01/moz__100x150.jpg'),(108,59,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:100;s:6:\"height\";i:150;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'64\'\";s:4:\"file\";s:70:\"/home/moztroni/public_html/wp-content/uploads/2009/01/moz__100x150.jpg\";s:10:\"image_meta\";a:10:{s:8:\"aperture\";i:0;s:6:\"credit\";s:0:\"\";s:6:\"camera\";s:0:\"\";s:7:\"caption\";s:0:\"\";s:17:\"created_timestamp\";i:0;s:9:\"copyright\";s:0:\"\";s:12:\"focal_length\";i:0;s:3:\"iso\";i:0;s:13:\"shutter_speed\";i:0;s:5:\"title\";s:0:\"\";}}'),(159,87,'_wp_attached_file','/home/moztroni/public_html/wp-content/uploads/2009/01/cctv_monitors1.jpg'),(160,87,'_wp_attachment_metadata','a:6:{s:5:\"width\";i:312;s:6:\"height\";i:425;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'70\'\";s:4:\"file\";s:72:\"/home/moztroni/public_html/wp-content/uploads/2009/01/cctv_monitors1.jpg\";s:5:\"sizes\";a:2:{s:9:\"thumbnail\";a:3:{s:4:\"file\";s:26:\"cctv_monitors1-150x150.jpg\";s:5:\"width\";i:150;s:6:\"height\";i:150;}s:6:\"medium\";a:3:{s:4:\"file\";s:26:\"cctv_monitors1-220x300.jpg\";s:5:\"width\";i:220;s:6:\"height\";i:300;}}s:10:\"image_meta\";a:10:{s:8:\"aperture\";i:0;s:6:\"credit\";s:0:\"\";s:6:\"camera\";s:0:\"\";s:7:\"caption\";s:0:\"\";s:17:\"created_timestamp\";i:0;s:9:\"copyright\";s:0:\"\";s:12:\"focal_length\";i:0;s:3:\"iso\";i:0;s:13:\"shutter_speed\";i:0;s:5:\"title\";s:0:\"\";}}'),(161,88,'_wp_attached_file','/home/moztroni/public_html/wp-content/uploads/2009/01/kaspersky_20091.jpg'),(162,88,'_wp_attachment_metadata','a:6:{s:5:\"width\";i:245;s:6:\"height\";i:356;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'66\'\";s:4:\"file\";s:73:\"/home/moztroni/public_html/wp-content/uploads/2009/01/kaspersky_20091.jpg\";s:5:\"sizes\";a:2:{s:9:\"thumbnail\";a:3:{s:4:\"file\";s:27:\"kaspersky_20091-150x150.jpg\";s:5:\"width\";i:150;s:6:\"height\";i:150;}s:6:\"medium\";a:3:{s:4:\"file\";s:27:\"kaspersky_20091-206x300.jpg\";s:5:\"width\";i:206;s:6:\"height\";i:300;}}s:10:\"image_meta\";a:10:{s:8:\"aperture\";i:0;s:6:\"credit\";s:0:\"\";s:6:\"camera\";s:0:\"\";s:7:\"caption\";s:0:\"\";s:17:\"created_timestamp\";i:0;s:9:\"copyright\";s:0:\"\";s:12:\"focal_length\";i:0;s:3:\"iso\";i:0;s:13:\"shutter_speed\";i:0;s:5:\"title\";s:0:\"\";}}'),(163,89,'_wp_attached_file','/home/moztroni/public_html/wp-content/uploads/2009/01/kaspersky_logo_1.jpg'),(164,89,'_wp_attachment_metadata','a:6:{s:5:\"width\";i:357;s:6:\"height\";i:361;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'94\'\";s:4:\"file\";s:74:\"/home/moztroni/public_html/wp-content/uploads/2009/01/kaspersky_logo_1.jpg\";s:5:\"sizes\";a:2:{s:9:\"thumbnail\";a:3:{s:4:\"file\";s:28:\"kaspersky_logo_1-150x150.jpg\";s:5:\"width\";i:150;s:6:\"height\";i:150;}s:6:\"medium\";a:3:{s:4:\"file\";s:28:\"kaspersky_logo_1-296x300.jpg\";s:5:\"width\";i:296;s:6:\"height\";i:300;}}s:10:\"image_meta\";a:10:{s:8:\"aperture\";i:0;s:6:\"credit\";s:0:\"\";s:6:\"camera\";s:0:\"\";s:7:\"caption\";s:0:\"\";s:17:\"created_timestamp\";i:0;s:9:\"copyright\";s:0:\"\";s:12:\"focal_length\";i:0;s:3:\"iso\";i:0;s:13:\"shutter_speed\";i:0;s:5:\"title\";s:0:\"\";}}'),(165,90,'_wp_attached_file','/home/moztroni/public_html/wp-content/uploads/2009/01/moztronics_griffin_blu.jpg'),(166,90,'_wp_attachment_metadata','a:6:{s:5:\"width\";i:360;s:6:\"height\";i:216;s:14:\"hwstring_small\";s:23:\"height=\'76\' width=\'128\'\";s:4:\"file\";s:80:\"/home/moztroni/public_html/wp-content/uploads/2009/01/moztronics_griffin_blu.jpg\";s:5:\"sizes\";a:2:{s:9:\"thumbnail\";a:3:{s:4:\"file\";s:34:\"moztronics_griffin_blu-150x150.jpg\";s:5:\"width\";i:150;s:6:\"height\";i:150;}s:6:\"medium\";a:3:{s:4:\"file\";s:34:\"moztronics_griffin_blu-300x180.jpg\";s:5:\"width\";i:300;s:6:\"height\";i:180;}}s:10:\"image_meta\";a:10:{s:8:\"aperture\";i:0;s:6:\"credit\";s:0:\"\";s:6:\"camera\";s:0:\"\";s:7:\"caption\";s:9:\"AppleMark\";s:17:\"created_timestamp\";i:0;s:9:\"copyright\";s:0:\"\";s:12:\"focal_length\";i:0;s:3:\"iso\";i:0;s:13:\"shutter_speed\";i:0;s:5:\"title\";s:0:\"\";}}'),(167,91,'_wp_attached_file','/home/moztroni/public_html/wp-content/uploads/2009/01/phone_aria.gif'),(168,91,'_wp_attachment_metadata','a:6:{s:5:\"width\";i:300;s:6:\"height\";i:301;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'95\'\";s:4:\"file\";s:68:\"/home/moztroni/public_html/wp-content/uploads/2009/01/phone_aria.gif\";s:5:\"sizes\";a:2:{s:9:\"thumbnail\";a:3:{s:4:\"file\";s:22:\"phone_aria-150x150.gif\";s:5:\"width\";i:150;s:6:\"height\";i:150;}s:6:\"medium\";a:3:{s:4:\"file\";s:22:\"phone_aria-299x300.gif\";s:5:\"width\";i:299;s:6:\"height\";i:300;}}s:10:\"image_meta\";a:10:{s:8:\"aperture\";i:0;s:6:\"credit\";s:0:\"\";s:6:\"camera\";s:0:\"\";s:7:\"caption\";s:0:\"\";s:17:\"created_timestamp\";i:0;s:9:\"copyright\";s:0:\"\";s:12:\"focal_length\";i:0;s:3:\"iso\";i:0;s:13:\"shutter_speed\";i:0;s:5:\"title\";s:0:\"\";}}'),(169,92,'_wp_attached_file','/home/moztroni/public_html/wp-content/uploads/2009/01/plasma1.jpg'),(170,92,'_wp_attachment_metadata','a:6:{s:5:\"width\";i:194;s:6:\"height\";i:148;s:14:\"hwstring_small\";s:23:\"height=\'96\' width=\'125\'\";s:4:\"file\";s:65:\"/home/moztroni/public_html/wp-content/uploads/2009/01/plasma1.jpg\";s:5:\"sizes\";a:1:{s:9:\"thumbnail\";a:3:{s:4:\"file\";s:19:\"plasma1-150x148.jpg\";s:5:\"width\";i:150;s:6:\"height\";i:148;}}s:10:\"image_meta\";a:10:{s:8:\"aperture\";i:0;s:6:\"credit\";s:0:\"\";s:6:\"camera\";s:0:\"\";s:7:\"caption\";s:0:\"\";s:17:\"created_timestamp\";i:0;s:9:\"copyright\";s:0:\"\";s:12:\"focal_length\";i:0;s:3:\"iso\";i:0;s:13:\"shutter_speed\";i:0;s:5:\"title\";s:0:\"\";}}'),(171,93,'_wp_attached_file','/home/moztroni/public_html/wp-content/uploads/2009/01/smart-wire-cabinet.jpg'),(172,93,'_wp_attachment_metadata','a:6:{s:5:\"width\";i:113;s:6:\"height\";i:170;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'63\'\";s:4:\"file\";s:76:\"/home/moztroni/public_html/wp-content/uploads/2009/01/smart-wire-cabinet.jpg\";s:5:\"sizes\";a:1:{s:9:\"thumbnail\";a:3:{s:4:\"file\";s:30:\"smart-wire-cabinet-113x150.jpg\";s:5:\"width\";i:113;s:6:\"height\";i:150;}}s:10:\"image_meta\";a:10:{s:8:\"aperture\";i:0;s:6:\"credit\";s:0:\"\";s:6:\"camera\";s:0:\"\";s:7:\"caption\";s:0:\"\";s:17:\"created_timestamp\";i:0;s:9:\"copyright\";s:0:\"\";s:12:\"focal_length\";i:0;s:3:\"iso\";i:0;s:13:\"shutter_speed\";i:0;s:5:\"title\";s:0:\"\";}}'),(173,94,'_wp_attached_file','/home/moztroni/public_html/wp-content/uploads/2009/01/smokealarm1.gif'),(174,94,'_wp_attachment_metadata','a:6:{s:5:\"width\";i:1295;s:6:\"height\";i:1655;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'75\'\";s:4:\"file\";s:69:\"/home/moztroni/public_html/wp-content/uploads/2009/01/smokealarm1.gif\";s:5:\"sizes\";a:2:{s:9:\"thumbnail\";a:3:{s:4:\"file\";s:23:\"smokealarm1-150x150.gif\";s:5:\"width\";i:150;s:6:\"height\";i:150;}s:6:\"medium\";a:3:{s:4:\"file\";s:23:\"smokealarm1-234x300.gif\";s:5:\"width\";i:234;s:6:\"height\";i:300;}}s:10:\"image_meta\";a:10:{s:8:\"aperture\";i:0;s:6:\"credit\";s:0:\"\";s:6:\"camera\";s:0:\"\";s:7:\"caption\";s:0:\"\";s:17:\"created_timestamp\";i:0;s:9:\"copyright\";s:0:\"\";s:12:\"focal_length\";i:0;s:3:\"iso\";i:0;s:13:\"shutter_speed\";i:0;s:5:\"title\";s:0:\"\";}}'),(175,95,'_wp_attached_file','/home/moztroni/public_html/wp-content/uploads/2009/01/vacdiagram.gif'),(176,95,'_wp_attachment_metadata','a:6:{s:5:\"width\";i:203;s:6:\"height\";i:432;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'45\'\";s:4:\"file\";s:68:\"/home/moztroni/public_html/wp-content/uploads/2009/01/vacdiagram.gif\";s:5:\"sizes\";a:2:{s:9:\"thumbnail\";a:3:{s:4:\"file\";s:22:\"vacdiagram-150x150.gif\";s:5:\"width\";i:150;s:6:\"height\";i:150;}s:6:\"medium\";a:3:{s:4:\"file\";s:22:\"vacdiagram-140x300.gif\";s:5:\"width\";i:140;s:6:\"height\";i:300;}}s:10:\"image_meta\";a:10:{s:8:\"aperture\";i:0;s:6:\"credit\";s:0:\"\";s:6:\"camera\";s:0:\"\";s:7:\"caption\";s:0:\"\";s:17:\"created_timestamp\";i:0;s:9:\"copyright\";s:0:\"\";s:12:\"focal_length\";i:0;s:3:\"iso\";i:0;s:13:\"shutter_speed\";i:0;s:5:\"title\";s:0:\"\";}}'),(177,96,'_wp_attached_file','/home/moztroni/public_html/wp-content/uploads/2009/01/vacuum.gif'),(178,96,'_wp_attachment_metadata','a:6:{s:5:\"width\";i:210;s:6:\"height\";i:432;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'46\'\";s:4:\"file\";s:64:\"/home/moztroni/public_html/wp-content/uploads/2009/01/vacuum.gif\";s:5:\"sizes\";a:2:{s:9:\"thumbnail\";a:3:{s:4:\"file\";s:18:\"vacuum-150x150.gif\";s:5:\"width\";i:150;s:6:\"height\";i:150;}s:6:\"medium\";a:3:{s:4:\"file\";s:18:\"vacuum-145x300.gif\";s:5:\"width\";i:145;s:6:\"height\";i:300;}}s:10:\"image_meta\";a:10:{s:8:\"aperture\";i:0;s:6:\"credit\";s:0:\"\";s:6:\"camera\";s:0:\"\";s:7:\"caption\";s:0:\"\";s:17:\"created_timestamp\";i:0;s:9:\"copyright\";s:0:\"\";s:12:\"focal_length\";i:0;s:3:\"iso\";i:0;s:13:\"shutter_speed\";i:0;s:5:\"title\";s:0:\"\";}}'),(179,97,'_wp_attached_file','/home/moztroni/public_html/wp-content/uploads/2009/01/vacuum_11.jpg'),(180,97,'_wp_attachment_metadata','a:5:{s:5:\"width\";i:150;s:6:\"height\";i:150;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'96\'\";s:4:\"file\";s:67:\"/home/moztroni/public_html/wp-content/uploads/2009/01/vacuum_11.jpg\";s:10:\"image_meta\";a:10:{s:8:\"aperture\";i:0;s:6:\"credit\";s:0:\"\";s:6:\"camera\";s:0:\"\";s:7:\"caption\";s:0:\"\";s:17:\"created_timestamp\";i:0;s:9:\"copyright\";s:0:\"\";s:12:\"focal_length\";i:0;s:3:\"iso\";i:0;s:13:\"shutter_speed\";i:0;s:5:\"title\";s:0:\"\";}}'),(181,98,'_wp_attached_file','/home/moztroni/public_html/wp-content/uploads/2009/01/vacuum_21.jpg'),(182,98,'_wp_attachment_metadata','a:6:{s:5:\"width\";i:250;s:6:\"height\";i:177;s:14:\"hwstring_small\";s:23:\"height=\'90\' width=\'128\'\";s:4:\"file\";s:67:\"/home/moztroni/public_html/wp-content/uploads/2009/01/vacuum_21.jpg\";s:5:\"sizes\";a:1:{s:9:\"thumbnail\";a:3:{s:4:\"file\";s:21:\"vacuum_21-150x150.jpg\";s:5:\"width\";i:150;s:6:\"height\";i:150;}}s:10:\"image_meta\";a:10:{s:8:\"aperture\";i:0;s:6:\"credit\";s:0:\"\";s:6:\"camera\";s:0:\"\";s:7:\"caption\";s:0:\"\";s:17:\"created_timestamp\";i:0;s:9:\"copyright\";s:0:\"\";s:12:\"focal_length\";i:0;s:3:\"iso\";i:0;s:13:\"shutter_speed\";i:0;s:5:\"title\";s:0:\"\";}}'),(183,99,'_wp_attached_file','/home/moztroni/public_html/wp-content/uploads/2009/01/voip_phone1.gif'),(184,99,'_wp_attachment_metadata','a:6:{s:5:\"width\";i:350;s:6:\"height\";i:350;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'96\'\";s:4:\"file\";s:69:\"/home/moztroni/public_html/wp-content/uploads/2009/01/voip_phone1.gif\";s:5:\"sizes\";a:2:{s:9:\"thumbnail\";a:3:{s:4:\"file\";s:23:\"voip_phone1-150x150.gif\";s:5:\"width\";i:150;s:6:\"height\";i:150;}s:6:\"medium\";a:3:{s:4:\"file\";s:23:\"voip_phone1-300x300.gif\";s:5:\"width\";i:300;s:6:\"height\";i:300;}}s:10:\"image_meta\";a:10:{s:8:\"aperture\";i:0;s:6:\"credit\";s:0:\"\";s:6:\"camera\";s:0:\"\";s:7:\"caption\";s:0:\"\";s:17:\"created_timestamp\";i:0;s:9:\"copyright\";s:0:\"\";s:12:\"focal_length\";i:0;s:3:\"iso\";i:0;s:13:\"shutter_speed\";i:0;s:5:\"title\";s:0:\"\";}}'),(185,100,'_wp_attached_file','/home/moztroni/public_html/wp-content/uploads/2009/01/voip_phone.jpg'),(186,100,'_wp_attachment_metadata','a:6:{s:5:\"width\";i:350;s:6:\"height\";i:350;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'96\'\";s:4:\"file\";s:68:\"/home/moztroni/public_html/wp-content/uploads/2009/01/voip_phone.jpg\";s:5:\"sizes\";a:2:{s:9:\"thumbnail\";a:3:{s:4:\"file\";s:22:\"voip_phone-150x150.jpg\";s:5:\"width\";i:150;s:6:\"height\";i:150;}s:6:\"medium\";a:3:{s:4:\"file\";s:22:\"voip_phone-300x300.jpg\";s:5:\"width\";i:300;s:6:\"height\";i:300;}}s:10:\"image_meta\";a:10:{s:8:\"aperture\";i:0;s:6:\"credit\";s:0:\"\";s:6:\"camera\";s:0:\"\";s:7:\"caption\";s:0:\"\";s:17:\"created_timestamp\";i:0;s:9:\"copyright\";s:0:\"\";s:12:\"focal_length\";i:0;s:3:\"iso\";i:0;s:13:\"shutter_speed\";i:0;s:5:\"title\";s:0:\"\";}}'),(187,101,'_wp_attached_file','/home/moztroni/public_html/wp-content/uploads/2009/01/mediacentre1.jpg'),(188,101,'_wp_attachment_metadata','a:6:{s:5:\"width\";i:544;s:6:\"height\";i:540;s:14:\"hwstring_small\";s:22:\"height=\'96\' width=\'96\'\";s:4:\"file\";s:70:\"/home/moztroni/public_html/wp-content/uploads/2009/01/mediacentre1.jpg\";s:5:\"sizes\";a:2:{s:9:\"thumbnail\";a:3:{s:4:\"file\";s:24:\"mediacentre1-150x150.jpg\";s:5:\"width\";i:150;s:6:\"height\";i:150;}s:6:\"medium\";a:3:{s:4:\"file\";s:24:\"mediacentre1-300x297.jpg\";s:5:\"width\";i:300;s:6:\"height\";i:297;}}s:10:\"image_meta\";a:10:{s:8:\"aperture\";i:0;s:6:\"credit\";s:0:\"\";s:6:\"camera\";s:0:\"\";s:7:\"caption\";s:0:\"\";s:17:\"created_timestamp\";i:0;s:9:\"copyright\";s:0:\"\";s:12:\"focal_length\";i:0;s:3:\"iso\";i:0;s:13:\"shutter_speed\";i:0;s:5:\"title\";s:0:\"\";}}'),(200,109,'_edit_last','1'),(199,109,'_edit_lock','1232186466'),(201,109,'_wp_page_template','default');
/*!40000 ALTER TABLE `wp_postmeta` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `wp_posts`
--

DROP TABLE IF EXISTS `wp_posts`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `wp_posts` (
  `ID` bigint(20) unsigned NOT NULL auto_increment,
  `post_author` bigint(20) NOT NULL default '0',
  `post_date` datetime NOT NULL default '0000-00-00 00:00:00',
  `post_date_gmt` datetime NOT NULL default '0000-00-00 00:00:00',
  `post_content` longtext NOT NULL,
  `post_title` text NOT NULL,
  `post_category` int(4) NOT NULL default '0',
  `post_excerpt` text NOT NULL,
  `post_status` varchar(20) NOT NULL default 'publish',
  `comment_status` varchar(20) NOT NULL default 'open',
  `ping_status` varchar(20) NOT NULL default 'open',
  `post_password` varchar(20) NOT NULL default '',
  `post_name` varchar(200) NOT NULL default '',
  `to_ping` text NOT NULL,
  `pinged` text NOT NULL,
  `post_modified` datetime NOT NULL default '0000-00-00 00:00:00',
  `post_modified_gmt` datetime NOT NULL default '0000-00-00 00:00:00',
  `post_content_filtered` text NOT NULL,
  `post_parent` bigint(20) NOT NULL default '0',
  `guid` varchar(255) NOT NULL default '',
  `menu_order` int(11) NOT NULL default '0',
  `post_type` varchar(20) NOT NULL default 'post',
  `post_mime_type` varchar(100) NOT NULL default '',
  `comment_count` bigint(20) NOT NULL default '0',
  PRIMARY KEY  (`ID`),
  KEY `post_name` (`post_name`),
  KEY `type_status_date` (`post_type`,`post_status`,`post_date`,`ID`)
) ENGINE=MyISAM AUTO_INCREMENT=111 DEFAULT CHARSET=latin1;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `wp_posts`
--

LOCK TABLES `wp_posts` WRITE;
/*!40000 ALTER TABLE `wp_posts` DISABLE KEYS */;
INSERT INTO `wp_posts` VALUES (1,1,'2009-01-01 01:30:57','2008-12-31 15:30:57','Welcome to Moztronics','Intro',0,'','publish','closed','closed','','hello-world','','','2009-01-13 21:03:54','2009-01-13 11:03:54','',0,'http://moztronics.com.au/?p=1',0,'post','',0),(15,1,'2009-01-13 12:30:53','2009-01-13 02:30:53','Welcome to Moztronics','Intro',0,'','inherit','open','open','','1-revision-2','','','2009-01-13 12:30:53','2009-01-13 02:30:53','',1,'http://moztronics.com.au/?p=15',0,'revision','',0),(2,1,'2009-01-01 03:57:57','2008-12-31 17:57:57','[caption id=\"attachment_59\" align=\"alignright\" width=\"100\" caption=\"Moz\"]<a href=\"http://moztronics.com.au/wp-content/uploads/2009/01/moz__100x150.jpg\"><img class=\"size-medium wp-image-59\" title=\"moz__100x150\" src=\"http://moztronics.com.au/wp-content/uploads/2009/01/moz__100x150.jpg\" alt=\"Moz\" width=\"100\" height=\"150\" /></a>[/caption]\r\n\r\nMoztronics has been in business for over 15 years. Some of our services include: installation of security alarms, and offer back-to-base monitoring services. We also custom build DVR’s for use with security cameras for your home or business. We can help you get your business up and running, from smart wiring to getting the computers networked to installing the telephony, setting up and maintaining a web presence, VOiP and switchboards. We offer &amp; install customized home media centers, central ducted vacuum services\r\n\r\nWe love our line of work and enjoy being able to provide out customers with the latest cutting edge technology for all aspects of your life.','About',0,'','publish','closed','open','','about','','','2009-01-13 20:52:04','2009-01-13 10:52:04','',0,'http://moztronics.com.au/?page_id=2',0,'page','',0),(17,1,'2009-01-01 13:02:51','2009-01-01 03:02:51','<strong>Security</strong> is the condition of being protected against danger, loss, and criminals. In the general sense, security is a concept similar to <a title=\"Safety\" href=\"http://en.wikipedia.org/wiki/Safety\">safety</a>. The nuance between the two is an added emphasis on being protected from dangers that originate from outside. Individuals or actions that encroach upon the condition of protection are responsible for the breach of security.\r\n<ul>\r\n	<li>A condition that results from the establishment and <a class=\"mw-redirect\" title=\"Repair and maintenance\" href=\"http://en.wikipedia.org/wiki/Repair_and_maintenance\">maintenance</a> of protective measures that ensure a state of inviolability from hostile acts or influences.</li>\r\n	<li>With respect to classified matter, the condition that prevents unauthorized persons from having <a title=\"Access\" href=\"http://en.wikipedia.org/wiki/Access\">access</a> to official <a title=\"Information\" href=\"http://en.wikipedia.org/wiki/Information\">information</a> that is safeguarded in the interests of <a title=\"National security\" href=\"http://en.wikipedia.org/wiki/National_security\">national security</a>.</li>\r\n	<li>Measures taken by a military unit, an activity or installation to protect itself against all acts designed to, or which may, impair its effectiveness.</li>\r\n</ul>\r\nSecurity has to be compared and contrasted with other related concepts: <a title=\"Safety\" href=\"http://en.wikipedia.org/wiki/Safety\">Safety</a>, <a class=\"extiw\" title=\"wiktionary:continuity\" href=\"http://en.wiktionary.org/wiki/continuity\">continuity</a>, <a title=\"Reliability engineering\" href=\"http://en.wikipedia.org/wiki/Reliability_engineering\">reliability</a>. The key difference between security and reliability is that security must take into account the actions of active malicious agents attempting to cause destruction.','What is Electrical Engineering?',0,'','publish','closed','closed','','what-is-electrical-engineering','','','2009-01-13 21:02:10','2009-01-13 11:02:10','',0,'http://moztronics.com.au/?p=17',0,'post','',0),(4,1,'2009-01-01 09:45:54','2008-12-31 23:45:54','<!--more--><a href=\"http://moztronics.com.au/wp-content/uploads/2009/01/mediacentre1.jpg\"><img class=\"alignright size-medium wp-image-101\" style=\"border: 0pt none; margin: 10px;\" title=\"Media Center\" src=\"http://moztronics.com.au/wp-content/uploads/2009/01/mediacentre1-300x297.jpg\" alt=\"Media Center\" width=\"300\" height=\"297\" /></a>The term <strong>media center</strong> refers either to a dedicated <a title=\"Computer appliance\" href=\"http://en.wikipedia.org/wiki/Computer_appliance\">computer appliance</a> or to a specialized <a title=\"Personal computer\" href=\"http://en.wikipedia.org/wiki/Personal_computer\">personal computer</a> <a title=\"Software\" href=\"http://en.wikipedia.org/wiki/Software\">software</a>, both of which are adapted for playing various kinds of <a title=\"Electronic media\" href=\"http://en.wikipedia.org/wiki/Electronic_media\">media</a> (<a title=\"Music\" href=\"http://en.wikipedia.org/wiki/Music\">music</a>, <a class=\"mw-redirect\" title=\"Movie\" href=\"http://en.wikipedia.org/wiki/Movie\">movies</a>, <a class=\"mw-redirect\" title=\"Photos\" href=\"http://en.wikipedia.org/wiki/Photos\">photos</a> etc.). A media center may also allow watching <a title=\"DVD\" href=\"http://en.wikipedia.org/wiki/DVD\">DVD</a> movies and watching and recording <a class=\"mw-redirect\" title=\"Television broadcast\" href=\"http://en.wikipedia.org/wiki/Television_broadcast\">television broadcasts</a>.\r\n\r\nThe media itself may be <a class=\"mw-redirect\" title=\"Computer storage\" href=\"http://en.wikipedia.org/wiki/Computer_storage\">stored</a>, received by <a title=\"Terrestrial television\" href=\"http://en.wikipedia.org/wiki/Terrestrial_television\">terrestrial</a>, <a title=\"Satellite television\" href=\"http://en.wikipedia.org/wiki/Satellite_television\">satellite</a> or <a title=\"Cable television\" href=\"http://en.wikipedia.org/wiki/Cable_television\">cable</a> broadcasting or <a class=\"mw-redirect\" title=\"Streaming\" href=\"http://en.wikipedia.org/wiki/Streaming\">streamed</a> from the internet. Stored media is kept either on a local <a class=\"mw-redirect\" title=\"Hard drive\" href=\"http://en.wikipedia.org/wiki/Hard_drive\">hard drive</a> or on a (<a title=\"Wireless LAN\" href=\"http://en.wikipedia.org/wiki/Wireless_LAN\">wireless</a>) <a class=\"mw-redirect\" title=\"Network attached storage\" href=\"http://en.wikipedia.org/wiki/Network_attached_storage\">network attached storage</a>. Some software is capable of doing other tasks, such as finding news (<a class=\"mw-redirect\" title=\"RSS (file format)\" href=\"http://en.wikipedia.org/wiki/RSS_%28file_format%29\">RSS</a>) from the <a title=\"Internet\" href=\"http://en.wikipedia.org/wiki/Internet\">Internet</a>. Media centers are often operated with a <a title=\"Remote control\" href=\"http://en.wikipedia.org/wiki/Remote_control\">remote control</a>, connected to a television set for <a title=\"TV-out\" href=\"http://en.wikipedia.org/wiki/TV-out\">video output</a>, and can sometimes function as a normal personal computer.\r\n\r\nA media center can be purpose-built, modified or created by individuals by adding media center software to a PC or some other computer, for example an <a title=\"Xbox\" href=\"http://en.wikipedia.org/wiki/Xbox\">Xbox</a>. Lately, some <a title=\"Video game console\" href=\"http://en.wikipedia.org/wiki/Video_game_console\">video game consoles</a> (<a class=\"mw-redirect\" title=\"Playstation 3\" href=\"http://en.wikipedia.org/wiki/Playstation_3\">Playstation 3</a> and <a title=\"Xbox 360\" href=\"http://en.wikipedia.org/wiki/Xbox_360\">Xbox 360</a>) with their network services can act as a media center devices by default.','What is a Media Center?',0,'','publish','closed','closed','','what-is-a-media-center','','','2009-01-13 23:07:59','2009-01-13 13:07:59','',0,'http://moztronics.com.au/?p=4',0,'post','',0),(5,1,'2009-01-13 12:14:09','2009-01-13 02:14:09','The term <strong>media center</strong> refers either to a dedicated <a title=\"Computer appliance\" href=\"http://en.wikipedia.org/wiki/Computer_appliance\">computer appliance</a> or to a specialized <a title=\"Personal computer\" href=\"http://en.wikipedia.org/wiki/Personal_computer\">personal computer</a> <a title=\"Software\" href=\"http://en.wikipedia.org/wiki/Software\">software</a>, both of which are adapted for playing various kinds of <a title=\"Electronic media\" href=\"http://en.wikipedia.org/wiki/Electronic_media\">media</a> (<a title=\"Music\" href=\"http://en.wikipedia.org/wiki/Music\">music</a>, <a class=\"mw-redirect\" title=\"Movie\" href=\"http://en.wikipedia.org/wiki/Movie\">movies</a>, <a class=\"mw-redirect\" title=\"Photos\" href=\"http://en.wikipedia.org/wiki/Photos\">photos</a> etc.). A media center may also allow watching <a title=\"DVD\" href=\"http://en.wikipedia.org/wiki/DVD\">DVD</a> movies and watching and recording <a class=\"mw-redirect\" title=\"Television broadcast\" href=\"http://en.wikipedia.org/wiki/Television_broadcast\">television broadcasts</a>.\n\nThe media itself may be <a class=\"mw-redirect\" title=\"Computer storage\" href=\"http://en.wikipedia.org/wiki/Computer_storage\">stored</a>, received by <a title=\"Terrestrial television\" href=\"http://en.wikipedia.org/wiki/Terrestrial_television\">terrestrial</a>, <a title=\"Satellite television\" href=\"http://en.wikipedia.org/wiki/Satellite_television\">satellite</a> or <a title=\"Cable television\" href=\"http://en.wikipedia.org/wiki/Cable_television\">cable</a> broadcasting or <a class=\"mw-redirect\" title=\"Streaming\" href=\"http://en.wikipedia.org/wiki/Streaming\">streamed</a> from the internet. Stored media is kept either on a local <a class=\"mw-redirect\" title=\"Hard drive\" href=\"http://en.wikipedia.org/wiki/Hard_drive\">hard drive</a> or on a (<a title=\"Wireless LAN\" href=\"http://en.wikipedia.org/wiki/Wireless_LAN\">wireless</a>) <a class=\"mw-redirect\" title=\"Network attached storage\" href=\"http://en.wikipedia.org/wiki/Network_attached_storage\">network attached storage</a>. Some software is capable of doing other tasks, such as finding news (<a class=\"mw-redirect\" title=\"RSS (file format)\" href=\"http://en.wikipedia.org/wiki/RSS_%28file_format%29\">RSS</a>) from the <a title=\"Internet\" href=\"http://en.wikipedia.org/wiki/Internet\">Internet</a>. Media centers are often operated with a <a title=\"Remote control\" href=\"http://en.wikipedia.org/wiki/Remote_control\">remote control</a>, connected to a television set for <a title=\"TV-out\" href=\"http://en.wikipedia.org/wiki/TV-out\">video output</a>, and can sometimes function as a normal personal computer.\n\nA media center can be purpose-built, modified or created by individuals by adding media center software to a PC or some other computer, for example an <a title=\"Xbox\" href=\"http://en.wikipedia.org/wiki/Xbox\">Xbox</a>. Lately, some <a title=\"Video game console\" href=\"http://en.wikipedia.org/wiki/Video_game_console\">video game consoles</a> (<a class=\"mw-redirect\" title=\"Playstation 3\" href=\"http://en.wikipedia.org/wiki/Playstation_3\">Playstation 3</a> and <a title=\"Xbox 360\" href=\"http://en.wikipedia.org/wiki/Xbox_360\">Xbox 360</a>) with their network services can act as a media center devices by default.','What is a Media Center',0,'','inherit','open','open','','4-revision','','','2009-01-13 12:14:09','2009-01-13 02:14:09','',4,'http://moztronics.com.au/?p=5',0,'revision','',0),(6,1,'2009-01-01 12:16:15','2009-01-01 02:16:15','<!--more--><a href=\"http://moztronics.com.au/wp-content/uploads/2009/01/voip_phone.jpg\"><img class=\"size-medium wp-image-100 alignright\" style=\"border: 0pt none;\" title=\"VOIP Handset\" src=\"http://moztronics.com.au/wp-content/uploads/2009/01/voip_phone-300x300.jpg\" alt=\"\" width=\"200\" height=\"200\" /></a><strong>Voice over Internet Protocol</strong> is a general term for a family of transmission technologies for delivery of voice communications over the <a title=\"Internet\" href=\"http://en.wikipedia.org/wiki/Internet\">Internet</a> or other <a class=\"mw-redirect\" title=\"Packet-switched\" href=\"http://en.wikipedia.org/wiki/Packet-switched\">packet-switched</a> <a title=\"Computer network\" href=\"http://en.wikipedia.org/wiki/Computer_network\">networks</a>. Other terms frequently encountered and synonymous with VoIP are <em>IP telephony</em> and <em>Internet telephony</em>, as well as <em>voice over broadband</em>, <em><a title=\"Broadband\" href=\"http://en.wikipedia.org/wiki/Broadband\">broadband</a> telephony</em>, and <em>broadband phone</em>, when the network connectivity is available over broadband Internet access.\r\n\r\nVoIP systems usually interface with the traditional <a title=\"Public switched telephone network\" href=\"http://en.wikipedia.org/wiki/Public_switched_telephone_network\">public switched telephone network</a> (PSTN) to allow for transparent phone communications worldwide<sup id=\"cite_ref-0\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Voip#cite_note-0\"><span>[</span>1<span>]</span></a></sup>.\r\n\r\nVoIP can be a benefit for reducing communication and infrastructure costs by routing phone calls over existing data networks and avoiding duplicate network systems.\r\n\r\nVoice-over-IP systems carry telephony speech as <a title=\"Digital audio\" href=\"http://en.wikipedia.org/wiki/Digital_audio\">digital audio</a>, typically reduced in data rate using <a class=\"mw-redirect\" title=\"Speech data compression\" href=\"http://en.wikipedia.org/wiki/Speech_data_compression\">speech data compression</a> techniques, packetized in small units of typically tens of milliseconds of speech, and <a title=\"Data encapsulation\" href=\"http://en.wikipedia.org/wiki/Data_encapsulation\">encapsulated</a> in a packet stream over IP.','What is VoIP?',0,'','publish','closed','closed','','what-is-voip','','','2009-01-13 23:11:02','2009-01-13 13:11:02','',0,'http://moztronics.com.au/?p=6',0,'post','',0),(7,1,'2009-01-13 12:15:58','2009-01-13 02:15:58','<strong>Voice over Internet Protocol</strong> (<strong>VoIP</strong>, <small>IPA</small>: <span class=\"IPA\" title=\"Pronunciation in IPA\"><a title=\"Wikipedia:IPA for English\" href=\"http://en.wikipedia.org/wiki/Wikipedia:IPA_for_English\">/v??p/</a></span>) is a general term for a family of transmission technologies for delivery of voice communications over the <a title=\"Internet\" href=\"http://en.wikipedia.org/wiki/Internet\">Internet</a> or other <a class=\"mw-redirect\" title=\"Packet-switched\" href=\"http://en.wikipedia.org/wiki/Packet-switched\">packet-switched</a> <a title=\"Computer network\" href=\"http://en.wikipedia.org/wiki/Computer_network\">networks</a>. Other terms frequently encountered and synonymous with VoIP are <em>IP telephony</em> and <em>Internet telephony</em>, as well as <em>voice over broadband</em>, <em><a title=\"Broadband\" href=\"http://en.wikipedia.org/wiki/Broadband\">broadband</a> telephony</em>, and <em>broadband phone</em>, when the network connectivity is available over broadband Internet access.\n\nVoIP systems usually interface with the traditional <a title=\"Public switched telephone network\" href=\"http://en.wikipedia.org/wiki/Public_switched_telephone_network\">public switched telephone network</a> (PSTN) to allow for transparent phone communications worldwide<sup id=\"cite_ref-0\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Voip#cite_note-0\"><span>[</span>1<span>]</span></a></sup>.\n\nVoIP can be a benefit for reducing communication and infrastructure costs by routing phone calls over existing data networks and avoiding duplicate network systems.\n\nVoice-over-IP systems carry telephony speech as <a title=\"Digital audio\" href=\"http://en.wikipedia.org/wiki/Digital_audio\">digital audio</a>, typically reduced in data rate using <a class=\"mw-redirect\" title=\"Speech data compression\" href=\"http://en.wikipedia.org/wiki/Speech_data_compression\">speech data compression</a> techniques, packetized in small units of typically tens of milliseconds of speech, and <a title=\"Data encapsulation\" href=\"http://en.wikipedia.org/wiki/Data_encapsulation\">encapsulated</a> in a packet stream over IP.','What is VoIP?',0,'','inherit','open','open','','6-revision','','','2009-01-13 12:15:58','2009-01-13 02:15:58','',6,'http://moztronics.com.au/?p=7',0,'revision','',0),(80,1,'2009-01-13 12:20:07','2009-01-13 02:20:07','<strong>Computer networking</strong> is the <a title=\"Engineering\" href=\"http://en.wikipedia.org/wiki/Engineering\">engineering</a> <a title=\"Discipline\" href=\"http://en.wikipedia.org/wiki/Discipline\">discipline</a> concerned with communication between <a class=\"mw-redirect\" title=\"Computer system\" href=\"http://en.wikipedia.org/wiki/Computer_system\">computer systems</a> or <a class=\"mw-redirect\" title=\"Peripheral device\" href=\"http://en.wikipedia.org/wiki/Peripheral_device\">devices</a>. Networking, routers, routing protocols, and networking over the public <a title=\"Internet\" href=\"http://en.wikipedia.org/wiki/Internet\">Internet</a> have their specifications defined in documents called <a title=\"Request for Comments\" href=\"http://en.wikipedia.org/wiki/Request_for_Comments\">RFCs</a>.<sup id=\"cite_ref-0\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_networking#cite_note-0\"><span>[</span>1<span>]</span></a></sup> Computer networking is sometimes considered a sub-discipline of <a class=\"mw-redirect\" title=\"Telecommunications\" href=\"http://en.wikipedia.org/wiki/Telecommunications\">telecommunications</a>, <a title=\"Computer science\" href=\"http://en.wikipedia.org/wiki/Computer_science\">computer science</a>, <a title=\"Information technology\" href=\"http://en.wikipedia.org/wiki/Information_technology\">information technology</a> and/or <a title=\"Computer engineering\" href=\"http://en.wikipedia.org/wiki/Computer_engineering\">computer engineering</a>. Computer networks rely heavily upon the theoretical and practical application of these scientific and engineering disciplines.\r\n\r\nA computer network is any set of computers or devices connected to each other with the ability to exchange data.<sup id=\"cite_ref-1\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_networking#cite_note-1\"><span>[</span>2<span>]</span></a></sup> Examples of different networks are:\r\n<ul>\r\n	<li><a title=\"Local area network\" href=\"http://en.wikipedia.org/wiki/Local_area_network\">Local area network</a> (LAN), which is usually a small network constrained to a small geographic area.</li>\r\n	<li><a title=\"Wide area network\" href=\"http://en.wikipedia.org/wiki/Wide_area_network\">Wide area network</a> (WAN) that is usually a larger network that covers a large geographic area.</li>\r\n	<li><a title=\"Wireless network\" href=\"http://en.wikipedia.org/wiki/Wireless_network\">Wireless LANs and WANs</a> (WLAN &amp; WWAN) are the wireless equivalent of the LAN and WAN.</li>\r\n</ul>\r\nAll networks are interconnected to allow communication with a variety of different kinds of media, including <a title=\"Twisted pair\" href=\"http://en.wikipedia.org/wiki/Twisted_pair\">twisted-pair</a> copper wire cable, <a title=\"Coaxial cable\" href=\"http://en.wikipedia.org/wiki/Coaxial_cable\">coaxial cable</a>, <a title=\"Fiber-optic communication\" href=\"http://en.wikipedia.org/wiki/Fiber-optic_communication\">optical fiber</a>, and various wireless technologies.<sup id=\"cite_ref-2\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_networking#cite_note-2\"><span>[</span>3<span>]</span></a></sup> The devices can be separated by a few meters (e.g. via <a title=\"Bluetooth\" href=\"http://en.wikipedia.org/wiki/Bluetooth\">Bluetooth</a>) or nearly unlimited distances (e.g. via the interconnections of the <a title=\"Internet\" href=\"http://en.wikipedia.org/wiki/Internet\">Internet</a><sup id=\"cite_ref-3\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_networking#cite_note-3\"><span>[</span>4<span>]</span></a></sup>).','What is Computer Networking?',0,'','inherit','closed','open','','10-revision-2','','','2009-01-13 12:20:07','2009-01-13 02:20:07','',10,'http://moztronics.com.au/?p=80',0,'revision','',0),(8,1,'2009-01-01 11:18:42','2009-01-01 01:18:42','<strong>C-Bus</strong> is a home and building automation <a title=\"Communications protocol\" href=\"http://en.wikipedia.org/wiki/Communications_protocol\">protocol</a> that is used in <a title=\"Australia\" href=\"http://en.wikipedia.org/wiki/Australia\">Australia</a>, <a title=\"New Zealand\" href=\"http://en.wikipedia.org/wiki/New_Zealand\">New Zealand</a>, <a title=\"Asia\" href=\"http://en.wikipedia.org/wiki/Asia\">Asia</a>, the <a title=\"Middle East\" href=\"http://en.wikipedia.org/wiki/Middle_East\">Middle East</a>, <a title=\"Russia\" href=\"http://en.wikipedia.org/wiki/Russia\">Russia</a>, <a class=\"mw-redirect\" title=\"USA\" href=\"http://en.wikipedia.org/wiki/USA\">USA</a>, <a title=\"South Africa\" href=\"http://en.wikipedia.org/wiki/South_Africa\">South Africa</a>, the <a class=\"mw-redirect\" title=\"UK\" href=\"http://en.wikipedia.org/wiki/UK\">UK</a> and other parts of Europe including <a title=\"Greece\" href=\"http://en.wikipedia.org/wiki/Greece\">Greece</a> and <a title=\"Romania\" href=\"http://en.wikipedia.org/wiki/Romania\">Romania</a>. C-Bus was created by <a title=\"Clipsal\" href=\"http://en.wikipedia.org/wiki/Clipsal\">Clipsal</a>\'s <em>Clipsal Integrated Systems</em> division for use with its brand of home automation and building lighting control system. C-Bus has recently become available in the <a class=\"mw-redirect\" title=\"USA\" href=\"http://en.wikipedia.org/wiki/USA\">USA</a> under the \'SquareD Clipsal\' brand name.\r\n\r\nC-Bus is used in the control of <a class=\"mw-redirect\" title=\"Domotics\" href=\"http://en.wikipedia.org/wiki/Domotics\">domotics</a>, or <a title=\"Home automation\" href=\"http://en.wikipedia.org/wiki/Home_automation\">home automation</a> systems, as well as commercial building lighting control systems. Unlike the more common <a title=\"X10 (industry standard)\" href=\"http://en.wikipedia.org/wiki/X10_%28industry_standard%29\">X10</a> protocol which uses a signal imposed upon the <a title=\"Power line communication\" href=\"http://en.wikipedia.org/wiki/Power_line_communication\">AC power line</a>, C-Bus uses a dedicated low-voltage cable or two-way wireless network to carry command and control signals. This improves the reliability of command transmission and makes C-Bus far more suitable for large, commercial applications than X10.\r\n\r\nThe C-Bus System can be used to control lighting and other electrical systems and products via <a title=\"Remote control\" href=\"http://en.wikipedia.org/wiki/Remote_control\">remote control</a> and can also be interfaced to a home security system, AV products or other electrical items. The C-Bus system is available in a wired version and a <a title=\"Wireless\" href=\"http://en.wikipedia.org/wiki/Wireless\">wireless</a> version, with a gateway available to allow messages to be sent between wired and wireless networks.\r\n\r\nThe wired C-Bus system uses a standard category 5 UTP (Unshielded Twisted Pair) cable as its network communications cable. Clipsal manufacture a specific category 5 cable for use within electrical distribution panels. This cable has a pink outer sheath which is rated to ensure adequate electrical isolation between the mains voltages found in distribution panels and the extra low voltage C-Bus. Outside of distribution panels standard category 5 UTP cable can be used.\r\n\r\nThe category 5 C-Bus network wiring uses a free topology architecture. The maximum length of cable used on a C-Bus network is 1000 metres; however this is easily extended using C-Bus Network Bridges. Up to 100 units can be installed on a C-Bus network and this can also be extended using Network Bridges.\r\n\r\nThe maximum number of C-Bus networks in one installation is 255 (note that this limitation does not apply if a C-Bus Ethernet Interface is utilised, the system size is then limited to IP Addressing only). The maximum number of networks connected in series to the local network via Network Bridges is seven (i.e. using six network bridges).\r\n\r\nEach standard C-Bus unit requires 18mA @ 15-36Vdc to operate. However some C-Bus units require up to 40mA.\r\n\r\nMore than one C-Bus power supply can be connected to a C-Bus network to provide sufficient power to the C-Bus units, the C-Bus power supplies will share the load evenly.\r\n\r\nEach C-Bus network requires a network burden. This network burden can be enabled on C-Bus output units through software or a hardware burden can be connected to the network.\r\n\r\nEach C-Bus network requires at least one system clock generating unit for data synchronisation.\r\n\r\nThe isolation between the mains supply circuitry and the 36V dc C-Bus circuitry is greater than 3.5kV. This is achieved using double wound transformers and opto isolators. This means the C-Bus wiring, connections and circuitry can be considered Extra Low Voltage.','What is C-Bus?',0,'','publish','closed','closed','','what-is-c-bus','','','2009-01-13 20:58:49','2009-01-13 10:58:49','',0,'http://moztronics.com.au/?p=8',0,'post','',0),(9,1,'2009-01-13 12:18:19','2009-01-13 02:18:19','<strong>C-Bus</strong> is a home and building automation <a title=\"Communications protocol\" href=\"http://en.wikipedia.org/wiki/Communications_protocol\">protocol</a> that is used in <a title=\"Australia\" href=\"http://en.wikipedia.org/wiki/Australia\">Australia</a>, <a title=\"New Zealand\" href=\"http://en.wikipedia.org/wiki/New_Zealand\">New Zealand</a>, <a title=\"Asia\" href=\"http://en.wikipedia.org/wiki/Asia\">Asia</a>, the <a title=\"Middle East\" href=\"http://en.wikipedia.org/wiki/Middle_East\">Middle East</a>, <a title=\"Russia\" href=\"http://en.wikipedia.org/wiki/Russia\">Russia</a>, <a class=\"mw-redirect\" title=\"USA\" href=\"http://en.wikipedia.org/wiki/USA\">USA</a>, <a title=\"South Africa\" href=\"http://en.wikipedia.org/wiki/South_Africa\">South Africa</a>, the <a class=\"mw-redirect\" title=\"UK\" href=\"http://en.wikipedia.org/wiki/UK\">UK</a> and other parts of Europe including <a title=\"Greece\" href=\"http://en.wikipedia.org/wiki/Greece\">Greece</a> and <a title=\"Romania\" href=\"http://en.wikipedia.org/wiki/Romania\">Romania</a>. C-Bus was created by <a title=\"Clipsal\" href=\"http://en.wikipedia.org/wiki/Clipsal\">Clipsal</a>\'s <em>Clipsal Integrated Systems</em> division for use with its brand of home automation and building lighting control system. C-Bus has recently become available in the <a class=\"mw-redirect\" title=\"USA\" href=\"http://en.wikipedia.org/wiki/USA\">USA</a> under the \'SquareD Clipsal\' brand name.\n\nC-Bus is used in the control of <a class=\"mw-redirect\" title=\"Domotics\" href=\"http://en.wikipedia.org/wiki/Domotics\">domotics</a>, or <a title=\"Home automation\" href=\"http://en.wikipedia.org/wiki/Home_automation\">home automation</a> systems, as well as commercial building lighting control systems. Unlike the more common <a title=\"X10 (industry standard)\" href=\"http://en.wikipedia.org/wiki/X10_%28industry_standard%29\">X10</a> protocol which uses a signal imposed upon the <a title=\"Power line communication\" href=\"http://en.wikipedia.org/wiki/Power_line_communication\">AC power line</a>, C-Bus uses a dedicated low-voltage cable or two-way wireless network to carry command and control signals. This improves the reliability of command transmission and makes C-Bus far more suitable for large, commercial applications than X10.','What is C-Bus?',0,'','inherit','open','open','','8-revision','','','2009-01-13 12:18:19','2009-01-13 02:18:19','',8,'http://moztronics.com.au/?p=9',0,'revision','',0),(10,1,'2009-01-01 12:20:07','2009-01-01 02:20:07','<strong>Computer networking</strong> is the <a title=\"Engineering\" href=\"http://en.wikipedia.org/wiki/Engineering\">engineering</a> <a title=\"Discipline\" href=\"http://en.wikipedia.org/wiki/Discipline\">discipline</a> concerned with communication between <a class=\"mw-redirect\" title=\"Computer system\" href=\"http://en.wikipedia.org/wiki/Computer_system\">computer systems</a> or <a class=\"mw-redirect\" title=\"Peripheral device\" href=\"http://en.wikipedia.org/wiki/Peripheral_device\">devices</a>. Networking, routers, routing protocols, and networking over the public <a title=\"Internet\" href=\"http://en.wikipedia.org/wiki/Internet\">Internet</a> have their specifications defined in documents called <a title=\"Request for Comments\" href=\"http://en.wikipedia.org/wiki/Request_for_Comments\">RFCs</a>.<sup id=\"cite_ref-0\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_networking#cite_note-0\"><span>[</span>1<span>]</span></a></sup> Computer networking is sometimes considered a sub-discipline of <a class=\"mw-redirect\" title=\"Telecommunications\" href=\"http://en.wikipedia.org/wiki/Telecommunications\">telecommunications</a>, <a title=\"Computer science\" href=\"http://en.wikipedia.org/wiki/Computer_science\">computer science</a>, <a title=\"Information technology\" href=\"http://en.wikipedia.org/wiki/Information_technology\">information technology</a> and/or <a title=\"Computer engineering\" href=\"http://en.wikipedia.org/wiki/Computer_engineering\">computer engineering</a>. Computer networks rely heavily upon the theoretical and practical application of these scientific and engineering disciplines.\r\n\r\nA computer network is any set of computers or devices connected to each other with the ability to exchange data.<sup id=\"cite_ref-1\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_networking#cite_note-1\"><span>[</span>2<span>]</span></a></sup> Examples of different networks are:\r\n<ul>\r\n	<li><a title=\"Local area network\" href=\"http://en.wikipedia.org/wiki/Local_area_network\">Local area network</a> (LAN), which is usually a small network constrained to a small geographic area.</li>\r\n	<li><a title=\"Wide area network\" href=\"http://en.wikipedia.org/wiki/Wide_area_network\">Wide area network</a> (WAN) that is usually a larger network that covers a large geographic area.</li>\r\n	<li><a title=\"Wireless network\" href=\"http://en.wikipedia.org/wiki/Wireless_network\">Wireless LANs and WANs</a> (WLAN &amp; WWAN) are the wireless equivalent of the LAN and WAN.</li>\r\n</ul>\r\nAll networks are interconnected to allow communication with a variety of different kinds of media, including <a title=\"Twisted pair\" href=\"http://en.wikipedia.org/wiki/Twisted_pair\">twisted-pair</a> copper wire cable, <a title=\"Coaxial cable\" href=\"http://en.wikipedia.org/wiki/Coaxial_cable\">coaxial cable</a>, <a title=\"Fiber-optic communication\" href=\"http://en.wikipedia.org/wiki/Fiber-optic_communication\">optical fiber</a>, and various wireless technologies.<sup id=\"cite_ref-2\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_networking#cite_note-2\"><span>[</span>3<span>]</span></a></sup> The devices can be separated by a few meters (e.g. via <a title=\"Bluetooth\" href=\"http://en.wikipedia.org/wiki/Bluetooth\">Bluetooth</a>) or nearly unlimited distances (e.g. via the interconnections of the <a title=\"Internet\" href=\"http://en.wikipedia.org/wiki/Internet\">Internet</a><sup id=\"cite_ref-3\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_networking#cite_note-3\"><span>[</span>4<span>]</span></a></sup>).','What is Computer Networking?',0,'','publish','closed','open','','what-is-computer-networking','','','2009-01-13 21:01:03','2009-01-13 11:01:03','',0,'http://moztronics.com.au/?p=10',0,'post','',0),(11,1,'2009-01-13 12:19:46','2009-01-13 02:19:46','<strong>Computer networking</strong> is the <a title=\"Engineering\" href=\"http://en.wikipedia.org/wiki/Engineering\">engineering</a> <a title=\"Discipline\" href=\"http://en.wikipedia.org/wiki/Discipline\">discipline</a> concerned with communication between <a class=\"mw-redirect\" title=\"Computer system\" href=\"http://en.wikipedia.org/wiki/Computer_system\">computer systems</a> or <a class=\"mw-redirect\" title=\"Peripheral device\" href=\"http://en.wikipedia.org/wiki/Peripheral_device\">devices</a>. Networking, routers, routing protocols, and networking over the public <a title=\"Internet\" href=\"http://en.wikipedia.org/wiki/Internet\">Internet</a> have their specifications defined in documents called <a title=\"Request for Comments\" href=\"http://en.wikipedia.org/wiki/Request_for_Comments\">RFCs</a>.<sup id=\"cite_ref-0\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_networking#cite_note-0\"><span>[</span>1<span>]</span></a></sup> Computer networking is sometimes considered a sub-discipline of <a class=\"mw-redirect\" title=\"Telecommunications\" href=\"http://en.wikipedia.org/wiki/Telecommunications\">telecommunications</a>, <a title=\"Computer science\" href=\"http://en.wikipedia.org/wiki/Computer_science\">computer science</a>, <a title=\"Information technology\" href=\"http://en.wikipedia.org/wiki/Information_technology\">information technology</a> and/or <a title=\"Computer engineering\" href=\"http://en.wikipedia.org/wiki/Computer_engineering\">computer engineering</a>. Computer networks rely heavily upon the theoretical and practical application of these scientific and engineering disciplines.\n\nA computer network is any set of computers or devices connected to each other with the ability to exchange data.<sup id=\"cite_ref-1\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_networking#cite_note-1\"><span>[</span>2<span>]</span></a></sup> Examples of different networks are:\n<ul>\n	<li><a title=\"Local area network\" href=\"http://en.wikipedia.org/wiki/Local_area_network\">Local area network</a> (LAN), which is usually a small network constrained to a small geographic area.</li>\n	<li><a title=\"Wide area network\" href=\"http://en.wikipedia.org/wiki/Wide_area_network\">Wide area network</a> (WAN) that is usually a larger network that covers a large geographic area.</li>\n	<li><a title=\"Wireless network\" href=\"http://en.wikipedia.org/wiki/Wireless_network\">Wireless LANs and WANs</a> (WLAN &amp; WWAN) are the wireless equivalent of the LAN and WAN.</li>\n</ul>\nAll networks are interconnected to allow communication with a variety of different kinds of media, including <a title=\"Twisted pair\" href=\"http://en.wikipedia.org/wiki/Twisted_pair\">twisted-pair</a> copper wire cable, <a title=\"Coaxial cable\" href=\"http://en.wikipedia.org/wiki/Coaxial_cable\">coaxial cable</a>, <a title=\"Fiber-optic communication\" href=\"http://en.wikipedia.org/wiki/Fiber-optic_communication\">optical fiber</a>, and various wireless technologies.<sup id=\"cite_ref-2\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_networking#cite_note-2\"><span>[</span>3<span>]</span></a></sup> The devices can be separated by a few meters (e.g. via <a title=\"Bluetooth\" href=\"http://en.wikipedia.org/wiki/Bluetooth\">Bluetooth</a>) or nearly unlimited distances (e.g. via the interconnections of the <a title=\"Internet\" href=\"http://en.wikipedia.org/wiki/Internet\">Internet</a><sup id=\"cite_ref-3\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_networking#cite_note-3\"><span>[</span>4<span>]</span></a></sup>).','What is Computer Networking?',0,'','inherit','open','open','','10-revision','','','2009-01-13 12:19:46','2009-01-13 02:19:46','',10,'http://moztronics.com.au/?p=11',0,'revision','',0),(12,1,'2009-01-01 12:21:34','2009-01-01 02:21:34','<strong>Security</strong> is the condition of being protected against danger, loss, and criminals. In the general sense, security is a concept similar to <a title=\"Safety\" href=\"http://en.wikipedia.org/wiki/Safety\">safety</a>. The nuance between the two is an added emphasis on being protected from dangers that originate from outside. Individuals or actions that encroach upon the condition of protection are responsible for the breach of security.\r\n<ul>\r\n	<li>A condition that results from the establishment and <a class=\"mw-redirect\" title=\"Repair and maintenance\" href=\"http://en.wikipedia.org/wiki/Repair_and_maintenance\">maintenance</a> of protective measures that ensure a state of inviolability from hostile acts or influences.</li>\r\n	<li>With respect to classified matter, the condition that prevents unauthorized persons from having <a title=\"Access\" href=\"http://en.wikipedia.org/wiki/Access\">access</a> to official <a title=\"Information\" href=\"http://en.wikipedia.org/wiki/Information\">information</a> that is safeguarded in the interests of <a title=\"National security\" href=\"http://en.wikipedia.org/wiki/National_security\">national security</a>.</li>\r\n	<li>Measures taken by a military unit, an activity or installation to protect itself against all acts designed to, or which may, impair its effectiveness.</li>\r\n</ul>\r\nSecurity has to be compared and contrasted with other related concepts: <a title=\"Safety\" href=\"http://en.wikipedia.org/wiki/Safety\">Safety</a>, <a class=\"extiw\" title=\"wiktionary:continuity\" href=\"http://en.wiktionary.org/wiki/continuity\">continuity</a>, <a title=\"Reliability engineering\" href=\"http://en.wikipedia.org/wiki/Reliability_engineering\">reliability</a>. The key difference between security and reliability is that security must take into account the actions of active malicious agents attempting to cause destruction.','What is Security?',0,'','publish','closed','closed','','what-is-security','','','2009-01-13 21:01:34','2009-01-13 11:01:34','',0,'http://moztronics.com.au/?p=12',0,'post','',0),(14,1,'2009-01-11 03:57:57','2009-01-11 10:57:57','Welcome to WordPress. This is your first post. Edit or delete it, then start blogging!','Hello world!',0,'','inherit','open','open','','1-revision','','','2009-01-11 03:57:57','2009-01-11 10:57:57','',1,'http://moztronics.com.au/?p=14',0,'revision','',0),(16,1,'2009-01-13 12:31:35','2009-01-13 02:31:35','Welcome to Moztronics','Intro',0,'','inherit','open','open','','1-revision-3','','','2009-01-13 12:31:35','2009-01-13 02:31:35','',1,'http://moztronics.com.au/?p=16',0,'revision','',0),(18,1,'2009-01-13 13:02:21','2009-01-13 03:02:21','','What is Electrical Engineering?',0,'','inherit','open','open','','17-revision','','','2009-01-13 13:02:21','2009-01-13 03:02:21','',17,'http://moztronics.com.au/?p=18',0,'revision','',0),(13,1,'2009-01-13 12:21:10','2009-01-13 02:21:10','<strong>Computer networking</strong> is the <a title=\"Engineering\" href=\"http://en.wikipedia.org/wiki/Engineering\">engineering</a> <a title=\"Discipline\" href=\"http://en.wikipedia.org/wiki/Discipline\">discipline</a> concerned with communication between <a class=\"mw-redirect\" title=\"Computer system\" href=\"http://en.wikipedia.org/wiki/Computer_system\">computer systems</a> or <a class=\"mw-redirect\" title=\"Peripheral device\" href=\"http://en.wikipedia.org/wiki/Peripheral_device\">devices</a>. Networking, routers, routing protocols, and networking over the public <a title=\"Internet\" href=\"http://en.wikipedia.org/wiki/Internet\">Internet</a> have their specifications defined in documents called <a title=\"Request for Comments\" href=\"http://en.wikipedia.org/wiki/Request_for_Comments\">RFCs</a>.<sup id=\"cite_ref-0\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_networking#cite_note-0\"><span>[</span>1<span>]</span></a></sup> Computer networking is sometimes considered a sub-discipline of <a class=\"mw-redirect\" title=\"Telecommunications\" href=\"http://en.wikipedia.org/wiki/Telecommunications\">telecommunications</a>, <a title=\"Computer science\" href=\"http://en.wikipedia.org/wiki/Computer_science\">computer science</a>, <a title=\"Information technology\" href=\"http://en.wikipedia.org/wiki/Information_technology\">information technology</a> and/or <a title=\"Computer engineering\" href=\"http://en.wikipedia.org/wiki/Computer_engineering\">computer engineering</a>. Computer networks rely heavily upon the theoretical and practical application of these scientific and engineering disciplines.\n\nA computer network is any set of computers or devices connected to each other with the ability to exchange data.<sup id=\"cite_ref-1\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_networking#cite_note-1\"><span>[</span>2<span>]</span></a></sup> Examples of different networks are:\n<ul>\n	<li><a title=\"Local area network\" href=\"http://en.wikipedia.org/wiki/Local_area_network\">Local area network</a> (LAN), which is usually a small network constrained to a small geographic area.</li>\n	<li><a title=\"Wide area network\" href=\"http://en.wikipedia.org/wiki/Wide_area_network\">Wide area network</a> (WAN) that is usually a larger network that covers a large geographic area.</li>\n	<li><a title=\"Wireless network\" href=\"http://en.wikipedia.org/wiki/Wireless_network\">Wireless LANs and WANs</a> (WLAN &amp; WWAN) are the wireless equivalent of the LAN and WAN.</li>\n</ul>\nAll networks are interconnected to allow communication with a variety of different kinds of media, including <a title=\"Twisted pair\" href=\"http://en.wikipedia.org/wiki/Twisted_pair\">twisted-pair</a> copper wire cable, <a title=\"Coaxial cable\" href=\"http://en.wikipedia.org/wiki/Coaxial_cable\">coaxial cable</a>, <a title=\"Fiber-optic communication\" href=\"http://en.wikipedia.org/wiki/Fiber-optic_communication\">optical fiber</a>, and various wireless technologies.<sup id=\"cite_ref-2\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_networking#cite_note-2\"><span>[</span>3<span>]</span></a></sup> The devices can be separated by a few meters (e.g. via <a title=\"Bluetooth\" href=\"http://en.wikipedia.org/wiki/Bluetooth\">Bluetooth</a>) or nearly unlimited distances (e.g. via the interconnections of the <a title=\"Internet\" href=\"http://en.wikipedia.org/wiki/Internet\">Internet</a><sup id=\"cite_ref-3\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_networking#cite_note-3\"><span>[</span>4<span>]</span></a></sup>).','What is Security?',0,'','inherit','open','open','','12-revision','','','2009-01-13 12:21:10','2009-01-13 02:21:10','',12,'http://moztronics.com.au/?p=13',0,'revision','',0),(19,1,'2009-01-01 15:08:23','2009-01-01 05:08:23','<strong>Surveillance</strong> is the monitoring of <a title=\"Behavior\" href=\"http://en.wikipedia.org/wiki/Behavior\">behavior</a>. <strong>Systems surveillance</strong> is the process of monitoring the behavior of people, objects or processes within systems for conformity to expected or desired <a title=\"Norm (sociology)\" href=\"http://en.wikipedia.org/wiki/Norm_%28sociology%29\">norms</a> in <a class=\"mw-redirect\" title=\"Trusted systems\" href=\"http://en.wikipedia.org/wiki/Trusted_systems\">trusted systems</a> for <a title=\"Security\" href=\"http://en.wikipedia.org/wiki/Security\">security</a> or <a title=\"Social control\" href=\"http://en.wikipedia.org/wiki/Social_control\">social control</a>. <a title=\"Clinical surveillance\" href=\"http://en.wikipedia.org/wiki/Clinical_surveillance\">Clinical surveillance</a> refers to the monitoring of <a title=\"Disease\" href=\"http://en.wikipedia.org/wiki/Disease\">diseases</a> or <a title=\"Public health\" href=\"http://en.wikipedia.org/wiki/Public_health\">public health</a>–related indicators (for example symptoms indicating an act of bioterrorism) by <a title=\"Epidemiology\" href=\"http://en.wikipedia.org/wiki/Epidemiology\">epidemiologists</a> and public health professionals. The word is pronounced <span class=\"IPA\" title=\"Pronunciation in the International Phonetic Alphabet (IPA)\"><a title=\"Wikipedia:IPA for English\" href=\"http://en.wikipedia.org/wiki/Wikipedia:IPA_for_English\">/s??ve??ns/</a></span> or <span class=\"IPA\" title=\"Representation in the International Phonetic Alphabet (IPA)\">/s??ve?l?ns/</span>.<sup id=\"cite_ref-0\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Surveillance#cite_note-0\"><span>[</span>1<span>]</span></a></sup>\r\n\r\nAlthough the word <em>surveillance</em> in <a title=\"French language\" href=\"http://en.wikipedia.org/wiki/French_language\">French</a> literally means \"watching over\",<sup id=\"cite_ref-1\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Surveillance#cite_note-1\"><span>[</span>2<span>]</span></a></sup> the term is often used for all forms of observation or monitoring, not just visual observation. Nevertheless, the all-seeing \"<a title=\"Eye in the sky (camera)\" href=\"http://en.wikipedia.org/wiki/Eye_in_the_sky_%28camera%29\">eye in the sky</a>\" is still a general icon of surveillance. Surveillance in many modern cities and buildings often uses <a title=\"Closed-circuit television\" href=\"http://en.wikipedia.org/wiki/Closed-circuit_television\">closed-circuit television</a> cameras. Although surveillance can be a useful tool for <a title=\"Police\" href=\"http://en.wikipedia.org/wiki/Police\">law enforcement</a> and security companies, many people have concerns about the loss of <a title=\"Privacy\" href=\"http://en.wikipedia.org/wiki/Privacy\">privacy</a>.\r\n\r\nThe word <em>surveillance</em> is commonly used to describe observation from a distance by means of electronic equipment or other <a title=\"Technology\" href=\"http://en.wikipedia.org/wiki/Technology\">technological</a> means. However, surveillance also includes simple, relatively no- or low-technology methods such as direct observation, observation with <a title=\"Binoculars\" href=\"http://en.wikipedia.org/wiki/Binoculars\">binoculars</a>, <a title=\"Postal interception\" href=\"http://en.wikipedia.org/wiki/Postal_interception\">postal interception</a>, or similar methods.','What is Surveillance?',0,'','publish','closed','open','','what-is-surveillance','','','2009-01-13 20:56:42','2009-01-13 10:56:42','',0,'http://moztronics.com.au/?p=19',0,'post','',0),(20,1,'2009-01-13 15:07:58','2009-01-13 05:07:58','','What is Surveillance?',0,'','inherit','closed','open','','19-revision','','','2009-01-13 15:07:58','2009-01-13 05:07:58','',19,'http://moztronics.com.au/?p=20',0,'revision','',0),(21,1,'2009-01-01 09:10:20','2008-12-31 23:10:20','<strong>Antivirus software</strong> (or anti-virus) is <a title=\"Computer software\" href=\"http://en.wikipedia.org/wiki/Computer_software\">computer software</a> used to identify and remove <a title=\"Computer virus\" href=\"http://en.wikipedia.org/wiki/Computer_virus\">computer viruses</a>, as well as many other types of harmful computer software, collectively referred to as <a title=\"Malware\" href=\"http://en.wikipedia.org/wiki/Malware\">malware</a>. While the first antivirus software was designed exclusively to combat <a title=\"Computer virus\" href=\"http://en.wikipedia.org/wiki/Computer_virus\">computer viruses</a> (hence \"antivirus\"), modern antivirus software can protect computer systems against a wide range of malware, including <a title=\"Computer worm\" href=\"http://en.wikipedia.org/wiki/Computer_worm\">worms</a>, <a title=\"Phishing\" href=\"http://en.wikipedia.org/wiki/Phishing\">phishing</a> attacks, <a title=\"Rootkit\" href=\"http://en.wikipedia.org/wiki/Rootkit\">rootkits</a>, and <a title=\"Trojan horse (computing)\" href=\"http://en.wikipedia.org/wiki/Trojan_horse_%28computing%29\">Trojans</a>.\r\n\r\nA <strong>virus removal tool</strong> is <a title=\"Computer software\" href=\"http://en.wikipedia.org/wiki/Computer_software\">software</a> for removing specific <a title=\"Computer virus\" href=\"http://en.wikipedia.org/wiki/Computer_virus\">viruses</a> from infected computers. Unlike complete antivirus scanners, they are usually not intended to detect and remove an extensive list of viruses; rather they are designed to remove specific viruses, usually more effectively than normal antivirus software. Examples of these tools include <a title=\"McAfee Stinger\" href=\"http://en.wikipedia.org/wiki/McAfee_Stinger\">McAfee Stinger</a> and the <a title=\"Microsoft\" href=\"http://en.wikipedia.org/wiki/Microsoft\">Microsoft</a> <a class=\"external text\" title=\"http://www.microsoft.com/security/malwareremove/families.mspx\" rel=\"nofollow\" href=\"http://www.microsoft.com/security/malwareremove/families.mspx\">Malicious Software Removal Tool</a> (which is run automatically by <a class=\"mw-redirect\" title=\"Windows update\" href=\"http://en.wikipedia.org/wiki/Windows_update\">Windows update</a>). Many of these tools are available for free <a class=\"mw-redirect\" title=\"Download\" href=\"http://en.wikipedia.org/wiki/Download\">download</a>.\r\n\r\nThese tools can sometimes do a better job of removing a specific virus than conventional antivirus software.\r\n\r\nAntivirus programs can in themselves pose a security risk as they often run at the \'System\' level of privileges and may hook the kernel - Both of these are necessary for the software to effectively do its job but it has a major downside. This can mean exploitation of the Antivirus program itself could lead to <a title=\"Privilege escalation\" href=\"http://en.wikipedia.org/wiki/Privilege_escalation\">privilege escalation</a> and create a severe security threat. Arguably, use of Antivirus software when compared to <a title=\"Principle of least privilege\" href=\"http://en.wikipedia.org/wiki/Principle_of_least_privilege\">Principle of least privilege</a> is largely ineffective when ramifications of the added software are taken into account.\r\n\r\nWhen purchasing antivirus software, the agreement may include a clause that the subscription will be automatically renewed, and the purchaser\'s credit card automatically billed, at the renewal time without explicit approval. For example, <a title=\"McAfee\" href=\"http://en.wikipedia.org/wiki/McAfee\">McAfee</a> requires one to unsubscribe at least 60 days before the expiration of the present subscription.<sup id=\"cite_ref-2\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Anti-Virus#cite_note-2\"><span>[</span>3<span>]</span></a></sup> Norton Antivirus also renews subscriptions automatically by default. <sup id=\"cite_ref-3\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Anti-Virus#cite_note-3\"><span>[</span>4<span>]</span></a></sup>\r\n\r\nSome antivirus programs are actually <a title=\"Spyware\" href=\"http://en.wikipedia.org/wiki/Spyware\">spyware</a> masquerading as antivirus software. It is best to double-check that the antivirus software which is being downloaded is actually a real antivirus program.<sup id=\"cite_ref-4\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Anti-Virus#cite_note-4\"><span>[</span>5<span>]</span></a></sup>\r\n\r\nAnti-virus manufacturers have been criticised for <a title=\"Fear mongering\" href=\"http://en.wikipedia.org/wiki/Fear_mongering\">fear mongering</a> by exaggerating the risk that virus pose to consumers.<sup id=\"cite_ref-5\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Anti-Virus#cite_note-5\"><span>[</span>6<span>]</span></a></sup>\r\n\r\nIf an antivirus program is configured to immediately delete or quarantine infected files (or does this by default), false positives in essential files can render the operating system or some applications unusable.<sup id=\"cite_ref-6\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Anti-Virus#cite_note-6\"><span>[</span>7<span>]</span></a></sup>','What is Anti-Virus?',0,'','publish','closed','open','','what-is-anti-virus','','','2009-01-13 20:57:45','2009-01-13 10:57:45','',0,'http://moztronics.com.au/?p=21',0,'post','',0),(22,1,'2009-01-13 15:09:33','2009-01-13 05:09:33','<strong>Antivirus software</strong> (or anti-virus) is <a title=\"Computer software\" href=\"http://en.wikipedia.org/wiki/Computer_software\">computer software</a> used to identify and remove <a title=\"Computer virus\" href=\"http://en.wikipedia.org/wiki/Computer_virus\">computer viruses</a>, as well as many other types of harmful computer software, collectively referred to as <a title=\"Malware\" href=\"http://en.wikipedia.org/wiki/Malware\">malware</a>. While the first antivirus software was designed exclusively to combat <a title=\"Computer virus\" href=\"http://en.wikipedia.org/wiki/Computer_virus\">computer viruses</a> (hence \"antivirus\"), modern antivirus software can protect computer systems against a wide range of malware, including <a title=\"Computer worm\" href=\"http://en.wikipedia.org/wiki/Computer_worm\">worms</a>, <a title=\"Phishing\" href=\"http://en.wikipedia.org/wiki/Phishing\">phishing</a> attacks, <a title=\"Rootkit\" href=\"http://en.wikipedia.org/wiki/Rootkit\">rootkits</a>, and <a title=\"Trojan horse (computing)\" href=\"http://en.wikipedia.org/wiki/Trojan_horse_%28computing%29\">Trojans</a>.\n<h2></h2>','What is Anti-Virus?',0,'','inherit','closed','open','','21-revision','','','2009-01-13 15:09:33','2009-01-13 05:09:33','',21,'http://moztronics.com.au/?p=22',0,'revision','',0),(23,1,'2009-01-01 15:11:42','2009-01-01 05:11:42','An <strong>uninterrupted power supply</strong> (<strong>UPS</strong>), also known as a <strong>battery back-up</strong>, provides emergency power and, depending on the topology, line regulation as well to connected equipment by supplying power from a separate source when utility power is not available. It differs from an auxiliary or <a title=\"Emergency power system\" href=\"http://en.wikipedia.org/wiki/Emergency_power_system\">emergency power system</a> or standby generator, which does not provide instant protection from a momentary power interruption. A UPS, however, can be used to provide uninterrupted power to equipment, typically for 5-15 minutes until an auxiliary power supply can be turned on or utility power is restored.\r\n\r\nWhile not limited to safeguarding any particular type of equipment, a UPS is typically used to protect <a title=\"Computer\" href=\"http://en.wikipedia.org/wiki/Computer\">computers</a>, <a title=\"Data center\" href=\"http://en.wikipedia.org/wiki/Data_center\">data centers</a>, <a title=\"Telecommunication\" href=\"http://en.wikipedia.org/wiki/Telecommunication\">telecommunication</a> equipment or other electrical equipment where an unexpected power disruption could cause injuries, fatalities, serious business disruption or data loss. UPS units come in sizes ranging from units which will back up a single computer without monitor (around 200 <a title=\"Volt-ampere\" href=\"http://en.wikipedia.org/wiki/Volt-ampere\">VA</a>) to units which will power entire data centers or buildings (several megawatts).\r\n\r\nThere are various common power problems that UPS units are used to correct. They are as follows (with a typical example of damage that might be caused):\r\n<ol>\r\n	<li><a class=\"mw-redirect\" title=\"Power failure\" href=\"http://en.wikipedia.org/wiki/Power_failure\">Power failure</a> — Total loss of utility power, with possibility of severe transient conditions upon failure and/or restoration: Causes electrical equipment to stop working (transients may cause permanent damage).</li>\r\n	<li><a class=\"mw-redirect\" title=\"Voltage sag\" href=\"http://en.wikipedia.org/wiki/Voltage_sag\">Voltage sag</a> — Transient (short term) under-voltage: Causes flickering of lights.</li>\r\n	<li><a title=\"Voltage spike\" href=\"http://en.wikipedia.org/wiki/Voltage_spike\">Voltage spike</a> — Transient (short term) over-voltage i.e. spike or peak: Causes wear or acute damage to electronic equipment.</li>\r\n	<li><a class=\"mw-redirect\" title=\"Under-voltage (brownout)\" href=\"http://en.wikipedia.org/wiki/Under-voltage_%28brownout%29\">Under-voltage (brownout)</a> — Low line voltage for an extended period of time: Causes overheating in motors.</li>\r\n	<li><a class=\"mw-redirect\" title=\"Over-voltage\" href=\"http://en.wikipedia.org/wiki/Over-voltage\">Over-voltage</a> — Increased voltage for an extended period of time: Causes light bulbs to burnout.</li>\r\n	<li><a class=\"mw-redirect\" title=\"Line noise\" href=\"http://en.wikipedia.org/wiki/Line_noise\">Line noise</a> — Distortions superimposed on the power waveform: Causes electromagnetic interference.</li>\r\n	<li><a class=\"new\" title=\"Frequency variation (page does not exist)\" href=\"http://en.wikipedia.org/w/index.php?title=Frequency_variation&amp;action=edit&amp;redlink=1\">Frequency variation</a> — Deviation from the nominal frequency (50 or 60 Hz): Causes motors to increase or decrease speed and line-driven clocks and timing devices to gain or lose time.</li>\r\n	<li><a class=\"new\" title=\"Switching transient (page does not exist)\" href=\"http://en.wikipedia.org/w/index.php?title=Switching_transient&amp;action=edit&amp;redlink=1\">Switching transient</a> — Instantaneous undervoltage (notch) in the range of milliseconds to seconds: May cause erratic behavior in some equipment, memory loss, data error, data loss and component stress.</li>\r\n	<li><a class=\"mw-redirect\" title=\"Harmonic distortion\" href=\"http://en.wikipedia.org/wiki/Harmonic_distortion\">Harmonic distortion</a> — Multiples of power frequency superimposed on the power waveform: Causes excess heating in wiring and fuses.</li>\r\n</ol>\r\nUPS units are divided into categories based on which of the above problems they address. Manufacturers categorize their products in accordance with the number of power related problems they address.','What is a UPS?',0,'','publish','closed','open','','what-is-a-ups','','','2009-01-13 20:57:11','2009-01-13 10:57:11','',0,'http://moztronics.com.au/?p=23',0,'post','',0),(24,1,'2009-01-13 15:11:31','2009-01-13 05:11:31','An <strong>uninterrupted power supply</strong> (<strong>UPS</strong>), also known as a <strong>battery back-up</strong>, provides emergency power and, depending on the topology, line regulation as well to connected equipment by supplying power from a separate source when utility power is not available. It differs from an auxiliary or <a title=\"Emergency power system\" href=\"http://en.wikipedia.org/wiki/Emergency_power_system\">emergency power system</a> or standby generator, which does not provide instant protection from a momentary power interruption. A UPS, however, can be used to provide uninterrupted power to equipment, typically for 5-15 minutes until an auxiliary power supply can be turned on or utility power is restored.\n\nWhile not limited to safeguarding any particular type of equipment, a UPS is typically used to protect <a title=\"Computer\" href=\"http://en.wikipedia.org/wiki/Computer\">computers</a>, <a title=\"Data center\" href=\"http://en.wikipedia.org/wiki/Data_center\">data centers</a>, <a title=\"Telecommunication\" href=\"http://en.wikipedia.org/wiki/Telecommunication\">telecommunication</a> equipment or other electrical equipment where an unexpected power disruption could cause injuries, fatalities, serious business disruption or data loss. UPS units come in sizes ranging from units which will back up a single computer without monitor (around 200 <a title=\"Volt-ampere\" href=\"http://en.wikipedia.org/wiki/Volt-ampere\">VA</a>) to units which will power entire data centers or buildings (several megawatts).\n\nThere are various common power problems that UPS units are used to correct. They are as follows (with a typical example of damage that might be caused):\n<ol>\n	<li><a class=\"mw-redirect\" title=\"Power failure\" href=\"http://en.wikipedia.org/wiki/Power_failure\">Power failure</a> — Total loss of utility power, with possibility of severe transient conditions upon failure and/or restoration: Causes electrical equipment to stop working (transients may cause permanent damage).</li>\n	<li><a class=\"mw-redirect\" title=\"Voltage sag\" href=\"http://en.wikipedia.org/wiki/Voltage_sag\">Voltage sag</a> — Transient (short term) under-voltage: Causes flickering of lights.</li>\n	<li><a title=\"Voltage spike\" href=\"http://en.wikipedia.org/wiki/Voltage_spike\">Voltage spike</a> — Transient (short term) over-voltage i.e. spike or peak: Causes wear or acute damage to electronic equipment.</li>\n	<li><a class=\"mw-redirect\" title=\"Under-voltage (brownout)\" href=\"http://en.wikipedia.org/wiki/Under-voltage_%28brownout%29\">Under-voltage (brownout)</a> — Low line voltage for an extended period of time: Causes overheating in motors.</li>\n	<li><a class=\"mw-redirect\" title=\"Over-voltage\" href=\"http://en.wikipedia.org/wiki/Over-voltage\">Over-voltage</a> — Increased voltage for an extended period of time: Causes light bulbs to burnout.</li>\n	<li><a class=\"mw-redirect\" title=\"Line noise\" href=\"http://en.wikipedia.org/wiki/Line_noise\">Line noise</a> — Distortions superimposed on the power waveform: Causes electromagnetic interference.</li>\n	<li><a class=\"new\" title=\"Frequency variation (page does not exist)\" href=\"http://en.wikipedia.org/w/index.php?title=Frequency_variation&amp;action=edit&amp;redlink=1\">Frequency variation</a> — Deviation from the nominal frequency (50 or 60 Hz): Causes motors to increase or decrease speed and line-driven clocks and timing devices to gain or lose time.</li>\n	<li><a class=\"new\" title=\"Switching transient (page does not exist)\" href=\"http://en.wikipedia.org/w/index.php?title=Switching_transient&amp;action=edit&amp;redlink=1\">Switching transient</a> — Instantaneous undervoltage (notch) in the range of milliseconds to seconds: May cause erratic behavior in some equipment, memory loss, data error, data loss and component stress.</li>\n	<li><a class=\"mw-redirect\" title=\"Harmonic distortion\" href=\"http://en.wikipedia.org/wiki/Harmonic_distortion\">Harmonic distortion</a> — Multiples of power frequency superimposed on the power waveform: Causes excess heating in wiring and fuses.</li>\n</ol>\nUPS units are divided into categories based on which of the above problems they address. Manufacturers categorize their products in accordance with the number of power related problems they address.','What is a UPS?',0,'','inherit','closed','open','','23-revision','','','2009-01-13 15:11:31','2009-01-13 05:11:31','',23,'http://moztronics.com.au/?p=24',0,'revision','',0),(25,1,'2009-01-01 10:15:04','2009-01-01 00:15:04','<strong>Closed-circuit television</strong> (<strong>CCTV</strong>) is the use of <a title=\"Video camera\" href=\"http://en.wikipedia.org/wiki/Video_camera\">video cameras</a> to transmit a signal to a specific place, limited set of monitors.\r\n\r\nIt differs from <a class=\"mw-redirect\" title=\"Broadcast television\" href=\"http://en.wikipedia.org/wiki/Broadcast_television\">broadcast television</a> in that the signal is not openly transmitted, though it may employ point to point wireless links. CCTV is often used for <a title=\"Surveillance\" href=\"http://en.wikipedia.org/wiki/Surveillance\">surveillance</a> in areas that may need monitoring such as <a title=\"Bank\" href=\"http://en.wikipedia.org/wiki/Bank\">banks</a>, <a title=\"Casino\" href=\"http://en.wikipedia.org/wiki/Casino\">casinos</a>, <a title=\"Airport\" href=\"http://en.wikipedia.org/wiki/Airport\">airports</a>, military installations and convenience stores.\r\n\r\nThe increasing use of CCTV in public places has caused a debate over public <a title=\"Surveillance\" href=\"http://en.wikipedia.org/wiki/Surveillance\">surveillance</a> versus <a title=\"Privacy\" href=\"http://en.wikipedia.org/wiki/Privacy\">privacy</a>. People can also buy consumer CCTV Systems for personal, private or commercial use. A more advanced form of CCTV, utilizing <a class=\"mw-redirect\" title=\"Digital Video Recorders\" href=\"http://en.wikipedia.org/wiki/Digital_Video_Recorders\">Digital Video Recorders</a> (DVRs), provides recording for possibly many years, with a variety of quality and performance options and extra features (such as motion-detection and email alerts).\r\n\r\nIn industrial plants, CCTV equipment may be used to observe parts of a process from a central control room; when, for example, the environment is not comfortable for humans. CCTV systems may operate continuously or only as required to monitor a particular event.','What is CCTV?',0,'','publish','closed','open','','what-is-cctv','','','2009-01-13 20:58:13','2009-01-13 10:58:13','',0,'http://moztronics.com.au/?p=25',0,'post','',0),(26,1,'2009-01-13 15:14:52','2009-01-13 05:14:52','<strong>Closed-circuit television</strong> (<strong>CCTV</strong>) is the use of <a title=\"Video camera\" href=\"http://en.wikipedia.org/wiki/Video_camera\">video cameras</a> to transmit a signal to a specific place, limited set of monitors.\n\nIt differs from <a class=\"mw-redirect\" title=\"Broadcast television\" href=\"http://en.wikipedia.org/wiki/Broadcast_television\">broadcast television</a> in that the signal is not openly transmitted, though it may employ point to point wireless links. CCTV is often used for <a title=\"Surveillance\" href=\"http://en.wikipedia.org/wiki/Surveillance\">surveillance</a> in areas that may need monitoring such as <a title=\"Bank\" href=\"http://en.wikipedia.org/wiki/Bank\">banks</a>, <a title=\"Casino\" href=\"http://en.wikipedia.org/wiki/Casino\">casinos</a>, <a title=\"Airport\" href=\"http://en.wikipedia.org/wiki/Airport\">airports</a>, military installations and convenience stores.\n\nThe increasing use of CCTV in public places has caused a debate over public <a title=\"Surveillance\" href=\"http://en.wikipedia.org/wiki/Surveillance\">surveillance</a> versus <a title=\"Privacy\" href=\"http://en.wikipedia.org/wiki/Privacy\">privacy</a>. People can also buy consumer CCTV Systems for personal, private or commercial use. A more advanced form of CCTV, utilizing <a class=\"mw-redirect\" title=\"Digital Video Recorders\" href=\"http://en.wikipedia.org/wiki/Digital_Video_Recorders\">Digital Video Recorders</a> (DVRs), provides recording for possibly many years, with a variety of quality and performance options and extra features (such as motion-detection and email alerts).\n\nIn industrial plants, CCTV equipment may be used to observe parts of a process from a central control room; when, for example, the environment is not comfortable for humans. CCTV systems may operate continuously or only as required to monitor a particular event.','What is CCTV?',0,'','inherit','closed','open','','25-revision','','','2009-01-13 15:14:52','2009-01-13 05:14:52','',25,'http://moztronics.com.au/?p=26',0,'revision','',0),(27,1,'2009-01-01 15:17:08','2009-01-01 05:17:08','A <strong>fire extinguisher</strong> is an <a title=\"Active fire protection\" href=\"http://en.wikipedia.org/wiki/Active_fire_protection\">active fire protection</a> device used to extinguish or control small fires, often in emergency situations. It is not intended for use on an out-of-control fire, such as one which has reached the <a title=\"Ceiling\" href=\"http://en.wikipedia.org/wiki/Ceiling\">ceiling</a>, endangers the user (i.e. no escape route, smoke, explosion hazard, etc.), or otherwise requires the expertise of a <a class=\"mw-redirect\" title=\"Fire department\" href=\"http://en.wikipedia.org/wiki/Fire_department\">fire department</a>. Typically, a fire extinguisher consists of a hand-held cylindrical <a title=\"Pressure vessel\" href=\"http://en.wikipedia.org/wiki/Pressure_vessel\">pressure vessel</a> containing an <a href=\"http://en.wikipedia.org/wiki/Extinguisher#Types_of_extinguishing_agents\">agent</a> which can be discharged to extinguish a <a title=\"Fire\" href=\"http://en.wikipedia.org/wiki/Fire\">fire</a>.\r\n\r\nThere are two main types of fire extinguishers: Stored pressure and generated pressure. In stored pressure units, the expellant is stored in the same chamber as the firefighting agent itself. Depending on the agent used, different propellants are used. With dry chemical extinguishers, <a title=\"Nitrogen\" href=\"http://en.wikipedia.org/wiki/Nitrogen\">nitrogen</a> is typically used; water and foam are pressurized with air. Stored pressure are the most common types of fire extinguishers. Cartridge-operated extinguishers, contain the expellant gas in a separate cartridge that is punctured prior to discharge, exposing the propellant to the agent. These types as are not as common, used primarily in areas such as industrial facilities, where they receive higher-than-average use. They have the advantage of simple and prompt recharge, allowing an operator to discharge the extinguisher, recharge it, and return to the fire in an reasonable amount of time. Unlike stored pressure types, these extinguishers utilize compressed <a title=\"Carbon dioxide\" href=\"http://en.wikipedia.org/wiki/Carbon_dioxide\">carbon dioxide</a> instead of nitrogen, although nitrogen cartridges are used on low temperature (-60 rated) models. Cartridge operated types are available in dry chemical and dry powder in the US and water, wetting agent, foam, and dry powder(ABC, BC, or D) in the rest of the world.\r\n\r\nFire extinguishers are further divided into handheld and cart-mounted, also called wheeled extinguishers. Handheld extinguishers weigh from 2 to 30 pounds (1 to 14 kilograms), and are hence easily portable by hand. They exist in both stored- and generated-pressure types and contain all types of suppressants. Cart-mounted units typically weigh 50+ pounds (23+ kilograms), are cartridge-operated, and typically contain either dry chemical, <a title=\"Purple-K\" href=\"http://en.wikipedia.org/wiki/Purple-K\">Purple-K</a>, foam, Halon, Halotron-1 or CO<sub>2</sub>. Wheeled models are most commonly found at <a class=\"mw-redirect\" title=\"Construction sites\" href=\"http://en.wikipedia.org/wiki/Construction_sites\">construction sites</a>, <a title=\"Airport\" href=\"http://en.wikipedia.org/wiki/Airport\">airport</a> <a class=\"mw-redirect\" title=\"Runways\" href=\"http://en.wikipedia.org/wiki/Runways\">runways</a>, <a class=\"mw-redirect\" title=\"Heliports\" href=\"http://en.wikipedia.org/wiki/Heliports\">heliports</a>, and temporary landing sites.','What is an Extinguisher?',0,'','publish','closed','open','','what-is-an-extinguisher','','','2009-01-13 20:56:18','2009-01-13 10:56:18','',0,'http://moztronics.com.au/?p=27',0,'post','',0),(28,1,'2009-01-13 15:16:49','2009-01-13 05:16:49','','What is an Extinguisher?',0,'','inherit','closed','open','','27-revision','','','2009-01-13 15:16:49','2009-01-13 05:16:49','',27,'http://moztronics.com.au/?p=28',0,'revision','',0),(29,1,'2009-01-01 15:18:17','2009-01-01 05:18:17','<strong>Fire protection engineering</strong> (also known as <strong>fire engineering</strong> or <strong>fire safety engineering</strong>) is the application of science and engineering principles to protect people and their environments from the destructive effects of <a title=\"Fire\" href=\"http://en.wikipedia.org/wiki/Fire\">fire</a> and smoke.\r\n\r\nThe discipline of fire protection engineering includes, but is not exclusive to:\r\n<ul>\r\n	<li><a title=\"Active fire protection\" href=\"http://en.wikipedia.org/wiki/Active_fire_protection\">Active fire protection</a> - fire suppression systems, and fire alarm.</li>\r\n	<li><a title=\"Passive fire protection\" href=\"http://en.wikipedia.org/wiki/Passive_fire_protection\">Passive fire protection</a> - fire and smoke barriers, space separation</li>\r\n	<li><a class=\"new\" title=\"Smoke control and management (page does not exist)\" href=\"http://en.wikipedia.org/w/index.php?title=Smoke_control_and_management&amp;action=edit&amp;redlink=1\">Smoke control and management</a></li>\r\n	<li>Building design, layout, and space planning</li>\r\n	<li>Fire prevention programs</li>\r\n	<li><a class=\"new\" title=\"Fire dynamics (page does not exist)\" href=\"http://en.wikipedia.org/w/index.php?title=Fire_dynamics&amp;action=edit&amp;redlink=1\">Fire dynamics</a> and <a class=\"new\" title=\"Fire modeling (page does not exist)\" href=\"http://en.wikipedia.org/w/index.php?title=Fire_modeling&amp;action=edit&amp;redlink=1\">fire modeling</a></li>\r\n	<li>Human behavior during fire events</li>\r\n	<li><a title=\"Risk analysis\" href=\"http://en.wikipedia.org/wiki/Risk_analysis\">Risk analysis</a>, including economic factors</li>\r\n</ul>\r\nIn practice, fire protection engineers typically identify risks and design safeguards that aid in preventing, controlling, and mitigating the effects of fires. Fire protection engineers assist <a class=\"mw-redirect\" title=\"Architects\" href=\"http://en.wikipedia.org/wiki/Architects\">architects</a> in evaluating buildings\' life safety and property protection goals. FPEs are also employed as fire investigators, including such very large-scale cases as the analysis of the collapse of the World Trade Centers. <a title=\"NASA\" href=\"http://en.wikipedia.org/wiki/NASA\">NASA</a> uses fire protection engineers in its space program to help improve safety.','What is Fire Safety (Fire Protection Engineering)?',0,'','publish','closed','open','','what-is-fire-safety-fire-protection-engineering','','','2009-01-13 20:55:23','2009-01-13 10:55:23','',0,'http://moztronics.com.au/?p=29',0,'post','',0),(30,1,'2009-01-13 15:18:00','2009-01-13 05:18:00','','What is Fire Safety (Fire Protection Engineering)?',0,'','inherit','closed','open','','29-revision','','','2009-01-13 15:18:00','2009-01-13 05:18:00','',29,'http://moztronics.com.au/?p=30',0,'revision','',0),(31,1,'2009-01-01 15:19:19','2009-01-01 05:19:19','A <strong>smoke detector</strong> is a device that detects <a title=\"Smoke\" href=\"http://en.wikipedia.org/wiki/Smoke\">smoke</a> and issues a signal to a <a title=\"Fire alarm system\" href=\"http://en.wikipedia.org/wiki/Fire_alarm_system\">fire alarm system</a>, or issues a local audible <a title=\"Alarm\" href=\"http://en.wikipedia.org/wiki/Alarm\">alarm</a> from the detector itself.\r\n\r\nA household smoke detector will typically be mounted in a disk-shaped plastic enclosure about 150 millimetres (6 in) in diameter and 25 millimetres (1 in) thick, but the shape can vary by manufacturer. Most smoke detectors work either by optical detection (<a class=\"mw-redirect\" title=\"Photoelectric\" href=\"http://en.wikipedia.org/wiki/Photoelectric\">photoelectric</a>) or by physical process (<a title=\"Ionization\" href=\"http://en.wikipedia.org/wiki/Ionization\">ionization</a>), but some of them use both detection methods to increase sensitivity to smoke. Smoke detectors are usually powered by <a title=\"Battery (electricity)\" href=\"http://en.wikipedia.org/wiki/Battery_%28electricity%29\">battery</a>; some are connected directly to power mains — often have a battery as a power supply backup in case the mains power fails.\r\n\r\nThe smoke detector is one of three items of fire safety apparatus which are both recommended for homes and can be self-installed by the consumer. The second is a <a title=\"Fire extinguisher\" href=\"http://en.wikipedia.org/wiki/Fire_extinguisher\">fire extinguisher</a>, and the third is a <a title=\"Fire blanket\" href=\"http://en.wikipedia.org/wiki/Fire_blanket\">fire blanket</a>.','What is Smoke Detection?',0,'','publish','closed','open','','what-is-smoke-detection','','','2009-01-13 20:54:28','2009-01-13 10:54:28','',0,'http://moztronics.com.au/?p=31',0,'post','',0),(32,1,'2009-01-13 15:19:02','2009-01-13 05:19:02','','What is Smoke Detection?',0,'','inherit','closed','open','','31-revision','','','2009-01-13 15:19:02','2009-01-13 05:19:02','',31,'http://moztronics.com.au/?p=32',0,'revision','',0),(33,1,'2009-01-01 15:25:37','2009-01-01 05:25:37','<p class=\"standardtext\" align=\"left\"></p>\r\n<p class=\"standardtext\" align=\"left\">Any alarm installed in your premises can be remotely monitored. This is achieved by programming a communications device in the alarm panel to a specific computer located at Central Monitoring Services.The way communications occur varies and can be tailored for the level of security required and the ongoing charges incurred by the reporting costs. Most monitored alarms communicate via the telephone and incur a local call charge to the client account each time they communicate.</p>\r\n<p class=\"standardtext\" align=\"left\"></p>\r\n\r\n<ul>\r\n	<li class=\"style7\"> If you have a Smoke Detector attached to the alarm, you can be guaranteed some-one will respond if that alarm goes off and send the Fire Brigade if necessary.</li>\r\n	<li class=\"style7\">If you have a Medical Emergency button attached to the alarm you can be guaranteed some-one will respond and send the ambulance if necessary.</li>\r\n	<li class=\"style7\">If you have a Hold Up button attached to the alarm system you can be guaranteed some will respond and send the Police.</li>\r\n	<li class=\"style7\">If you are away on holiday and your alarm goes off you are guaranteed of someone responding and ensuring something is done to check and make sure your premises is secure.</li>\r\n	<li class=\"style7\">Peace of mind to know that someone will always follow up on an alarm at your premises 24 hours a day 7 days a week.</li>\r\n	<li class=\"style7\">Can you rely on members of the Public to do that?</li>\r\n</ul>\r\n<p class=\"standardtext\" align=\"left\"></p>\r\n<p class=\"standardtext\" align=\"left\"></p>\r\n<p class=\"standardtext\" align=\"left\"><strong>WHY MONITOR? </strong></p>\r\n<p class=\"standardtext\" align=\"left\">In the troubled times of today,                Security Systems are vital <strong>investments</strong> in the protection of families,                property, plant and possessions.</p>\r\n<p class=\"standardtext\" align=\"left\">This investment is necessary                as it can do more than just ring bells and sirens which by law must                shut down after 5 minutes.</p>\r\n<p class=\"standardtext\" align=\"left\">All activities that require an                urgent response are transmitted by the Central Security Link to                Central Monitoring Services 24hours a day 7 days a week.</p>\r\n<p class=\"style9\" align=\"left\"><span class=\"standardtext\">Security                alarms, hold-up and duress emergencies, fire, medical and critical                plant alarms can be strictly supervised by Central Monitoring Services\'                sophisticated computers. </span></p>\r\n<p class=\"style9\" align=\"left\"></p>\r\n\r\n<ul>\r\n	<li>\r\n<div>Keyholders are people (family, friends, neighbours and employees) who have been given keys and alarm codes to attend if requested by CMS in the event of an alarm at your premises. If CMS need to contact a keyholder they will advise the nature of the alarm event for action. If required CMS are available for any further action or follow up.</div></li>\r\n	<li>\r\n<div>Keyholders are also authorised to request CMS send a Security Patrol to an alarm event.</div></li>\r\n	<li>Keyholders are given to CMS by the Owner / Alarm Installer and are entered into the database for the specific alarm action for those premises on the understanding that the keyholder has given permission and understands his / her responsibility in the matter.</li>\r\n</ul>','Why use Back to Base Monitoring?',0,'','publish','closed','open','','why-use-back-to-base-monitoring','','','2009-01-13 20:55:52','2009-01-13 10:55:52','',0,'http://moztronics.com.au/?p=33',0,'post','',0),(34,1,'2009-01-13 15:25:30','2009-01-13 05:25:30','<p class=\"standardtext\" align=\"left\"><strong>WHY MONITOR? </strong></p>\n<p class=\"standardtext\" align=\"left\">In the troubled times of today,                Security Systems are vital <strong>investments</strong> in the protection of families,                property, plant and possessions.</p>\n<p class=\"standardtext\" align=\"left\">This investment is necessary                as it can do more than just ring bells and sirens which by law must                shut down after 5 minutes.</p>\n<p class=\"standardtext\" align=\"left\">All activities that require an                urgent response are transmitted by the Central Security Link to                Central Monitoring Services 24hours a day 7 days a week.</p>\n<p class=\"style9\" align=\"left\"><span class=\"standardtext\">Security                alarms, hold-up and duress emergencies, fire, medical and critical                plant alarms can be strictly supervised by Central Monitoring Services\'                sophisticated computers. </span></p>','Why use Back to Base Monitoring?',0,'','inherit','closed','open','','33-revision','','','2009-01-13 15:25:30','2009-01-13 05:25:30','',33,'http://moztronics.com.au/?p=34',0,'revision','',0),(35,1,'2009-01-13 15:55:29','2009-01-13 05:55:29','<p class=\"standardtext\" align=\"left\"></p>\n<p class=\"standardtext\" align=\"left\">Any alarm installed in your premises can be remotely monitored. This is achieved by programming a communications device in the alarm panel to a specific computer located at Central Monitoring Services.The way communications occur varies and can be tailored for the level of security required and the ongoing charges incurred by the reporting costs. Most monitored alarms communicate via the telephone and incur a local call charge to the client account each time they communicate.</p>\n<p class=\"standardtext\" align=\"left\"></p>\n\n<ul>\n	<li class=\"style7\"> If you have a Smoke Detector attached to the alarm, you can be guaranteed some-one will respond if that alarm goes off and send the Fire Brigade if necessary.</li>\n	<li class=\"style7\">If you have a Medical Emergency button attached to the alarm you can be guaranteed some-one will respond and send the ambulance if necessary.</li>\n	<li class=\"style7\">If you have a Hold Up button attached to the alarm system you can be guaranteed some will respond and send the Police.</li>\n	<li class=\"style7\">If you are away on holiday and your alarm goes off you are guaranteed of someone responding and ensuring something is done to check and make sure your premises is secure.</li>\n	<li class=\"style7\">Peace of mind to know that someone will always follow up on an alarm at your premises 24 hours a day 7 days a week.</li>\n	<li class=\"style7\">Can you rely on members of the Public to do that?</li>\n</ul>\n<p class=\"standardtext\" align=\"left\"></p>\n<p class=\"standardtext\" align=\"left\"></p>\n<p class=\"standardtext\" align=\"left\"><strong>WHY MONITOR? </strong></p>\n<p class=\"standardtext\" align=\"left\">In the troubled times of today,                Security Systems are vital <strong>investments</strong> in the protection of families,                property, plant and possessions.</p>\n<p class=\"standardtext\" align=\"left\">This investment is necessary                as it can do more than just ring bells and sirens which by law must                shut down after 5 minutes.</p>\n<p class=\"standardtext\" align=\"left\">All activities that require an                urgent response are transmitted by the Central Security Link to                Central Monitoring Services 24hours a day 7 days a week.</p>\n<p class=\"style9\" align=\"left\"><span class=\"standardtext\">Security                alarms, hold-up and duress emergencies, fire, medical and critical                plant alarms can be strictly supervised by Central Monitoring Services\'                sophisticated computers. </span></p>\n<p class=\"style9\" align=\"left\"></p>\n\n<ul>\n	<li>\n<div>Keyholders are people (family, friends, neighbours and employees) who have been given keys and alarm codes to attend if requested by CMS in the event of an alarm at your premises. If CMS need to contact a keyholder they will advise the nature of the alarm event for action. If required CMS are available for any further action or follow up.</div></li>\n	<li>\n<div>Keyholders are also authorised to request CMS send a Security Patrol to an alarm event.</div></li>\n	<li>Keyholders are given to CMS by the Owner / Alarm Installer and are entered into the database for the specific alarm action for those premises on the understanding that the keyholder has given permission and understands his / her responsibility in the matter.</li>\n</ul>','Why use Back to Base Monitoring?',0,'','inherit','closed','open','','33-autosave','','','2009-01-13 15:55:29','2009-01-13 05:55:29','',33,'http://moztronics.com.au/?p=35',0,'revision','',0),(36,1,'2009-01-13 15:25:37','2009-01-13 05:25:37','<p class=\"standardtext\" align=\"left\"><strong>WHY MONITOR? </strong></p>\r\n<p class=\"standardtext\" align=\"left\">In the troubled times of today,                Security Systems are vital <strong>investments</strong> in the protection of families,                property, plant and possessions.</p>\r\n<p class=\"standardtext\" align=\"left\">This investment is necessary                as it can do more than just ring bells and sirens which by law must                shut down after 5 minutes.</p>\r\n<p class=\"standardtext\" align=\"left\">All activities that require an                urgent response are transmitted by the Central Security Link to                Central Monitoring Services 24hours a day 7 days a week.</p>\r\n<p class=\"style9\" align=\"left\"><span class=\"standardtext\">Security                alarms, hold-up and duress emergencies, fire, medical and critical                plant alarms can be strictly supervised by Central Monitoring Services\'                sophisticated computers. </span></p>','Why use Back to Base Monitoring?',0,'','inherit','closed','open','','33-revision-2','','','2009-01-13 15:25:37','2009-01-13 05:25:37','',33,'http://moztronics.com.au/?p=36',0,'revision','',0),(37,1,'2009-01-13 15:54:18','2009-01-13 05:54:18','<p class=\"standardtext\" align=\"left\"></p>\r\n<p class=\"standardtext\" align=\"left\">Any alarm installed in your premises can be remotely monitored. This is achieved by programming a communications device in the alarm panel to a specific computer located at Central Monitoring Services.The way communications occur varies and can be tailored for the level of security required and the ongoing charges incurred by the reporting costs. Most monitored alarms communicate via the telephone and incur a local call charge to the client account each time they communicate.</p>\r\n<p class=\"standardtext\" align=\"left\"></p>\r\n\r\n<ul>\r\n	<li class=\"style7\"> If you have a Smoke Detector attached to the alarm, you can be guaranteed some-one will respond if that alarm goes off and send the Fire Brigade if necessary.</li>\r\n	<li class=\"style7\">If you have a Medical Emergency button attached to the alarm you can be guaranteed some-one will respond and send the ambulance if necessary.</li>\r\n	<li class=\"style7\">If you have a Hold Up button attached to the alarm system you can be guaranteed some will respond and send the Police.</li>\r\n	<li class=\"style7\">If you are away on holiday and your alarm goes off you are guaranteed of someone responding and ensuring something is done to check and make sure your premises is secure.</li>\r\n	<li class=\"style7\">Peace of mind to know that someone will always follow up on an alarm at your premises 24 hours a day 7 days a week.</li>\r\n	<li class=\"style7\">Can you rely on members of the Public to do that?</li>\r\n</ul>\r\n<p class=\"standardtext\" align=\"left\"></p>\r\n<p class=\"standardtext\" align=\"left\"></p>\r\n<p class=\"standardtext\" align=\"left\"><strong>WHY MONITOR? </strong></p>\r\n<p class=\"standardtext\" align=\"left\">In the troubled times of today,                Security Systems are vital <strong>investments</strong> in the protection of families,                property, plant and possessions.</p>\r\n<p class=\"standardtext\" align=\"left\">This investment is necessary                as it can do more than just ring bells and sirens which by law must                shut down after 5 minutes.</p>\r\n<p class=\"standardtext\" align=\"left\">All activities that require an                urgent response are transmitted by the Central Security Link to                Central Monitoring Services 24hours a day 7 days a week.</p>\r\n<p class=\"style9\" align=\"left\"><span class=\"standardtext\">Security                alarms, hold-up and duress emergencies, fire, medical and critical                plant alarms can be strictly supervised by Central Monitoring Services\'                sophisticated computers. </span></p>\r\n<p class=\"style9\" align=\"left\"></p>\r\n\r\n<ul>\r\n	<li>\r\n<div>Keyholders are people (family, friends, neighbours and employees) who have been given keys and alarm codes to attend if requested by CMS in the event of an alarm at your premises. If CMS need to contact a keyholder they will advise the nature of the alarm event for action. If required CMS are available for any further action or follow up.</div></li>\r\n	<li>\r\n<div>Keyholders are also authorised to request CMS send a Security Patrol to an alarm event.</div></li>\r\n	<li>Keyholders are given to CMS by the Owner / Alarm Installer and are entered into the database for the specific alarm action for those premises on the understanding that the keyholder has given permission and understands his / her responsibility in the matter.</li>\r\n</ul>','Why use Back to Base Monitoring?',0,'','inherit','closed','open','','33-revision-3','','','2009-01-13 15:54:18','2009-01-13 05:54:18','',33,'http://moztronics.com.au/?p=37',0,'revision','',0),(38,1,'2009-01-01 16:00:46','2009-01-01 06:00:46','In <a title=\"Telecommunication\" href=\"http://en.wikipedia.org/wiki/Telecommunication\">telecommunication</a>, <strong>telephony</strong> (pronounced teh-LEH-fuh-nee) encompasses the general use of equipment to provide voice communication over distances, specifically by connecting <a title=\"Telephone\" href=\"http://en.wikipedia.org/wiki/Telephone\">telephones</a> to each other.\r\n\r\nTelephones were originally connected directly together in pairs. Each user had separate telephones wired to the various places he might wish to reach. This became inconvenient when people wanted to talk to many other telephones, so the <a title=\"Telephone exchange\" href=\"http://en.wikipedia.org/wiki/Telephone_exchange\">telephone exchange</a> was invented. Each telephone could then be connected to other local ones, thus inventing the <a title=\"Local loop\" href=\"http://en.wikipedia.org/wiki/Local_loop\">local loop</a> and the <a title=\"Telephone call\" href=\"http://en.wikipedia.org/wiki/Telephone_call\">telephone call</a>. Soon, nearby exchanges were connected by <a title=\"Trunking\" href=\"http://en.wikipedia.org/wiki/Trunking\">trunk lines</a>, and eventually distant ones were as well.\r\n\r\nIn modern times, most telephones are plugged into <a class=\"mw-redirect\" title=\"Telephone jack\" href=\"http://en.wikipedia.org/wiki/Telephone_jack\">telephone jacks</a>. Each jack is connected by <a title=\"On-premises wiring\" href=\"http://en.wikipedia.org/wiki/On-premises_wiring\">inside wiring</a> to a <a title=\"Drop (telecommunication)\" href=\"http://en.wikipedia.org/wiki/Drop_%28telecommunication%29\">drop</a> wire and then to a cable with other wires. Cables usually bring a large number of wires from all over a district <a title=\"Access network\" href=\"http://en.wikipedia.org/wiki/Access_network\">access network</a> to one wire center or telephone exchange. When the user of a telephone wants to make a <a title=\"Telephone call\" href=\"http://en.wikipedia.org/wiki/Telephone_call\">telephone call</a>, equipment at the exchange examines the dialed <a title=\"Telephone number\" href=\"http://en.wikipedia.org/wiki/Telephone_number\">telephone number</a> and connects that <a title=\"Telephone line\" href=\"http://en.wikipedia.org/wiki/Telephone_line\">telephone line</a> to another in the same wire center, or to a trunk to a distant exchange. Most of the exchanges in the world are connected to each other, forming the <a class=\"mw-redirect\" title=\"Public Switched Telephone Network\" href=\"http://en.wikipedia.org/wiki/Public_Switched_Telephone_Network\">Public Switched Telephone Network</a> or PSTN. By the end of the 20th century almost all were <a title=\"Stored Program Control exchange\" href=\"http://en.wikipedia.org/wiki/Stored_Program_Control_exchange\">Stored Program Control exchanges</a>.\r\n\r\nAfter the middle 20th century fax and data became important secondary users of the network created to carry voices, and late in the century parts of the network were upgraded with <a class=\"mw-redirect\" title=\"ISDN\" href=\"http://en.wikipedia.org/wiki/ISDN\">ISDN</a> and <a class=\"mw-redirect\" title=\"DSL\" href=\"http://en.wikipedia.org/wiki/DSL\">DSL</a> to improve handling of such traffic.\r\n\r\n<a title=\"Digital telephony\" href=\"http://en.wikipedia.org/wiki/Digital_telephony\">Digital telephony</a> is the use of digital technology in the provision of telephone services and systems. Almost all telephone calls are provided this way, but sometimes the term is restricted to cases in which the <a title=\"Last mile\" href=\"http://en.wikipedia.org/wiki/Last_mile\">last mile</a> is digital, or where the conversion between digital and analog signals takes place inside the telephone. Telephony was digitized to cut the cost and improve the quality of voice services, but digital telephony was then found useful for new network services (<a class=\"mw-redirect\" title=\"ISDN\" href=\"http://en.wikipedia.org/wiki/ISDN\">ISDN</a>) to transfer data speedily over telephone lines.\r\n\r\n<a class=\"mw-redirect\" title=\"IP Telephony\" href=\"http://en.wikipedia.org/wiki/IP_Telephony\">IP Telephony</a> is a modern form of telephony which uses the <a class=\"mw-redirect\" title=\"TCP/IP\" href=\"http://en.wikipedia.org/wiki/TCP/IP\">TCP/IP</a> protocol popularized by the <a title=\"Internet\" href=\"http://en.wikipedia.org/wiki/Internet\">internet</a> to transmit digitized voice data. Contrast this with the operation of POTS (an acronym for \"<a class=\"mw-redirect\" title=\"Plain Old Telephone Service\" href=\"http://en.wikipedia.org/wiki/Plain_Old_Telephone_Service\">Plain Old Telephone Service</a>\").\r\n\r\n<a title=\"Computer telephony integration\" href=\"http://en.wikipedia.org/wiki/Computer_telephony_integration\">Computer <strong>Telephony</strong> Integration (CTI)</a> enables computers to know about and control phone functions such as making and receiving voice, fax, and data calls with telephone directory services and caller identification. The integration of telephone software and computer systems is a major development in the evolution of the automated office.\r\n\r\nCTI is not a new concept. Such links have been used in the past in large telephone networks but only dedicated call centers could justify the costs of the required equipment installation. Primary telephone service providers are offering information services such as <a class=\"mw-redirect\" title=\"Automatic Number Identification\" href=\"http://en.wikipedia.org/wiki/Automatic_Number_Identification\">Automatic Number Identification</a> and <a title=\"Dialed Number Identification Service\" href=\"http://en.wikipedia.org/wiki/Dialed_Number_Identification_Service\">Dialed Number Identification Service</a> on a scale wide enough for its implementation to bring real value to business or residential telephone usage. A new generation of applications (middleware) is being developed as a result of standardization and availability of low cost computer telephony links.','What is Telephony?',0,'','publish','closed','open','','what-is-telephony','','','2009-01-13 20:55:01','2009-01-13 10:55:01','',0,'http://moztronics.com.au/?p=38',0,'post','',0),(39,1,'2009-01-13 16:00:15','2009-01-13 06:00:15','','What is Telephony?',0,'','inherit','closed','open','','38-revision','','','2009-01-13 16:00:15','2009-01-13 06:00:15','',38,'http://moztronics.com.au/?p=39',0,'revision','',0),(69,1,'2009-01-13 15:18:17','2009-01-13 05:18:17','<strong>Fire protection engineering</strong> (also known as <strong>fire engineering</strong> or <strong>fire safety engineering</strong>) is the application of science and engineering principles to protect people and their environments from the destructive effects of <a title=\"Fire\" href=\"http://en.wikipedia.org/wiki/Fire\">fire</a> and smoke.\r\n\r\nThe discipline of fire protection engineering includes, but is not exclusive to:\r\n<ul>\r\n	<li><a title=\"Active fire protection\" href=\"http://en.wikipedia.org/wiki/Active_fire_protection\">Active fire protection</a> - fire suppression systems, and fire alarm.</li>\r\n	<li><a title=\"Passive fire protection\" href=\"http://en.wikipedia.org/wiki/Passive_fire_protection\">Passive fire protection</a> - fire and smoke barriers, space separation</li>\r\n	<li><a class=\"new\" title=\"Smoke control and management (page does not exist)\" href=\"http://en.wikipedia.org/w/index.php?title=Smoke_control_and_management&amp;action=edit&amp;redlink=1\">Smoke control and management</a></li>\r\n	<li>Building design, layout, and space planning</li>\r\n	<li>Fire prevention programs</li>\r\n	<li><a class=\"new\" title=\"Fire dynamics (page does not exist)\" href=\"http://en.wikipedia.org/w/index.php?title=Fire_dynamics&amp;action=edit&amp;redlink=1\">Fire dynamics</a> and <a class=\"new\" title=\"Fire modeling (page does not exist)\" href=\"http://en.wikipedia.org/w/index.php?title=Fire_modeling&amp;action=edit&amp;redlink=1\">fire modeling</a></li>\r\n	<li>Human behavior during fire events</li>\r\n	<li><a title=\"Risk analysis\" href=\"http://en.wikipedia.org/wiki/Risk_analysis\">Risk analysis</a>, including economic factors</li>\r\n</ul>\r\nIn practice, fire protection engineers typically identify risks and design safeguards that aid in preventing, controlling, and mitigating the effects of fires. Fire protection engineers assist <a class=\"mw-redirect\" title=\"Architects\" href=\"http://en.wikipedia.org/wiki/Architects\">architects</a> in evaluating buildings\' life safety and property protection goals. FPEs are also employed as fire investigators, including such very large-scale cases as the analysis of the collapse of the World Trade Centers. <a title=\"NASA\" href=\"http://en.wikipedia.org/wiki/NASA\">NASA</a> uses fire protection engineers in its space program to help improve safety.','What is Fire Safety (Fire Protection Engineering)?',0,'','inherit','closed','open','','29-revision-2','','','2009-01-13 15:18:17','2009-01-13 05:18:17','',29,'http://moztronics.com.au/?p=69',0,'revision','',0),(40,1,'2009-01-01 17:01:35','2009-01-01 07:01:35','<strong>Web presence</strong> refers to the appearance of a person or organization on the <a title=\"World Wide Web\" href=\"http://en.wikipedia.org/wiki/World_Wide_Web\">World Wide Web</a>. The phrase can be definite (as in \"Example Company\'s web presence\") or indefinite (as in \"develop a web presence\").\r\n\r\nA company has web presence if it is available on the web. The amount of web presence can be measured in the amount of sites a organization or individual has, which can include their own website, <a title=\"Social network\" href=\"http://en.wikipedia.org/wiki/Social_network\">social network</a> profiles, and their site\'s <a title=\"PageRank\" href=\"http://en.wikipedia.org/wiki/PageRank\">search engine ranking</a>, traffic, popularity, and <a title=\"Backlink\" href=\"http://en.wikipedia.org/wiki/Backlink\">backlinks</a>.\r\n\r\nUsers of the web often employ <a title=\"Egosurfing\" href=\"http://en.wikipedia.org/wiki/Egosurfing\">egosurfing</a> as a means of assessing their web presence.\r\n\r\nSome companies have employees that are focused on <a title=\"Internet presence management\" href=\"http://en.wikipedia.org/wiki/Internet_presence_management\">internet presence management</a>. Some will hire a firm to manage this aspect of their company for them.\r\n\r\n<strong>Internet presence management</strong> is the process of controlling the <a title=\"Web presence\" href=\"http://en.wikipedia.org/wiki/Web_presence\">Web presence</a>, or <a title=\"Internet\" href=\"http://en.wikipedia.org/wiki/Internet\">Internet</a>-based channels of an organization or company, with the goal of increasing that entity\'s operational efficiency.\r\n\r\nThe Internet presence, or <em>Web presence</em>, for an organization or company encompasses, but is not limited to:\r\n<ul>\r\n	<li><a title=\"E-mail\" href=\"http://en.wikipedia.org/wiki/E-mail\">E-mail</a></li>\r\n	<li><a title=\"Internet forum\" href=\"http://en.wikipedia.org/wiki/Internet_forum\">Internet forums</a></li>\r\n	<li><a title=\"Blog\" href=\"http://en.wikipedia.org/wiki/Blog\">Blogs</a></li>\r\n	<li><a title=\"Minisite\" href=\"http://en.wikipedia.org/wiki/Minisite\">Minisites</a></li>\r\n	<li><a title=\"Web search engine\" href=\"http://en.wikipedia.org/wiki/Web_search_engine\">Search engine</a> listings</li>\r\n	<li><a title=\"Social network\" href=\"http://en.wikipedia.org/wiki/Social_network\">Social networks</a> (e.g., <a title=\"MySpace\" href=\"http://en.wikipedia.org/wiki/MySpace\">MySpace</a>, <a title=\"Facebook\" href=\"http://en.wikipedia.org/wiki/Facebook\">Facebook</a> and <a title=\"YouTube\" href=\"http://en.wikipedia.org/wiki/YouTube\">YouTube</a>)</li>\r\n	<li><a title=\"Web directory\" href=\"http://en.wikipedia.org/wiki/Web_directory\">Web directories</a></li>\r\n	<li><a title=\"Website\" href=\"http://en.wikipedia.org/wiki/Website\">Websites</a></li>\r\n	<li><a title=\"Word of mouth\" href=\"http://en.wikipedia.org/wiki/Word_of_mouth\">Word of mouth</a> marketing (WOMM).</li>\r\n</ul>','What is Web Presence?',0,'','publish','closed','open','','what-is-web-presence','','','2009-01-13 21:02:42','2009-01-13 11:02:42','',0,'http://moztronics.com.au/?p=40',0,'post','',0),(41,1,'2009-01-13 17:00:37','2009-01-13 07:00:37','<strong>Web presence</strong> refers to the appearance of a person or organization on the <a title=\"World Wide Web\" href=\"http://en.wikipedia.org/wiki/World_Wide_Web\">World Wide Web</a>. The phrase can be definite (as in \"Example Company\'s web presence\") or indefinite (as in \"develop a web presence\").\n\nA company has web presence if it is available on the web. The amount of web presence can be measured in the amount of sites a organization or individual has, which can include their own website, <a title=\"Social network\" href=\"http://en.wikipedia.org/wiki/Social_network\">social network</a> profiles, and their site\'s <a title=\"PageRank\" href=\"http://en.wikipedia.org/wiki/PageRank\">search engine ranking</a>, traffic, popularity, and <a title=\"Backlink\" href=\"http://en.wikipedia.org/wiki/Backlink\">backlinks</a>.\n\nUsers of the web often employ <a title=\"Egosurfing\" href=\"http://en.wikipedia.org/wiki/Egosurfing\">egosurfing</a> as a means of assessing their web presence.\n\nSome companies have employees that are focused on <a title=\"Internet presence management\" href=\"http://en.wikipedia.org/wiki/Internet_presence_management\">internet presence management</a>. Some will hire a firm to manage this aspect of their company for them.','What is Web Presence?',0,'','inherit','closed','open','','40-revision','','','2009-01-13 17:00:37','2009-01-13 07:00:37','',40,'http://moztronics.com.au/?p=41',0,'revision','',0),(42,1,'2009-01-13 17:05:23','2009-01-13 07:05:23','<strong>Web presence</strong> refers to the appearance of a person or organization on the <a title=\"World Wide Web\" href=\"http://en.wikipedia.org/wiki/World_Wide_Web\">World Wide Web</a>. The phrase can be definite (as in \"Example Company\'s web presence\") or indefinite (as in \"develop a web presence\").\n\nA company has web presence if it is available on the web. The amount of web presence can be measured in the amount of sites a organization or individual has, which can include their own website, <a title=\"Social network\" href=\"http://en.wikipedia.org/wiki/Social_network\">social network</a> profiles, and their site\'s <a title=\"PageRank\" href=\"http://en.wikipedia.org/wiki/PageRank\">search engine ranking</a>, traffic, popularity, and <a title=\"Backlink\" href=\"http://en.wikipedia.org/wiki/Backlink\">backlinks</a>.\n\nUsers of the web often employ <a title=\"Egosurfing\" href=\"http://en.wikipedia.org/wiki/Egosurfing\">egosurfing</a> as a means of assessing their web presence.\n\nSome companies have employees that are focused on <a title=\"Internet presence management\" href=\"http://en.wikipedia.org/wiki/Internet_presence_management\">internet presence management</a>. Some will hire a firm to manage this aspect of their company for them.\n\n<strong>Internet presence management</strong> is the process of controlling the <a title=\"Web presence\" href=\"http://en.wikipedia.org/wiki/Web_presence\">Web presence</a>, or <a title=\"Internet\" href=\"http://en.wikipedia.org/wiki/Internet\">Internet</a>-based channels of an organization or company, with the goal of increasing that entity\'s operational efficiency.\n\nThe Internet presence, or <em>Web presence</em>, for an organization or company encompasses, but is not limited to:\n<ul>\n	<li><a title=\"E-mail\" href=\"http://en.wikipedia.org/wiki/E-mail\">E-mail</a></li>\n	<li><a title=\"Internet forum\" href=\"http://en.wikipedia.org/wiki/Internet_forum\">Internet forums</a></li>\n	<li><a title=\"Blog\" href=\"http://en.wikipedia.org/wiki/Blog\">Blogs</a></li>\n	<li><a title=\"Minisite\" href=\"http://en.wikipedia.org/wiki/Minisite\">Minisites</a></li>\n	<li><a title=\"Web search engine\" href=\"http://en.wikipedia.org/wiki/Web_search_engine\">Search engine</a> listings</li>\n	<li><a title=\"Social network\" href=\"http://en.wikipedia.org/wiki/Social_network\">Social networks</a> (e.g., <a title=\"MySpace\" href=\"http://en.wikipedia.org/wiki/MySpace\">MySpace</a>, <a title=\"Facebook\" href=\"http://en.wikipedia.org/wiki/Facebook\">Facebook</a> and <a title=\"YouTube\" href=\"http://en.wikipedia.org/wiki/YouTube\">YouTube</a>)</li>\n	<li><a title=\"Web directory\" href=\"http://en.wikipedia.org/wiki/Web_directory\">Web directories</a></li>\n	<li><a title=\"Website\" href=\"http://en.wikipedia.org/wiki/Website\">Websites</a></li>\n	<li><a title=\"Word of mouth\" href=\"http://en.wikipedia.org/wiki/Word_of_mouth\">Word of mouth</a> marketing (WOMM).</li>\n</ul>','What is Web Presence?',0,'','inherit','closed','open','','40-autosave','','','2009-01-13 17:05:23','2009-01-13 07:05:23','',40,'http://moztronics.com.au/?p=42',0,'revision','',0),(43,1,'2009-01-13 17:01:35','2009-01-13 07:01:35','<strong>Web presence</strong> refers to the appearance of a person or organization on the <a title=\"World Wide Web\" href=\"http://en.wikipedia.org/wiki/World_Wide_Web\">World Wide Web</a>. The phrase can be definite (as in \"Example Company\'s web presence\") or indefinite (as in \"develop a web presence\").\r\n\r\nA company has web presence if it is available on the web. The amount of web presence can be measured in the amount of sites a organization or individual has, which can include their own website, <a title=\"Social network\" href=\"http://en.wikipedia.org/wiki/Social_network\">social network</a> profiles, and their site\'s <a title=\"PageRank\" href=\"http://en.wikipedia.org/wiki/PageRank\">search engine ranking</a>, traffic, popularity, and <a title=\"Backlink\" href=\"http://en.wikipedia.org/wiki/Backlink\">backlinks</a>.\r\n\r\nUsers of the web often employ <a title=\"Egosurfing\" href=\"http://en.wikipedia.org/wiki/Egosurfing\">egosurfing</a> as a means of assessing their web presence.\r\n\r\nSome companies have employees that are focused on <a title=\"Internet presence management\" href=\"http://en.wikipedia.org/wiki/Internet_presence_management\">internet presence management</a>. Some will hire a firm to manage this aspect of their company for them.\r\n\r\n<strong>Internet presence management</strong> is the process of controlling the <a title=\"Web presence\" href=\"http://en.wikipedia.org/wiki/Web_presence\">Web presence</a>, or <a title=\"Internet\" href=\"http://en.wikipedia.org/wiki/Internet\">Internet</a>-based channels of an organization or company, with the goal of increasing that entity\'s operational efficiency.','What is Web Presence?',0,'','inherit','closed','open','','40-revision-2','','','2009-01-13 17:01:35','2009-01-13 07:01:35','',40,'http://moztronics.com.au/?p=43',0,'revision','',0),(44,1,'2009-01-01 17:07:49','2009-01-01 07:07:49','Smart Wiring <sup><span>TM</span></sup> is the standard home wiring system that lets you combine phone &amp; fax lines, pay TV cabling, sound, computer and Internet, intelligent lighting, security, home automation, and much more, at the one time and it gives the flexibility to add and change in the future without expensive re-wiring costs.\r\n\r\nInstalled by just one Smart Wired <sup><span>TM</span></sup> accredited electrician, not teams of specialists, Smart Wiring <sup><span>TM</span></sup> is designed to suit both your budget and life.\r\nBest installed when you\'re building or renovating, Smart Wiring <sup><span>TM</span></sup> should be discussed with your Smart Wired TM builder to make sure you pick the right options for you.\r\n\r\nIt must be good, it is recognised by FOXTEL and other Partners are Australian household names.','What is Smart Wiring™ ?',0,'','publish','closed','open','','what-is-smart-wiring%e2%84%a2','','','2009-01-13 20:54:00','2009-01-13 10:54:00','',0,'http://moztronics.com.au/?p=44',0,'post','',0),(45,1,'2009-01-13 17:07:03','2009-01-13 07:07:03','Smart Wiring <sup><span>TM</span></sup> is the standard home wiring system that lets you combine phone &amp; fax lines, pay TV cabling, sound, computer and Internet, intelligent lighting, security, home automation, and much more, at the one time and it gives the flexibility to add and change in the future without expensive re-wiring costs.\n\nInstalled by just one Smart Wired <sup><span>TM</span></sup> accredited electrician, not teams of specialists, Smart Wiring <sup><span>TM</span></sup> is designed to suit both your budget and life.\nBest installed when you\'re building or renovating, Smart Wiring <sup><span>TM</span></sup> should be discussed with your Smart Wired TM builder to make sure you pick the right options for you.\n\nIt must be good, it is recognised by FOXTEL and our Partners are Australian household names.','What is Smart Wiring TM?',0,'','inherit','closed','open','','44-revision','','','2009-01-13 17:07:03','2009-01-13 07:07:03','',44,'http://moztronics.com.au/?p=45',0,'revision','',0),(46,1,'2009-01-01 17:20:02','2009-01-01 07:20:02','<span class=\"fsx03\" style=\"font-family: Verdana;\">A central vacuum system consists of a central power unit, normally situated in the garage, store room or cupboard. A network of PVC pipes then connect the inlet valves, situated throughout the house to the power unit. Inlet valves are located in such a way as to ensure that all areas of the residence can be vacuumed. All dirt and debris vacuumed passes along the pipework to the central power unit.</span>\r\n\r\nSEVEN REASONS TO HAVE A CENTRAL VACUUM SYSTEM:\r\n<div id=\"Oobj375\" style=\"position: absolute; z-index: 34; visibility: visible; left: 347px; top: 516px; width: 1px; height: 1px;\">\r\n<div id=\"Grtf378\" class=\"dfltt\"><span class=\"fsx03\" style=\"font-family: Verdana;\"><strong>\r\n</strong></span></div>\r\n</div>\r\n<span class=\"fsx03\" style=\"font-family: Verdana;\"><strong>1) Healthy air</strong>\r\nCentral vacuum systems totally eliminate the recirculation of dirty air inside your living area. All the hype about allergens, including dust mites is true!  Read what the EPA, American Lung Association, US News and World Report, and others have to say. The long term benefits are amazing.</span>\r\n\r\n<span class=\"fsx03\" style=\"font-family: Verdana;\"><strong>2) Vacuum power</strong>\r\nWith 3-5 times more cleaning power than most portable vacuum cleaners you get a superior clean in less time. Since the central vacuum is located in the garage or basement it can have bigger heavier motors. This power will give a deep down clean and pick up that thread you usually have to go over three times to pick up. The standard model recommended has an airflow of 262 l/s  (litres per second), compared with 85-128 l/s from a portable.</span>\r\n\r\n<span class=\"fsx03\" style=\"font-family: Verdana;\"><strong>3) Convenience</strong>\r\nJust connect the lightweight hose to any conveniently located inlet. No heavy unit to pull,push or drag upstairs, no switches, and electrical cords to keep tripping over. </span>\r\n\r\n<span class=\"fsx03\" style=\"font-family: Verdana;\"><strong>4) Home value</strong>\r\nAs with other built-in appliances, investing in a central vacuum system increases the market value of your home. For less than the cost of a high-end portable vacuum, you can buy a central vacuum and watch the resale value of your home increase. </span>\r\n\r\n<span class=\"fsx03\" style=\"font-family: Verdana;\"><strong>5) Less noise</strong></span>\r\n<span class=\"fsx03\" style=\"font-family: Verdana;\">MD SilentMaster eliminates the loud, irritating noise of portable vacuum cleaners because the power unit is not only acoustically insulated, it is located outside you living area. Important phone calls will be heard, the baby will sleep, and the favorite TV program will not be disturbed</span><span class=\"fsx04\" style=\"font-family: Arial;\">.</span>\r\n\r\n<span class=\"fsx03\" style=\"font-family: Verdana;\"><strong>6) Versatility</strong>\r\nDozens of attachments designed to clean any type of surface: carpeting, wood and tile floors, drapes, furniture, corners, crevices, staircases, ceiling fans, mini blinds, cars, etc.</span>\r\n\r\n<span class=\"fsx03\" style=\"font-family: Verdana;\"><strong>7) Cost savings</strong></span>\r\n<span class=\"fsx03\" style=\"font-family: Verdana;\">Saves you money by greatly prolonging the life of your carpeting and furniture due to the increased, deep-down cleaning power. A central vacuum is one of the best investments you can make in your new home.</span>','What are the benefits of Central (ducted) Vacuum Systems?',0,'','publish','closed','open','','what-are-the-benefits-of-central-ducted-vacuum-systems','','','2009-01-13 20:53:24','2009-01-13 10:53:24','',0,'http://moztronics.com.au/?p=46',0,'post','',0),(47,1,'2009-01-13 17:19:16','2009-01-13 07:19:16','<span class=\"fsx03\" style=\"font-family: Verdana;\">A central vacuum system consists of a central power unit, normally situated in the garage, store room or cupboard. A network of PVC pipes then connect the inlet valves, situated throughout the house to the power unit. Inlet valves are located in such a way as to ensure that all areas of the residence can be vacuumed. All dirt and debris vacuumed passes along the pipework to the central power unit.</span>\n\nSEVEN REASONS TO HAVE A CENTRAL VACUUM SYSTEM:\n<div id=\"Oobj375\" style=\"position: absolute; z-index: 34; visibility: visible; left: 347px; top: 516px; width: 1px; height: 1px;\">\n<div id=\"Grtf378\" class=\"dfltt\"><span class=\"fsx03\" style=\"font-family: Verdana;\"><strong>\n</strong></span></div>\n</div>\n<span class=\"fsx03\" style=\"font-family: Verdana;\"><strong>1) Healthy air</strong>\nCentral vacuum systems totally eliminate the recirculation of dirty air inside your living area. All the hype about allergens, including dust mites is true!  Read what the EPA, American Lung Association, US News and World Report, and others have to say. The long term benefits are amazing.</span>\n\n<span class=\"fsx03\" style=\"font-family: Verdana;\"><strong>2) Vacuum power</strong>\nWith 3-5 times more cleaning power than most portable vacuum cleaners you get a superior clean in less time. Since the central vacuum is located in the garage or basement it can have bigger heavier motors. This power will give a deep down clean and pick up that thread you usually have to go over three times to pick up. The standard model recommended has an airflow of 262 l/s  (litres per second), compared with 85-128 l/s from a portable.</span>\n\n<span class=\"fsx03\" style=\"font-family: Verdana;\"><strong>3) Convenience</strong>\nJust connect the lightweight hose to any conveniently located inlet. No heavy unit to pull,push or drag upstairs, no switches, and electrical cords to keep tripping over. </span>\n\n<span class=\"fsx03\" style=\"font-family: Verdana;\"><strong>4) Home value</strong>\nAs with other built-in appliances, investing in a central vacuum system increases the market value of your home. For less than the cost of a high-end portable vacuum, you can buy a central vacuum and watch the resale value of your home increase. </span>\n\n<span class=\"fsx03\" style=\"font-family: Verdana;\"><strong>5) Less noise</strong></span>\n<span class=\"fsx03\" style=\"font-family: Verdana;\">MD SilentMaster eliminates the loud, irritating noise of portable vacuum cleaners because the power unit is not only acoustically insulated, it is located outside you living area. Important phone calls will be heard, the baby will sleep, and the favorite TV program will not be disturbed</span><span class=\"fsx04\" style=\"font-family: Arial;\">.</span>\n\n<span class=\"fsx03\" style=\"font-family: Verdana;\"><strong>6) Versatility</strong>\nDozens of attachments designed to clean any type of surface: carpeting, wood and tile floors, drapes, furniture, corners, crevices, staircases, ceiling fans, mini blinds, cars, etc.</span>\n\n<span class=\"fsx03\" style=\"font-family: Verdana;\"><strong>7) Cost savings</strong></span>\n<span class=\"fsx03\" style=\"font-family: Verdana;\">Saves you money by greatly prolonging the life of your carpeting and furniture due to the increased, deep-down cleaning power. A central vacuum is one of the best investments you can make in your new home.</span>','What are the benefits of Central (ducted) Vacuum Systems?',0,'','inherit','closed','open','','46-revision','','','2009-01-13 17:19:16','2009-01-13 07:19:16','',46,'http://moztronics.com.au/?p=47',0,'revision','',0),(48,1,'2009-01-13 17:07:49','2009-01-13 07:07:49','Smart Wiring <sup><span>TM</span></sup> is the standard home wiring system that lets you combine phone &amp; fax lines, pay TV cabling, sound, computer and Internet, intelligent lighting, security, home automation, and much more, at the one time and it gives the flexibility to add and change in the future without expensive re-wiring costs.\r\n\r\nInstalled by just one Smart Wired <sup><span>TM</span></sup> accredited electrician, not teams of specialists, Smart Wiring <sup><span>TM</span></sup> is designed to suit both your budget and life.\r\nBest installed when you\'re building or renovating, Smart Wiring <sup><span>TM</span></sup> should be discussed with your Smart Wired TM builder to make sure you pick the right options for you.\r\n\r\nIt must be good, it is recognised by FOXTEL and other Partners are Australian household names.','What is Smart Wiring™ ?',0,'','inherit','closed','open','','44-revision-2','','','2009-01-13 17:07:49','2009-01-13 07:07:49','',44,'http://moztronics.com.au/?p=48',0,'revision','',0),(49,1,'2009-01-13 17:51:32','2009-01-13 07:51:32','Smart Wiring <sup><span>TM</span></sup> is the standard home wiring system that lets you combine phone &amp; fax lines, pay TV cabling, sound, computer and Internet, intelligent lighting, security, home automation, and much more, at the one time and it gives the flexibility to add and change in the future without expensive re-wiring costs.\n\nInstalled by just one Smart Wired <sup><span>TM</span></sup> accredited electrician, not teams of specialists, Smart Wiring <sup><span>TM</span></sup> is designed to suit both your budget and life.\nBest installed when you\'re building or renovating, Smart Wiring <sup><span>TM</span></sup> should be discussed with your Smart Wired TM builder to make sure you pick the right options for you.\n\nIt must be good, it is recognised by FOXTEL and other Partners are Australian household names.','What is Smart Wiring™ ?',0,'','inherit','closed','open','','44-autosave','','','2009-01-13 17:51:32','2009-01-13 07:51:32','',44,'http://moztronics.com.au/?p=49',0,'revision','',0),(50,1,'2009-01-13 17:50:19','2009-01-13 07:50:19','Smart Wiring <sup><span>TM</span></sup> is the standard home wiring system that lets you combine phone &amp; fax lines, pay TV cabling, sound, computer and Internet, intelligent lighting, security, home automation, and much more, at the one time and it gives the flexibility to add and change in the future without expensive re-wiring costs.\r\n\r\nInstalled by just one Smart Wired <sup><span>TM</span></sup> accredited electrician, not teams of specialists, Smart Wiring <sup><span>TM</span></sup> is designed to suit both your budget and life.\r\nBest installed when you\'re building or renovating, Smart Wiring <sup><span>TM</span></sup> should be discussed with your Smart Wired TM builder to make sure you pick the right options for you.\r\n\r\nIt must be good, it is recognised by FOXTEL and other Partners are Australian household names.','What is Smart Wiring™ ?',0,'','inherit','closed','open','','44-revision-3','','','2009-01-13 17:50:19','2009-01-13 07:50:19','',44,'http://moztronics.com.au/?p=50',0,'revision','',0),(51,1,'2009-01-01 18:11:41','2009-01-01 08:11:41','<strong>Technical support</strong> (also <em>tech support</em>) is a range of <a title=\"Customer service\" href=\"http://en.wikipedia.org/wiki/Customer_service\">services</a> providing assistance with technology products such as mobile phones, televisions, <a title=\"Computer\" href=\"http://en.wikipedia.org/wiki/Computer\">computers</a>, or other electronic or mechanical goods. In general, technical support services attempt to help the user solve specific problems with a product—rather than providing training, customization, or other support services.\r\n\r\nMost companies offer technical support for the products they sell, either freely available or for a fee. Technical support may be delivered over the <a title=\"Telephone\" href=\"http://en.wikipedia.org/wiki/Telephone\">telephone</a> or online by <a title=\"E-mail\" href=\"http://en.wikipedia.org/wiki/E-mail\">e-mail</a> or a <a class=\"mw-redirect\" title=\"Web site\" href=\"http://en.wikipedia.org/wiki/Web_site\">web site</a>. Larger organizations frequently have internal technical support available to their staff for computer related problems. The internet is also a good source for freely available tech support, where experienced users may provide advice and assistance with problems. In addition, some fee-based service companies charge for premium technical support services.\r\n\r\n<strong>Remote PC repair</strong> is troubleshooting common <a class=\"mw-redirect\" title=\"Computer errors\" href=\"http://en.wikipedia.org/wiki/Computer_errors\">computer errors</a> online via <a class=\"mw-redirect\" title=\"Remote desktop\" href=\"http://en.wikipedia.org/wiki/Remote_desktop\">remote desktop</a> connection which works by logging in to the remote PC with the username and password.<sup id=\"cite_ref-8\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_support#cite_note-8\"><span>[</span>9<span>]</span></a></sup> The person owning the computer uses it as himself, apart from the fact that it is being controlled over the Internet. The technology is being embraced by many people as it saves them from hauling their PCs to a shop and wait weeks to get it back. Another benefit is the lower cost.\r\n\r\n<strong>Remote PC repair services</strong> are extremely cost effective and generally offered with a free policy which means that customers don’t have to pay if the issue is not resolved. These repairs are popular as technical support, online computer help, and onsite technical support. With an increase in online resources, there are many companies to get exclusive remote support at competitive prices.\r\n\r\nCommon repairs available with online computer support providers are <a title=\"Computer virus\" href=\"http://en.wikipedia.org/wiki/Computer_virus\">computer virus</a> and <a title=\"Spyware\" href=\"http://en.wikipedia.org/wiki/Spyware\">spyware</a> removal, computer optimization, <a title=\"Registry\" href=\"http://en.wikipedia.org/wiki/Registry\">registry</a> repair, <a title=\"Device driver\" href=\"http://en.wikipedia.org/wiki/Device_driver\">device driver</a> issues and <a title=\"Web\" href=\"http://en.wikipedia.org/wiki/Web\">Web</a> related issues.\r\n\r\n<em>Not all repairs can be fixed using remote PC repair</em>. It can be of no help to <a title=\"Computer hardware\" href=\"http://en.wikipedia.org/wiki/Computer_hardware\">computer hardware</a> with physical damage. Remote repair is ineffective for computers that are not able to boot.\r\n\r\nTechnical support is often subdivided into tiers, or levels, in order to better serve a business or customer base. The number of levels a business uses to organize their technical support group is dependent on a business’ need, want, or desire as it revolves around their ability to sufficiently serve their customers or users. The reason for providing a multi-tiered support system instead of one general support group is to provide the best possible service in the most efficient possible manner. Success of the organizational structure is dependent on the technicians’ understanding of their level of responsibility and commitments, their customer response time commitments, and when to appropriately escalate an issue and to which level.<sup id=\"cite_ref-walker_4-0\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_support#cite_note-walker-4\"><span>[</span>5<span>]</span></a></sup> A common support structure revolves around a three-tiered technical support system.\r\n\r\n<strong>Tier I</strong> – This is the initial support level responsible for basic customer issues. It is synonymous with first-line support, level 1 support, front-end support, support line 1, and various other headings denoting basic level technical support functions. The first job of a Tier I specialist is to gather the customer’s information and to determine the customer’s issue by analyzing the symptoms and figuring out the underlying problem.<sup id=\"cite_ref-walker_4-1\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_support#cite_note-walker-4\"><span>[</span>5<span>]</span></a></sup> When analyzing the symptoms, it is important for the <a title=\"Technician\" href=\"http://en.wikipedia.org/wiki/Technician\">technician</a> to identify what the customer is trying to accomplish so that time is not wasted on “attempting to solve a symptom instead of a problem.” <sup id=\"cite_ref-walker_4-2\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_support#cite_note-walker-4\"><span>[</span>5<span>]</span></a></sup> Once identification of the underlying problem is established, the specialist can begin sorting through the possible solutions available. Technical support specialists in this group typically handle straightforward and simple problems while “possibly using some kind of knowledge management tool.” <sup id=\"cite_ref-windley_5-0\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_support#cite_note-windley-5\"><span>[</span>6<span>]</span></a></sup> This includes troubleshooting methods such as verifying physical layer issues, resolving username and password problems, uninstalling/reinstalling basic <a class=\"mw-redirect\" title=\"Software applications\" href=\"http://en.wikipedia.org/wiki/Software_applications\">software applications</a>, verification of proper <a title=\"Hardware\" href=\"http://en.wikipedia.org/wiki/Hardware\">hardware</a> and <a title=\"Software\" href=\"http://en.wikipedia.org/wiki/Software\">software</a> set up, and assistance with navigating around application menus. Personnel at this level have a basic to general understanding of the product or service and may not always contain the competency required for solving complex issues.<sup id=\"cite_ref-kajko_6-0\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_support#cite_note-kajko-6\"><span>[</span>7<span>]</span></a></sup> Nevertheless, the goal for this group is to handle 70%-80% of the user problems before finding it necessary to escalate the issue to a higher level.<sup id=\"cite_ref-kajko_6-1\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_support#cite_note-kajko-6\"><span>[</span>7<span>]</span></a></sup>\r\n\r\n<strong>Tier II</strong> – This is a more in-depth technical support level than Tier I containing experienced and more knowledgeable personnel on a particular product or service. It is synonymous with level 2 support, support line 2, administrative level support, and various other headings denoting advanced technical <a title=\"Troubleshooting\" href=\"http://en.wikipedia.org/wiki/Troubleshooting\">troubleshooting</a> and analysis methods. <a class=\"mw-redirect\" title=\"Technicians\" href=\"http://en.wikipedia.org/wiki/Technicians\">Technicians</a> in this realm of knowledge are responsible for assisting Tier I personnel solve basic technical problems and for investigating elevated issues by confirming the validity of the problem and seeking for known solutions related to these more complex issues.<sup id=\"cite_ref-kajko_6-2\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_support#cite_note-kajko-6\"><span>[</span>7<span>]</span></a></sup> However, prior to the <a title=\"Troubleshooting\" href=\"http://en.wikipedia.org/wiki/Troubleshooting\">troubleshooting</a> process, it is important that the technician review the work order to see what has already been accomplished by the Tier I technician and how long the technician has been working with the particular customer. This is a key element in meeting both the customer and business needs as it allows the technician to prioritize the troubleshooting process and properly manage his or her time.<sup id=\"cite_ref-walker_4-3\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_support#cite_note-walker-4\"><span>[</span>5<span>]</span></a></sup> If a problem is new and/or personnel from this group cannot determine a solution, they are responsible for raising this issue to the Tier III technical support group. In addition, many companies may specify that certain troubleshooting solutions be performed by this group to help ensure the intricacies of a challenging issue are solved by providing experienced and knowledgeable technicians. This may include, but is not limited to onsite installations or replacements of various hardware components, software repair, diagnostic testing, and the utilization of remote control tools used to take over the user’s machine for the sole purpose of troubleshooting and finding a solution to the problem.<sup id=\"cite_ref-walker_4-4\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_support#cite_note-walker-4\"><span>[</span>5<span>]</span></a></sup><sup id=\"cite_ref-nelson_7-0\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_support#cite_note-nelson-7\"><span>[</span>8<span>]</span></a></sup>\r\n\r\n<strong>Tier III</strong> – This is the highest level of support in a three-tiered technical support model responsible for handling the most difficult or advanced problems. It is synonymous with level 3 support, back-end support, support line 3, high-end support, and various other headings denoting expert level troubleshooting and analysis methods. These individuals are experts in their fields and are responsible for not only assisting both Tier I and Tier II personnel, but with the research and development of solutions to new or unknown issues. Note that Tier III technicians have the same responsibility as Tier II technicians in reviewing the work order and assessing the time already spent with the customer so that the work is prioritized and time management is sufficiently utilized.<sup id=\"cite_ref-walker_4-5\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_support#cite_note-walker-4\"><span>[</span>5<span>]</span></a></sup> If it is at all possible, the <a title=\"Technician\" href=\"http://en.wikipedia.org/wiki/Technician\">technician</a> will work to solve the problem with the customer as it may become apparent that the Tier I and/or Tier II technicians simply failed to discover the proper solution. Upon encountering new problems; however, Tier III personnel must first determine whether or not to solve the problem and may require the customer’s contact information so that the technician can have adequate time to troubleshoot the issue and find a solution.<sup id=\"cite_ref-kajko_6-3\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_support#cite_note-kajko-6\"><span>[</span>7<span>]</span></a></sup> In some instances, an issue may be so problematic to the point where the product cannot be salvaged and must be replaced. Such extreme problems are also sent to the original developers for in-depth analysis. If it is determined that a problem can be solved, this group is responsible for designing and developing one or more courses of action, evaluating each of these courses in a test case environment, and implementing the best solution to the problem.<sup id=\"cite_ref-kajko_6-4\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_support#cite_note-kajko-6\"><span>[</span>7<span>]</span></a></sup> Once the solution is verified, it is delivered to the customer and made available for future troubleshooting and analysis.\r\n\r\n<strong>Tier IV</strong> – While not universally used, a fourth level often represents an escalation point beyond the organization. This is generally a hardware or software vendor. Within a corporate incident management system it is important to continue to track incidents even when they are being actioned by a vendor and the <a class=\"mw-redirect\" title=\"Service Level Agreement\" href=\"http://en.wikipedia.org/wiki/Service_Level_Agreement\">Service Level Agreement</a> (or <a title=\"SLA\" href=\"http://en.wikipedia.org/wiki/SLA\">SLA</a>) may have specific provision for this.','What is Technical Support?',0,'','publish','closed','open','','what-is-technical-support','','','2009-01-13 20:53:01','2009-01-13 10:53:01','',0,'http://moztronics.com.au/?p=51',0,'post','',0),(52,1,'2009-01-13 18:10:43','2009-01-13 08:10:43','<strong>Technical support</strong> (also <em>tech support</em>) is a range of <a title=\"Customer service\" href=\"http://en.wikipedia.org/wiki/Customer_service\">services</a> providing assistance with technology products such as mobile phones, televisions, <a title=\"Computer\" href=\"http://en.wikipedia.org/wiki/Computer\">computers</a>, or other electronic or mechanical goods. In general, technical support services attempt to help the user solve specific problems with a product—rather than providing training, customization, or other support services.\n\nMost companies offer technical support for the products they sell, either freely available or for a fee. Technical support may be delivered over the <a title=\"Telephone\" href=\"http://en.wikipedia.org/wiki/Telephone\">telephone</a> or online by <a title=\"E-mail\" href=\"http://en.wikipedia.org/wiki/E-mail\">e-mail</a> or a <a class=\"mw-redirect\" title=\"Web site\" href=\"http://en.wikipedia.org/wiki/Web_site\">web site</a>. Larger organizations frequently have internal technical support available to their staff for computer related problems. The internet is also a good source for freely available tech support, where experienced users may provide advice and assistance with problems. In addition, some fee-based service companies charge for premium technical support services.','What is Technical Support?',0,'','inherit','closed','open','','51-revision','','','2009-01-13 18:10:43','2009-01-13 08:10:43','',51,'http://moztronics.com.au/?p=52',0,'revision','',0),(53,1,'2009-01-01 19:36:06','2009-01-01 09:36:06','Whether you call it internet stalking, cyber stalking, online stalking, or celebrity stalking, the definition of stalking is when someone consistently contacts a person regardless of their requests for them not to.\r\n\r\nStalking is about domination. It is one or more persons  continually making efforts to control another person’s life and thoughts by  paying unwanted attention. Stalkers become obsessive investigators,  interrogators, intimidators and terrorists. According to current statistics,  almost a million and a half people are being stalked by an ex-boyfriend,  ex-girlfriend, ex-husband, ex-wife, estranged husband, estranged wife, secret  admirer, or an infatuated mentally unstable individual.\r\n\r\nCelebrities and everyday people are potential victims of the stalker. Stalking  is when someone contacts you when you repeatedly request that they do not. They  watch, follow, call, email, fax or continually send mail to you after you  request they do not. Stalking is psychological terror. They make you a prisoner  in your own life. They make it known that they know where you have been, whom  you have spoken to, what you have done and where you are going next. They insist  that they cannot live without you and you cannot live without them. Here are a  few things to consider.\r\n\r\n<strong>Red Flags</strong>; signs that you are being stalked include; an obsessive  relationship that continues after the victim requests it does not, which  includes; repeated contact of you, friends, family or work, following, threats,  vandalism, dead or missing pets or an assault on the victim.\r\n<p align=\"left\"><strong>Warning Signals</strong>; when your intuition is telling you something is wrong  immediately respond. When the red flags become obvious it might be too late. The  moment things start to go wrong respond with stated boundaries and call it  quits. Ending a relationship; most stalkers have had some form of an emotional  relationship with the victim. When the victim requests that the relationship  must end, do it sternly and efficiently and make your feelings known. Stringing  the stalker along only gives them hope and sends mixed signals. They will  misconstrue your words and find hope in their meaning.</p>\r\n<p align=\"left\">Final Words; once you have ended the relationship and the stalker continues to  make contact, under no circumstances do you respond. Emotions can eventually  fade away, however, if you respond after a month of being contacted, you give  the stalker their emotional fix and then they want more. More is never enough  for the stalker.</p>\r\n<p align=\"left\"><strong>Begging</strong>; trying to reason with, pleading and requesting the mercy of the  stalker only empowers them and gives them the feeling of being in control of  your life. Under no circumstances do you respond and especially respond with  begging, pleading or their mercy. Never try to rationalize with irrational  people.</p>\r\n<p align=\"left\"><span style=\"color: #000080;\"><strong>Home Security</strong>; If their was ever a time to install an alarm it is when  you are being stalked. Make sure it is monitored by local law enforcement and  keep it on while you are home during the day and when you sleep at night.  <strong><span style=\"text-decoration: underline;\">Wireless alarms can be installed quickly and there are no phone lines to cut. </span></strong></span></p>\r\n<p align=\"left\"><strong>Dogs</strong>; this is also a good time to get a vicious dog. With little research  a fully-grown Doberman, Pit-bull, German Shepard, Rotweiler or any other dog  trained to kill can be a lifesaver. There are many outfits that will rent you a  guard dog while you are in jeopardy.</p>\r\n<p align=\"left\"><strong>Friends and Family</strong>; make sure you notify friends, family, neighbors,  co-workers and local businesses who you are a customer of and acquainted with  what your situation is and show photos of the stalker. Your circle of  relationships might be a significant factor in staying safe.</p>\r\n<p align=\"left\"><strong>Self Defense</strong>; knowing how to disable an attacker armed or unarmed should  be a staple of everyday living. When you are being stalked you are essentially  at war and need to understand the fundamentals of armed and unarmed combat. Once  you have the tools to debilitate another human being, that’s when you decide if  carrying a weapon is appropriate.</p>\r\n<p align=\"left\"><strong>Self Care</strong>; these are extremely emotional times. Sleep deprivation,  starvation, anxiety, and a number of physical and emotional anomalies are side  effects of being stalked. Seek professional help and maintain as much personal  balance as possible.</p>\r\n\r\n<strong>Documentation</strong>; experts disagree on if a restraining order is a  helpful or hurtful tool when being stalked. The introduction of a restraining  order can emotionally charge your stalker or give them the warning to back off.  Either way, a paper trail of all events and proper reporting of each incident  will serve as a back up in the event that you kill your attacker in  self-defense. Too many people serve jail time as a result of killing their  attacker in self-defense because they have not documented their obsessed  stalkers attempts at disrupting their life.\r\n\r\nAuthor: Robert Siciliano','What is Anti-Stalking Security?',0,'','publish','closed','open','','what-is-anti-stalking-security','','','2009-01-13 20:52:37','2009-01-13 10:52:37','',0,'http://moztronics.com.au/?p=53',0,'post','',0),(54,1,'2009-01-13 19:35:57','2009-01-13 09:35:57','Whether you call it internet stalking, cyber stalking, online stalking, or celebrity stalking, the definition of stalking is when someone consistently contacts a person regardless of their requests for them not to.\n\nStalking is about domination. It is one or more persons  continually making efforts to control another person’s life and thoughts by  paying unwanted attention. Stalkers become obsessive investigators,  interrogators, intimidators and terrorists. According to current statistics,  almost a million and a half people are being stalked by an ex-boyfriend,  ex-girlfriend, ex-husband, ex-wife, estranged husband, estranged wife, secret  admirer, or an infatuated mentally unstable individual.\n\nCelebrities and everyday people are potential victims of the stalker. Stalking  is when someone contacts you when you repeatedly request that they do not. They  watch, follow, call, email, fax or continually send mail to you after you  request they do not. Stalking is psychological terror. They make you a prisoner  in your own life. They make it known that they know where you have been, whom  you have spoken to, what you have done and where you are going next. They insist  that they cannot live without you and you cannot live without them. Here are a  few things to consider.\n\n<strong>Red Flags</strong>; signs that you are being stalked include; an obsessive  relationship that continues after the victim requests it does not, which  includes; repeated contact of you, friends, family or work, following, threats,  vandalism, dead or missing pets or an assault on the victim.\n<p align=\"left\">\n<strong>Warning Signals</strong>; when your intuition is telling you something is wrong  immediately respond. When the red flags become obvious it might be too late. The  moment things start to go wrong respond with stated boundaries and call it  quits. Ending a relationship; most stalkers have had some form of an emotional  relationship with the victim. When the victim requests that the relationship  must end, do it sternly and efficiently and make your feelings known. Stringing  the stalker along only gives them hope and sends mixed signals. They will  misconstrue your words and find hope in their meaning.\n\n<p align=\"left\">\nFinal Words; once you have ended the relationship and the stalker continues to  make contact, under no circumstances do you respond. Emotions can eventually  fade away, however, if you respond after a month of being contacted, you give  the stalker their emotional fix and then they want more. More is never enough  for the stalker.\n\n<p align=\"left\">\n<strong>Begging</strong>; trying to reason with, pleading and requesting the mercy of the  stalker only empowers them and gives them the feeling of being in control of  your life. Under no circumstances do you respond and especially respond with  begging, pleading or their mercy. Never try to rationalize with irrational  people.\n\n<p align=\"left\">\n<span style=\"color: #000080;\"><strong>Home Security</strong>; If their was ever a time to install an alarm it is when  you are being stalked. Make sure it is monitored by local law enforcement and  keep it on while you are home during the day and when you sleep at night.  <strong><span style=\"text-decoration: underline;\">Wireless alarms can be installed quickly and there are no phone lines to cut. </span></strong></span>\n\n<p align=\"left\">\n<strong>Dogs</strong>; this is also a good time to get a vicious dog. With little research  a fully-grown Doberman, Pit-bull, German Shepard, Rotweiler or any other dog  trained to kill can be a lifesaver. There are many outfits that will rent you a  guard dog while you are in jeopardy.\n\n<p align=\"left\">\n<strong>Friends and Family</strong>; make sure you notify friends, family, neighbors,  co-workers and local businesses who you are a customer of and acquainted with  what your situation is and show photos of the stalker. Your circle of  relationships might be a significant factor in staying safe.\n\n<p align=\"left\">\n<strong>Self Defense</strong>; knowing how to disable an attacker armed or unarmed should  be a staple of everyday living. When you are being stalked you are essentially  at war and need to understand the fundamentals of armed and unarmed combat. Once  you have the tools to debilitate another human being, that’s when you decide if  carrying a weapon is appropriate.\n\n<p align=\"left\">\n<strong>Self Care</strong>; these are extremely emotional times. Sleep deprivation,  starvation, anxiety, and a number of physical and emotional anomalies are side  effects of being stalked. Seek professional help and maintain as much personal  balance as possible.\n\n<strong>Documentation</strong>; experts disagree on if a restraining order is a  helpful or hurtful tool when being stalked. The introduction of a restraining  order can emotionally charge your stalker or give them the warning to back off.  Either way, a paper trail of all events and proper reporting of each incident  will serve as a back up in the event that you kill your attacker in  self-defense. Too many people serve jail time as a result of killing their  attacker in self-defense because they have not documented their obsessed  stalkers attempts at disrupting their life.\n\nAuthor: Robert Siciliano','What is Anti-Stalking Security?',0,'','inherit','closed','open','','53-revision','','','2009-01-13 19:35:57','2009-01-13 09:35:57','',53,'http://moztronics.com.au/?p=54',0,'revision','',0),(55,1,'2009-01-01 19:51:43','2009-01-01 09:51:43','Moztronics has been in business for over 15 years. Some of our services include: install security alarms, and offer back-to-base monitoring services. We also custom build DVR\'s for use with security cameras for your home or business. We can help you get your business up and running, from smart wiring to getting the computers networked to installing the telephony, setting up a web presence, VOiP and switchboards. We offer &amp; install customized home media centers, ducted vaccum services\r\n\r\nWe love our line of work and enjoy being able to provide out customers with the latest cutting edge technology','About Moztronics',0,'','publish','closed','open','','about-moztronics','','','2009-01-13 21:03:12','2009-01-13 11:03:12','',0,'http://moztronics.com.au/?p=55',0,'post','',0),(56,1,'2009-01-13 19:51:19','2009-01-13 09:51:19','Moztronics has been in business for over 15 years. Some of our services include: install security alarms, and offer back-to-base monitoring services. We also custom build DVR\'s for use with security cameras for your home or business. We can help you get your business up and running, from smart wiring to getting the computers networked to installing the telephony, setting up a web presence, VOiP and switchboards. We offer &amp; install customized home media centers, ducted vaccum services\n\nWe love our line of work and enjoy being able to provide out customers with the latest cutting edge technology','About Moztronics',0,'','inherit','closed','open','','55-revision','','','2009-01-13 19:51:19','2009-01-13 09:51:19','',55,'http://moztronics.com.au/?p=56',0,'revision','',0),(57,1,'2009-01-13 21:04:59','2009-01-13 11:04:59','Welcome to Moztronics','Intro',0,'','inherit','closed','open','','1-autosave','','','2009-01-13 21:04:59','2009-01-13 11:04:59','',1,'http://moztronics.com.au/?p=57',0,'revision','',0),(58,1,'2009-01-13 20:47:20','2009-01-13 10:47:20','[caption id=\"attachment_59\" align=\"alignright\" width=\"100\" caption=\"Moz\"]<a href=\"http://moztronics.com.au/wp-content/uploads/2009/01/moz__100x150.jpg\"><img class=\"size-medium wp-image-59\" title=\"moz__100x150\" src=\"http://moztronics.com.au/wp-content/uploads/2009/01/moz__100x150.jpg\" alt=\"Moz\" width=\"100\" height=\"150\" /></a>[/caption]\n\nMoztronics has been in business for over 15 years. Some of our services include: installation of security alarms, and offer back-to-base monitoring services. We also custom build DVR’s for use with security cameras for your home or business. We can help you get your business up and running, from smart wiring to getting the computers networked to installing the telephony, setting up and maintaining a web presence, VOiP and switchboards. We offer &amp; install customized home media centers, central ducted vacuum services\n\nWe love our line of work and enjoy being able to provide out customers with the latest cutting edge technology for all aspects of your life.','About',0,'','inherit','closed','open','','2-autosave','','','2009-01-13 20:47:20','2009-01-13 10:47:20','',2,'http://moztronics.com.au/?p=58',0,'revision','',0),(59,1,'2009-01-13 20:44:09','2009-01-13 10:44:09','','moz__100x150',0,'Moz','inherit','closed','open','','moz__100x150','','','2009-01-13 20:44:09','2009-01-13 10:44:09','',2,'http://moztronics.com.au/wp-content/uploads/2009/01/moz__100x150.jpg',0,'attachment','image/jpeg',0),(60,1,'2009-01-11 03:57:57','2009-01-11 10:57:57','This is an example of a WordPress page, you could edit this to put information about yourself or your site so readers know where you are coming from. You can create as many pages like this one or sub-pages as you like and manage all of your content inside of WordPress.','About',0,'','inherit','closed','open','','2-revision','','','2009-01-11 03:57:57','2009-01-11 10:57:57','',2,'http://moztronics.com.au/?p=60',0,'revision','',0),(61,1,'2009-01-13 20:46:15','2009-01-13 10:46:15','[caption id=\"attachment_59\" align=\"alignright\" width=\"100\" caption=\"Moz\"]<a href=\"http://moztronics.com.au/wp-content/uploads/2009/01/moz__100x150.jpg\"><img class=\"size-medium wp-image-59\" title=\"moz__100x150\" src=\"http://moztronics.com.au/wp-content/uploads/2009/01/moz__100x150.jpg\" alt=\"Moz\" width=\"100\" height=\"150\" /></a>[/caption]\r\n\r\nMoztronics has been in business for over 15 years. Some of our services include: installation of security alarms, and offer back-to-base monitoring services. We also custom build DVR’s for use with security cameras for your home or business. We can help you get your business up and running, from smart wiring to getting the computers networked to installing the telephony, setting up and maintaining a web presence, VOiP and switchboards. We offer &amp; install customized home media centers, central ducted vacuum services\r\n\r\nWe love our line of work and enjoy being able to provide out customers with the latest cutting edge technology for all aspects of your life.','About',0,'','inherit','closed','open','','2-revision-2','','','2009-01-13 20:46:15','2009-01-13 10:46:15','',2,'http://moztronics.com.au/?p=61',0,'revision','',0),(62,1,'2009-01-13 19:36:06','2009-01-13 09:36:06','Whether you call it internet stalking, cyber stalking, online stalking, or celebrity stalking, the definition of stalking is when someone consistently contacts a person regardless of their requests for them not to.\r\n\r\nStalking is about domination. It is one or more persons  continually making efforts to control another person’s life and thoughts by  paying unwanted attention. Stalkers become obsessive investigators,  interrogators, intimidators and terrorists. According to current statistics,  almost a million and a half people are being stalked by an ex-boyfriend,  ex-girlfriend, ex-husband, ex-wife, estranged husband, estranged wife, secret  admirer, or an infatuated mentally unstable individual.\r\n\r\nCelebrities and everyday people are potential victims of the stalker. Stalking  is when someone contacts you when you repeatedly request that they do not. They  watch, follow, call, email, fax or continually send mail to you after you  request they do not. Stalking is psychological terror. They make you a prisoner  in your own life. They make it known that they know where you have been, whom  you have spoken to, what you have done and where you are going next. They insist  that they cannot live without you and you cannot live without them. Here are a  few things to consider.\r\n\r\n<strong>Red Flags</strong>; signs that you are being stalked include; an obsessive  relationship that continues after the victim requests it does not, which  includes; repeated contact of you, friends, family or work, following, threats,  vandalism, dead or missing pets or an assault on the victim.\r\n<p align=\"left\">\r\n<strong>Warning Signals</strong>; when your intuition is telling you something is wrong  immediately respond. When the red flags become obvious it might be too late. The  moment things start to go wrong respond with stated boundaries and call it  quits. Ending a relationship; most stalkers have had some form of an emotional  relationship with the victim. When the victim requests that the relationship  must end, do it sternly and efficiently and make your feelings known. Stringing  the stalker along only gives them hope and sends mixed signals. They will  misconstrue your words and find hope in their meaning.\r\n\r\n<p align=\"left\">\r\nFinal Words; once you have ended the relationship and the stalker continues to  make contact, under no circumstances do you respond. Emotions can eventually  fade away, however, if you respond after a month of being contacted, you give  the stalker their emotional fix and then they want more. More is never enough  for the stalker.\r\n\r\n<p align=\"left\">\r\n<strong>Begging</strong>; trying to reason with, pleading and requesting the mercy of the  stalker only empowers them and gives them the feeling of being in control of  your life. Under no circumstances do you respond and especially respond with  begging, pleading or their mercy. Never try to rationalize with irrational  people.\r\n\r\n<p align=\"left\">\r\n<span style=\"color: #000080;\"><strong>Home Security</strong>; If their was ever a time to install an alarm it is when  you are being stalked. Make sure it is monitored by local law enforcement and  keep it on while you are home during the day and when you sleep at night.  <strong><span style=\"text-decoration: underline;\">Wireless alarms can be installed quickly and there are no phone lines to cut. </span></strong></span>\r\n\r\n<p align=\"left\">\r\n<strong>Dogs</strong>; this is also a good time to get a vicious dog. With little research  a fully-grown Doberman, Pit-bull, German Shepard, Rotweiler or any other dog  trained to kill can be a lifesaver. There are many outfits that will rent you a  guard dog while you are in jeopardy.\r\n\r\n<p align=\"left\">\r\n<strong>Friends and Family</strong>; make sure you notify friends, family, neighbors,  co-workers and local businesses who you are a customer of and acquainted with  what your situation is and show photos of the stalker. Your circle of  relationships might be a significant factor in staying safe.\r\n\r\n<p align=\"left\">\r\n<strong>Self Defense</strong>; knowing how to disable an attacker armed or unarmed should  be a staple of everyday living. When you are being stalked you are essentially  at war and need to understand the fundamentals of armed and unarmed combat. Once  you have the tools to debilitate another human being, that’s when you decide if  carrying a weapon is appropriate.\r\n\r\n<p align=\"left\">\r\n<strong>Self Care</strong>; these are extremely emotional times. Sleep deprivation,  starvation, anxiety, and a number of physical and emotional anomalies are side  effects of being stalked. Seek professional help and maintain as much personal  balance as possible.\r\n\r\n<strong>Documentation</strong>; experts disagree on if a restraining order is a  helpful or hurtful tool when being stalked. The introduction of a restraining  order can emotionally charge your stalker or give them the warning to back off.  Either way, a paper trail of all events and proper reporting of each incident  will serve as a back up in the event that you kill your attacker in  self-defense. Too many people serve jail time as a result of killing their  attacker in self-defense because they have not documented their obsessed  stalkers attempts at disrupting their life.\r\n\r\nAuthor: Robert Siciliano','What is Anti-Stalking Security?',0,'','inherit','closed','open','','53-revision-2','','','2009-01-13 19:36:06','2009-01-13 09:36:06','',53,'http://moztronics.com.au/?p=62',0,'revision','',0),(63,1,'2009-01-13 18:11:41','2009-01-13 08:11:41','<strong>Technical support</strong> (also <em>tech support</em>) is a range of <a title=\"Customer service\" href=\"http://en.wikipedia.org/wiki/Customer_service\">services</a> providing assistance with technology products such as mobile phones, televisions, <a title=\"Computer\" href=\"http://en.wikipedia.org/wiki/Computer\">computers</a>, or other electronic or mechanical goods. In general, technical support services attempt to help the user solve specific problems with a product—rather than providing training, customization, or other support services.\r\n\r\nMost companies offer technical support for the products they sell, either freely available or for a fee. Technical support may be delivered over the <a title=\"Telephone\" href=\"http://en.wikipedia.org/wiki/Telephone\">telephone</a> or online by <a title=\"E-mail\" href=\"http://en.wikipedia.org/wiki/E-mail\">e-mail</a> or a <a class=\"mw-redirect\" title=\"Web site\" href=\"http://en.wikipedia.org/wiki/Web_site\">web site</a>. Larger organizations frequently have internal technical support available to their staff for computer related problems. The internet is also a good source for freely available tech support, where experienced users may provide advice and assistance with problems. In addition, some fee-based service companies charge for premium technical support services.\r\n\r\n<strong>Remote PC repair</strong> is troubleshooting common <a class=\"mw-redirect\" title=\"Computer errors\" href=\"http://en.wikipedia.org/wiki/Computer_errors\">computer errors</a> online via <a class=\"mw-redirect\" title=\"Remote desktop\" href=\"http://en.wikipedia.org/wiki/Remote_desktop\">remote desktop</a> connection which works by logging in to the remote PC with the username and password.<sup id=\"cite_ref-8\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_support#cite_note-8\"><span>[</span>9<span>]</span></a></sup> The person owning the computer uses it as himself, apart from the fact that it is being controlled over the Internet. The technology is being embraced by many people as it saves them from hauling their PCs to a shop and wait weeks to get it back. Another benefit is the lower cost.\r\n\r\n<strong>Remote PC repair services</strong> are extremely cost effective and generally offered with a free policy which means that customers don’t have to pay if the issue is not resolved. These repairs are popular as technical support, online computer help, and onsite technical support. With an increase in online resources, there are many companies to get exclusive remote support at competitive prices.\r\n\r\nCommon repairs available with online computer support providers are <a title=\"Computer virus\" href=\"http://en.wikipedia.org/wiki/Computer_virus\">computer virus</a> and <a title=\"Spyware\" href=\"http://en.wikipedia.org/wiki/Spyware\">spyware</a> removal, computer optimization, <a title=\"Registry\" href=\"http://en.wikipedia.org/wiki/Registry\">registry</a> repair, <a title=\"Device driver\" href=\"http://en.wikipedia.org/wiki/Device_driver\">device driver</a> issues and <a title=\"Web\" href=\"http://en.wikipedia.org/wiki/Web\">Web</a> related issues.\r\n\r\n<em>Not all repairs can be fixed using remote PC repair</em>. It can be of no help to <a title=\"Computer hardware\" href=\"http://en.wikipedia.org/wiki/Computer_hardware\">computer hardware</a> with physical damage. Remote repair is ineffective for computers that are not able to boot.\r\n\r\nTechnical support is often subdivided into tiers, or levels, in order to better serve a business or customer base. The number of levels a business uses to organize their technical support group is dependent on a business’ need, want, or desire as it revolves around their ability to sufficiently serve their customers or users. The reason for providing a multi-tiered support system instead of one general support group is to provide the best possible service in the most efficient possible manner. Success of the organizational structure is dependent on the technicians’ understanding of their level of responsibility and commitments, their customer response time commitments, and when to appropriately escalate an issue and to which level.<sup id=\"cite_ref-walker_4-0\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_support#cite_note-walker-4\"><span>[</span>5<span>]</span></a></sup> A common support structure revolves around a three-tiered technical support system.\r\n\r\n<strong>Tier I</strong> – This is the initial support level responsible for basic customer issues. It is synonymous with first-line support, level 1 support, front-end support, support line 1, and various other headings denoting basic level technical support functions. The first job of a Tier I specialist is to gather the customer’s information and to determine the customer’s issue by analyzing the symptoms and figuring out the underlying problem.<sup id=\"cite_ref-walker_4-1\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_support#cite_note-walker-4\"><span>[</span>5<span>]</span></a></sup> When analyzing the symptoms, it is important for the <a title=\"Technician\" href=\"http://en.wikipedia.org/wiki/Technician\">technician</a> to identify what the customer is trying to accomplish so that time is not wasted on “attempting to solve a symptom instead of a problem.” <sup id=\"cite_ref-walker_4-2\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_support#cite_note-walker-4\"><span>[</span>5<span>]</span></a></sup> Once identification of the underlying problem is established, the specialist can begin sorting through the possible solutions available. Technical support specialists in this group typically handle straightforward and simple problems while “possibly using some kind of knowledge management tool.” <sup id=\"cite_ref-windley_5-0\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_support#cite_note-windley-5\"><span>[</span>6<span>]</span></a></sup> This includes troubleshooting methods such as verifying physical layer issues, resolving username and password problems, uninstalling/reinstalling basic <a class=\"mw-redirect\" title=\"Software applications\" href=\"http://en.wikipedia.org/wiki/Software_applications\">software applications</a>, verification of proper <a title=\"Hardware\" href=\"http://en.wikipedia.org/wiki/Hardware\">hardware</a> and <a title=\"Software\" href=\"http://en.wikipedia.org/wiki/Software\">software</a> set up, and assistance with navigating around application menus. Personnel at this level have a basic to general understanding of the product or service and may not always contain the competency required for solving complex issues.<sup id=\"cite_ref-kajko_6-0\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_support#cite_note-kajko-6\"><span>[</span>7<span>]</span></a></sup> Nevertheless, the goal for this group is to handle 70%-80% of the user problems before finding it necessary to escalate the issue to a higher level.<sup id=\"cite_ref-kajko_6-1\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_support#cite_note-kajko-6\"><span>[</span>7<span>]</span></a></sup>\r\n\r\n<strong>Tier II</strong> – This is a more in-depth technical support level than Tier I containing experienced and more knowledgeable personnel on a particular product or service. It is synonymous with level 2 support, support line 2, administrative level support, and various other headings denoting advanced technical <a title=\"Troubleshooting\" href=\"http://en.wikipedia.org/wiki/Troubleshooting\">troubleshooting</a> and analysis methods. <a class=\"mw-redirect\" title=\"Technicians\" href=\"http://en.wikipedia.org/wiki/Technicians\">Technicians</a> in this realm of knowledge are responsible for assisting Tier I personnel solve basic technical problems and for investigating elevated issues by confirming the validity of the problem and seeking for known solutions related to these more complex issues.<sup id=\"cite_ref-kajko_6-2\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_support#cite_note-kajko-6\"><span>[</span>7<span>]</span></a></sup> However, prior to the <a title=\"Troubleshooting\" href=\"http://en.wikipedia.org/wiki/Troubleshooting\">troubleshooting</a> process, it is important that the technician review the work order to see what has already been accomplished by the Tier I technician and how long the technician has been working with the particular customer. This is a key element in meeting both the customer and business needs as it allows the technician to prioritize the troubleshooting process and properly manage his or her time.<sup id=\"cite_ref-walker_4-3\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_support#cite_note-walker-4\"><span>[</span>5<span>]</span></a></sup> If a problem is new and/or personnel from this group cannot determine a solution, they are responsible for raising this issue to the Tier III technical support group. In addition, many companies may specify that certain troubleshooting solutions be performed by this group to help ensure the intricacies of a challenging issue are solved by providing experienced and knowledgeable technicians. This may include, but is not limited to onsite installations or replacements of various hardware components, software repair, diagnostic testing, and the utilization of remote control tools used to take over the user’s machine for the sole purpose of troubleshooting and finding a solution to the problem.<sup id=\"cite_ref-walker_4-4\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_support#cite_note-walker-4\"><span>[</span>5<span>]</span></a></sup><sup id=\"cite_ref-nelson_7-0\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_support#cite_note-nelson-7\"><span>[</span>8<span>]</span></a></sup>\r\n\r\n<strong>Tier III</strong> – This is the highest level of support in a three-tiered technical support model responsible for handling the most difficult or advanced problems. It is synonymous with level 3 support, back-end support, support line 3, high-end support, and various other headings denoting expert level troubleshooting and analysis methods. These individuals are experts in their fields and are responsible for not only assisting both Tier I and Tier II personnel, but with the research and development of solutions to new or unknown issues. Note that Tier III technicians have the same responsibility as Tier II technicians in reviewing the work order and assessing the time already spent with the customer so that the work is prioritized and time management is sufficiently utilized.<sup id=\"cite_ref-walker_4-5\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_support#cite_note-walker-4\"><span>[</span>5<span>]</span></a></sup> If it is at all possible, the <a title=\"Technician\" href=\"http://en.wikipedia.org/wiki/Technician\">technician</a> will work to solve the problem with the customer as it may become apparent that the Tier I and/or Tier II technicians simply failed to discover the proper solution. Upon encountering new problems; however, Tier III personnel must first determine whether or not to solve the problem and may require the customer’s contact information so that the technician can have adequate time to troubleshoot the issue and find a solution.<sup id=\"cite_ref-kajko_6-3\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_support#cite_note-kajko-6\"><span>[</span>7<span>]</span></a></sup> In some instances, an issue may be so problematic to the point where the product cannot be salvaged and must be replaced. Such extreme problems are also sent to the original developers for in-depth analysis. If it is determined that a problem can be solved, this group is responsible for designing and developing one or more courses of action, evaluating each of these courses in a test case environment, and implementing the best solution to the problem.<sup id=\"cite_ref-kajko_6-4\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_support#cite_note-kajko-6\"><span>[</span>7<span>]</span></a></sup> Once the solution is verified, it is delivered to the customer and made available for future troubleshooting and analysis.\r\n\r\n<strong>Tier IV</strong> – While not universally used, a fourth level often represents an escalation point beyond the organization. This is generally a hardware or software vendor. Within a corporate incident management system it is important to continue to track incidents even when they are being actioned by a vendor and the <a class=\"mw-redirect\" title=\"Service Level Agreement\" href=\"http://en.wikipedia.org/wiki/Service_Level_Agreement\">Service Level Agreement</a> (or <a title=\"SLA\" href=\"http://en.wikipedia.org/wiki/SLA\">SLA</a>) may have specific provision for this.','What is Technical Support?',0,'','inherit','closed','open','','51-revision-2','','','2009-01-13 18:11:41','2009-01-13 08:11:41','',51,'http://moztronics.com.au/?p=63',0,'revision','',0),(64,1,'2009-01-13 17:20:02','2009-01-13 07:20:02','<span class=\"fsx03\" style=\"font-family: Verdana;\">A central vacuum system consists of a central power unit, normally situated in the garage, store room or cupboard. A network of PVC pipes then connect the inlet valves, situated throughout the house to the power unit. Inlet valves are located in such a way as to ensure that all areas of the residence can be vacuumed. All dirt and debris vacuumed passes along the pipework to the central power unit.</span>\r\n\r\nSEVEN REASONS TO HAVE A CENTRAL VACUUM SYSTEM:\r\n<div id=\"Oobj375\" style=\"position: absolute; z-index: 34; visibility: visible; left: 347px; top: 516px; width: 1px; height: 1px;\">\r\n<div id=\"Grtf378\" class=\"dfltt\"><span class=\"fsx03\" style=\"font-family: Verdana;\"><strong>\r\n</strong></span></div>\r\n</div>\r\n<span class=\"fsx03\" style=\"font-family: Verdana;\"><strong>1) Healthy air</strong>\r\nCentral vacuum systems totally eliminate the recirculation of dirty air inside your living area. All the hype about allergens, including dust mites is true!  Read what the EPA, American Lung Association, US News and World Report, and others have to say. The long term benefits are amazing.</span>\r\n\r\n<span class=\"fsx03\" style=\"font-family: Verdana;\"><strong>2) Vacuum power</strong>\r\nWith 3-5 times more cleaning power than most portable vacuum cleaners you get a superior clean in less time. Since the central vacuum is located in the garage or basement it can have bigger heavier motors. This power will give a deep down clean and pick up that thread you usually have to go over three times to pick up. The standard model recommended has an airflow of 262 l/s  (litres per second), compared with 85-128 l/s from a portable.</span>\r\n\r\n<span class=\"fsx03\" style=\"font-family: Verdana;\"><strong>3) Convenience</strong>\r\nJust connect the lightweight hose to any conveniently located inlet. No heavy unit to pull,push or drag upstairs, no switches, and electrical cords to keep tripping over. </span>\r\n\r\n<span class=\"fsx03\" style=\"font-family: Verdana;\"><strong>4) Home value</strong>\r\nAs with other built-in appliances, investing in a central vacuum system increases the market value of your home. For less than the cost of a high-end portable vacuum, you can buy a central vacuum and watch the resale value of your home increase. </span>\r\n\r\n<span class=\"fsx03\" style=\"font-family: Verdana;\"><strong>5) Less noise</strong></span>\r\n<span class=\"fsx03\" style=\"font-family: Verdana;\">MD SilentMaster eliminates the loud, irritating noise of portable vacuum cleaners because the power unit is not only acoustically insulated, it is located outside you living area. Important phone calls will be heard, the baby will sleep, and the favorite TV program will not be disturbed</span><span class=\"fsx04\" style=\"font-family: Arial;\">.</span>\r\n\r\n<span class=\"fsx03\" style=\"font-family: Verdana;\"><strong>6) Versatility</strong>\r\nDozens of attachments designed to clean any type of surface: carpeting, wood and tile floors, drapes, furniture, corners, crevices, staircases, ceiling fans, mini blinds, cars, etc.</span>\r\n\r\n<span class=\"fsx03\" style=\"font-family: Verdana;\"><strong>7) Cost savings</strong></span>\r\n<span class=\"fsx03\" style=\"font-family: Verdana;\">Saves you money by greatly prolonging the life of your carpeting and furniture due to the increased, deep-down cleaning power. A central vacuum is one of the best investments you can make in your new home.</span>','What are the benefits of Central (ducted) Vacuum Systems?',0,'','inherit','closed','open','','46-revision-2','','','2009-01-13 17:20:02','2009-01-13 07:20:02','',46,'http://moztronics.com.au/?p=64',0,'revision','',0),(65,1,'2009-01-13 18:09:25','2009-01-13 08:09:25','Smart Wiring <sup><span>TM</span></sup> is the standard home wiring system that lets you combine phone &amp; fax lines, pay TV cabling, sound, computer and Internet, intelligent lighting, security, home automation, and much more, at the one time and it gives the flexibility to add and change in the future without expensive re-wiring costs.\r\n\r\nInstalled by just one Smart Wired <sup><span>TM</span></sup> accredited electrician, not teams of specialists, Smart Wiring <sup><span>TM</span></sup> is designed to suit both your budget and life.\r\nBest installed when you\'re building or renovating, Smart Wiring <sup><span>TM</span></sup> should be discussed with your Smart Wired TM builder to make sure you pick the right options for you.\r\n\r\nIt must be good, it is recognised by FOXTEL and other Partners are Australian household names.','What is Smart Wiring™ ?',0,'','inherit','closed','open','','44-revision-4','','','2009-01-13 18:09:25','2009-01-13 08:09:25','',44,'http://moztronics.com.au/?p=65',0,'revision','',0),(66,1,'2009-01-13 15:19:19','2009-01-13 05:19:19','A <strong>smoke detector</strong> is a device that detects <a title=\"Smoke\" href=\"http://en.wikipedia.org/wiki/Smoke\">smoke</a> and issues a signal to a <a title=\"Fire alarm system\" href=\"http://en.wikipedia.org/wiki/Fire_alarm_system\">fire alarm system</a>, or issues a local audible <a title=\"Alarm\" href=\"http://en.wikipedia.org/wiki/Alarm\">alarm</a> from the detector itself.\r\n\r\nA household smoke detector will typically be mounted in a disk-shaped plastic enclosure about 150 millimetres (6 in) in diameter and 25 millimetres (1 in) thick, but the shape can vary by manufacturer. Most smoke detectors work either by optical detection (<a class=\"mw-redirect\" title=\"Photoelectric\" href=\"http://en.wikipedia.org/wiki/Photoelectric\">photoelectric</a>) or by physical process (<a title=\"Ionization\" href=\"http://en.wikipedia.org/wiki/Ionization\">ionization</a>), but some of them use both detection methods to increase sensitivity to smoke. Smoke detectors are usually powered by <a title=\"Battery (electricity)\" href=\"http://en.wikipedia.org/wiki/Battery_%28electricity%29\">battery</a>; some are connected directly to power mains — often have a battery as a power supply backup in case the mains power fails.\r\n\r\nThe smoke detector is one of three items of fire safety apparatus which are both recommended for homes and can be self-installed by the consumer. The second is a <a title=\"Fire extinguisher\" href=\"http://en.wikipedia.org/wiki/Fire_extinguisher\">fire extinguisher</a>, and the third is a <a title=\"Fire blanket\" href=\"http://en.wikipedia.org/wiki/Fire_blanket\">fire blanket</a>.','What is Smoke Detection?',0,'','inherit','closed','open','','31-revision-2','','','2009-01-13 15:19:19','2009-01-13 05:19:19','',31,'http://moztronics.com.au/?p=66',0,'revision','',0),(67,1,'2009-01-13 16:00:46','2009-01-13 06:00:46','In <a title=\"Telecommunication\" href=\"http://en.wikipedia.org/wiki/Telecommunication\">telecommunication</a>, <strong>telephony</strong> (pronounced <span class=\"IPA\" title=\"Pronunciation in the International Phonetic Alphabet (IPA)\"><a title=\"Wikipedia:IPA for English\" href=\"http://en.wikipedia.org/wiki/Wikipedia:IPA_for_English\">/t??l?f?ni/</a></span> <em>or</em> teh-LEH-fuh-nee) encompasses the general use of equipment to provide voice communication over distances, specifically by connecting <a title=\"Telephone\" href=\"http://en.wikipedia.org/wiki/Telephone\">telephones</a> to each other.\r\n\r\nTelephones were originally connected directly together in pairs. Each user had separate telephones wired to the various places he might wish to reach. This became inconvenient when people wanted to talk to many other telephones, so the <a title=\"Telephone exchange\" href=\"http://en.wikipedia.org/wiki/Telephone_exchange\">telephone exchange</a> was invented. Each telephone could then be connected to other local ones, thus inventing the <a title=\"Local loop\" href=\"http://en.wikipedia.org/wiki/Local_loop\">local loop</a> and the <a title=\"Telephone call\" href=\"http://en.wikipedia.org/wiki/Telephone_call\">telephone call</a>. Soon, nearby exchanges were connected by <a title=\"Trunking\" href=\"http://en.wikipedia.org/wiki/Trunking\">trunk lines</a>, and eventually distant ones were as well.\r\n\r\nIn modern times, most telephones are plugged into <a class=\"mw-redirect\" title=\"Telephone jack\" href=\"http://en.wikipedia.org/wiki/Telephone_jack\">telephone jacks</a>. Each jack is connected by <a title=\"On-premises wiring\" href=\"http://en.wikipedia.org/wiki/On-premises_wiring\">inside wiring</a> to a <a title=\"Drop (telecommunication)\" href=\"http://en.wikipedia.org/wiki/Drop_%28telecommunication%29\">drop</a> wire and then to a cable with other wires. Cables usually bring a large number of wires from all over a district <a title=\"Access network\" href=\"http://en.wikipedia.org/wiki/Access_network\">access network</a> to one wire center or telephone exchange. When the user of a telephone wants to make a <a title=\"Telephone call\" href=\"http://en.wikipedia.org/wiki/Telephone_call\">telephone call</a>, equipment at the exchange examines the dialed <a title=\"Telephone number\" href=\"http://en.wikipedia.org/wiki/Telephone_number\">telephone number</a> and connects that <a title=\"Telephone line\" href=\"http://en.wikipedia.org/wiki/Telephone_line\">telephone line</a> to another in the same wire center, or to a trunk to a distant exchange. Most of the exchanges in the world are connected to each other, forming the <a class=\"mw-redirect\" title=\"Public Switched Telephone Network\" href=\"http://en.wikipedia.org/wiki/Public_Switched_Telephone_Network\">Public Switched Telephone Network</a> or PSTN. By the end of the 20th century almost all were <a title=\"Stored Program Control exchange\" href=\"http://en.wikipedia.org/wiki/Stored_Program_Control_exchange\">Stored Program Control exchanges</a>.\r\n\r\nAfter the middle 20th century fax and data became important secondary users of the network created to carry voices, and late in the century parts of the network were upgraded with <a class=\"mw-redirect\" title=\"ISDN\" href=\"http://en.wikipedia.org/wiki/ISDN\">ISDN</a> and <a class=\"mw-redirect\" title=\"DSL\" href=\"http://en.wikipedia.org/wiki/DSL\">DSL</a> to improve handling of such traffic.\r\n\r\n<a title=\"Digital telephony\" href=\"http://en.wikipedia.org/wiki/Digital_telephony\">Digital telephony</a> is the use of digital technology in the provision of telephone services and systems. Almost all telephone calls are provided this way, but sometimes the term is restricted to cases in which the <a title=\"Last mile\" href=\"http://en.wikipedia.org/wiki/Last_mile\">last mile</a> is digital, or where the conversion between digital and analog signals takes place inside the telephone. Telephony was digitized to cut the cost and improve the quality of voice services, but digital telephony was then found useful for new network services (<a class=\"mw-redirect\" title=\"ISDN\" href=\"http://en.wikipedia.org/wiki/ISDN\">ISDN</a>) to transfer data speedily over telephone lines.\r\n\r\n<a class=\"mw-redirect\" title=\"IP Telephony\" href=\"http://en.wikipedia.org/wiki/IP_Telephony\">IP Telephony</a> is a modern form of telephony which uses the <a class=\"mw-redirect\" title=\"TCP/IP\" href=\"http://en.wikipedia.org/wiki/TCP/IP\">TCP/IP</a> protocol popularized by the <a title=\"Internet\" href=\"http://en.wikipedia.org/wiki/Internet\">internet</a> to transmit digitized voice data. Contrast this with the operation of POTS (an acronym for \"<a class=\"mw-redirect\" title=\"Plain Old Telephone Service\" href=\"http://en.wikipedia.org/wiki/Plain_Old_Telephone_Service\">Plain Old Telephone Service</a>\").\r\n\r\n<a title=\"Computer telephony integration\" href=\"http://en.wikipedia.org/wiki/Computer_telephony_integration\">Computer <strong>Telephony</strong> Integration (CTI)</a> enables computers to know about and control phone functions such as making and receiving voice, fax, and data calls with telephone directory services and caller identification. The integration of telephone software and computer systems is a major development in the evolution of the automated office.\r\n\r\nCTI is not a new concept. Such links have been used in the past in large telephone networks but only dedicated call centers could justify the costs of the required equipment installation. Primary telephone service providers are offering information services such as <a class=\"mw-redirect\" title=\"Automatic Number Identification\" href=\"http://en.wikipedia.org/wiki/Automatic_Number_Identification\">Automatic Number Identification</a> and <a title=\"Dialed Number Identification Service\" href=\"http://en.wikipedia.org/wiki/Dialed_Number_Identification_Service\">Dialed Number Identification Service</a> on a scale wide enough for its implementation to bring real value to business or residential telephone usage. A new generation of applications (middleware) is being developed as a result of standardization and availability of low cost computer telephony links.','What is Telephony?',0,'','inherit','closed','open','','38-revision-2','','','2009-01-13 16:00:46','2009-01-13 06:00:46','',38,'http://moztronics.com.au/?p=67',0,'revision','',0),(68,1,'2009-01-13 20:54:48','2009-01-13 10:54:48','In <a title=\"Telecommunication\" href=\"http://en.wikipedia.org/wiki/Telecommunication\">telecommunication</a>, <strong>telephony</strong> (pronounced <span class=\"IPA\" title=\"Pronunciation in the International Phonetic Alphabet (IPA)\"><a title=\"Wikipedia:IPA for English\" href=\"http://en.wikipedia.org/wiki/Wikipedia:IPA_for_English\">/t??l?f?ni/</a></span> <em>or</em> teh-LEH-fuh-nee) encompasses the general use of equipment to provide voice communication over distances, specifically by connecting <a title=\"Telephone\" href=\"http://en.wikipedia.org/wiki/Telephone\">telephones</a> to each other.\r\n\r\nTelephones were originally connected directly together in pairs. Each user had separate telephones wired to the various places he might wish to reach. This became inconvenient when people wanted to talk to many other telephones, so the <a title=\"Telephone exchange\" href=\"http://en.wikipedia.org/wiki/Telephone_exchange\">telephone exchange</a> was invented. Each telephone could then be connected to other local ones, thus inventing the <a title=\"Local loop\" href=\"http://en.wikipedia.org/wiki/Local_loop\">local loop</a> and the <a title=\"Telephone call\" href=\"http://en.wikipedia.org/wiki/Telephone_call\">telephone call</a>. Soon, nearby exchanges were connected by <a title=\"Trunking\" href=\"http://en.wikipedia.org/wiki/Trunking\">trunk lines</a>, and eventually distant ones were as well.\r\n\r\nIn modern times, most telephones are plugged into <a class=\"mw-redirect\" title=\"Telephone jack\" href=\"http://en.wikipedia.org/wiki/Telephone_jack\">telephone jacks</a>. Each jack is connected by <a title=\"On-premises wiring\" href=\"http://en.wikipedia.org/wiki/On-premises_wiring\">inside wiring</a> to a <a title=\"Drop (telecommunication)\" href=\"http://en.wikipedia.org/wiki/Drop_%28telecommunication%29\">drop</a> wire and then to a cable with other wires. Cables usually bring a large number of wires from all over a district <a title=\"Access network\" href=\"http://en.wikipedia.org/wiki/Access_network\">access network</a> to one wire center or telephone exchange. When the user of a telephone wants to make a <a title=\"Telephone call\" href=\"http://en.wikipedia.org/wiki/Telephone_call\">telephone call</a>, equipment at the exchange examines the dialed <a title=\"Telephone number\" href=\"http://en.wikipedia.org/wiki/Telephone_number\">telephone number</a> and connects that <a title=\"Telephone line\" href=\"http://en.wikipedia.org/wiki/Telephone_line\">telephone line</a> to another in the same wire center, or to a trunk to a distant exchange. Most of the exchanges in the world are connected to each other, forming the <a class=\"mw-redirect\" title=\"Public Switched Telephone Network\" href=\"http://en.wikipedia.org/wiki/Public_Switched_Telephone_Network\">Public Switched Telephone Network</a> or PSTN. By the end of the 20th century almost all were <a title=\"Stored Program Control exchange\" href=\"http://en.wikipedia.org/wiki/Stored_Program_Control_exchange\">Stored Program Control exchanges</a>.\r\n\r\nAfter the middle 20th century fax and data became important secondary users of the network created to carry voices, and late in the century parts of the network were upgraded with <a class=\"mw-redirect\" title=\"ISDN\" href=\"http://en.wikipedia.org/wiki/ISDN\">ISDN</a> and <a class=\"mw-redirect\" title=\"DSL\" href=\"http://en.wikipedia.org/wiki/DSL\">DSL</a> to improve handling of such traffic.\r\n\r\n<a title=\"Digital telephony\" href=\"http://en.wikipedia.org/wiki/Digital_telephony\">Digital telephony</a> is the use of digital technology in the provision of telephone services and systems. Almost all telephone calls are provided this way, but sometimes the term is restricted to cases in which the <a title=\"Last mile\" href=\"http://en.wikipedia.org/wiki/Last_mile\">last mile</a> is digital, or where the conversion between digital and analog signals takes place inside the telephone. Telephony was digitized to cut the cost and improve the quality of voice services, but digital telephony was then found useful for new network services (<a class=\"mw-redirect\" title=\"ISDN\" href=\"http://en.wikipedia.org/wiki/ISDN\">ISDN</a>) to transfer data speedily over telephone lines.\r\n\r\n<a class=\"mw-redirect\" title=\"IP Telephony\" href=\"http://en.wikipedia.org/wiki/IP_Telephony\">IP Telephony</a> is a modern form of telephony which uses the <a class=\"mw-redirect\" title=\"TCP/IP\" href=\"http://en.wikipedia.org/wiki/TCP/IP\">TCP/IP</a> protocol popularized by the <a title=\"Internet\" href=\"http://en.wikipedia.org/wiki/Internet\">internet</a> to transmit digitized voice data. Contrast this with the operation of POTS (an acronym for \"<a class=\"mw-redirect\" title=\"Plain Old Telephone Service\" href=\"http://en.wikipedia.org/wiki/Plain_Old_Telephone_Service\">Plain Old Telephone Service</a>\").\r\n\r\n<a title=\"Computer telephony integration\" href=\"http://en.wikipedia.org/wiki/Computer_telephony_integration\">Computer <strong>Telephony</strong> Integration (CTI)</a> enables computers to know about and control phone functions such as making and receiving voice, fax, and data calls with telephone directory services and caller identification. The integration of telephone software and computer systems is a major development in the evolution of the automated office.\r\n\r\nCTI is not a new concept. Such links have been used in the past in large telephone networks but only dedicated call centers could justify the costs of the required equipment installation. Primary telephone service providers are offering information services such as <a class=\"mw-redirect\" title=\"Automatic Number Identification\" href=\"http://en.wikipedia.org/wiki/Automatic_Number_Identification\">Automatic Number Identification</a> and <a title=\"Dialed Number Identification Service\" href=\"http://en.wikipedia.org/wiki/Dialed_Number_Identification_Service\">Dialed Number Identification Service</a> on a scale wide enough for its implementation to bring real value to business or residential telephone usage. A new generation of applications (middleware) is being developed as a result of standardization and availability of low cost computer telephony links.','What is Telephony?',0,'','inherit','closed','open','','38-revision-3','','','2009-01-13 20:54:48','2009-01-13 10:54:48','',38,'http://moztronics.com.au/?p=68',0,'revision','',0),(70,1,'2009-01-13 15:59:18','2009-01-13 05:59:18','<p class=\"standardtext\" align=\"left\"></p>\r\n<p class=\"standardtext\" align=\"left\">Any alarm installed in your premises can be remotely monitored. This is achieved by programming a communications device in the alarm panel to a specific computer located at Central Monitoring Services.The way communications occur varies and can be tailored for the level of security required and the ongoing charges incurred by the reporting costs. Most monitored alarms communicate via the telephone and incur a local call charge to the client account each time they communicate.</p>\r\n<p class=\"standardtext\" align=\"left\"></p>\r\n\r\n<ul>\r\n	<li class=\"style7\"> If you have a Smoke Detector attached to the alarm, you can be guaranteed some-one will respond if that alarm goes off and send the Fire Brigade if necessary.</li>\r\n	<li class=\"style7\">If you have a Medical Emergency button attached to the alarm you can be guaranteed some-one will respond and send the ambulance if necessary.</li>\r\n	<li class=\"style7\">If you have a Hold Up button attached to the alarm system you can be guaranteed some will respond and send the Police.</li>\r\n	<li class=\"style7\">If you are away on holiday and your alarm goes off you are guaranteed of someone responding and ensuring something is done to check and make sure your premises is secure.</li>\r\n	<li class=\"style7\">Peace of mind to know that someone will always follow up on an alarm at your premises 24 hours a day 7 days a week.</li>\r\n	<li class=\"style7\">Can you rely on members of the Public to do that?</li>\r\n</ul>\r\n<p class=\"standardtext\" align=\"left\"></p>\r\n<p class=\"standardtext\" align=\"left\"></p>\r\n<p class=\"standardtext\" align=\"left\"><strong>WHY MONITOR? </strong></p>\r\n<p class=\"standardtext\" align=\"left\">In the troubled times of today,                Security Systems are vital <strong>investments</strong> in the protection of families,                property, plant and possessions.</p>\r\n<p class=\"standardtext\" align=\"left\">This investment is necessary                as it can do more than just ring bells and sirens which by law must                shut down after 5 minutes.</p>\r\n<p class=\"standardtext\" align=\"left\">All activities that require an                urgent response are transmitted by the Central Security Link to                Central Monitoring Services 24hours a day 7 days a week.</p>\r\n<p class=\"style9\" align=\"left\"><span class=\"standardtext\">Security                alarms, hold-up and duress emergencies, fire, medical and critical                plant alarms can be strictly supervised by Central Monitoring Services\'                sophisticated computers. </span></p>\r\n<p class=\"style9\" align=\"left\"></p>\r\n\r\n<ul>\r\n	<li>\r\n<div>Keyholders are people (family, friends, neighbours and employees) who have been given keys and alarm codes to attend if requested by CMS in the event of an alarm at your premises. If CMS need to contact a keyholder they will advise the nature of the alarm event for action. If required CMS are available for any further action or follow up.</div></li>\r\n	<li>\r\n<div>Keyholders are also authorised to request CMS send a Security Patrol to an alarm event.</div></li>\r\n	<li>Keyholders are given to CMS by the Owner / Alarm Installer and are entered into the database for the specific alarm action for those premises on the understanding that the keyholder has given permission and understands his / her responsibility in the matter.</li>\r\n</ul>','Why use Back to Base Monitoring?',0,'','inherit','closed','open','','33-revision-4','','','2009-01-13 15:59:18','2009-01-13 05:59:18','',33,'http://moztronics.com.au/?p=70',0,'revision','',0),(71,1,'2009-01-13 15:17:08','2009-01-13 05:17:08','A <strong>fire extinguisher</strong> is an <a title=\"Active fire protection\" href=\"http://en.wikipedia.org/wiki/Active_fire_protection\">active fire protection</a> device used to extinguish or control small fires, often in emergency situations. It is not intended for use on an out-of-control fire, such as one which has reached the <a title=\"Ceiling\" href=\"http://en.wikipedia.org/wiki/Ceiling\">ceiling</a>, endangers the user (i.e. no escape route, smoke, explosion hazard, etc.), or otherwise requires the expertise of a <a class=\"mw-redirect\" title=\"Fire department\" href=\"http://en.wikipedia.org/wiki/Fire_department\">fire department</a>. Typically, a fire extinguisher consists of a hand-held cylindrical <a title=\"Pressure vessel\" href=\"http://en.wikipedia.org/wiki/Pressure_vessel\">pressure vessel</a> containing an <a href=\"http://en.wikipedia.org/wiki/Extinguisher#Types_of_extinguishing_agents\">agent</a> which can be discharged to extinguish a <a title=\"Fire\" href=\"http://en.wikipedia.org/wiki/Fire\">fire</a>.\r\n\r\nThere are two main types of fire extinguishers: Stored pressure and generated pressure. In stored pressure units, the expellant is stored in the same chamber as the firefighting agent itself. Depending on the agent used, different propellants are used. With dry chemical extinguishers, <a title=\"Nitrogen\" href=\"http://en.wikipedia.org/wiki/Nitrogen\">nitrogen</a> is typically used; water and foam are pressurized with air. Stored pressure are the most common types of fire extinguishers. Cartridge-operated extinguishers, contain the expellant gas in a separate cartridge that is punctured prior to discharge, exposing the propellant to the agent. These types as are not as common, used primarily in areas such as industrial facilities, where they receive higher-than-average use. They have the advantage of simple and prompt recharge, allowing an operator to discharge the extinguisher, recharge it, and return to the fire in an reasonable amount of time. Unlike stored pressure types, these extinguishers utilize compressed <a title=\"Carbon dioxide\" href=\"http://en.wikipedia.org/wiki/Carbon_dioxide\">carbon dioxide</a> instead of nitrogen, although nitrogen cartridges are used on low temperature (-60 rated) models. Cartridge operated types are available in dry chemical and dry powder in the US and water, wetting agent, foam, and dry powder(ABC, BC, or D) in the rest of the world.\r\n\r\nFire extinguishers are further divided into handheld and cart-mounted, also called wheeled extinguishers. Handheld extinguishers weigh from 2 to 30 pounds (1 to 14 kilograms), and are hence easily portable by hand. They exist in both stored- and generated-pressure types and contain all types of suppressants. Cart-mounted units typically weigh 50+ pounds (23+ kilograms), are cartridge-operated, and typically contain either dry chemical, <a title=\"Purple-K\" href=\"http://en.wikipedia.org/wiki/Purple-K\">Purple-K</a>, foam, Halon, Halotron-1 or CO<sub>2</sub>. Wheeled models are most commonly found at <a class=\"mw-redirect\" title=\"Construction sites\" href=\"http://en.wikipedia.org/wiki/Construction_sites\">construction sites</a>, <a title=\"Airport\" href=\"http://en.wikipedia.org/wiki/Airport\">airport</a> <a class=\"mw-redirect\" title=\"Runways\" href=\"http://en.wikipedia.org/wiki/Runways\">runways</a>, <a class=\"mw-redirect\" title=\"Heliports\" href=\"http://en.wikipedia.org/wiki/Heliports\">heliports</a>, and temporary landing sites.','What is an Extinguisher?',0,'','inherit','closed','open','','27-revision-2','','','2009-01-13 15:17:08','2009-01-13 05:17:08','',27,'http://moztronics.com.au/?p=71',0,'revision','',0),(72,1,'2009-01-13 15:08:23','2009-01-13 05:08:23','<strong>Surveillance</strong> is the monitoring of <a title=\"Behavior\" href=\"http://en.wikipedia.org/wiki/Behavior\">behavior</a>. <strong>Systems surveillance</strong> is the process of monitoring the behavior of people, objects or processes within systems for conformity to expected or desired <a title=\"Norm (sociology)\" href=\"http://en.wikipedia.org/wiki/Norm_%28sociology%29\">norms</a> in <a class=\"mw-redirect\" title=\"Trusted systems\" href=\"http://en.wikipedia.org/wiki/Trusted_systems\">trusted systems</a> for <a title=\"Security\" href=\"http://en.wikipedia.org/wiki/Security\">security</a> or <a title=\"Social control\" href=\"http://en.wikipedia.org/wiki/Social_control\">social control</a>. <a title=\"Clinical surveillance\" href=\"http://en.wikipedia.org/wiki/Clinical_surveillance\">Clinical surveillance</a> refers to the monitoring of <a title=\"Disease\" href=\"http://en.wikipedia.org/wiki/Disease\">diseases</a> or <a title=\"Public health\" href=\"http://en.wikipedia.org/wiki/Public_health\">public health</a>–related indicators (for example symptoms indicating an act of bioterrorism) by <a title=\"Epidemiology\" href=\"http://en.wikipedia.org/wiki/Epidemiology\">epidemiologists</a> and public health professionals. The word is pronounced <span class=\"IPA\" title=\"Pronunciation in the International Phonetic Alphabet (IPA)\"><a title=\"Wikipedia:IPA for English\" href=\"http://en.wikipedia.org/wiki/Wikipedia:IPA_for_English\">/s??ve??ns/</a></span> or <span class=\"IPA\" title=\"Representation in the International Phonetic Alphabet (IPA)\">/s??ve?l?ns/</span>.<sup id=\"cite_ref-0\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Surveillance#cite_note-0\"><span>[</span>1<span>]</span></a></sup>\r\n\r\nAlthough the word <em>surveillance</em> in <a title=\"French language\" href=\"http://en.wikipedia.org/wiki/French_language\">French</a> literally means \"watching over\",<sup id=\"cite_ref-1\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Surveillance#cite_note-1\"><span>[</span>2<span>]</span></a></sup> the term is often used for all forms of observation or monitoring, not just visual observation. Nevertheless, the all-seeing \"<a title=\"Eye in the sky (camera)\" href=\"http://en.wikipedia.org/wiki/Eye_in_the_sky_%28camera%29\">eye in the sky</a>\" is still a general icon of surveillance. Surveillance in many modern cities and buildings often uses <a title=\"Closed-circuit television\" href=\"http://en.wikipedia.org/wiki/Closed-circuit_television\">closed-circuit television</a> cameras. Although surveillance can be a useful tool for <a title=\"Police\" href=\"http://en.wikipedia.org/wiki/Police\">law enforcement</a> and security companies, many people have concerns about the loss of <a title=\"Privacy\" href=\"http://en.wikipedia.org/wiki/Privacy\">privacy</a>.\r\n\r\nThe word <em>surveillance</em> is commonly used to describe observation from a distance by means of electronic equipment or other <a title=\"Technology\" href=\"http://en.wikipedia.org/wiki/Technology\">technological</a> means. However, surveillance also includes simple, relatively no- or low-technology methods such as direct observation, observation with <a title=\"Binoculars\" href=\"http://en.wikipedia.org/wiki/Binoculars\">binoculars</a>, <a title=\"Postal interception\" href=\"http://en.wikipedia.org/wiki/Postal_interception\">postal interception</a>, or similar methods.\r\n<h2></h2>','What is Surveillance?',0,'','inherit','closed','open','','19-revision-2','','','2009-01-13 15:08:23','2009-01-13 05:08:23','',19,'http://moztronics.com.au/?p=72',0,'revision','',0),(73,1,'2009-01-13 15:11:42','2009-01-13 05:11:42','An <strong>uninterrupted power supply</strong> (<strong>UPS</strong>), also known as a <strong>battery back-up</strong>, provides emergency power and, depending on the topology, line regulation as well to connected equipment by supplying power from a separate source when utility power is not available. It differs from an auxiliary or <a title=\"Emergency power system\" href=\"http://en.wikipedia.org/wiki/Emergency_power_system\">emergency power system</a> or standby generator, which does not provide instant protection from a momentary power interruption. A UPS, however, can be used to provide uninterrupted power to equipment, typically for 5-15 minutes until an auxiliary power supply can be turned on or utility power is restored.\r\n\r\nWhile not limited to safeguarding any particular type of equipment, a UPS is typically used to protect <a title=\"Computer\" href=\"http://en.wikipedia.org/wiki/Computer\">computers</a>, <a title=\"Data center\" href=\"http://en.wikipedia.org/wiki/Data_center\">data centers</a>, <a title=\"Telecommunication\" href=\"http://en.wikipedia.org/wiki/Telecommunication\">telecommunication</a> equipment or other electrical equipment where an unexpected power disruption could cause injuries, fatalities, serious business disruption or data loss. UPS units come in sizes ranging from units which will back up a single computer without monitor (around 200 <a title=\"Volt-ampere\" href=\"http://en.wikipedia.org/wiki/Volt-ampere\">VA</a>) to units which will power entire data centers or buildings (several megawatts).\r\n\r\nThere are various common power problems that UPS units are used to correct. They are as follows (with a typical example of damage that might be caused):\r\n<ol>\r\n	<li><a class=\"mw-redirect\" title=\"Power failure\" href=\"http://en.wikipedia.org/wiki/Power_failure\">Power failure</a> — Total loss of utility power, with possibility of severe transient conditions upon failure and/or restoration: Causes electrical equipment to stop working (transients may cause permanent damage).</li>\r\n	<li><a class=\"mw-redirect\" title=\"Voltage sag\" href=\"http://en.wikipedia.org/wiki/Voltage_sag\">Voltage sag</a> — Transient (short term) under-voltage: Causes flickering of lights.</li>\r\n	<li><a title=\"Voltage spike\" href=\"http://en.wikipedia.org/wiki/Voltage_spike\">Voltage spike</a> — Transient (short term) over-voltage i.e. spike or peak: Causes wear or acute damage to electronic equipment.</li>\r\n	<li><a class=\"mw-redirect\" title=\"Under-voltage (brownout)\" href=\"http://en.wikipedia.org/wiki/Under-voltage_%28brownout%29\">Under-voltage (brownout)</a> — Low line voltage for an extended period of time: Causes overheating in motors.</li>\r\n	<li><a class=\"mw-redirect\" title=\"Over-voltage\" href=\"http://en.wikipedia.org/wiki/Over-voltage\">Over-voltage</a> — Increased voltage for an extended period of time: Causes light bulbs to burnout.</li>\r\n	<li><a class=\"mw-redirect\" title=\"Line noise\" href=\"http://en.wikipedia.org/wiki/Line_noise\">Line noise</a> — Distortions superimposed on the power waveform: Causes electromagnetic interference.</li>\r\n	<li><a class=\"new\" title=\"Frequency variation (page does not exist)\" href=\"http://en.wikipedia.org/w/index.php?title=Frequency_variation&amp;action=edit&amp;redlink=1\">Frequency variation</a> — Deviation from the nominal frequency (50 or 60 Hz): Causes motors to increase or decrease speed and line-driven clocks and timing devices to gain or lose time.</li>\r\n	<li><a class=\"new\" title=\"Switching transient (page does not exist)\" href=\"http://en.wikipedia.org/w/index.php?title=Switching_transient&amp;action=edit&amp;redlink=1\">Switching transient</a> — Instantaneous undervoltage (notch) in the range of milliseconds to seconds: May cause erratic behavior in some equipment, memory loss, data error, data loss and component stress.</li>\r\n	<li><a class=\"mw-redirect\" title=\"Harmonic distortion\" href=\"http://en.wikipedia.org/wiki/Harmonic_distortion\">Harmonic distortion</a> — Multiples of power frequency superimposed on the power waveform: Causes excess heating in wiring and fuses.</li>\r\n</ol>\r\nUPS units are divided into categories based on which of the above problems they address. Manufacturers categorize their products in accordance with the number of power related problems they address.','What is a UPS?',0,'','inherit','closed','open','','23-revision-2','','','2009-01-13 15:11:42','2009-01-13 05:11:42','',23,'http://moztronics.com.au/?p=73',0,'revision','',0),(74,1,'2009-01-13 15:10:20','2009-01-13 05:10:20','<strong>Antivirus software</strong> (or anti-virus) is <a title=\"Computer software\" href=\"http://en.wikipedia.org/wiki/Computer_software\">computer software</a> used to identify and remove <a title=\"Computer virus\" href=\"http://en.wikipedia.org/wiki/Computer_virus\">computer viruses</a>, as well as many other types of harmful computer software, collectively referred to as <a title=\"Malware\" href=\"http://en.wikipedia.org/wiki/Malware\">malware</a>. While the first antivirus software was designed exclusively to combat <a title=\"Computer virus\" href=\"http://en.wikipedia.org/wiki/Computer_virus\">computer viruses</a> (hence \"antivirus\"), modern antivirus software can protect computer systems against a wide range of malware, including <a title=\"Computer worm\" href=\"http://en.wikipedia.org/wiki/Computer_worm\">worms</a>, <a title=\"Phishing\" href=\"http://en.wikipedia.org/wiki/Phishing\">phishing</a> attacks, <a title=\"Rootkit\" href=\"http://en.wikipedia.org/wiki/Rootkit\">rootkits</a>, and <a title=\"Trojan horse (computing)\" href=\"http://en.wikipedia.org/wiki/Trojan_horse_%28computing%29\">Trojans</a>.\r\n\r\nA <strong>virus removal tool</strong> is <a title=\"Computer software\" href=\"http://en.wikipedia.org/wiki/Computer_software\">software</a> for removing specific <a title=\"Computer virus\" href=\"http://en.wikipedia.org/wiki/Computer_virus\">viruses</a> from infected computers. Unlike complete antivirus scanners, they are usually not intended to detect and remove an extensive list of viruses; rather they are designed to remove specific viruses, usually more effectively than normal antivirus software. Examples of these tools include <a title=\"McAfee Stinger\" href=\"http://en.wikipedia.org/wiki/McAfee_Stinger\">McAfee Stinger</a> and the <a title=\"Microsoft\" href=\"http://en.wikipedia.org/wiki/Microsoft\">Microsoft</a> <a class=\"external text\" title=\"http://www.microsoft.com/security/malwareremove/families.mspx\" rel=\"nofollow\" href=\"http://www.microsoft.com/security/malwareremove/families.mspx\">Malicious Software Removal Tool</a> (which is run automatically by <a class=\"mw-redirect\" title=\"Windows update\" href=\"http://en.wikipedia.org/wiki/Windows_update\">Windows update</a>). Many of these tools are available for free <a class=\"mw-redirect\" title=\"Download\" href=\"http://en.wikipedia.org/wiki/Download\">download</a>.\r\n\r\nThese tools can sometimes do a better job of removing a specific virus than conventional antivirus software.\r\n\r\nAntivirus programs can in themselves pose a security risk as they often run at the \'System\' level of privileges and may hook the kernel - Both of these are necessary for the software to effectively do its job but it has a major downside. This can mean exploitation of the Antivirus program itself could lead to <a title=\"Privilege escalation\" href=\"http://en.wikipedia.org/wiki/Privilege_escalation\">privilege escalation</a> and create a severe security threat. Arguably, use of Antivirus software when compared to <a title=\"Principle of least privilege\" href=\"http://en.wikipedia.org/wiki/Principle_of_least_privilege\">Principle of least privilege</a> is largely ineffective when ramifications of the added software are taken into account.\r\n\r\nWhen purchasing antivirus software, the agreement may include a clause that the subscription will be automatically renewed, and the purchaser\'s credit card automatically billed, at the renewal time without explicit approval. For example, <a title=\"McAfee\" href=\"http://en.wikipedia.org/wiki/McAfee\">McAfee</a> requires one to unsubscribe at least 60 days before the expiration of the present subscription.<sup id=\"cite_ref-2\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Anti-Virus#cite_note-2\"><span>[</span>3<span>]</span></a></sup> Norton Antivirus also renews subscriptions automatically by default. <sup id=\"cite_ref-3\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Anti-Virus#cite_note-3\"><span>[</span>4<span>]</span></a></sup>\r\n\r\nSome antivirus programs are actually <a title=\"Spyware\" href=\"http://en.wikipedia.org/wiki/Spyware\">spyware</a> masquerading as antivirus software. It is best to double-check that the antivirus software which is being downloaded is actually a real antivirus program.<sup id=\"cite_ref-4\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Anti-Virus#cite_note-4\"><span>[</span>5<span>]</span></a></sup>\r\n\r\nAnti-virus manufacturers have been criticised for <a title=\"Fear mongering\" href=\"http://en.wikipedia.org/wiki/Fear_mongering\">fear mongering</a> by exaggerating the risk that virus pose to consumers.<sup id=\"cite_ref-5\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Anti-Virus#cite_note-5\"><span>[</span>6<span>]</span></a></sup>\r\n\r\nIf an antivirus program is configured to immediately delete or quarantine infected files (or does this by default), false positives in essential files can render the operating system or some applications unusable.<sup id=\"cite_ref-6\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Anti-Virus#cite_note-6\"><span>[</span>7<span>]</span></a></sup>','What is Anti-Virus?',0,'','inherit','closed','open','','21-revision-2','','','2009-01-13 15:10:20','2009-01-13 05:10:20','',21,'http://moztronics.com.au/?p=74',0,'revision','',0),(75,1,'2009-01-13 15:15:04','2009-01-13 05:15:04','<strong>Closed-circuit television</strong> (<strong>CCTV</strong>) is the use of <a title=\"Video camera\" href=\"http://en.wikipedia.org/wiki/Video_camera\">video cameras</a> to transmit a signal to a specific place, limited set of monitors.\r\n\r\nIt differs from <a class=\"mw-redirect\" title=\"Broadcast television\" href=\"http://en.wikipedia.org/wiki/Broadcast_television\">broadcast television</a> in that the signal is not openly transmitted, though it may employ point to point wireless links. CCTV is often used for <a title=\"Surveillance\" href=\"http://en.wikipedia.org/wiki/Surveillance\">surveillance</a> in areas that may need monitoring such as <a title=\"Bank\" href=\"http://en.wikipedia.org/wiki/Bank\">banks</a>, <a title=\"Casino\" href=\"http://en.wikipedia.org/wiki/Casino\">casinos</a>, <a title=\"Airport\" href=\"http://en.wikipedia.org/wiki/Airport\">airports</a>, military installations and convenience stores.\r\n\r\nThe increasing use of CCTV in public places has caused a debate over public <a title=\"Surveillance\" href=\"http://en.wikipedia.org/wiki/Surveillance\">surveillance</a> versus <a title=\"Privacy\" href=\"http://en.wikipedia.org/wiki/Privacy\">privacy</a>. People can also buy consumer CCTV Systems for personal, private or commercial use. A more advanced form of CCTV, utilizing <a class=\"mw-redirect\" title=\"Digital Video Recorders\" href=\"http://en.wikipedia.org/wiki/Digital_Video_Recorders\">Digital Video Recorders</a> (DVRs), provides recording for possibly many years, with a variety of quality and performance options and extra features (such as motion-detection and email alerts).\r\n\r\nIn industrial plants, CCTV equipment may be used to observe parts of a process from a central control room; when, for example, the environment is not comfortable for humans. CCTV systems may operate continuously or only as required to monitor a particular event.','What is CCTV?',0,'','inherit','closed','open','','25-revision-2','','','2009-01-13 15:15:04','2009-01-13 05:15:04','',25,'http://moztronics.com.au/?p=75',0,'revision','',0),(76,1,'2009-01-13 12:18:42','2009-01-13 02:18:42','<strong>C-Bus</strong> is a home and building automation <a title=\"Communications protocol\" href=\"http://en.wikipedia.org/wiki/Communications_protocol\">protocol</a> that is used in <a title=\"Australia\" href=\"http://en.wikipedia.org/wiki/Australia\">Australia</a>, <a title=\"New Zealand\" href=\"http://en.wikipedia.org/wiki/New_Zealand\">New Zealand</a>, <a title=\"Asia\" href=\"http://en.wikipedia.org/wiki/Asia\">Asia</a>, the <a title=\"Middle East\" href=\"http://en.wikipedia.org/wiki/Middle_East\">Middle East</a>, <a title=\"Russia\" href=\"http://en.wikipedia.org/wiki/Russia\">Russia</a>, <a class=\"mw-redirect\" title=\"USA\" href=\"http://en.wikipedia.org/wiki/USA\">USA</a>, <a title=\"South Africa\" href=\"http://en.wikipedia.org/wiki/South_Africa\">South Africa</a>, the <a class=\"mw-redirect\" title=\"UK\" href=\"http://en.wikipedia.org/wiki/UK\">UK</a> and other parts of Europe including <a title=\"Greece\" href=\"http://en.wikipedia.org/wiki/Greece\">Greece</a> and <a title=\"Romania\" href=\"http://en.wikipedia.org/wiki/Romania\">Romania</a>. C-Bus was created by <a title=\"Clipsal\" href=\"http://en.wikipedia.org/wiki/Clipsal\">Clipsal</a>\'s <em>Clipsal Integrated Systems</em> division for use with its brand of home automation and building lighting control system. C-Bus has recently become available in the <a class=\"mw-redirect\" title=\"USA\" href=\"http://en.wikipedia.org/wiki/USA\">USA</a> under the \'SquareD Clipsal\' brand name.\r\n\r\nC-Bus is used in the control of <a class=\"mw-redirect\" title=\"Domotics\" href=\"http://en.wikipedia.org/wiki/Domotics\">domotics</a>, or <a title=\"Home automation\" href=\"http://en.wikipedia.org/wiki/Home_automation\">home automation</a> systems, as well as commercial building lighting control systems. Unlike the more common <a title=\"X10 (industry standard)\" href=\"http://en.wikipedia.org/wiki/X10_%28industry_standard%29\">X10</a> protocol which uses a signal imposed upon the <a title=\"Power line communication\" href=\"http://en.wikipedia.org/wiki/Power_line_communication\">AC power line</a>, C-Bus uses a dedicated low-voltage cable or two-way wireless network to carry command and control signals. This improves the reliability of command transmission and makes C-Bus far more suitable for large, commercial applications than X10.\r\n\r\nThe C-Bus System can be used to control lighting and other electrical systems and products via <a title=\"Remote control\" href=\"http://en.wikipedia.org/wiki/Remote_control\">remote control</a> and can also be interfaced to a home security system, AV products or other electrical items. The C-Bus system is available in a wired version and a <a title=\"Wireless\" href=\"http://en.wikipedia.org/wiki/Wireless\">wireless</a> version, with a gateway available to allow messages to be sent between wired and wireless networks.\r\n\r\nThe wired C-Bus system uses a standard category 5 UTP (Unshielded Twisted Pair) cable as its network communications cable. Clipsal manufacture a specific category 5 cable for use within electrical distribution panels. This cable has a pink outer sheath which is rated to ensure adequate electrical isolation between the mains voltages found in distribution panels and the extra low voltage C-Bus. Outside of distribution panels standard category 5 UTP cable can be used.\r\n\r\nThe category 5 C-Bus network wiring uses a free topology architecture. The maximum length of cable used on a C-Bus network is 1000 metres; however this is easily extended using C-Bus Network Bridges. Up to 100 units can be installed on a C-Bus network and this can also be extended using Network Bridges.\r\n\r\nThe maximum number of C-Bus networks in one installation is 255 (note that this limitation does not apply if a C-Bus Ethernet Interface is utilised, the system size is then limited to IP Addressing only). The maximum number of networks connected in series to the local network via Network Bridges is seven (i.e. using six network bridges).\r\n\r\nEach standard C-Bus unit requires 18mA @ 15-36Vdc to operate. However some C-Bus units require up to 40mA.\r\n\r\nMore than one C-Bus power supply can be connected to a C-Bus network to provide sufficient power to the C-Bus units, the C-Bus power supplies will share the load evenly.\r\n\r\nEach C-Bus network requires a network burden. This network burden can be enabled on C-Bus output units through software or a hardware burden can be connected to the network.\r\n\r\nEach C-Bus network requires at least one system clock generating unit for data synchronisation.\r\n\r\nThe isolation between the mains supply circuitry and the 36V dc C-Bus circuitry is greater than 3.5kV. This is achieved using double wound transformers and opto isolators. This means the C-Bus wiring, connections and circuitry can be considered Extra Low Voltage.','What is C-Bus?',0,'','inherit','closed','open','','8-revision-2','','','2009-01-13 12:18:42','2009-01-13 02:18:42','',8,'http://moztronics.com.au/?p=76',0,'revision','',0),(77,1,'2009-01-13 12:14:54','2009-01-13 02:14:54','The term <strong>media center</strong> refers either to a dedicated <a title=\"Computer appliance\" href=\"http://en.wikipedia.org/wiki/Computer_appliance\">computer appliance</a> or to a specialized <a title=\"Personal computer\" href=\"http://en.wikipedia.org/wiki/Personal_computer\">personal computer</a> <a title=\"Software\" href=\"http://en.wikipedia.org/wiki/Software\">software</a>, both of which are adapted for playing various kinds of <a title=\"Electronic media\" href=\"http://en.wikipedia.org/wiki/Electronic_media\">media</a> (<a title=\"Music\" href=\"http://en.wikipedia.org/wiki/Music\">music</a>, <a class=\"mw-redirect\" title=\"Movie\" href=\"http://en.wikipedia.org/wiki/Movie\">movies</a>, <a class=\"mw-redirect\" title=\"Photos\" href=\"http://en.wikipedia.org/wiki/Photos\">photos</a> etc.). A media center may also allow watching <a title=\"DVD\" href=\"http://en.wikipedia.org/wiki/DVD\">DVD</a> movies and watching and recording <a class=\"mw-redirect\" title=\"Television broadcast\" href=\"http://en.wikipedia.org/wiki/Television_broadcast\">television broadcasts</a>.\r\n\r\nThe media itself may be <a class=\"mw-redirect\" title=\"Computer storage\" href=\"http://en.wikipedia.org/wiki/Computer_storage\">stored</a>, received by <a title=\"Terrestrial television\" href=\"http://en.wikipedia.org/wiki/Terrestrial_television\">terrestrial</a>, <a title=\"Satellite television\" href=\"http://en.wikipedia.org/wiki/Satellite_television\">satellite</a> or <a title=\"Cable television\" href=\"http://en.wikipedia.org/wiki/Cable_television\">cable</a> broadcasting or <a class=\"mw-redirect\" title=\"Streaming\" href=\"http://en.wikipedia.org/wiki/Streaming\">streamed</a> from the internet. Stored media is kept either on a local <a class=\"mw-redirect\" title=\"Hard drive\" href=\"http://en.wikipedia.org/wiki/Hard_drive\">hard drive</a> or on a (<a title=\"Wireless LAN\" href=\"http://en.wikipedia.org/wiki/Wireless_LAN\">wireless</a>) <a class=\"mw-redirect\" title=\"Network attached storage\" href=\"http://en.wikipedia.org/wiki/Network_attached_storage\">network attached storage</a>. Some software is capable of doing other tasks, such as finding news (<a class=\"mw-redirect\" title=\"RSS (file format)\" href=\"http://en.wikipedia.org/wiki/RSS_%28file_format%29\">RSS</a>) from the <a title=\"Internet\" href=\"http://en.wikipedia.org/wiki/Internet\">Internet</a>. Media centers are often operated with a <a title=\"Remote control\" href=\"http://en.wikipedia.org/wiki/Remote_control\">remote control</a>, connected to a television set for <a title=\"TV-out\" href=\"http://en.wikipedia.org/wiki/TV-out\">video output</a>, and can sometimes function as a normal personal computer.\r\n\r\nA media center can be purpose-built, modified or created by individuals by adding media center software to a PC or some other computer, for example an <a title=\"Xbox\" href=\"http://en.wikipedia.org/wiki/Xbox\">Xbox</a>. Lately, some <a title=\"Video game console\" href=\"http://en.wikipedia.org/wiki/Video_game_console\">video game consoles</a> (<a class=\"mw-redirect\" title=\"Playstation 3\" href=\"http://en.wikipedia.org/wiki/Playstation_3\">Playstation 3</a> and <a title=\"Xbox 360\" href=\"http://en.wikipedia.org/wiki/Xbox_360\">Xbox 360</a>) with their network services can act as a media center devices by default.','What is a Media Center?',0,'','inherit','closed','open','','4-revision-2','','','2009-01-13 12:14:54','2009-01-13 02:14:54','',4,'http://moztronics.com.au/?p=77',0,'revision','',0),(78,1,'2009-01-13 12:16:15','2009-01-13 02:16:15','<strong>Voice over Internet Protocol</strong> (<strong>VoIP</strong>, <small>IPA</small>: <span class=\"IPA\" title=\"Pronunciation in IPA\"><a title=\"Wikipedia:IPA for English\" href=\"http://en.wikipedia.org/wiki/Wikipedia:IPA_for_English\">/v??p/</a></span>) is a general term for a family of transmission technologies for delivery of voice communications over the <a title=\"Internet\" href=\"http://en.wikipedia.org/wiki/Internet\">Internet</a> or other <a class=\"mw-redirect\" title=\"Packet-switched\" href=\"http://en.wikipedia.org/wiki/Packet-switched\">packet-switched</a> <a title=\"Computer network\" href=\"http://en.wikipedia.org/wiki/Computer_network\">networks</a>. Other terms frequently encountered and synonymous with VoIP are <em>IP telephony</em> and <em>Internet telephony</em>, as well as <em>voice over broadband</em>, <em><a title=\"Broadband\" href=\"http://en.wikipedia.org/wiki/Broadband\">broadband</a> telephony</em>, and <em>broadband phone</em>, when the network connectivity is available over broadband Internet access.\r\n\r\nVoIP systems usually interface with the traditional <a title=\"Public switched telephone network\" href=\"http://en.wikipedia.org/wiki/Public_switched_telephone_network\">public switched telephone network</a> (PSTN) to allow for transparent phone communications worldwide<sup id=\"cite_ref-0\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Voip#cite_note-0\"><span>[</span>1<span>]</span></a></sup>.\r\n\r\nVoIP can be a benefit for reducing communication and infrastructure costs by routing phone calls over existing data networks and avoiding duplicate network systems.\r\n\r\nVoice-over-IP systems carry telephony speech as <a title=\"Digital audio\" href=\"http://en.wikipedia.org/wiki/Digital_audio\">digital audio</a>, typically reduced in data rate using <a class=\"mw-redirect\" title=\"Speech data compression\" href=\"http://en.wikipedia.org/wiki/Speech_data_compression\">speech data compression</a> techniques, packetized in small units of typically tens of milliseconds of speech, and <a title=\"Data encapsulation\" href=\"http://en.wikipedia.org/wiki/Data_encapsulation\">encapsulated</a> in a packet stream over IP.','What is VoIP?',0,'','inherit','closed','open','','6-revision-2','','','2009-01-13 12:16:15','2009-01-13 02:16:15','',6,'http://moztronics.com.au/?p=78',0,'revision','',0),(79,1,'2009-01-13 20:59:47','2009-01-13 10:59:47','<strong>Voice over Internet Protocol</strong> (<strong>VoIP</strong>, <small>IPA</small>: <span class=\"IPA\" title=\"Pronunciation in IPA\"><a title=\"Wikipedia:IPA for English\" href=\"http://en.wikipedia.org/wiki/Wikipedia:IPA_for_English\">/v??p/</a></span>) is a general term for a family of transmission technologies for delivery of voice communications over the <a title=\"Internet\" href=\"http://en.wikipedia.org/wiki/Internet\">Internet</a> or other <a class=\"mw-redirect\" title=\"Packet-switched\" href=\"http://en.wikipedia.org/wiki/Packet-switched\">packet-switched</a> <a title=\"Computer network\" href=\"http://en.wikipedia.org/wiki/Computer_network\">networks</a>. Other terms frequently encountered and synonymous with VoIP are <em>IP telephony</em> and <em>Internet telephony</em>, as well as <em>voice over broadband</em>, <em><a title=\"Broadband\" href=\"http://en.wikipedia.org/wiki/Broadband\">broadband</a> telephony</em>, and <em>broadband phone</em>, when the network connectivity is available over broadband Internet access.\r\n\r\nVoIP systems usually interface with the traditional <a title=\"Public switched telephone network\" href=\"http://en.wikipedia.org/wiki/Public_switched_telephone_network\">public switched telephone network</a> (PSTN) to allow for transparent phone communications worldwide<sup id=\"cite_ref-0\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Voip#cite_note-0\"><span>[</span>1<span>]</span></a></sup>.\r\n\r\nVoIP can be a benefit for reducing communication and infrastructure costs by routing phone calls over existing data networks and avoiding duplicate network systems.\r\n\r\nVoice-over-IP systems carry telephony speech as <a title=\"Digital audio\" href=\"http://en.wikipedia.org/wiki/Digital_audio\">digital audio</a>, typically reduced in data rate using <a class=\"mw-redirect\" title=\"Speech data compression\" href=\"http://en.wikipedia.org/wiki/Speech_data_compression\">speech data compression</a> techniques, packetized in small units of typically tens of milliseconds of speech, and <a title=\"Data encapsulation\" href=\"http://en.wikipedia.org/wiki/Data_encapsulation\">encapsulated</a> in a packet stream over IP.','What is VoIP?',0,'','inherit','closed','open','','6-revision-3','','','2009-01-13 20:59:47','2009-01-13 10:59:47','',6,'http://moztronics.com.au/?p=79',0,'revision','',0),(81,1,'2009-01-13 21:00:32','2009-01-13 11:00:32','<strong>Computer networking</strong> is the <a title=\"Engineering\" href=\"http://en.wikipedia.org/wiki/Engineering\">engineering</a> <a title=\"Discipline\" href=\"http://en.wikipedia.org/wiki/Discipline\">discipline</a> concerned with communication between <a class=\"mw-redirect\" title=\"Computer system\" href=\"http://en.wikipedia.org/wiki/Computer_system\">computer systems</a> or <a class=\"mw-redirect\" title=\"Peripheral device\" href=\"http://en.wikipedia.org/wiki/Peripheral_device\">devices</a>. Networking, routers, routing protocols, and networking over the public <a title=\"Internet\" href=\"http://en.wikipedia.org/wiki/Internet\">Internet</a> have their specifications defined in documents called <a title=\"Request for Comments\" href=\"http://en.wikipedia.org/wiki/Request_for_Comments\">RFCs</a>.<sup id=\"cite_ref-0\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_networking#cite_note-0\"><span>[</span>1<span>]</span></a></sup> Computer networking is sometimes considered a sub-discipline of <a class=\"mw-redirect\" title=\"Telecommunications\" href=\"http://en.wikipedia.org/wiki/Telecommunications\">telecommunications</a>, <a title=\"Computer science\" href=\"http://en.wikipedia.org/wiki/Computer_science\">computer science</a>, <a title=\"Information technology\" href=\"http://en.wikipedia.org/wiki/Information_technology\">information technology</a> and/or <a title=\"Computer engineering\" href=\"http://en.wikipedia.org/wiki/Computer_engineering\">computer engineering</a>. Computer networks rely heavily upon the theoretical and practical application of these scientific and engineering disciplines.\r\n\r\nA computer network is any set of computers or devices connected to each other with the ability to exchange data.<sup id=\"cite_ref-1\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_networking#cite_note-1\"><span>[</span>2<span>]</span></a></sup> Examples of different networks are:\r\n<ul>\r\n	<li><a title=\"Local area network\" href=\"http://en.wikipedia.org/wiki/Local_area_network\">Local area network</a> (LAN), which is usually a small network constrained to a small geographic area.</li>\r\n	<li><a title=\"Wide area network\" href=\"http://en.wikipedia.org/wiki/Wide_area_network\">Wide area network</a> (WAN) that is usually a larger network that covers a large geographic area.</li>\r\n	<li><a title=\"Wireless network\" href=\"http://en.wikipedia.org/wiki/Wireless_network\">Wireless LANs and WANs</a> (WLAN &amp; WWAN) are the wireless equivalent of the LAN and WAN.</li>\r\n</ul>\r\nAll networks are interconnected to allow communication with a variety of different kinds of media, including <a title=\"Twisted pair\" href=\"http://en.wikipedia.org/wiki/Twisted_pair\">twisted-pair</a> copper wire cable, <a title=\"Coaxial cable\" href=\"http://en.wikipedia.org/wiki/Coaxial_cable\">coaxial cable</a>, <a title=\"Fiber-optic communication\" href=\"http://en.wikipedia.org/wiki/Fiber-optic_communication\">optical fiber</a>, and various wireless technologies.<sup id=\"cite_ref-2\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_networking#cite_note-2\"><span>[</span>3<span>]</span></a></sup> The devices can be separated by a few meters (e.g. via <a title=\"Bluetooth\" href=\"http://en.wikipedia.org/wiki/Bluetooth\">Bluetooth</a>) or nearly unlimited distances (e.g. via the interconnections of the <a title=\"Internet\" href=\"http://en.wikipedia.org/wiki/Internet\">Internet</a><sup id=\"cite_ref-3\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Computer_networking#cite_note-3\"><span>[</span>4<span>]</span></a></sup>).','What is Computer Networking?',0,'','inherit','closed','open','','10-revision-3','','','2009-01-13 21:00:32','2009-01-13 11:00:32','',10,'http://moztronics.com.au/?p=81',0,'revision','',0),(82,1,'2009-01-13 12:21:34','2009-01-13 02:21:34','<strong>Security</strong> is the condition of being protected against danger, loss, and criminals. In the general sense, security is a concept similar to <a title=\"Safety\" href=\"http://en.wikipedia.org/wiki/Safety\">safety</a>. The nuance between the two is an added emphasis on being protected from dangers that originate from outside. Individuals or actions that encroach upon the condition of protection are responsible for the breach of security.\r\n<ul>\r\n	<li>A condition that results from the establishment and <a class=\"mw-redirect\" title=\"Repair and maintenance\" href=\"http://en.wikipedia.org/wiki/Repair_and_maintenance\">maintenance</a> of protective measures that ensure a state of inviolability from hostile acts or influences.</li>\r\n	<li>With respect to classified matter, the condition that prevents unauthorized persons from having <a title=\"Access\" href=\"http://en.wikipedia.org/wiki/Access\">access</a> to official <a title=\"Information\" href=\"http://en.wikipedia.org/wiki/Information\">information</a> that is safeguarded in the interests of <a title=\"National security\" href=\"http://en.wikipedia.org/wiki/National_security\">national security</a>.</li>\r\n	<li>Measures taken by a military unit, an activity or installation to protect itself against all acts designed to, or which may, impair its effectiveness.</li>\r\n</ul>\r\nSecurity has to be compared and contrasted with other related concepts: <a title=\"Safety\" href=\"http://en.wikipedia.org/wiki/Safety\">Safety</a>, <a class=\"extiw\" title=\"wiktionary:continuity\" href=\"http://en.wiktionary.org/wiki/continuity\">continuity</a>, <a title=\"Reliability engineering\" href=\"http://en.wikipedia.org/wiki/Reliability_engineering\">reliability</a>. The key difference between security and reliability is that security must take into account the actions of active malicious agents attempting to cause destruction.','What is Security?',0,'','inherit','closed','open','','12-revision-2','','','2009-01-13 12:21:34','2009-01-13 02:21:34','',12,'http://moztronics.com.au/?p=82',0,'revision','',0),(83,1,'2009-01-13 13:02:51','2009-01-13 03:02:51','<strong>Security</strong> is the condition of being protected against danger, loss, and criminals. In the general sense, security is a concept similar to <a title=\"Safety\" href=\"http://en.wikipedia.org/wiki/Safety\">safety</a>. The nuance between the two is an added emphasis on being protected from dangers that originate from outside. Individuals or actions that encroach upon the condition of protection are responsible for the breach of security.\r\n<ul>\r\n	<li>A condition that results from the establishment and <a class=\"mw-redirect\" title=\"Repair and maintenance\" href=\"http://en.wikipedia.org/wiki/Repair_and_maintenance\">maintenance</a> of protective measures that ensure a state of inviolability from hostile acts or influences.</li>\r\n	<li>With respect to classified matter, the condition that prevents unauthorized persons from having <a title=\"Access\" href=\"http://en.wikipedia.org/wiki/Access\">access</a> to official <a title=\"Information\" href=\"http://en.wikipedia.org/wiki/Information\">information</a> that is safeguarded in the interests of <a title=\"National security\" href=\"http://en.wikipedia.org/wiki/National_security\">national security</a>.</li>\r\n	<li>Measures taken by a military unit, an activity or installation to protect itself against all acts designed to, or which may, impair its effectiveness.</li>\r\n</ul>\r\nSecurity has to be compared and contrasted with other related concepts: <a title=\"Safety\" href=\"http://en.wikipedia.org/wiki/Safety\">Safety</a>, <a class=\"extiw\" title=\"wiktionary:continuity\" href=\"http://en.wiktionary.org/wiki/continuity\">continuity</a>, <a title=\"Reliability engineering\" href=\"http://en.wikipedia.org/wiki/Reliability_engineering\">reliability</a>. The key difference between security and reliability is that security must take into account the actions of active malicious agents attempting to cause destruction.','What is Electrical Engineering?',0,'','inherit','closed','open','','17-revision-2','','','2009-01-13 13:02:51','2009-01-13 03:02:51','',17,'http://moztronics.com.au/?p=83',0,'revision','',0),(84,1,'2009-01-13 17:04:11','2009-01-13 07:04:11','<strong>Web presence</strong> refers to the appearance of a person or organization on the <a title=\"World Wide Web\" href=\"http://en.wikipedia.org/wiki/World_Wide_Web\">World Wide Web</a>. The phrase can be definite (as in \"Example Company\'s web presence\") or indefinite (as in \"develop a web presence\").\r\n\r\nA company has web presence if it is available on the web. The amount of web presence can be measured in the amount of sites a organization or individual has, which can include their own website, <a title=\"Social network\" href=\"http://en.wikipedia.org/wiki/Social_network\">social network</a> profiles, and their site\'s <a title=\"PageRank\" href=\"http://en.wikipedia.org/wiki/PageRank\">search engine ranking</a>, traffic, popularity, and <a title=\"Backlink\" href=\"http://en.wikipedia.org/wiki/Backlink\">backlinks</a>.\r\n\r\nUsers of the web often employ <a title=\"Egosurfing\" href=\"http://en.wikipedia.org/wiki/Egosurfing\">egosurfing</a> as a means of assessing their web presence.\r\n\r\nSome companies have employees that are focused on <a title=\"Internet presence management\" href=\"http://en.wikipedia.org/wiki/Internet_presence_management\">internet presence management</a>. Some will hire a firm to manage this aspect of their company for them.\r\n\r\n<strong>Internet presence management</strong> is the process of controlling the <a title=\"Web presence\" href=\"http://en.wikipedia.org/wiki/Web_presence\">Web presence</a>, or <a title=\"Internet\" href=\"http://en.wikipedia.org/wiki/Internet\">Internet</a>-based channels of an organization or company, with the goal of increasing that entity\'s operational efficiency.\r\n\r\nThe Internet presence, or <em>Web presence</em>, for an organization or company encompasses, but is not limited to:\r\n<ul>\r\n	<li><a title=\"E-mail\" href=\"http://en.wikipedia.org/wiki/E-mail\">E-mail</a></li>\r\n	<li><a title=\"Internet forum\" href=\"http://en.wikipedia.org/wiki/Internet_forum\">Internet forums</a></li>\r\n	<li><a title=\"Blog\" href=\"http://en.wikipedia.org/wiki/Blog\">Blogs</a></li>\r\n	<li><a title=\"Minisite\" href=\"http://en.wikipedia.org/wiki/Minisite\">Minisites</a></li>\r\n	<li><a title=\"Web search engine\" href=\"http://en.wikipedia.org/wiki/Web_search_engine\">Search engine</a> listings</li>\r\n	<li><a title=\"Social network\" href=\"http://en.wikipedia.org/wiki/Social_network\">Social networks</a> (e.g., <a title=\"MySpace\" href=\"http://en.wikipedia.org/wiki/MySpace\">MySpace</a>, <a title=\"Facebook\" href=\"http://en.wikipedia.org/wiki/Facebook\">Facebook</a> and <a title=\"YouTube\" href=\"http://en.wikipedia.org/wiki/YouTube\">YouTube</a>)</li>\r\n	<li><a title=\"Web directory\" href=\"http://en.wikipedia.org/wiki/Web_directory\">Web directories</a></li>\r\n	<li><a title=\"Website\" href=\"http://en.wikipedia.org/wiki/Website\">Websites</a></li>\r\n	<li><a title=\"Word of mouth\" href=\"http://en.wikipedia.org/wiki/Word_of_mouth\">Word of mouth</a> marketing (WOMM).</li>\r\n</ul>','What is Web Presence?',0,'','inherit','closed','open','','40-revision-3','','','2009-01-13 17:04:11','2009-01-13 07:04:11','',40,'http://moztronics.com.au/?p=84',0,'revision','',0),(85,1,'2009-01-13 19:51:43','2009-01-13 09:51:43','Moztronics has been in business for over 15 years. Some of our services include: install security alarms, and offer back-to-base monitoring services. We also custom build DVR\'s for use with security cameras for your home or business. We can help you get your business up and running, from smart wiring to getting the computers networked to installing the telephony, setting up a web presence, VOiP and switchboards. We offer &amp; install customized home media centers, ducted vaccum services\r\n\r\nWe love our line of work and enjoy being able to provide out customers with the latest cutting edge technology','About Moztronics',0,'','inherit','closed','open','','55-revision-2','','','2009-01-13 19:51:43','2009-01-13 09:51:43','',55,'http://moztronics.com.au/?p=85',0,'revision','',0),(86,1,'2009-01-13 12:32:03','2009-01-13 02:32:03','Welcome to Moztronics','Intro',0,'','inherit','closed','open','','1-revision-4','','','2009-01-13 12:32:03','2009-01-13 02:32:03','',1,'http://moztronics.com.au/?p=86',0,'revision','',0),(87,1,'2009-01-13 23:00:45','2009-01-13 13:00:45','','cctv_monitors1',0,'','inherit','closed','open','','cctv_monitors1','','','2009-01-13 23:00:45','2009-01-13 13:00:45','',4,'http://moztronics.com.au/wp-content/uploads/2009/01/cctv_monitors1.jpg',0,'attachment','image/jpeg',0),(88,1,'2009-01-13 23:01:04','2009-01-13 13:01:04','','kaspersky_20091',0,'','inherit','closed','open','','kaspersky_20091','','','2009-01-13 23:01:04','2009-01-13 13:01:04','',4,'http://moztronics.com.au/wp-content/uploads/2009/01/kaspersky_20091.jpg',0,'attachment','image/jpeg',0),(89,1,'2009-01-13 23:01:18','2009-01-13 13:01:18','','kaspersky_logo_1',0,'','inherit','closed','open','','kaspersky_logo_1','','','2009-01-13 23:01:18','2009-01-13 13:01:18','',4,'http://moztronics.com.au/wp-content/uploads/2009/01/kaspersky_logo_1.jpg',0,'attachment','image/jpeg',0),(90,1,'2009-01-13 23:01:29','2009-01-13 13:01:29','AppleMark','moztronics_griffin_blu',0,'','inherit','closed','open','','moztronics_griffin_blu','','','2009-01-13 23:01:29','2009-01-13 13:01:29','',4,'http://moztronics.com.au/wp-content/uploads/2009/01/moztronics_griffin_blu.jpg',0,'attachment','image/jpeg',0),(91,1,'2009-01-13 23:01:38','2009-01-13 13:01:38','','phone_aria',0,'','inherit','closed','open','','phone_aria','','','2009-01-13 23:01:38','2009-01-13 13:01:38','',4,'http://moztronics.com.au/wp-content/uploads/2009/01/phone_aria.gif',0,'attachment','image/gif',0),(92,1,'2009-01-13 23:01:48','2009-01-13 13:01:48','','plasma1',0,'','inherit','closed','open','','plasma1','','','2009-01-13 23:01:48','2009-01-13 13:01:48','',4,'http://moztronics.com.au/wp-content/uploads/2009/01/plasma1.jpg',0,'attachment','image/jpeg',0),(93,1,'2009-01-13 23:02:02','2009-01-13 13:02:02','','smart-wire-cabinet',0,'','inherit','closed','open','','smart-wire-cabinet','','','2009-01-13 23:02:02','2009-01-13 13:02:02','',4,'http://moztronics.com.au/wp-content/uploads/2009/01/smart-wire-cabinet.jpg',0,'attachment','image/jpeg',0),(94,1,'2009-01-13 23:02:41','2009-01-13 13:02:41','','smokealarm1',0,'','inherit','closed','open','','smokealarm1','','','2009-01-13 23:02:41','2009-01-13 13:02:41','',4,'http://moztronics.com.au/wp-content/uploads/2009/01/smokealarm1.gif',0,'attachment','image/gif',0),(95,1,'2009-01-13 23:02:56','2009-01-13 13:02:56','','vacdiagram',0,'','inherit','closed','open','','vacdiagram','','','2009-01-13 23:02:56','2009-01-13 13:02:56','',4,'http://moztronics.com.au/wp-content/uploads/2009/01/vacdiagram.gif',0,'attachment','image/gif',0),(96,1,'2009-01-13 23:03:07','2009-01-13 13:03:07','','vacuum',0,'','inherit','closed','open','','vacuum','','','2009-01-13 23:03:07','2009-01-13 13:03:07','',4,'http://moztronics.com.au/wp-content/uploads/2009/01/vacuum.gif',0,'attachment','image/gif',0),(97,1,'2009-01-13 23:03:18','2009-01-13 13:03:18','','vacuum_11',0,'','inherit','closed','open','','vacuum_11','','','2009-01-13 23:03:18','2009-01-13 13:03:18','',4,'http://moztronics.com.au/wp-content/uploads/2009/01/vacuum_11.jpg',0,'attachment','image/jpeg',0),(98,1,'2009-01-13 23:03:26','2009-01-13 13:03:26','','vacuum_21',0,'','inherit','closed','open','','vacuum_21','','','2009-01-13 23:03:26','2009-01-13 13:03:26','',4,'http://moztronics.com.au/wp-content/uploads/2009/01/vacuum_21.jpg',0,'attachment','image/jpeg',0),(99,1,'2009-01-13 23:03:34','2009-01-13 13:03:34','','voip_phone1',0,'','inherit','closed','open','','voip_phone1','','','2009-01-13 23:03:34','2009-01-13 13:03:34','',4,'http://moztronics.com.au/wp-content/uploads/2009/01/voip_phone1.gif',0,'attachment','image/gif',0),(100,1,'2009-01-13 23:04:23','2009-01-13 13:04:23','','VOIP Handset',0,'','inherit','closed','open','','voip_phone','','','2009-01-13 23:04:23','2009-01-13 13:04:23','',4,'http://moztronics.com.au/wp-content/uploads/2009/01/voip_phone.jpg',0,'attachment','image/jpeg',0),(101,1,'2009-01-13 23:05:10','2009-01-13 13:05:10','','Media Center',0,'','inherit','closed','open','','mediacentre1','','','2009-01-13 23:05:10','2009-01-13 13:05:10','',4,'http://moztronics.com.au/wp-content/uploads/2009/01/mediacentre1.jpg',0,'attachment','image/jpeg',0),(102,1,'2009-01-13 20:59:27','2009-01-13 10:59:27','The term <strong>media center</strong> refers either to a dedicated <a title=\"Computer appliance\" href=\"http://en.wikipedia.org/wiki/Computer_appliance\">computer appliance</a> or to a specialized <a title=\"Personal computer\" href=\"http://en.wikipedia.org/wiki/Personal_computer\">personal computer</a> <a title=\"Software\" href=\"http://en.wikipedia.org/wiki/Software\">software</a>, both of which are adapted for playing various kinds of <a title=\"Electronic media\" href=\"http://en.wikipedia.org/wiki/Electronic_media\">media</a> (<a title=\"Music\" href=\"http://en.wikipedia.org/wiki/Music\">music</a>, <a class=\"mw-redirect\" title=\"Movie\" href=\"http://en.wikipedia.org/wiki/Movie\">movies</a>, <a class=\"mw-redirect\" title=\"Photos\" href=\"http://en.wikipedia.org/wiki/Photos\">photos</a> etc.). A media center may also allow watching <a title=\"DVD\" href=\"http://en.wikipedia.org/wiki/DVD\">DVD</a> movies and watching and recording <a class=\"mw-redirect\" title=\"Television broadcast\" href=\"http://en.wikipedia.org/wiki/Television_broadcast\">television broadcasts</a>.\r\n\r\nThe media itself may be <a class=\"mw-redirect\" title=\"Computer storage\" href=\"http://en.wikipedia.org/wiki/Computer_storage\">stored</a>, received by <a title=\"Terrestrial television\" href=\"http://en.wikipedia.org/wiki/Terrestrial_television\">terrestrial</a>, <a title=\"Satellite television\" href=\"http://en.wikipedia.org/wiki/Satellite_television\">satellite</a> or <a title=\"Cable television\" href=\"http://en.wikipedia.org/wiki/Cable_television\">cable</a> broadcasting or <a class=\"mw-redirect\" title=\"Streaming\" href=\"http://en.wikipedia.org/wiki/Streaming\">streamed</a> from the internet. Stored media is kept either on a local <a class=\"mw-redirect\" title=\"Hard drive\" href=\"http://en.wikipedia.org/wiki/Hard_drive\">hard drive</a> or on a (<a title=\"Wireless LAN\" href=\"http://en.wikipedia.org/wiki/Wireless_LAN\">wireless</a>) <a class=\"mw-redirect\" title=\"Network attached storage\" href=\"http://en.wikipedia.org/wiki/Network_attached_storage\">network attached storage</a>. Some software is capable of doing other tasks, such as finding news (<a class=\"mw-redirect\" title=\"RSS (file format)\" href=\"http://en.wikipedia.org/wiki/RSS_%28file_format%29\">RSS</a>) from the <a title=\"Internet\" href=\"http://en.wikipedia.org/wiki/Internet\">Internet</a>. Media centers are often operated with a <a title=\"Remote control\" href=\"http://en.wikipedia.org/wiki/Remote_control\">remote control</a>, connected to a television set for <a title=\"TV-out\" href=\"http://en.wikipedia.org/wiki/TV-out\">video output</a>, and can sometimes function as a normal personal computer.\r\n\r\nA media center can be purpose-built, modified or created by individuals by adding media center software to a PC or some other computer, for example an <a title=\"Xbox\" href=\"http://en.wikipedia.org/wiki/Xbox\">Xbox</a>. Lately, some <a title=\"Video game console\" href=\"http://en.wikipedia.org/wiki/Video_game_console\">video game consoles</a> (<a class=\"mw-redirect\" title=\"Playstation 3\" href=\"http://en.wikipedia.org/wiki/Playstation_3\">Playstation 3</a> and <a title=\"Xbox 360\" href=\"http://en.wikipedia.org/wiki/Xbox_360\">Xbox 360</a>) with their network services can act as a media center devices by default.','What is a Media Center?',0,'','inherit','closed','open','','4-revision-3','','','2009-01-13 20:59:27','2009-01-13 10:59:27','',4,'http://moztronics.com.au/?p=102',0,'revision','',0),(103,1,'2009-01-13 23:05:40','2009-01-13 13:05:40','<!--more--><a href=\"http://moztronics.com.au/wp-content/uploads/2009/01/mediacentre1.jpg\"><img class=\"alignright size-medium wp-image-101\" title=\"Media Center\" src=\"http://moztronics.com.au/wp-content/uploads/2009/01/mediacentre1-300x297.jpg\" alt=\"\" width=\"300\" height=\"297\" /></a>The term <strong>media center</strong> refers either to a dedicated <a title=\"Computer appliance\" href=\"http://en.wikipedia.org/wiki/Computer_appliance\">computer appliance</a> or to a specialized <a title=\"Personal computer\" href=\"http://en.wikipedia.org/wiki/Personal_computer\">personal computer</a> <a title=\"Software\" href=\"http://en.wikipedia.org/wiki/Software\">software</a>, both of which are adapted for playing various kinds of <a title=\"Electronic media\" href=\"http://en.wikipedia.org/wiki/Electronic_media\">media</a> (<a title=\"Music\" href=\"http://en.wikipedia.org/wiki/Music\">music</a>, <a class=\"mw-redirect\" title=\"Movie\" href=\"http://en.wikipedia.org/wiki/Movie\">movies</a>, <a class=\"mw-redirect\" title=\"Photos\" href=\"http://en.wikipedia.org/wiki/Photos\">photos</a> etc.). A media center may also allow watching <a title=\"DVD\" href=\"http://en.wikipedia.org/wiki/DVD\">DVD</a> movies and watching and recording <a class=\"mw-redirect\" title=\"Television broadcast\" href=\"http://en.wikipedia.org/wiki/Television_broadcast\">television broadcasts</a>.\r\n\r\nThe media itself may be <a class=\"mw-redirect\" title=\"Computer storage\" href=\"http://en.wikipedia.org/wiki/Computer_storage\">stored</a>, received by <a title=\"Terrestrial television\" href=\"http://en.wikipedia.org/wiki/Terrestrial_television\">terrestrial</a>, <a title=\"Satellite television\" href=\"http://en.wikipedia.org/wiki/Satellite_television\">satellite</a> or <a title=\"Cable television\" href=\"http://en.wikipedia.org/wiki/Cable_television\">cable</a> broadcasting or <a class=\"mw-redirect\" title=\"Streaming\" href=\"http://en.wikipedia.org/wiki/Streaming\">streamed</a> from the internet. Stored media is kept either on a local <a class=\"mw-redirect\" title=\"Hard drive\" href=\"http://en.wikipedia.org/wiki/Hard_drive\">hard drive</a> or on a (<a title=\"Wireless LAN\" href=\"http://en.wikipedia.org/wiki/Wireless_LAN\">wireless</a>) <a class=\"mw-redirect\" title=\"Network attached storage\" href=\"http://en.wikipedia.org/wiki/Network_attached_storage\">network attached storage</a>. Some software is capable of doing other tasks, such as finding news (<a class=\"mw-redirect\" title=\"RSS (file format)\" href=\"http://en.wikipedia.org/wiki/RSS_%28file_format%29\">RSS</a>) from the <a title=\"Internet\" href=\"http://en.wikipedia.org/wiki/Internet\">Internet</a>. Media centers are often operated with a <a title=\"Remote control\" href=\"http://en.wikipedia.org/wiki/Remote_control\">remote control</a>, connected to a television set for <a title=\"TV-out\" href=\"http://en.wikipedia.org/wiki/TV-out\">video output</a>, and can sometimes function as a normal personal computer.\r\n\r\nA media center can be purpose-built, modified or created by individuals by adding media center software to a PC or some other computer, for example an <a title=\"Xbox\" href=\"http://en.wikipedia.org/wiki/Xbox\">Xbox</a>. Lately, some <a title=\"Video game console\" href=\"http://en.wikipedia.org/wiki/Video_game_console\">video game consoles</a> (<a class=\"mw-redirect\" title=\"Playstation 3\" href=\"http://en.wikipedia.org/wiki/Playstation_3\">Playstation 3</a> and <a title=\"Xbox 360\" href=\"http://en.wikipedia.org/wiki/Xbox_360\">Xbox 360</a>) with their network services can act as a media center devices by default.','What is a Media Center?',0,'','inherit','closed','open','','4-revision-4','','','2009-01-13 23:05:40','2009-01-13 13:05:40','',4,'http://moztronics.com.au/?p=103',0,'revision','',0),(104,1,'2009-01-13 23:07:12','2009-01-13 13:07:12','<!--more--><a href=\"http://moztronics.com.au/wp-content/uploads/2009/01/mediacentre1.jpg\"><img class=\"alignright size-medium wp-image-101\" style=\"border: 0pt none; margin: 10px;\" title=\"Media Center\" src=\"http://moztronics.com.au/wp-content/uploads/2009/01/mediacentre1-300x297.jpg\" alt=\"Media Center\" width=\"300\" height=\"297\" /></a>The term <strong>media center</strong> refers either to a dedicated <a title=\"Computer appliance\" href=\"http://en.wikipedia.org/wiki/Computer_appliance\">computer appliance</a> or to a specialized <a title=\"Personal computer\" href=\"http://en.wikipedia.org/wiki/Personal_computer\">personal computer</a> <a title=\"Software\" href=\"http://en.wikipedia.org/wiki/Software\">software</a>, both of which are adapted for playing various kinds of <a title=\"Electronic media\" href=\"http://en.wikipedia.org/wiki/Electronic_media\">media</a> (<a title=\"Music\" href=\"http://en.wikipedia.org/wiki/Music\">music</a>, <a class=\"mw-redirect\" title=\"Movie\" href=\"http://en.wikipedia.org/wiki/Movie\">movies</a>, <a class=\"mw-redirect\" title=\"Photos\" href=\"http://en.wikipedia.org/wiki/Photos\">photos</a> etc.). A media center may also allow watching <a title=\"DVD\" href=\"http://en.wikipedia.org/wiki/DVD\">DVD</a> movies and watching and recording <a class=\"mw-redirect\" title=\"Television broadcast\" href=\"http://en.wikipedia.org/wiki/Television_broadcast\">television broadcasts</a>.\n\nThe media itself may be <a class=\"mw-redirect\" title=\"Computer storage\" href=\"http://en.wikipedia.org/wiki/Computer_storage\">stored</a>, received by <a title=\"Terrestrial television\" href=\"http://en.wikipedia.org/wiki/Terrestrial_television\">terrestrial</a>, <a title=\"Satellite television\" href=\"http://en.wikipedia.org/wiki/Satellite_television\">satellite</a> or <a title=\"Cable television\" href=\"http://en.wikipedia.org/wiki/Cable_television\">cable</a> broadcasting or <a class=\"mw-redirect\" title=\"Streaming\" href=\"http://en.wikipedia.org/wiki/Streaming\">streamed</a> from the internet. Stored media is kept either on a local <a class=\"mw-redirect\" title=\"Hard drive\" href=\"http://en.wikipedia.org/wiki/Hard_drive\">hard drive</a> or on a (<a title=\"Wireless LAN\" href=\"http://en.wikipedia.org/wiki/Wireless_LAN\">wireless</a>) <a class=\"mw-redirect\" title=\"Network attached storage\" href=\"http://en.wikipedia.org/wiki/Network_attached_storage\">network attached storage</a>. Some software is capable of doing other tasks, such as finding news (<a class=\"mw-redirect\" title=\"RSS (file format)\" href=\"http://en.wikipedia.org/wiki/RSS_%28file_format%29\">RSS</a>) from the <a title=\"Internet\" href=\"http://en.wikipedia.org/wiki/Internet\">Internet</a>. Media centers are often operated with a <a title=\"Remote control\" href=\"http://en.wikipedia.org/wiki/Remote_control\">remote control</a>, connected to a television set for <a title=\"TV-out\" href=\"http://en.wikipedia.org/wiki/TV-out\">video output</a>, and can sometimes function as a normal personal computer.\n\nA media center can be purpose-built, modified or created by individuals by adding media center software to a PC or some other computer, for example an <a title=\"Xbox\" href=\"http://en.wikipedia.org/wiki/Xbox\">Xbox</a>. Lately, some <a title=\"Video game console\" href=\"http://en.wikipedia.org/wiki/Video_game_console\">video game consoles</a> (<a class=\"mw-redirect\" title=\"Playstation 3\" href=\"http://en.wikipedia.org/wiki/Playstation_3\">Playstation 3</a> and <a title=\"Xbox 360\" href=\"http://en.wikipedia.org/wiki/Xbox_360\">Xbox 360</a>) with their network services can act as a media center devices by default.','What is a Media Center?',0,'','inherit','closed','open','','4-autosave','','','2009-01-13 23:07:12','2009-01-13 13:07:12','',4,'http://moztronics.com.au/?p=104',0,'revision','',0),(105,1,'2009-01-13 23:07:06','2009-01-13 13:07:06','<!--more--><a href=\"http://moztronics.com.au/wp-content/uploads/2009/01/mediacentre1.jpg\"><img class=\"alignright size-medium wp-image-101\" style=\"border: 0pt none; margin: 10px;\" title=\"Media Center\" src=\"http://moztronics.com.au/wp-content/uploads/2009/01/mediacentre1-300x297.jpg\" alt=\"Media Center\" width=\"300\" height=\"297\" /></a>The term <strong>media center</strong> refers either to a dedicated <a title=\"Computer appliance\" href=\"http://en.wikipedia.org/wiki/Computer_appliance\">computer appliance</a> or to a specialized <a title=\"Personal computer\" href=\"http://en.wikipedia.org/wiki/Personal_computer\">personal computer</a> <a title=\"Software\" href=\"http://en.wikipedia.org/wiki/Software\">software</a>, both of which are adapted for playing various kinds of <a title=\"Electronic media\" href=\"http://en.wikipedia.org/wiki/Electronic_media\">media</a> (<a title=\"Music\" href=\"http://en.wikipedia.org/wiki/Music\">music</a>, <a class=\"mw-redirect\" title=\"Movie\" href=\"http://en.wikipedia.org/wiki/Movie\">movies</a>, <a class=\"mw-redirect\" title=\"Photos\" href=\"http://en.wikipedia.org/wiki/Photos\">photos</a> etc.). A media center may also allow watching <a title=\"DVD\" href=\"http://en.wikipedia.org/wiki/DVD\">DVD</a> movies and watching and recording <a class=\"mw-redirect\" title=\"Television broadcast\" href=\"http://en.wikipedia.org/wiki/Television_broadcast\">television broadcasts</a>.\r\n\r\nThe media itself may be <a class=\"mw-redirect\" title=\"Computer storage\" href=\"http://en.wikipedia.org/wiki/Computer_storage\">stored</a>, received by <a title=\"Terrestrial television\" href=\"http://en.wikipedia.org/wiki/Terrestrial_television\">terrestrial</a>, <a title=\"Satellite television\" href=\"http://en.wikipedia.org/wiki/Satellite_television\">satellite</a> or <a title=\"Cable television\" href=\"http://en.wikipedia.org/wiki/Cable_television\">cable</a> broadcasting or <a class=\"mw-redirect\" title=\"Streaming\" href=\"http://en.wikipedia.org/wiki/Streaming\">streamed</a> from the internet. Stored media is kept either on a local <a class=\"mw-redirect\" title=\"Hard drive\" href=\"http://en.wikipedia.org/wiki/Hard_drive\">hard drive</a> or on a (<a title=\"Wireless LAN\" href=\"http://en.wikipedia.org/wiki/Wireless_LAN\">wireless</a>) <a class=\"mw-redirect\" title=\"Network attached storage\" href=\"http://en.wikipedia.org/wiki/Network_attached_storage\">network attached storage</a>. Some software is capable of doing other tasks, such as finding news (<a class=\"mw-redirect\" title=\"RSS (file format)\" href=\"http://en.wikipedia.org/wiki/RSS_%28file_format%29\">RSS</a>) from the <a title=\"Internet\" href=\"http://en.wikipedia.org/wiki/Internet\">Internet</a>. Media centers are often operated with a <a title=\"Remote control\" href=\"http://en.wikipedia.org/wiki/Remote_control\">remote control</a>, connected to a television set for <a title=\"TV-out\" href=\"http://en.wikipedia.org/wiki/TV-out\">video output</a>, and can sometimes function as a normal personal computer.\r\n\r\nA media center can be purpose-built, modified or created by individuals by adding media center software to a PC or some other computer, for example an <a title=\"Xbox\" href=\"http://en.wikipedia.org/wiki/Xbox\">Xbox</a>. Lately, some <a title=\"Video game console\" href=\"http://en.wikipedia.org/wiki/Video_game_console\">video game consoles</a> (<a class=\"mw-redirect\" title=\"Playstation 3\" href=\"http://en.wikipedia.org/wiki/Playstation_3\">Playstation 3</a> and <a title=\"Xbox 360\" href=\"http://en.wikipedia.org/wiki/Xbox_360\">Xbox 360</a>) with their network services can act as a media center devices by default.','What is a Media Center?',0,'','inherit','closed','open','','4-revision-5','','','2009-01-13 23:07:06','2009-01-13 13:07:06','',4,'http://moztronics.com.au/?p=105',0,'revision','',0),(106,1,'2009-01-13 21:00:13','2009-01-13 11:00:13','<strong>Voice over Internet Protocol</strong> is a general term for a family of transmission technologies for delivery of voice communications over the <a title=\"Internet\" href=\"http://en.wikipedia.org/wiki/Internet\">Internet</a> or other <a class=\"mw-redirect\" title=\"Packet-switched\" href=\"http://en.wikipedia.org/wiki/Packet-switched\">packet-switched</a> <a title=\"Computer network\" href=\"http://en.wikipedia.org/wiki/Computer_network\">networks</a>. Other terms frequently encountered and synonymous with VoIP are <em>IP telephony</em> and <em>Internet telephony</em>, as well as <em>voice over broadband</em>, <em><a title=\"Broadband\" href=\"http://en.wikipedia.org/wiki/Broadband\">broadband</a> telephony</em>, and <em>broadband phone</em>, when the network connectivity is available over broadband Internet access.\r\n\r\nVoIP systems usually interface with the traditional <a title=\"Public switched telephone network\" href=\"http://en.wikipedia.org/wiki/Public_switched_telephone_network\">public switched telephone network</a> (PSTN) to allow for transparent phone communications worldwide<sup id=\"cite_ref-0\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Voip#cite_note-0\"><span>[</span>1<span>]</span></a></sup>.\r\n\r\nVoIP can be a benefit for reducing communication and infrastructure costs by routing phone calls over existing data networks and avoiding duplicate network systems.\r\n\r\nVoice-over-IP systems carry telephony speech as <a title=\"Digital audio\" href=\"http://en.wikipedia.org/wiki/Digital_audio\">digital audio</a>, typically reduced in data rate using <a class=\"mw-redirect\" title=\"Speech data compression\" href=\"http://en.wikipedia.org/wiki/Speech_data_compression\">speech data compression</a> techniques, packetized in small units of typically tens of milliseconds of speech, and <a title=\"Data encapsulation\" href=\"http://en.wikipedia.org/wiki/Data_encapsulation\">encapsulated</a> in a packet stream over IP.','What is VoIP?',0,'','inherit','closed','open','','6-revision-4','','','2009-01-13 21:00:13','2009-01-13 11:00:13','',6,'http://moztronics.com.au/?p=106',0,'revision','',0),(107,1,'2009-01-13 23:10:22','2009-01-13 13:10:22','<!--more--><a href=\"http://moztronics.com.au/wp-content/uploads/2009/01/voip_phone.jpg\"><img class=\"size-medium wp-image-100 alignright\" style=\"border: 0pt none;\" title=\"VOIP Handset\" src=\"http://moztronics.com.au/wp-content/uploads/2009/01/voip_phone-300x300.jpg\" alt=\"\" width=\"300\" height=\"300\" /></a><strong>Voice over Internet Protocol</strong> is a general term for a family of transmission technologies for delivery of voice communications over the <a title=\"Internet\" href=\"http://en.wikipedia.org/wiki/Internet\">Internet</a> or other <a class=\"mw-redirect\" title=\"Packet-switched\" href=\"http://en.wikipedia.org/wiki/Packet-switched\">packet-switched</a> <a title=\"Computer network\" href=\"http://en.wikipedia.org/wiki/Computer_network\">networks</a>. Other terms frequently encountered and synonymous with VoIP are <em>IP telephony</em> and <em>Internet telephony</em>, as well as <em>voice over broadband</em>, <em><a title=\"Broadband\" href=\"http://en.wikipedia.org/wiki/Broadband\">broadband</a> telephony</em>, and <em>broadband phone</em>, when the network connectivity is available over broadband Internet access.\n\nVoIP systems usually interface with the traditional <a title=\"Public switched telephone network\" href=\"http://en.wikipedia.org/wiki/Public_switched_telephone_network\">public switched telephone network</a> (PSTN) to allow for transparent phone communications worldwide<sup id=\"cite_ref-0\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Voip#cite_note-0\"><span>[</span>1<span>]</span></a></sup>.\n\nVoIP can be a benefit for reducing communication and infrastructure costs by routing phone calls over existing data networks and avoiding duplicate network systems.\n\nVoice-over-IP systems carry telephony speech as <a title=\"Digital audio\" href=\"http://en.wikipedia.org/wiki/Digital_audio\">digital audio</a>, typically reduced in data rate using <a class=\"mw-redirect\" title=\"Speech data compression\" href=\"http://en.wikipedia.org/wiki/Speech_data_compression\">speech data compression</a> techniques, packetized in small units of typically tens of milliseconds of speech, and <a title=\"Data encapsulation\" href=\"http://en.wikipedia.org/wiki/Data_encapsulation\">encapsulated</a> in a packet stream over IP.','What is VoIP?',0,'','inherit','closed','open','','6-autosave','','','2009-01-13 23:10:22','2009-01-13 13:10:22','',6,'http://moztronics.com.au/?p=107',0,'revision','',0),(108,1,'2009-01-13 23:09:19','2009-01-13 13:09:19','<!--more--><a href=\"http://moztronics.com.au/wp-content/uploads/2009/01/voip_phone.jpg\"><img class=\"alignright size-medium wp-image-100\" title=\"VOIP Handset\" src=\"http://moztronics.com.au/wp-content/uploads/2009/01/voip_phone-300x300.jpg\" alt=\"\" width=\"300\" height=\"300\" /></a><strong>Voice over Internet Protocol</strong> is a general term for a family of transmission technologies for delivery of voice communications over the <a title=\"Internet\" href=\"http://en.wikipedia.org/wiki/Internet\">Internet</a> or other <a class=\"mw-redirect\" title=\"Packet-switched\" href=\"http://en.wikipedia.org/wiki/Packet-switched\">packet-switched</a> <a title=\"Computer network\" href=\"http://en.wikipedia.org/wiki/Computer_network\">networks</a>. Other terms frequently encountered and synonymous with VoIP are <em>IP telephony</em> and <em>Internet telephony</em>, as well as <em>voice over broadband</em>, <em><a title=\"Broadband\" href=\"http://en.wikipedia.org/wiki/Broadband\">broadband</a> telephony</em>, and <em>broadband phone</em>, when the network connectivity is available over broadband Internet access.\r\n\r\nVoIP systems usually interface with the traditional <a title=\"Public switched telephone network\" href=\"http://en.wikipedia.org/wiki/Public_switched_telephone_network\">public switched telephone network</a> (PSTN) to allow for transparent phone communications worldwide<sup id=\"cite_ref-0\" class=\"reference\"><a href=\"http://en.wikipedia.org/wiki/Voip#cite_note-0\"><span>[</span>1<span>]</span></a></sup>.\r\n\r\nVoIP can be a benefit for reducing communication and infrastructure costs by routing phone calls over existing data networks and avoiding duplicate network systems.\r\n\r\nVoice-over-IP systems carry telephony speech as <a title=\"Digital audio\" href=\"http://en.wikipedia.org/wiki/Digital_audio\">digital audio</a>, typically reduced in data rate using <a class=\"mw-redirect\" title=\"Speech data compression\" href=\"http://en.wikipedia.org/wiki/Speech_data_compression\">speech data compression</a> techniques, packetized in small units of typically tens of milliseconds of speech, and <a title=\"Data encapsulation\" href=\"http://en.wikipedia.org/wiki/Data_encapsulation\">encapsulated</a> in a packet stream over IP.','What is VoIP?',0,'','inherit','closed','open','','6-revision-5','','','2009-01-13 23:09:19','2009-01-13 13:09:19','',6,'http://moztronics.com.au/?p=108',0,'revision','',0),(109,1,'2009-01-01 07:00:23','2008-12-31 21:00:23','MOZTRONICS\r\nMr. Moz Manolakis\r\n\r\nTurrella, NSW 2205\r\n\r\n0419 243 255\r\n02 9592 6600\r\n\r\nmoz [at] moztronics . com . au','Contact',0,'','publish','closed','open','','contact','','','2009-01-17 20:01:06','2009-01-17 10:01:06','',0,'http://moztronics.com.au/?page_id=109',0,'page','',0),(110,1,'2009-01-17 20:00:28','2009-01-17 10:00:28','MOZTRONICS\nMr. Moz Manolakis\n\nTurrella, NSW 2205\n\n0419 243 255\n02 9592 6600\n\nmoz [at] moztronics dot com','Contact',0,'','inherit','closed','open','','109-revision','','','2009-01-17 20:00:28','2009-01-17 10:00:28','',109,'http://moztronics.com.au/?p=110',0,'revision','',0);
/*!40000 ALTER TABLE `wp_posts` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `wp_term_relationships`
--

DROP TABLE IF EXISTS `wp_term_relationships`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `wp_term_relationships` (
  `object_id` bigint(20) NOT NULL default '0',
  `term_taxonomy_id` bigint(20) NOT NULL default '0',
  `term_order` int(11) NOT NULL default '0',
  PRIMARY KEY  (`object_id`,`term_taxonomy_id`),
  KEY `term_taxonomy_id` (`term_taxonomy_id`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `wp_term_relationships`
--

LOCK TABLES `wp_term_relationships` WRITE;
/*!40000 ALTER TABLE `wp_term_relationships` DISABLE KEYS */;
INSERT INTO `wp_term_relationships` VALUES (16,1,0),(4,3,0),(5,1,0),(7,1,0),(6,7,0),(8,10,0),(9,1,0),(11,1,0),(82,1,0),(12,4,0),(13,1,0),(14,1,0),(1,12,0),(15,1,0),(1,13,0),(1,14,0),(18,1,0),(17,8,0),(20,1,0),(19,24,0),(22,1,0),(21,19,0),(24,1,0),(23,23,0),(26,1,0),(25,22,0),(28,1,0),(27,20,0),(30,1,0),(29,21,0),(32,1,0),(31,15,0),(33,25,0),(34,1,0),(35,1,0),(36,1,0),(37,1,0),(39,1,0),(38,6,0),(41,1,0),(40,27,0),(42,1,0),(43,1,0),(45,1,0),(49,1,0),(46,9,0),(47,1,0),(48,1,0),(44,11,0),(50,1,0),(51,18,0),(52,1,0),(53,26,0),(54,1,0),(55,29,0),(55,16,0),(56,1,0),(57,1,0),(58,1,0),(59,1,0),(60,1,0),(2,1,0),(61,1,0),(62,1,0),(63,1,0),(64,1,0),(65,1,0),(66,1,0),(67,1,0),(68,1,0),(69,1,0),(70,1,0),(71,1,0),(72,1,0),(73,1,0),(74,1,0),(75,1,0),(76,1,0),(77,1,0),(78,1,0),(79,1,0),(80,1,0),(81,1,0),(10,17,0),(83,1,0),(84,1,0),(85,1,0),(86,1,0),(87,1,0),(88,1,0),(89,1,0),(90,1,0),(91,1,0),(92,1,0),(93,1,0),(94,1,0),(95,1,0),(96,1,0),(97,1,0),(98,1,0),(99,1,0),(100,1,0),(101,1,0),(102,1,0),(103,1,0),(104,1,0),(105,1,0),(106,1,0),(107,1,0),(108,1,0),(109,1,0),(110,1,0);
/*!40000 ALTER TABLE `wp_term_relationships` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `wp_term_taxonomy`
--

DROP TABLE IF EXISTS `wp_term_taxonomy`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `wp_term_taxonomy` (
  `term_taxonomy_id` bigint(20) NOT NULL auto_increment,
  `term_id` bigint(20) NOT NULL default '0',
  `taxonomy` varchar(32) NOT NULL default '',
  `description` longtext NOT NULL,
  `parent` bigint(20) NOT NULL default '0',
  `count` bigint(20) NOT NULL default '0',
  PRIMARY KEY  (`term_taxonomy_id`),
  UNIQUE KEY `term_id_taxonomy` (`term_id`,`taxonomy`)
) ENGINE=MyISAM AUTO_INCREMENT=31 DEFAULT CHARSET=latin1;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `wp_term_taxonomy`
--

LOCK TABLES `wp_term_taxonomy` WRITE;
/*!40000 ALTER TABLE `wp_term_taxonomy` DISABLE KEYS */;
INSERT INTO `wp_term_taxonomy` VALUES (1,1,'category','',0,0),(2,2,'link_category','',0,0),(3,3,'category','Our custom built media center',12,1),(4,4,'category','Security, alarms, intruder detection',0,1),(5,5,'category','Computers, Computers systems, networking, set-up &amp; installation &amp; troubleshooting.\r\nweb design',14,0),(6,6,'category','Telephony',12,1),(7,7,'category','Voice over IP (Telephone over the internet)',12,1),(8,8,'category','Electrical related services',12,1),(9,9,'category','Ducted vacuum installation',12,1),(10,10,'category','C-Bus Services',12,1),(11,11,'category','Smart wiring for your home or business',12,1),(12,12,'category','Home &amp; Office ',0,1),(13,13,'category','Fire Solutions',0,1),(14,14,'category','Computer Support',0,1),(15,15,'category','Smoke Alarm solutions',13,1),(22,22,'category','Closed Circuit TV and custom built DVR\'s',4,1),(16,16,'category','Moztronics is featuring these items',0,1),(17,17,'category','Computer Networking',14,1),(18,18,'category','Support for PC or Mac related issues.  Need assistance?  Just ask!',14,1),(19,19,'category','Anti Virus solutions for your PC',14,1),(20,20,'category','Fire Extinguishers',13,1),(21,21,'category','Fire Safety',13,1),(23,23,'category','Uniterrupted Power Supply - a must have for anyone with a computer!  We supply them.',14,1),(24,24,'category','Surveillance',4,1),(25,25,'category','Back to Base Monitoring',4,1),(26,26,'category','Anti-Stalking Systems',4,1),(27,27,'category','Web site maintenance, design and presence solutions',14,1),(28,28,'category','Computer Upgrades and customization',14,0),(29,29,'category','About Moztronics &amp; Contact Info',0,1),(30,30,'category','Contact Moztronics',29,0);
/*!40000 ALTER TABLE `wp_term_taxonomy` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `wp_terms`
--

DROP TABLE IF EXISTS `wp_terms`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `wp_terms` (
  `term_id` bigint(20) NOT NULL auto_increment,
  `name` varchar(200) NOT NULL default '',
  `slug` varchar(200) NOT NULL default '',
  `term_group` bigint(10) NOT NULL default '0',
  PRIMARY KEY  (`term_id`),
  UNIQUE KEY `slug` (`slug`),
  KEY `name` (`name`)
) ENGINE=MyISAM AUTO_INCREMENT=31 DEFAULT CHARSET=latin1;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `wp_terms`
--

LOCK TABLES `wp_terms` WRITE;
/*!40000 ALTER TABLE `wp_terms` DISABLE KEYS */;
INSERT INTO `wp_terms` VALUES (1,'Uncategorized','uncategorized',0),(2,'Blogroll','blogroll',0),(3,'Media Center','m_center',0),(4,'Security','security',0),(5,'Computers','computer',0),(6,'Telephony','teleph',0),(7,'VoIP','voip',0),(8,'Electrical','electrical',0),(9,'Vacuum','vacuum',0),(10,'C-Bus','cbus',0),(11,'Smart Wiring','smart',0),(12,'Home &amp; Office','home_office',0),(13,'Fire Solutions','fire',0),(14,'I.T.','it',0),(15,'Smoke Alarms','alarm',0),(16,'Featured','featuring',0),(17,'Networking','network',0),(18,'PC &amp; Mac Support','support',0),(19,'Anti-Virus','anti_virus',0),(20,'Extinguishers','extinguish',0),(21,'Safety','safety',0),(22,'CCTV','cctv',0),(23,'UPS','ups',0),(24,'Surveillance','surveillance',0),(25,'Back to Base','monitoring',0),(26,'Anti-Stalk','anti_stalk',0),(27,'Web Site','web',0),(28,'Upgrades','customize',0),(29,'About Us','about_us',0),(30,'Contact','contact',0);
/*!40000 ALTER TABLE `wp_terms` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `wp_usermeta`
--

DROP TABLE IF EXISTS `wp_usermeta`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `wp_usermeta` (
  `umeta_id` bigint(20) NOT NULL auto_increment,
  `user_id` bigint(20) NOT NULL default '0',
  `meta_key` varchar(255) default NULL,
  `meta_value` longtext,
  PRIMARY KEY  (`umeta_id`),
  KEY `user_id` (`user_id`),
  KEY `meta_key` (`meta_key`)
) ENGINE=MyISAM AUTO_INCREMENT=9 DEFAULT CHARSET=latin1;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `wp_usermeta`
--

LOCK TABLES `wp_usermeta` WRITE;
/*!40000 ALTER TABLE `wp_usermeta` DISABLE KEYS */;
INSERT INTO `wp_usermeta` VALUES (1,1,'nickname','admin'),(2,1,'rich_editing','true'),(3,1,'admin_color','fresh'),(4,1,'wp_capabilities','a:1:{s:13:\"administrator\";b:1;}'),(5,1,'wp_user_level','10'),(6,1,'wp_autosave_draft_ids','a:23:{i:-1231765028;i:3;i:-1231812787;i:4;i:-1231812895;i:6;i:-1231812975;i:8;i:-1231813123;i:10;i:-1231813208;i:12;i:-1231815718;i:17;i:-1231823250;i:19;i:-1231823303;i:21;i:-1231823421;i:23;i:-1231823502;i:25;i:-1231823704;i:27;i:-1231823829;i:29;i:-1231823898;i:31;i:-1231823960;i:33;i:-1231826396;i:38;i:-1231829966;i:40;i:-1231830353;i:44;i:-1231830470;i:46;i:-1231834173;i:51;i:-1231834302;i:53;i:-1231839368;i:55;i:-1232186363;i:109;}'),(7,1,'closedpostboxes_post','a:1:{i:0;s:7:\"slugdiv\";}'),(8,1,'closedpostboxes_page','a:3:{i:0;s:13:\"pagecustomdiv\";i:1;s:15:\"pagepassworddiv\";i:2;s:11:\"pageslugdiv\";}');
/*!40000 ALTER TABLE `wp_usermeta` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `wp_users`
--

DROP TABLE IF EXISTS `wp_users`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `wp_users` (
  `ID` bigint(20) unsigned NOT NULL auto_increment,
  `user_login` varchar(60) NOT NULL default '',
  `user_pass` varchar(64) NOT NULL default '',
  `user_nicename` varchar(50) NOT NULL default '',
  `user_email` varchar(100) NOT NULL default '',
  `user_url` varchar(100) NOT NULL default '',
  `user_registered` datetime NOT NULL default '0000-00-00 00:00:00',
  `user_activation_key` varchar(60) NOT NULL default '',
  `user_status` int(11) NOT NULL default '0',
  `display_name` varchar(250) NOT NULL default '',
  PRIMARY KEY  (`ID`),
  KEY `user_login_key` (`user_login`),
  KEY `user_nicename` (`user_nicename`)
) ENGINE=MyISAM AUTO_INCREMENT=2 DEFAULT CHARSET=latin1;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `wp_users`
--

LOCK TABLES `wp_users` WRITE;
/*!40000 ALTER TABLE `wp_users` DISABLE KEYS */;
INSERT INTO `wp_users` VALUES (1,'moztronics','$P$Bvufk63d0eyenwqjMJzG.M3fekpS1u.','moztronics','moz@moztronics.com.au','','2009-01-11 10:57:57','',0,'moztronics');
/*!40000 ALTER TABLE `wp_users` ENABLE KEYS */;
UNLOCK TABLES;
/*!40103 SET TIME_ZONE=@OLD_TIME_ZONE */;

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
/*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;

-- Dump completed on 2009-03-20  9:28:10
